var I1 = Object.defineProperty;
var il = (n) => {
  throw TypeError(n);
};
var L1 = (n, e, t) => e in n ? I1(n, e, { enumerable: !0, configurable: !0, writable: !0, value: t }) : n[e] = t;
var pe = (n, e, t) => L1(n, typeof e != "symbol" ? e + "" : e, t), $n = (n, e, t) => e.has(n) || il("Cannot " + t);
var Y0 = (n, e, t) => ($n(n, e, "read from private field"), t ? t.call(n) : e.get(n)), ea = (n, e, t) => e.has(n) ? il("Cannot add the same private member more than once") : e instanceof WeakSet ? e.add(n) : e.set(n, t), ll = (n, e, t, r) => ($n(n, e, "write to private field"), r ? r.call(n, t) : e.set(n, t), t), Hr = (n, e, t) => ($n(n, e, "access private method"), t);
const {
  SvelteComponent: O1,
  assign: q1,
  children: P1,
  claim_element: H1,
  create_slot: U1,
  detach: sl,
  element: G1,
  get_all_dirty_from_scope: V1,
  get_slot_changes: W1,
  get_spread_update: X1,
  init: Y1,
  insert_hydration: j1,
  safe_not_equal: Z1,
  set_dynamic_element_data: ol,
  set_style: Ie,
  toggle_class: je,
  transition_in: Eo,
  transition_out: Fo,
  update_slot_base: K1
} = window.__gradio__svelte__internal;
function Q1(n) {
  let e, t, r;
  const a = (
    /*#slots*/
    n[22].default
  ), i = U1(
    a,
    n,
    /*$$scope*/
    n[21],
    null
  );
  let l = [
    { "data-testid": (
      /*test_id*/
      n[10]
    ) },
    { id: (
      /*elem_id*/
      n[5]
    ) },
    {
      class: t = "block " + /*elem_classes*/
      n[6].join(" ") + " svelte-dbzldu"
    }
  ], s = {};
  for (let o = 0; o < l.length; o += 1)
    s = q1(s, l[o]);
  return {
    c() {
      e = G1(
        /*tag*/
        n[18]
      ), i && i.c(), this.h();
    },
    l(o) {
      e = H1(
        o,
        /*tag*/
        (n[18] || "null").toUpperCase(),
        {
          "data-testid": !0,
          id: !0,
          class: !0
        }
      );
      var c = P1(e);
      i && i.l(c), c.forEach(sl), this.h();
    },
    h() {
      ol(
        /*tag*/
        n[18]
      )(e, s), je(
        e,
        "hidden",
        /*visible*/
        n[13] === !1
      ), je(
        e,
        "padded",
        /*padding*/
        n[9]
      ), je(
        e,
        "flex",
        /*flex*/
        n[0]
      ), je(
        e,
        "border_focus",
        /*border_mode*/
        n[8] === "focus"
      ), je(
        e,
        "border_contrast",
        /*border_mode*/
        n[8] === "contrast"
      ), je(e, "hide-container", !/*explicit_call*/
      n[11] && !/*container*/
      n[12]), je(
        e,
        "auto-margin",
        /*scale*/
        n[16] === null
      ), Ie(
        e,
        "height",
        /*get_dimension*/
        n[19](
          /*height*/
          n[1]
        )
      ), Ie(
        e,
        "min-height",
        /*get_dimension*/
        n[19](
          /*min_height*/
          n[2]
        )
      ), Ie(
        e,
        "max-height",
        /*get_dimension*/
        n[19](
          /*max_height*/
          n[3]
        )
      ), Ie(e, "width", typeof /*width*/
      n[4] == "number" ? `calc(min(${/*width*/
      n[4]}px, 100%))` : (
        /*get_dimension*/
        n[19](
          /*width*/
          n[4]
        )
      )), Ie(
        e,
        "border-style",
        /*variant*/
        n[7]
      ), Ie(
        e,
        "overflow",
        /*allow_overflow*/
        n[14] ? (
          /*overflow_behavior*/
          n[15]
        ) : "hidden"
      ), Ie(
        e,
        "flex-grow",
        /*scale*/
        n[16]
      ), Ie(e, "min-width", `calc(min(${/*min_width*/
      n[17]}px, 100%))`), Ie(e, "border-width", "var(--block-border-width)");
    },
    m(o, c) {
      j1(o, e, c), i && i.m(e, null), r = !0;
    },
    p(o, c) {
      i && i.p && (!r || c & /*$$scope*/
      2097152) && K1(
        i,
        a,
        o,
        /*$$scope*/
        o[21],
        r ? W1(
          a,
          /*$$scope*/
          o[21],
          c,
          null
        ) : V1(
          /*$$scope*/
          o[21]
        ),
        null
      ), ol(
        /*tag*/
        o[18]
      )(e, s = X1(l, [
        (!r || c & /*test_id*/
        1024) && { "data-testid": (
          /*test_id*/
          o[10]
        ) },
        (!r || c & /*elem_id*/
        32) && { id: (
          /*elem_id*/
          o[5]
        ) },
        (!r || c & /*elem_classes*/
        64 && t !== (t = "block " + /*elem_classes*/
        o[6].join(" ") + " svelte-dbzldu")) && { class: t }
      ])), je(
        e,
        "hidden",
        /*visible*/
        o[13] === !1
      ), je(
        e,
        "padded",
        /*padding*/
        o[9]
      ), je(
        e,
        "flex",
        /*flex*/
        o[0]
      ), je(
        e,
        "border_focus",
        /*border_mode*/
        o[8] === "focus"
      ), je(
        e,
        "border_contrast",
        /*border_mode*/
        o[8] === "contrast"
      ), je(e, "hide-container", !/*explicit_call*/
      o[11] && !/*container*/
      o[12]), je(
        e,
        "auto-margin",
        /*scale*/
        o[16] === null
      ), c & /*height*/
      2 && Ie(
        e,
        "height",
        /*get_dimension*/
        o[19](
          /*height*/
          o[1]
        )
      ), c & /*min_height*/
      4 && Ie(
        e,
        "min-height",
        /*get_dimension*/
        o[19](
          /*min_height*/
          o[2]
        )
      ), c & /*max_height*/
      8 && Ie(
        e,
        "max-height",
        /*get_dimension*/
        o[19](
          /*max_height*/
          o[3]
        )
      ), c & /*width*/
      16 && Ie(e, "width", typeof /*width*/
      o[4] == "number" ? `calc(min(${/*width*/
      o[4]}px, 100%))` : (
        /*get_dimension*/
        o[19](
          /*width*/
          o[4]
        )
      )), c & /*variant*/
      128 && Ie(
        e,
        "border-style",
        /*variant*/
        o[7]
      ), c & /*allow_overflow, overflow_behavior*/
      49152 && Ie(
        e,
        "overflow",
        /*allow_overflow*/
        o[14] ? (
          /*overflow_behavior*/
          o[15]
        ) : "hidden"
      ), c & /*scale*/
      65536 && Ie(
        e,
        "flex-grow",
        /*scale*/
        o[16]
      ), c & /*min_width*/
      131072 && Ie(e, "min-width", `calc(min(${/*min_width*/
      o[17]}px, 100%))`);
    },
    i(o) {
      r || (Eo(i, o), r = !0);
    },
    o(o) {
      Fo(i, o), r = !1;
    },
    d(o) {
      o && sl(e), i && i.d(o);
    }
  };
}
function J1(n) {
  let e, t = (
    /*tag*/
    n[18] && Q1(n)
  );
  return {
    c() {
      t && t.c();
    },
    l(r) {
      t && t.l(r);
    },
    m(r, a) {
      t && t.m(r, a), e = !0;
    },
    p(r, [a]) {
      /*tag*/
      r[18] && t.p(r, a);
    },
    i(r) {
      e || (Eo(t, r), e = !0);
    },
    o(r) {
      Fo(t, r), e = !1;
    },
    d(r) {
      t && t.d(r);
    }
  };
}
function $1(n, e, t) {
  let { $$slots: r = {}, $$scope: a } = e, { height: i = void 0 } = e, { min_height: l = void 0 } = e, { max_height: s = void 0 } = e, { width: o = void 0 } = e, { elem_id: c = "" } = e, { elem_classes: f = [] } = e, { variant: d = "solid" } = e, { border_mode: g = "base" } = e, { padding: v = !0 } = e, { type: y = "normal" } = e, { test_id: k = void 0 } = e, { explicit_call: E = !1 } = e, { container: A = !0 } = e, { visible: D = !0 } = e, { allow_overflow: b = !0 } = e, { overflow_behavior: F = "auto" } = e, { scale: T = null } = e, { min_width: M = 0 } = e, { flex: z = !1 } = e;
  D || (z = !1);
  let O = y === "fieldset" ? "fieldset" : "div";
  const R = (B) => {
    if (B !== void 0) {
      if (typeof B == "number")
        return B + "px";
      if (typeof B == "string")
        return B;
    }
  };
  return n.$$set = (B) => {
    "height" in B && t(1, i = B.height), "min_height" in B && t(2, l = B.min_height), "max_height" in B && t(3, s = B.max_height), "width" in B && t(4, o = B.width), "elem_id" in B && t(5, c = B.elem_id), "elem_classes" in B && t(6, f = B.elem_classes), "variant" in B && t(7, d = B.variant), "border_mode" in B && t(8, g = B.border_mode), "padding" in B && t(9, v = B.padding), "type" in B && t(20, y = B.type), "test_id" in B && t(10, k = B.test_id), "explicit_call" in B && t(11, E = B.explicit_call), "container" in B && t(12, A = B.container), "visible" in B && t(13, D = B.visible), "allow_overflow" in B && t(14, b = B.allow_overflow), "overflow_behavior" in B && t(15, F = B.overflow_behavior), "scale" in B && t(16, T = B.scale), "min_width" in B && t(17, M = B.min_width), "flex" in B && t(0, z = B.flex), "$$scope" in B && t(21, a = B.$$scope);
  }, [
    z,
    i,
    l,
    s,
    o,
    c,
    f,
    d,
    g,
    v,
    k,
    E,
    A,
    D,
    b,
    F,
    T,
    M,
    O,
    R,
    y,
    a,
    r
  ];
}
class ec extends O1 {
  constructor(e) {
    super(), Y1(this, e, $1, J1, Z1, {
      height: 1,
      min_height: 2,
      max_height: 3,
      width: 4,
      elem_id: 5,
      elem_classes: 6,
      variant: 7,
      border_mode: 8,
      padding: 9,
      type: 20,
      test_id: 10,
      explicit_call: 11,
      container: 12,
      visible: 13,
      allow_overflow: 14,
      overflow_behavior: 15,
      scale: 16,
      min_width: 17,
      flex: 0
    });
  }
}
class nt {
  // The + prefix indicates that these fields aren't writeable
  // Lexer holding the input string.
  // Start offset, zero-based inclusive.
  // End offset, zero-based exclusive.
  constructor(e, t, r) {
    this.lexer = void 0, this.start = void 0, this.end = void 0, this.lexer = e, this.start = t, this.end = r;
  }
  /**
   * Merges two `SourceLocation`s from location providers, given they are
   * provided in order of appearance.
   * - Returns the first one's location if only the first is provided.
   * - Returns a merged range of the first and the last if both are provided
   *   and their lexers match.
   * - Otherwise, returns null.
   */
  static range(e, t) {
    return t ? !e || !e.loc || !t.loc || e.loc.lexer !== t.loc.lexer ? null : new nt(e.loc.lexer, e.loc.start, t.loc.end) : e && e.loc;
  }
}
class mt {
  // don't expand the token
  // used in \noexpand
  constructor(e, t) {
    this.text = void 0, this.loc = void 0, this.noexpand = void 0, this.treatAsRelax = void 0, this.text = e, this.loc = t;
  }
  /**
   * Given a pair of tokens (this and endToken), compute a `Token` encompassing
   * the whole input range enclosed by these two.
   */
  range(e, t) {
    return new mt(t, nt.range(this, e));
  }
}
class L {
  // Error start position based on passed-in Token or ParseNode.
  // Length of affected text based on passed-in Token or ParseNode.
  // The underlying error message without any context added.
  constructor(e, t) {
    this.name = void 0, this.position = void 0, this.length = void 0, this.rawMessage = void 0;
    var r = "KaTeX parse error: " + e, a, i, l = t && t.loc;
    if (l && l.start <= l.end) {
      var s = l.lexer.input;
      a = l.start, i = l.end, a === s.length ? r += " at end of input: " : r += " at position " + (a + 1) + ": ";
      var o = s.slice(a, i).replace(/[^]/g, "$&̲"), c;
      a > 15 ? c = "…" + s.slice(a - 15, a) : c = s.slice(0, a);
      var f;
      i + 15 < s.length ? f = s.slice(i, i + 15) + "…" : f = s.slice(i), r += c + o + f;
    }
    var d = new Error(r);
    return d.name = "ParseError", d.__proto__ = L.prototype, d.position = a, a != null && i != null && (d.length = i - a), d.rawMessage = e, d;
  }
}
L.prototype.__proto__ = Error.prototype;
var tc = function(e, t) {
  return e.indexOf(t) !== -1;
}, rc = function(e, t) {
  return e === void 0 ? t : e;
}, nc = /([A-Z])/g, ac = function(e) {
  return e.replace(nc, "-$1").toLowerCase();
}, ic = {
  "&": "&amp;",
  ">": "&gt;",
  "<": "&lt;",
  '"': "&quot;",
  "'": "&#x27;"
}, lc = /[&><"']/g;
function sc(n) {
  return String(n).replace(lc, (e) => ic[e]);
}
var To = function n(e) {
  return e.type === "ordgroup" || e.type === "color" ? e.body.length === 1 ? n(e.body[0]) : e : e.type === "font" ? n(e.body) : e;
}, oc = function(e) {
  var t = To(e);
  return t.type === "mathord" || t.type === "textord" || t.type === "atom";
}, uc = function(e) {
  if (!e)
    throw new Error("Expected non-null, but got " + String(e));
  return e;
}, cc = function(e) {
  var t = /^[\x00-\x20]*([^\\/#?]*?)(:|&#0*58|&#x0*3a|&colon)/i.exec(e);
  return t ? t[2] !== ":" || !/^[a-zA-Z][a-zA-Z0-9+\-.]*$/.test(t[1]) ? null : t[1].toLowerCase() : "_relative";
}, j = {
  contains: tc,
  deflt: rc,
  escape: sc,
  hyphenate: ac,
  getBaseElem: To,
  isCharacterBox: oc,
  protocolFromUrl: cc
}, dn = {
  displayMode: {
    type: "boolean",
    description: "Render math in display mode, which puts the math in display style (so \\int and \\sum are large, for example), and centers the math on the page on its own line.",
    cli: "-d, --display-mode"
  },
  output: {
    type: {
      enum: ["htmlAndMathml", "html", "mathml"]
    },
    description: "Determines the markup language of the output.",
    cli: "-F, --format <type>"
  },
  leqno: {
    type: "boolean",
    description: "Render display math in leqno style (left-justified tags)."
  },
  fleqn: {
    type: "boolean",
    description: "Render display math flush left."
  },
  throwOnError: {
    type: "boolean",
    default: !0,
    cli: "-t, --no-throw-on-error",
    cliDescription: "Render errors (in the color given by --error-color) instead of throwing a ParseError exception when encountering an error."
  },
  errorColor: {
    type: "string",
    default: "#cc0000",
    cli: "-c, --error-color <color>",
    cliDescription: "A color string given in the format 'rgb' or 'rrggbb' (no #). This option determines the color of errors rendered by the -t option.",
    cliProcessor: (n) => "#" + n
  },
  macros: {
    type: "object",
    cli: "-m, --macro <def>",
    cliDescription: "Define custom macro of the form '\\foo:expansion' (use multiple -m arguments for multiple macros).",
    cliDefault: [],
    cliProcessor: (n, e) => (e.push(n), e)
  },
  minRuleThickness: {
    type: "number",
    description: "Specifies a minimum thickness, in ems, for fraction lines, `\\sqrt` top lines, `{array}` vertical lines, `\\hline`, `\\hdashline`, `\\underline`, `\\overline`, and the borders of `\\fbox`, `\\boxed`, and `\\fcolorbox`.",
    processor: (n) => Math.max(0, n),
    cli: "--min-rule-thickness <size>",
    cliProcessor: parseFloat
  },
  colorIsTextColor: {
    type: "boolean",
    description: "Makes \\color behave like LaTeX's 2-argument \\textcolor, instead of LaTeX's one-argument \\color mode change.",
    cli: "-b, --color-is-text-color"
  },
  strict: {
    type: [{
      enum: ["warn", "ignore", "error"]
    }, "boolean", "function"],
    description: "Turn on strict / LaTeX faithfulness mode, which throws an error if the input uses features that are not supported by LaTeX.",
    cli: "-S, --strict",
    cliDefault: !1
  },
  trust: {
    type: ["boolean", "function"],
    description: "Trust the input, enabling all HTML features such as \\url.",
    cli: "-T, --trust"
  },
  maxSize: {
    type: "number",
    default: 1 / 0,
    description: "If non-zero, all user-specified sizes, e.g. in \\rule{500em}{500em}, will be capped to maxSize ems. Otherwise, elements and spaces can be arbitrarily large",
    processor: (n) => Math.max(0, n),
    cli: "-s, --max-size <n>",
    cliProcessor: parseInt
  },
  maxExpand: {
    type: "number",
    default: 1e3,
    description: "Limit the number of macro expansions to the specified number, to prevent e.g. infinite macro loops. If set to Infinity, the macro expander will try to fully expand as in LaTeX.",
    processor: (n) => Math.max(0, n),
    cli: "-e, --max-expand <n>",
    cliProcessor: (n) => n === "Infinity" ? 1 / 0 : parseInt(n)
  },
  globalGroup: {
    type: "boolean",
    cli: !1
  }
};
function hc(n) {
  if (n.default)
    return n.default;
  var e = n.type, t = Array.isArray(e) ? e[0] : e;
  if (typeof t != "string")
    return t.enum[0];
  switch (t) {
    case "boolean":
      return !1;
    case "string":
      return "";
    case "number":
      return 0;
    case "object":
      return {};
  }
}
class ui {
  constructor(e) {
    this.displayMode = void 0, this.output = void 0, this.leqno = void 0, this.fleqn = void 0, this.throwOnError = void 0, this.errorColor = void 0, this.macros = void 0, this.minRuleThickness = void 0, this.colorIsTextColor = void 0, this.strict = void 0, this.trust = void 0, this.maxSize = void 0, this.maxExpand = void 0, this.globalGroup = void 0, e = e || {};
    for (var t in dn)
      if (dn.hasOwnProperty(t)) {
        var r = dn[t];
        this[t] = e[t] !== void 0 ? r.processor ? r.processor(e[t]) : e[t] : hc(r);
      }
  }
  /**
   * Report nonstrict (non-LaTeX-compatible) input.
   * Can safely not be called if `this.strict` is false in JavaScript.
   */
  reportNonstrict(e, t, r) {
    var a = this.strict;
    if (typeof a == "function" && (a = a(e, t, r)), !(!a || a === "ignore")) {
      if (a === !0 || a === "error")
        throw new L("LaTeX-incompatible input and strict mode is set to 'error': " + (t + " [" + e + "]"), r);
      a === "warn" ? typeof console < "u" && console.warn("LaTeX-incompatible input and strict mode is set to 'warn': " + (t + " [" + e + "]")) : typeof console < "u" && console.warn("LaTeX-incompatible input and strict mode is set to " + ("unrecognized '" + a + "': " + t + " [" + e + "]"));
    }
  }
  /**
   * Check whether to apply strict (LaTeX-adhering) behavior for unusual
   * input (like `\\`).  Unlike `nonstrict`, will not throw an error;
   * instead, "error" translates to a return value of `true`, while "ignore"
   * translates to a return value of `false`.  May still print a warning:
   * "warn" prints a warning and returns `false`.
   * This is for the second category of `errorCode`s listed in the README.
   */
  useStrictBehavior(e, t, r) {
    var a = this.strict;
    if (typeof a == "function")
      try {
        a = a(e, t, r);
      } catch {
        a = "error";
      }
    return !a || a === "ignore" ? !1 : a === !0 || a === "error" ? !0 : a === "warn" ? (typeof console < "u" && console.warn("LaTeX-incompatible input and strict mode is set to 'warn': " + (t + " [" + e + "]")), !1) : (typeof console < "u" && console.warn("LaTeX-incompatible input and strict mode is set to " + ("unrecognized '" + a + "': " + t + " [" + e + "]")), !1);
  }
  /**
   * Check whether to test potentially dangerous input, and return
   * `true` (trusted) or `false` (untrusted).  The sole argument `context`
   * should be an object with `command` field specifying the relevant LaTeX
   * command (as a string starting with `\`), and any other arguments, etc.
   * If `context` has a `url` field, a `protocol` field will automatically
   * get added by this function (changing the specified object).
   */
  isTrusted(e) {
    if (e.url && !e.protocol) {
      var t = j.protocolFromUrl(e.url);
      if (t == null)
        return !1;
      e.protocol = t;
    }
    var r = typeof this.trust == "function" ? this.trust(e) : this.trust;
    return !!r;
  }
}
class p0 {
  constructor(e, t, r) {
    this.id = void 0, this.size = void 0, this.cramped = void 0, this.id = e, this.size = t, this.cramped = r;
  }
  /**
   * Get the style of a superscript given a base in the current style.
   */
  sup() {
    return qt[fc[this.id]];
  }
  /**
   * Get the style of a subscript given a base in the current style.
   */
  sub() {
    return qt[mc[this.id]];
  }
  /**
   * Get the style of a fraction numerator given the fraction in the current
   * style.
   */
  fracNum() {
    return qt[dc[this.id]];
  }
  /**
   * Get the style of a fraction denominator given the fraction in the current
   * style.
   */
  fracDen() {
    return qt[pc[this.id]];
  }
  /**
   * Get the cramped version of a style (in particular, cramping a cramped style
   * doesn't change the style).
   */
  cramp() {
    return qt[gc[this.id]];
  }
  /**
   * Get a text or display version of this style.
   */
  text() {
    return qt[vc[this.id]];
  }
  /**
   * Return true if this style is tightly spaced (scriptstyle/scriptscriptstyle)
   */
  isTight() {
    return this.size >= 2;
  }
}
var ci = 0, Dn = 1, $0 = 2, u0 = 3, Sr = 4, ct = 5, tr = 6, Ve = 7, qt = [new p0(ci, 0, !1), new p0(Dn, 0, !0), new p0($0, 1, !1), new p0(u0, 1, !0), new p0(Sr, 2, !1), new p0(ct, 2, !0), new p0(tr, 3, !1), new p0(Ve, 3, !0)], fc = [Sr, ct, Sr, ct, tr, Ve, tr, Ve], mc = [ct, ct, ct, ct, Ve, Ve, Ve, Ve], dc = [$0, u0, Sr, ct, tr, Ve, tr, Ve], pc = [u0, u0, ct, ct, Ve, Ve, Ve, Ve], gc = [Dn, Dn, u0, u0, ct, ct, Ve, Ve], vc = [ci, Dn, $0, u0, $0, u0, $0, u0], Q = {
  DISPLAY: qt[ci],
  TEXT: qt[$0],
  SCRIPT: qt[Sr],
  SCRIPTSCRIPT: qt[tr]
}, qa = [{
  // Latin characters beyond the Latin-1 characters we have metrics for.
  // Needed for Czech, Hungarian and Turkish text, for example.
  name: "latin",
  blocks: [
    [256, 591],
    // Latin Extended-A and Latin Extended-B
    [768, 879]
    // Combining Diacritical marks
  ]
}, {
  // The Cyrillic script used by Russian and related languages.
  // A Cyrillic subset used to be supported as explicitly defined
  // symbols in symbols.js
  name: "cyrillic",
  blocks: [[1024, 1279]]
}, {
  // Armenian
  name: "armenian",
  blocks: [[1328, 1423]]
}, {
  // The Brahmic scripts of South and Southeast Asia
  // Devanagari (0900–097F)
  // Bengali (0980–09FF)
  // Gurmukhi (0A00–0A7F)
  // Gujarati (0A80–0AFF)
  // Oriya (0B00–0B7F)
  // Tamil (0B80–0BFF)
  // Telugu (0C00–0C7F)
  // Kannada (0C80–0CFF)
  // Malayalam (0D00–0D7F)
  // Sinhala (0D80–0DFF)
  // Thai (0E00–0E7F)
  // Lao (0E80–0EFF)
  // Tibetan (0F00–0FFF)
  // Myanmar (1000–109F)
  name: "brahmic",
  blocks: [[2304, 4255]]
}, {
  name: "georgian",
  blocks: [[4256, 4351]]
}, {
  // Chinese and Japanese.
  // The "k" in cjk is for Korean, but we've separated Korean out
  name: "cjk",
  blocks: [
    [12288, 12543],
    // CJK symbols and punctuation, Hiragana, Katakana
    [19968, 40879],
    // CJK ideograms
    [65280, 65376]
    // Fullwidth punctuation
    // TODO: add halfwidth Katakana and Romanji glyphs
  ]
}, {
  // Korean
  name: "hangul",
  blocks: [[44032, 55215]]
}];
function bc(n) {
  for (var e = 0; e < qa.length; e++)
    for (var t = qa[e], r = 0; r < t.blocks.length; r++) {
      var a = t.blocks[r];
      if (n >= a[0] && n <= a[1])
        return t.name;
    }
  return null;
}
var pn = [];
qa.forEach((n) => n.blocks.forEach((e) => pn.push(...e)));
function Co(n) {
  for (var e = 0; e < pn.length; e += 2)
    if (n >= pn[e] && n <= pn[e + 1])
      return !0;
  return !1;
}
var j0 = 80, yc = function(e, t) {
  return "M95," + (622 + e + t) + `
c-2.7,0,-7.17,-2.7,-13.5,-8c-5.8,-5.3,-9.5,-10,-9.5,-14
c0,-2,0.3,-3.3,1,-4c1.3,-2.7,23.83,-20.7,67.5,-54
c44.2,-33.3,65.8,-50.3,66.5,-51c1.3,-1.3,3,-2,5,-2c4.7,0,8.7,3.3,12,10
s173,378,173,378c0.7,0,35.3,-71,104,-213c68.7,-142,137.5,-285,206.5,-429
c69,-144,104.5,-217.7,106.5,-221
l` + e / 2.075 + " -" + e + `
c5.3,-9.3,12,-14,20,-14
H400000v` + (40 + e) + `H845.2724
s-225.272,467,-225.272,467s-235,486,-235,486c-2.7,4.7,-9,7,-19,7
c-6,0,-10,-1,-12,-3s-194,-422,-194,-422s-65,47,-65,47z
M` + (834 + e) + " " + t + "h400000v" + (40 + e) + "h-400000z";
}, wc = function(e, t) {
  return "M263," + (601 + e + t) + `c0.7,0,18,39.7,52,119
c34,79.3,68.167,158.7,102.5,238c34.3,79.3,51.8,119.3,52.5,120
c340,-704.7,510.7,-1060.3,512,-1067
l` + e / 2.084 + " -" + e + `
c4.7,-7.3,11,-11,19,-11
H40000v` + (40 + e) + `H1012.3
s-271.3,567,-271.3,567c-38.7,80.7,-84,175,-136,283c-52,108,-89.167,185.3,-111.5,232
c-22.3,46.7,-33.8,70.3,-34.5,71c-4.7,4.7,-12.3,7,-23,7s-12,-1,-12,-1
s-109,-253,-109,-253c-72.7,-168,-109.3,-252,-110,-252c-10.7,8,-22,16.7,-34,26
c-22,17.3,-33.3,26,-34,26s-26,-26,-26,-26s76,-59,76,-59s76,-60,76,-60z
M` + (1001 + e) + " " + t + "h400000v" + (40 + e) + "h-400000z";
}, kc = function(e, t) {
  return "M983 " + (10 + e + t) + `
l` + e / 3.13 + " -" + e + `
c4,-6.7,10,-10,18,-10 H400000v` + (40 + e) + `
H1013.1s-83.4,268,-264.1,840c-180.7,572,-277,876.3,-289,913c-4.7,4.7,-12.7,7,-24,7
s-12,0,-12,0c-1.3,-3.3,-3.7,-11.7,-7,-25c-35.3,-125.3,-106.7,-373.3,-214,-744
c-10,12,-21,25,-33,39s-32,39,-32,39c-6,-5.3,-15,-14,-27,-26s25,-30,25,-30
c26.7,-32.7,52,-63,76,-91s52,-60,52,-60s208,722,208,722
c56,-175.3,126.3,-397.3,211,-666c84.7,-268.7,153.8,-488.2,207.5,-658.5
c53.7,-170.3,84.5,-266.8,92.5,-289.5z
M` + (1001 + e) + " " + t + "h400000v" + (40 + e) + "h-400000z";
}, _c = function(e, t) {
  return "M424," + (2398 + e + t) + `
c-1.3,-0.7,-38.5,-172,-111.5,-514c-73,-342,-109.8,-513.3,-110.5,-514
c0,-2,-10.7,14.3,-32,49c-4.7,7.3,-9.8,15.7,-15.5,25c-5.7,9.3,-9.8,16,-12.5,20
s-5,7,-5,7c-4,-3.3,-8.3,-7.7,-13,-13s-13,-13,-13,-13s76,-122,76,-122s77,-121,77,-121
s209,968,209,968c0,-2,84.7,-361.7,254,-1079c169.3,-717.3,254.7,-1077.7,256,-1081
l` + e / 4.223 + " -" + e + `c4,-6.7,10,-10,18,-10 H400000
v` + (40 + e) + `H1014.6
s-87.3,378.7,-272.6,1166c-185.3,787.3,-279.3,1182.3,-282,1185
c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2z M` + (1001 + e) + " " + t + `
h400000v` + (40 + e) + "h-400000z";
}, Dc = function(e, t) {
  return "M473," + (2713 + e + t) + `
c339.3,-1799.3,509.3,-2700,510,-2702 l` + e / 5.298 + " -" + e + `
c3.3,-7.3,9.3,-11,18,-11 H400000v` + (40 + e) + `H1017.7
s-90.5,478,-276.2,1466c-185.7,988,-279.5,1483,-281.5,1485c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2c0,-1.3,-5.3,-32,-16,-92c-50.7,-293.3,-119.7,-693.3,-207,-1200
c0,-1.3,-5.3,8.7,-16,30c-10.7,21.3,-21.3,42.7,-32,64s-16,33,-16,33s-26,-26,-26,-26
s76,-153,76,-153s77,-151,77,-151c0.7,0.7,35.7,202,105,604c67.3,400.7,102,602.7,104,
606zM` + (1001 + e) + " " + t + "h400000v" + (40 + e) + "H1017.7z";
}, xc = function(e) {
  var t = e / 2;
  return "M400000 " + e + " H0 L" + t + " 0 l65 45 L145 " + (e - 80) + " H400000z";
}, Ac = function(e, t, r) {
  var a = r - 54 - t - e;
  return "M702 " + (e + t) + "H400000" + (40 + e) + `
H742v` + a + `l-4 4-4 4c-.667.7 -2 1.5-4 2.5s-4.167 1.833-6.5 2.5-5.5 1-9.5 1
h-12l-28-84c-16.667-52-96.667 -294.333-240-727l-212 -643 -85 170
c-4-3.333-8.333-7.667-13 -13l-13-13l77-155 77-156c66 199.333 139 419.667
219 661 l218 661zM702 ` + t + "H400000v" + (40 + e) + "H742z";
}, Sc = function(e, t, r) {
  t = 1e3 * t;
  var a = "";
  switch (e) {
    case "sqrtMain":
      a = yc(t, j0);
      break;
    case "sqrtSize1":
      a = wc(t, j0);
      break;
    case "sqrtSize2":
      a = kc(t, j0);
      break;
    case "sqrtSize3":
      a = _c(t, j0);
      break;
    case "sqrtSize4":
      a = Dc(t, j0);
      break;
    case "sqrtTall":
      a = Ac(t, j0, r);
  }
  return a;
}, Ec = function(e, t) {
  switch (e) {
    case "⎜":
      return "M291 0 H417 V" + t + " H291z M291 0 H417 V" + t + " H291z";
    case "∣":
      return "M145 0 H188 V" + t + " H145z M145 0 H188 V" + t + " H145z";
    case "∥":
      return "M145 0 H188 V" + t + " H145z M145 0 H188 V" + t + " H145z" + ("M367 0 H410 V" + t + " H367z M367 0 H410 V" + t + " H367z");
    case "⎟":
      return "M457 0 H583 V" + t + " H457z M457 0 H583 V" + t + " H457z";
    case "⎢":
      return "M319 0 H403 V" + t + " H319z M319 0 H403 V" + t + " H319z";
    case "⎥":
      return "M263 0 H347 V" + t + " H263z M263 0 H347 V" + t + " H263z";
    case "⎪":
      return "M384 0 H504 V" + t + " H384z M384 0 H504 V" + t + " H384z";
    case "⏐":
      return "M312 0 H355 V" + t + " H312z M312 0 H355 V" + t + " H312z";
    case "‖":
      return "M257 0 H300 V" + t + " H257z M257 0 H300 V" + t + " H257z" + ("M478 0 H521 V" + t + " H478z M478 0 H521 V" + t + " H478z");
    default:
      return "";
  }
}, ul = {
  // The doubleleftarrow geometry is from glyph U+21D0 in the font KaTeX Main
  doubleleftarrow: `M262 157
l10-10c34-36 62.7-77 86-123 3.3-8 5-13.3 5-16 0-5.3-6.7-8-20-8-7.3
 0-12.2.5-14.5 1.5-2.3 1-4.8 4.5-7.5 10.5-49.3 97.3-121.7 169.3-217 216-28
 14-57.3 25-88 33-6.7 2-11 3.8-13 5.5-2 1.7-3 4.2-3 7.5s1 5.8 3 7.5
c2 1.7 6.3 3.5 13 5.5 68 17.3 128.2 47.8 180.5 91.5 52.3 43.7 93.8 96.2 124.5
 157.5 9.3 8 15.3 12.3 18 13h6c12-.7 18-4 18-10 0-2-1.7-7-5-15-23.3-46-52-87
-86-123l-10-10h399738v-40H218c328 0 0 0 0 0l-10-8c-26.7-20-65.7-43-117-69 2.7
-2 6-3.7 10-5 36.7-16 72.3-37.3 107-64l10-8h399782v-40z
m8 0v40h399730v-40zm0 194v40h399730v-40z`,
  // doublerightarrow is from glyph U+21D2 in font KaTeX Main
  doublerightarrow: `M399738 392l
-10 10c-34 36-62.7 77-86 123-3.3 8-5 13.3-5 16 0 5.3 6.7 8 20 8 7.3 0 12.2-.5
 14.5-1.5 2.3-1 4.8-4.5 7.5-10.5 49.3-97.3 121.7-169.3 217-216 28-14 57.3-25 88
-33 6.7-2 11-3.8 13-5.5 2-1.7 3-4.2 3-7.5s-1-5.8-3-7.5c-2-1.7-6.3-3.5-13-5.5-68
-17.3-128.2-47.8-180.5-91.5-52.3-43.7-93.8-96.2-124.5-157.5-9.3-8-15.3-12.3-18
-13h-6c-12 .7-18 4-18 10 0 2 1.7 7 5 15 23.3 46 52 87 86 123l10 10H0v40h399782
c-328 0 0 0 0 0l10 8c26.7 20 65.7 43 117 69-2.7 2-6 3.7-10 5-36.7 16-72.3 37.3
-107 64l-10 8H0v40zM0 157v40h399730v-40zm0 194v40h399730v-40z`,
  // leftarrow is from glyph U+2190 in font KaTeX Main
  leftarrow: `M400000 241H110l3-3c68.7-52.7 113.7-120
 135-202 4-14.7 6-23 6-25 0-7.3-7-11-21-11-8 0-13.2.8-15.5 2.5-2.3 1.7-4.2 5.8
-5.5 12.5-1.3 4.7-2.7 10.3-4 17-12 48.7-34.8 92-68.5 130S65.3 228.3 18 247
c-10 4-16 7.7-18 11 0 8.7 6 14.3 18 17 47.3 18.7 87.8 47 121.5 85S196 441.3 208
 490c.7 2 1.3 5 2 9s1.2 6.7 1.5 8c.3 1.3 1 3.3 2 6s2.2 4.5 3.5 5.5c1.3 1 3.3
 1.8 6 2.5s6 1 10 1c14 0 21-3.7 21-11 0-2-2-10.3-6-25-20-79.3-65-146.7-135-202
 l-3-3h399890zM100 241v40h399900v-40z`,
  // overbrace is from glyphs U+23A9/23A8/23A7 in font KaTeX_Size4-Regular
  leftbrace: `M6 548l-6-6v-35l6-11c56-104 135.3-181.3 238-232 57.3-28.7 117
-45 179-50h399577v120H403c-43.3 7-81 15-113 26-100.7 33-179.7 91-237 174-2.7
 5-6 9-10 13-.7 1-7.3 1-20 1H6z`,
  leftbraceunder: `M0 6l6-6h17c12.688 0 19.313.3 20 1 4 4 7.313 8.3 10 13
 35.313 51.3 80.813 93.8 136.5 127.5 55.688 33.7 117.188 55.8 184.5 66.5.688
 0 2 .3 4 1 18.688 2.7 76 4.3 172 5h399450v120H429l-6-1c-124.688-8-235-61.7
-331-161C60.687 138.7 32.312 99.3 7 54L0 41V6z`,
  // overgroup is from the MnSymbol package (public domain)
  leftgroup: `M400000 80
H435C64 80 168.3 229.4 21 260c-5.9 1.2-18 0-18 0-2 0-3-1-3-3v-38C76 61 257 0
 435 0h399565z`,
  leftgroupunder: `M400000 262
H435C64 262 168.3 112.6 21 82c-5.9-1.2-18 0-18 0-2 0-3 1-3 3v38c76 158 257 219
 435 219h399565z`,
  // Harpoons are from glyph U+21BD in font KaTeX Main
  leftharpoon: `M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3
-3.3 10.2-9.5 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5
-18.3 3-21-1.3-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7
-196 228-6.7 4.7-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40z`,
  leftharpoonplus: `M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3-3.3 10.2-9.5
 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5-18.3 3-21-1.3
-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7-196 228-6.7 4.7
-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40zM0 435v40h400000v-40z
m0 0v40h400000v-40z`,
  leftharpoondown: `M7 241c-4 4-6.333 8.667-7 14 0 5.333.667 9 2 11s5.333
 5.333 12 10c90.667 54 156 130 196 228 3.333 10.667 6.333 16.333 9 17 2 .667 5
 1 9 1h5c10.667 0 16.667-2 18-6 2-2.667 1-9.667-3-21-32-87.333-82.667-157.667
-152-211l-3-3h399907v-40zM93 281 H400000 v-40L7 241z`,
  leftharpoondownplus: `M7 435c-4 4-6.3 8.7-7 14 0 5.3.7 9 2 11s5.3 5.3 12
 10c90.7 54 156 130 196 228 3.3 10.7 6.3 16.3 9 17 2 .7 5 1 9 1h5c10.7 0 16.7
-2 18-6 2-2.7 1-9.7-3-21-32-87.3-82.7-157.7-152-211l-3-3h399907v-40H7zm93 0
v40h399900v-40zM0 241v40h399900v-40zm0 0v40h399900v-40z`,
  // hook is from glyph U+21A9 in font KaTeX Main
  lefthook: `M400000 281 H103s-33-11.2-61-33.5S0 197.3 0 164s14.2-61.2 42.5
-83.5C70.8 58.2 104 47 142 47 c16.7 0 25 6.7 25 20 0 12-8.7 18.7-26 20-40 3.3
-68.7 15.7-86 37-10 12-15 25.3-15 40 0 22.7 9.8 40.7 29.5 54 19.7 13.3 43.5 21
 71.5 23h399859zM103 281v-40h399897v40z`,
  leftlinesegment: `M40 281 V428 H0 V94 H40 V241 H400000 v40z
M40 281 V428 H0 V94 H40 V241 H400000 v40z`,
  leftmapsto: `M40 281 V448H0V74H40V241H400000v40z
M40 281 V448H0V74H40V241H400000v40z`,
  // tofrom is from glyph U+21C4 in font KaTeX AMS Regular
  leftToFrom: `M0 147h400000v40H0zm0 214c68 40 115.7 95.7 143 167h22c15.3 0 23
-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69-70-101l-7-8h399905v-40H95l7-8
c28.7-32 52-65.7 70-101 10.7-23.3 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 265.3
 68 321 0 361zm0-174v-40h399900v40zm100 154v40h399900v-40z`,
  longequal: `M0 50 h400000 v40H0z m0 194h40000v40H0z
M0 50 h400000 v40H0z m0 194h40000v40H0z`,
  midbrace: `M200428 334
c-100.7-8.3-195.3-44-280-108-55.3-42-101.7-93-139-153l-9-14c-2.7 4-5.7 8.7-9 14
-53.3 86.7-123.7 153-211 199-66.7 36-137.3 56.3-212 62H0V214h199568c178.3-11.7
 311.7-78.3 403-201 6-8 9.7-12 11-12 .7-.7 6.7-1 18-1s17.3.3 18 1c1.3 0 5 4 11
 12 44.7 59.3 101.3 106.3 170 141s145.3 54.3 229 60h199572v120z`,
  midbraceunder: `M199572 214
c100.7 8.3 195.3 44 280 108 55.3 42 101.7 93 139 153l9 14c2.7-4 5.7-8.7 9-14
 53.3-86.7 123.7-153 211-199 66.7-36 137.3-56.3 212-62h199568v120H200432c-178.3
 11.7-311.7 78.3-403 201-6 8-9.7 12-11 12-.7.7-6.7 1-18 1s-17.3-.3-18-1c-1.3 0
-5-4-11-12-44.7-59.3-101.3-106.3-170-141s-145.3-54.3-229-60H0V214z`,
  oiintSize1: `M512.6 71.6c272.6 0 320.3 106.8 320.3 178.2 0 70.8-47.7 177.6
-320.3 177.6S193.1 320.6 193.1 249.8c0-71.4 46.9-178.2 319.5-178.2z
m368.1 178.2c0-86.4-60.9-215.4-368.1-215.4-306.4 0-367.3 129-367.3 215.4 0 85.8
60.9 214.8 367.3 214.8 307.2 0 368.1-129 368.1-214.8z`,
  oiintSize2: `M757.8 100.1c384.7 0 451.1 137.6 451.1 230 0 91.3-66.4 228.8
-451.1 228.8-386.3 0-452.7-137.5-452.7-228.8 0-92.4 66.4-230 452.7-230z
m502.4 230c0-111.2-82.4-277.2-502.4-277.2s-504 166-504 277.2
c0 110 84 276 504 276s502.4-166 502.4-276z`,
  oiiintSize1: `M681.4 71.6c408.9 0 480.5 106.8 480.5 178.2 0 70.8-71.6 177.6
-480.5 177.6S202.1 320.6 202.1 249.8c0-71.4 70.5-178.2 479.3-178.2z
m525.8 178.2c0-86.4-86.8-215.4-525.7-215.4-437.9 0-524.7 129-524.7 215.4 0
85.8 86.8 214.8 524.7 214.8 438.9 0 525.7-129 525.7-214.8z`,
  oiiintSize2: `M1021.2 53c603.6 0 707.8 165.8 707.8 277.2 0 110-104.2 275.8
-707.8 275.8-606 0-710.2-165.8-710.2-275.8C311 218.8 415.2 53 1021.2 53z
m770.4 277.1c0-131.2-126.4-327.6-770.5-327.6S248.4 198.9 248.4 330.1
c0 130 128.8 326.4 772.7 326.4s770.5-196.4 770.5-326.4z`,
  rightarrow: `M0 241v40h399891c-47.3 35.3-84 78-110 128
-16.7 32-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20
 11 8 0 13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7
 39-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85
-40.5-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
 151.7 139 205zm0 0v40h399900v-40z`,
  rightbrace: `M400000 542l
-6 6h-17c-12.7 0-19.3-.3-20-1-4-4-7.3-8.3-10-13-35.3-51.3-80.8-93.8-136.5-127.5
s-117.2-55.8-184.5-66.5c-.7 0-2-.3-4-1-18.7-2.7-76-4.3-172-5H0V214h399571l6 1
c124.7 8 235 61.7 331 161 31.3 33.3 59.7 72.7 85 118l7 13v35z`,
  rightbraceunder: `M399994 0l6 6v35l-6 11c-56 104-135.3 181.3-238 232-57.3
 28.7-117 45-179 50H-300V214h399897c43.3-7 81-15 113-26 100.7-33 179.7-91 237
-174 2.7-5 6-9 10-13 .7-1 7.3-1 20-1h17z`,
  rightgroup: `M0 80h399565c371 0 266.7 149.4 414 180 5.9 1.2 18 0 18 0 2 0
 3-1 3-3v-38c-76-158-257-219-435-219H0z`,
  rightgroupunder: `M0 262h399565c371 0 266.7-149.4 414-180 5.9-1.2 18 0 18
 0 2 0 3 1 3 3v38c-76 158-257 219-435 219H0z`,
  rightharpoon: `M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3
-3.7-15.3-11-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2
-10.7 0-16.7 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58
 69.2 92 94.5zm0 0v40h399900v-40z`,
  rightharpoonplus: `M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3-3.7-15.3-11
-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2-10.7 0-16.7
 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58 69.2 92 94.5z
m0 0v40h399900v-40z m100 194v40h399900v-40zm0 0v40h399900v-40z`,
  rightharpoondown: `M399747 511c0 7.3 6.7 11 20 11 8 0 13-.8 15-2.5s4.7-6.8
 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3 8.5-5.8 9.5
-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3-64.7 57-92 95
-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 241v40h399900v-40z`,
  rightharpoondownplus: `M399747 705c0 7.3 6.7 11 20 11 8 0 13-.8
 15-2.5s4.7-6.8 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3
 8.5-5.8 9.5-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3
-64.7 57-92 95-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 435v40h399900v-40z
m0-194v40h400000v-40zm0 0v40h400000v-40z`,
  righthook: `M399859 241c-764 0 0 0 0 0 40-3.3 68.7-15.7 86-37 10-12 15-25.3
 15-40 0-22.7-9.8-40.7-29.5-54-19.7-13.3-43.5-21-71.5-23-17.3-1.3-26-8-26-20 0
-13.3 8.7-20 26-20 38 0 71 11.2 99 33.5 0 0 7 5.6 21 16.7 14 11.2 21 33.5 21
 66.8s-14 61.2-42 83.5c-28 22.3-61 33.5-99 33.5L0 241z M0 281v-40h399859v40z`,
  rightlinesegment: `M399960 241 V94 h40 V428 h-40 V281 H0 v-40z
M399960 241 V94 h40 V428 h-40 V281 H0 v-40z`,
  rightToFrom: `M400000 167c-70.7-42-118-97.7-142-167h-23c-15.3 0-23 .3-23
 1 0 1.3 5.3 13.7 16 37 18 35.3 41.3 69 70 101l7 8H0v40h399905l-7 8c-28.7 32
-52 65.7-70 101-10.7 23.3-16 35.7-16 37 0 .7 7.7 1 23 1h23c24-69.3 71.3-125 142
-167z M100 147v40h399900v-40zM0 341v40h399900v-40z`,
  // twoheadleftarrow is from glyph U+219E in font KaTeX AMS Regular
  twoheadleftarrow: `M0 167c68 40
 115.7 95.7 143 167h22c15.3 0 23-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69
-70-101l-7-8h125l9 7c50.7 39.3 85 86 103 140h46c0-4.7-6.3-18.7-19-42-18-35.3
-40-67.3-66-96l-9-9h399716v-40H284l9-9c26-28.7 48-60.7 66-96 12.7-23.333 19
-37.333 19-42h-46c-18 54-52.3 100.7-103 140l-9 7H95l7-8c28.7-32 52-65.7 70-101
 10.7-23.333 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 71.3 68 127 0 167z`,
  twoheadrightarrow: `M400000 167
c-68-40-115.7-95.7-143-167h-22c-15.3 0-23 .3-23 1 0 1.3 5.3 13.7 16 37 18 35.3
 41.3 69 70 101l7 8h-125l-9-7c-50.7-39.3-85-86-103-140h-46c0 4.7 6.3 18.7 19 42
 18 35.3 40 67.3 66 96l9 9H0v40h399716l-9 9c-26 28.7-48 60.7-66 96-12.7 23.333
-19 37.333-19 42h46c18-54 52.3-100.7 103-140l9-7h125l-7 8c-28.7 32-52 65.7-70
 101-10.7 23.333-16 35.7-16 37 0 .7 7.7 1 23 1h22c27.3-71.3 75-127 143-167z`,
  // tilde1 is a modified version of a glyph from the MnSymbol package
  tilde1: `M200 55.538c-77 0-168 73.953-177 73.953-3 0-7
-2.175-9-5.437L2 97c-1-2-2-4-2-6 0-4 2-7 5-9l20-12C116 12 171 0 207 0c86 0
 114 68 191 68 78 0 168-68 177-68 4 0 7 2 9 5l12 19c1 2.175 2 4.35 2 6.525 0
 4.35-2 7.613-5 9.788l-19 13.05c-92 63.077-116.937 75.308-183 76.128
-68.267.847-113-73.952-191-73.952z`,
  // ditto tilde2, tilde3, & tilde4
  tilde2: `M344 55.266c-142 0-300.638 81.316-311.5 86.418
-8.01 3.762-22.5 10.91-23.5 5.562L1 120c-1-2-1-3-1-4 0-5 3-9 8-10l18.4-9C160.9
 31.9 283 0 358 0c148 0 188 122 331 122s314-97 326-97c4 0 8 2 10 7l7 21.114
c1 2.14 1 3.21 1 4.28 0 5.347-3 9.626-7 10.696l-22.3 12.622C852.6 158.372 751
 181.476 676 181.476c-149 0-189-126.21-332-126.21z`,
  tilde3: `M786 59C457 59 32 175.242 13 175.242c-6 0-10-3.457
-11-10.37L.15 138c-1-7 3-12 10-13l19.2-6.4C378.4 40.7 634.3 0 804.3 0c337 0
 411.8 157 746.8 157 328 0 754-112 773-112 5 0 10 3 11 9l1 14.075c1 8.066-.697
 16.595-6.697 17.492l-21.052 7.31c-367.9 98.146-609.15 122.696-778.15 122.696
 -338 0-409-156.573-744-156.573z`,
  tilde4: `M786 58C457 58 32 177.487 13 177.487c-6 0-10-3.345
-11-10.035L.15 143c-1-7 3-12 10-13l22-6.7C381.2 35 637.15 0 807.15 0c337 0 409
 177 744 177 328 0 754-127 773-127 5 0 10 3 11 9l1 14.794c1 7.805-3 13.38-9
 14.495l-20.7 5.574c-366.85 99.79-607.3 139.372-776.3 139.372-338 0-409
 -175.236-744-175.236z`,
  // vec is from glyph U+20D7 in font KaTeX Main
  vec: `M377 20c0-5.333 1.833-10 5.5-14S391 0 397 0c4.667 0 8.667 1.667 12 5
3.333 2.667 6.667 9 10 19 6.667 24.667 20.333 43.667 41 57 7.333 4.667 11
10.667 11 18 0 6-1 10-3 12s-6.667 5-14 9c-28.667 14.667-53.667 35.667-75 63
-1.333 1.333-3.167 3.5-5.5 6.5s-4 4.833-5 5.5c-1 .667-2.5 1.333-4.5 2s-4.333 1
-7 1c-4.667 0-9.167-1.833-13.5-5.5S337 184 337 178c0-12.667 15.667-32.333 47-59
H213l-171-1c-8.667-6-13-12.333-13-19 0-4.667 4.333-11.333 13-20h359
c-16-25.333-24-45-24-59z`,
  // widehat1 is a modified version of a glyph from the MnSymbol package
  widehat1: `M529 0h5l519 115c5 1 9 5 9 10 0 1-1 2-1 3l-4 22
c-1 5-5 9-11 9h-2L532 67 19 159h-2c-5 0-9-4-11-9l-5-22c-1-6 2-12 8-13z`,
  // ditto widehat2, widehat3, & widehat4
  widehat2: `M1181 0h2l1171 176c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 220h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,
  widehat3: `M1181 0h2l1171 236c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 280h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,
  widehat4: `M1181 0h2l1171 296c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 340h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,
  // widecheck paths are all inverted versions of widehat
  widecheck1: `M529,159h5l519,-115c5,-1,9,-5,9,-10c0,-1,-1,-2,-1,-3l-4,-22c-1,
-5,-5,-9,-11,-9h-2l-512,92l-513,-92h-2c-5,0,-9,4,-11,9l-5,22c-1,6,2,12,8,13z`,
  widecheck2: `M1181,220h2l1171,-176c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,153l-1167,-153h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,
  widecheck3: `M1181,280h2l1171,-236c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,213l-1167,-213h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,
  widecheck4: `M1181,340h2l1171,-296c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,273l-1167,-273h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,
  // The next ten paths support reaction arrows from the mhchem package.
  // Arrows for \ce{<-->} are offset from xAxis by 0.22ex, per mhchem in LaTeX
  // baraboveleftarrow is mostly from glyph U+2190 in font KaTeX Main
  baraboveleftarrow: `M400000 620h-399890l3 -3c68.7 -52.7 113.7 -120 135 -202
c4 -14.7 6 -23 6 -25c0 -7.3 -7 -11 -21 -11c-8 0 -13.2 0.8 -15.5 2.5
c-2.3 1.7 -4.2 5.8 -5.5 12.5c-1.3 4.7 -2.7 10.3 -4 17c-12 48.7 -34.8 92 -68.5 130
s-74.2 66.3 -121.5 85c-10 4 -16 7.7 -18 11c0 8.7 6 14.3 18 17c47.3 18.7 87.8 47
121.5 85s56.5 81.3 68.5 130c0.7 2 1.3 5 2 9s1.2 6.7 1.5 8c0.3 1.3 1 3.3 2 6
s2.2 4.5 3.5 5.5c1.3 1 3.3 1.8 6 2.5s6 1 10 1c14 0 21 -3.7 21 -11
c0 -2 -2 -10.3 -6 -25c-20 -79.3 -65 -146.7 -135 -202l-3 -3h399890z
M100 620v40h399900v-40z M0 241v40h399900v-40zM0 241v40h399900v-40z`,
  // rightarrowabovebar is mostly from glyph U+2192, KaTeX Main
  rightarrowabovebar: `M0 241v40h399891c-47.3 35.3-84 78-110 128-16.7 32
-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20 11 8 0
13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7 39
-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85-40.5
-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
151.7 139 205zm96 379h399894v40H0zm0 0h399904v40H0z`,
  // The short left harpoon has 0.5em (i.e. 500 units) kern on the left end.
  // Ref from mhchem.sty: \rlap{\raisebox{-.22ex}{$\kern0.5em
  baraboveshortleftharpoon: `M507,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17
c2,0.7,5,1,9,1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21
c-32,-87.3,-82.7,-157.7,-152,-211c0,0,-3,-3,-3,-3l399351,0l0,-40
c-398570,0,-399437,0,-399437,0z M593 435 v40 H399500 v-40z
M0 281 v-40 H399908 v40z M0 281 v-40 H399908 v40z`,
  rightharpoonaboveshortbar: `M0,241 l0,40c399126,0,399993,0,399993,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M0 241 v40 H399908 v-40z M0 475 v-40 H399500 v40z M0 475 v-40 H399500 v40z`,
  shortbaraboveleftharpoon: `M7,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17c2,0.7,5,1,9,
1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21c-32,-87.3,-82.7,-157.7,
-152,-211c0,0,-3,-3,-3,-3l399907,0l0,-40c-399126,0,-399993,0,-399993,0z
M93 435 v40 H400000 v-40z M500 241 v40 H400000 v-40z M500 241 v40 H400000 v-40z`,
  shortrightharpoonabovebar: `M53,241l0,40c398570,0,399437,0,399437,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M500 241 v40 H399408 v-40z M500 435 v40 H400000 v-40z`
}, Fc = function(e, t) {
  switch (e) {
    case "lbrack":
      return "M403 1759 V84 H666 V0 H319 V1759 v" + t + ` v1759 h347 v-84
H403z M403 1759 V0 H319 V1759 v` + t + " v1759 h84z";
    case "rbrack":
      return "M347 1759 V0 H0 V84 H263 V1759 v" + t + ` v1759 H0 v84 H347z
M347 1759 V0 H263 V1759 v` + t + " v1759 h84z";
    case "vert":
      return "M145 15 v585 v" + t + ` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v` + -t + ` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v` + t + " v585 h43z";
    case "doublevert":
      return "M145 15 v585 v" + t + ` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v` + -t + ` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v` + t + ` v585 h43z
M367 15 v585 v` + t + ` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v` + -t + ` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M410 15 H367 v585 v` + t + " v585 h43z";
    case "lfloor":
      return "M319 602 V0 H403 V602 v" + t + ` v1715 h263 v84 H319z
MM319 602 V0 H403 V602 v` + t + " v1715 H319z";
    case "rfloor":
      return "M319 602 V0 H403 V602 v" + t + ` v1799 H0 v-84 H319z
MM319 602 V0 H403 V602 v` + t + " v1715 H319z";
    case "lceil":
      return "M403 1759 V84 H666 V0 H319 V1759 v" + t + ` v602 h84z
M403 1759 V0 H319 V1759 v` + t + " v602 h84z";
    case "rceil":
      return "M347 1759 V0 H0 V84 H263 V1759 v" + t + ` v602 h84z
M347 1759 V0 h-84 V1759 v` + t + " v602 h84z";
    case "lparen":
      return `M863,9c0,-2,-2,-5,-6,-9c0,0,-17,0,-17,0c-12.7,0,-19.3,0.3,-20,1
c-5.3,5.3,-10.3,11,-15,17c-242.7,294.7,-395.3,682,-458,1162c-21.3,163.3,-33.3,349,
-36,557 l0,` + (t + 84) + `c0.2,6,0,26,0,60c2,159.3,10,310.7,24,454c53.3,528,210,
949.7,470,1265c4.7,6,9.7,11.7,15,17c0.7,0.7,7,1,19,1c0,0,18,0,18,0c4,-4,6,-7,6,-9
c0,-2.7,-3.3,-8.7,-10,-18c-135.3,-192.7,-235.5,-414.3,-300.5,-665c-65,-250.7,-102.5,
-544.7,-112.5,-882c-2,-104,-3,-167,-3,-189
l0,-` + (t + 92) + `c0,-162.7,5.7,-314,17,-454c20.7,-272,63.7,-513,129,-723c65.3,
-210,155.3,-396.3,270,-559c6.7,-9.3,10,-15.3,10,-18z`;
    case "rparen":
      return `M76,0c-16.7,0,-25,3,-25,9c0,2,2,6.3,6,13c21.3,28.7,42.3,60.3,
63,95c96.7,156.7,172.8,332.5,228.5,527.5c55.7,195,92.8,416.5,111.5,664.5
c11.3,139.3,17,290.7,17,454c0,28,1.7,43,3.3,45l0,` + (t + 9) + `
c-3,4,-3.3,16.7,-3.3,38c0,162,-5.7,313.7,-17,455c-18.7,248,-55.8,469.3,-111.5,664
c-55.7,194.7,-131.8,370.3,-228.5,527c-20.7,34.7,-41.7,66.3,-63,95c-2,3.3,-4,7,-6,11
c0,7.3,5.7,11,17,11c0,0,11,0,11,0c9.3,0,14.3,-0.3,15,-1c5.3,-5.3,10.3,-11,15,-17
c242.7,-294.7,395.3,-681.7,458,-1161c21.3,-164.7,33.3,-350.7,36,-558
l0,-` + (t + 144) + `c-2,-159.3,-10,-310.7,-24,-454c-53.3,-528,-210,-949.7,
-470,-1265c-4.7,-6,-9.7,-11.7,-15,-17c-0.7,-0.7,-6.7,-1,-18,-1z`;
    default:
      throw new Error("Unknown stretchy delimiter.");
  }
};
class Cr {
  // HtmlDomNode
  // Never used; needed for satisfying interface.
  constructor(e) {
    this.children = void 0, this.classes = void 0, this.height = void 0, this.depth = void 0, this.maxFontSize = void 0, this.style = void 0, this.children = e, this.classes = [], this.height = 0, this.depth = 0, this.maxFontSize = 0, this.style = {};
  }
  hasClass(e) {
    return j.contains(this.classes, e);
  }
  /** Convert the fragment into a node. */
  toNode() {
    for (var e = document.createDocumentFragment(), t = 0; t < this.children.length; t++)
      e.appendChild(this.children[t].toNode());
    return e;
  }
  /** Convert the fragment into HTML markup. */
  toMarkup() {
    for (var e = "", t = 0; t < this.children.length; t++)
      e += this.children[t].toMarkup();
    return e;
  }
  /**
   * Converts the math node into a string, similar to innerText. Applies to
   * MathDomNode's only.
   */
  toText() {
    var e = (t) => t.toText();
    return this.children.map(e).join("");
  }
}
var Pt = {
  "AMS-Regular": {
    32: [0, 0, 0, 0, 0.25],
    65: [0, 0.68889, 0, 0, 0.72222],
    66: [0, 0.68889, 0, 0, 0.66667],
    67: [0, 0.68889, 0, 0, 0.72222],
    68: [0, 0.68889, 0, 0, 0.72222],
    69: [0, 0.68889, 0, 0, 0.66667],
    70: [0, 0.68889, 0, 0, 0.61111],
    71: [0, 0.68889, 0, 0, 0.77778],
    72: [0, 0.68889, 0, 0, 0.77778],
    73: [0, 0.68889, 0, 0, 0.38889],
    74: [0.16667, 0.68889, 0, 0, 0.5],
    75: [0, 0.68889, 0, 0, 0.77778],
    76: [0, 0.68889, 0, 0, 0.66667],
    77: [0, 0.68889, 0, 0, 0.94445],
    78: [0, 0.68889, 0, 0, 0.72222],
    79: [0.16667, 0.68889, 0, 0, 0.77778],
    80: [0, 0.68889, 0, 0, 0.61111],
    81: [0.16667, 0.68889, 0, 0, 0.77778],
    82: [0, 0.68889, 0, 0, 0.72222],
    83: [0, 0.68889, 0, 0, 0.55556],
    84: [0, 0.68889, 0, 0, 0.66667],
    85: [0, 0.68889, 0, 0, 0.72222],
    86: [0, 0.68889, 0, 0, 0.72222],
    87: [0, 0.68889, 0, 0, 1],
    88: [0, 0.68889, 0, 0, 0.72222],
    89: [0, 0.68889, 0, 0, 0.72222],
    90: [0, 0.68889, 0, 0, 0.66667],
    107: [0, 0.68889, 0, 0, 0.55556],
    160: [0, 0, 0, 0, 0.25],
    165: [0, 0.675, 0.025, 0, 0.75],
    174: [0.15559, 0.69224, 0, 0, 0.94666],
    240: [0, 0.68889, 0, 0, 0.55556],
    295: [0, 0.68889, 0, 0, 0.54028],
    710: [0, 0.825, 0, 0, 2.33334],
    732: [0, 0.9, 0, 0, 2.33334],
    770: [0, 0.825, 0, 0, 2.33334],
    771: [0, 0.9, 0, 0, 2.33334],
    989: [0.08167, 0.58167, 0, 0, 0.77778],
    1008: [0, 0.43056, 0.04028, 0, 0.66667],
    8245: [0, 0.54986, 0, 0, 0.275],
    8463: [0, 0.68889, 0, 0, 0.54028],
    8487: [0, 0.68889, 0, 0, 0.72222],
    8498: [0, 0.68889, 0, 0, 0.55556],
    8502: [0, 0.68889, 0, 0, 0.66667],
    8503: [0, 0.68889, 0, 0, 0.44445],
    8504: [0, 0.68889, 0, 0, 0.66667],
    8513: [0, 0.68889, 0, 0, 0.63889],
    8592: [-0.03598, 0.46402, 0, 0, 0.5],
    8594: [-0.03598, 0.46402, 0, 0, 0.5],
    8602: [-0.13313, 0.36687, 0, 0, 1],
    8603: [-0.13313, 0.36687, 0, 0, 1],
    8606: [0.01354, 0.52239, 0, 0, 1],
    8608: [0.01354, 0.52239, 0, 0, 1],
    8610: [0.01354, 0.52239, 0, 0, 1.11111],
    8611: [0.01354, 0.52239, 0, 0, 1.11111],
    8619: [0, 0.54986, 0, 0, 1],
    8620: [0, 0.54986, 0, 0, 1],
    8621: [-0.13313, 0.37788, 0, 0, 1.38889],
    8622: [-0.13313, 0.36687, 0, 0, 1],
    8624: [0, 0.69224, 0, 0, 0.5],
    8625: [0, 0.69224, 0, 0, 0.5],
    8630: [0, 0.43056, 0, 0, 1],
    8631: [0, 0.43056, 0, 0, 1],
    8634: [0.08198, 0.58198, 0, 0, 0.77778],
    8635: [0.08198, 0.58198, 0, 0, 0.77778],
    8638: [0.19444, 0.69224, 0, 0, 0.41667],
    8639: [0.19444, 0.69224, 0, 0, 0.41667],
    8642: [0.19444, 0.69224, 0, 0, 0.41667],
    8643: [0.19444, 0.69224, 0, 0, 0.41667],
    8644: [0.1808, 0.675, 0, 0, 1],
    8646: [0.1808, 0.675, 0, 0, 1],
    8647: [0.1808, 0.675, 0, 0, 1],
    8648: [0.19444, 0.69224, 0, 0, 0.83334],
    8649: [0.1808, 0.675, 0, 0, 1],
    8650: [0.19444, 0.69224, 0, 0, 0.83334],
    8651: [0.01354, 0.52239, 0, 0, 1],
    8652: [0.01354, 0.52239, 0, 0, 1],
    8653: [-0.13313, 0.36687, 0, 0, 1],
    8654: [-0.13313, 0.36687, 0, 0, 1],
    8655: [-0.13313, 0.36687, 0, 0, 1],
    8666: [0.13667, 0.63667, 0, 0, 1],
    8667: [0.13667, 0.63667, 0, 0, 1],
    8669: [-0.13313, 0.37788, 0, 0, 1],
    8672: [-0.064, 0.437, 0, 0, 1.334],
    8674: [-0.064, 0.437, 0, 0, 1.334],
    8705: [0, 0.825, 0, 0, 0.5],
    8708: [0, 0.68889, 0, 0, 0.55556],
    8709: [0.08167, 0.58167, 0, 0, 0.77778],
    8717: [0, 0.43056, 0, 0, 0.42917],
    8722: [-0.03598, 0.46402, 0, 0, 0.5],
    8724: [0.08198, 0.69224, 0, 0, 0.77778],
    8726: [0.08167, 0.58167, 0, 0, 0.77778],
    8733: [0, 0.69224, 0, 0, 0.77778],
    8736: [0, 0.69224, 0, 0, 0.72222],
    8737: [0, 0.69224, 0, 0, 0.72222],
    8738: [0.03517, 0.52239, 0, 0, 0.72222],
    8739: [0.08167, 0.58167, 0, 0, 0.22222],
    8740: [0.25142, 0.74111, 0, 0, 0.27778],
    8741: [0.08167, 0.58167, 0, 0, 0.38889],
    8742: [0.25142, 0.74111, 0, 0, 0.5],
    8756: [0, 0.69224, 0, 0, 0.66667],
    8757: [0, 0.69224, 0, 0, 0.66667],
    8764: [-0.13313, 0.36687, 0, 0, 0.77778],
    8765: [-0.13313, 0.37788, 0, 0, 0.77778],
    8769: [-0.13313, 0.36687, 0, 0, 0.77778],
    8770: [-0.03625, 0.46375, 0, 0, 0.77778],
    8774: [0.30274, 0.79383, 0, 0, 0.77778],
    8776: [-0.01688, 0.48312, 0, 0, 0.77778],
    8778: [0.08167, 0.58167, 0, 0, 0.77778],
    8782: [0.06062, 0.54986, 0, 0, 0.77778],
    8783: [0.06062, 0.54986, 0, 0, 0.77778],
    8785: [0.08198, 0.58198, 0, 0, 0.77778],
    8786: [0.08198, 0.58198, 0, 0, 0.77778],
    8787: [0.08198, 0.58198, 0, 0, 0.77778],
    8790: [0, 0.69224, 0, 0, 0.77778],
    8791: [0.22958, 0.72958, 0, 0, 0.77778],
    8796: [0.08198, 0.91667, 0, 0, 0.77778],
    8806: [0.25583, 0.75583, 0, 0, 0.77778],
    8807: [0.25583, 0.75583, 0, 0, 0.77778],
    8808: [0.25142, 0.75726, 0, 0, 0.77778],
    8809: [0.25142, 0.75726, 0, 0, 0.77778],
    8812: [0.25583, 0.75583, 0, 0, 0.5],
    8814: [0.20576, 0.70576, 0, 0, 0.77778],
    8815: [0.20576, 0.70576, 0, 0, 0.77778],
    8816: [0.30274, 0.79383, 0, 0, 0.77778],
    8817: [0.30274, 0.79383, 0, 0, 0.77778],
    8818: [0.22958, 0.72958, 0, 0, 0.77778],
    8819: [0.22958, 0.72958, 0, 0, 0.77778],
    8822: [0.1808, 0.675, 0, 0, 0.77778],
    8823: [0.1808, 0.675, 0, 0, 0.77778],
    8828: [0.13667, 0.63667, 0, 0, 0.77778],
    8829: [0.13667, 0.63667, 0, 0, 0.77778],
    8830: [0.22958, 0.72958, 0, 0, 0.77778],
    8831: [0.22958, 0.72958, 0, 0, 0.77778],
    8832: [0.20576, 0.70576, 0, 0, 0.77778],
    8833: [0.20576, 0.70576, 0, 0, 0.77778],
    8840: [0.30274, 0.79383, 0, 0, 0.77778],
    8841: [0.30274, 0.79383, 0, 0, 0.77778],
    8842: [0.13597, 0.63597, 0, 0, 0.77778],
    8843: [0.13597, 0.63597, 0, 0, 0.77778],
    8847: [0.03517, 0.54986, 0, 0, 0.77778],
    8848: [0.03517, 0.54986, 0, 0, 0.77778],
    8858: [0.08198, 0.58198, 0, 0, 0.77778],
    8859: [0.08198, 0.58198, 0, 0, 0.77778],
    8861: [0.08198, 0.58198, 0, 0, 0.77778],
    8862: [0, 0.675, 0, 0, 0.77778],
    8863: [0, 0.675, 0, 0, 0.77778],
    8864: [0, 0.675, 0, 0, 0.77778],
    8865: [0, 0.675, 0, 0, 0.77778],
    8872: [0, 0.69224, 0, 0, 0.61111],
    8873: [0, 0.69224, 0, 0, 0.72222],
    8874: [0, 0.69224, 0, 0, 0.88889],
    8876: [0, 0.68889, 0, 0, 0.61111],
    8877: [0, 0.68889, 0, 0, 0.61111],
    8878: [0, 0.68889, 0, 0, 0.72222],
    8879: [0, 0.68889, 0, 0, 0.72222],
    8882: [0.03517, 0.54986, 0, 0, 0.77778],
    8883: [0.03517, 0.54986, 0, 0, 0.77778],
    8884: [0.13667, 0.63667, 0, 0, 0.77778],
    8885: [0.13667, 0.63667, 0, 0, 0.77778],
    8888: [0, 0.54986, 0, 0, 1.11111],
    8890: [0.19444, 0.43056, 0, 0, 0.55556],
    8891: [0.19444, 0.69224, 0, 0, 0.61111],
    8892: [0.19444, 0.69224, 0, 0, 0.61111],
    8901: [0, 0.54986, 0, 0, 0.27778],
    8903: [0.08167, 0.58167, 0, 0, 0.77778],
    8905: [0.08167, 0.58167, 0, 0, 0.77778],
    8906: [0.08167, 0.58167, 0, 0, 0.77778],
    8907: [0, 0.69224, 0, 0, 0.77778],
    8908: [0, 0.69224, 0, 0, 0.77778],
    8909: [-0.03598, 0.46402, 0, 0, 0.77778],
    8910: [0, 0.54986, 0, 0, 0.76042],
    8911: [0, 0.54986, 0, 0, 0.76042],
    8912: [0.03517, 0.54986, 0, 0, 0.77778],
    8913: [0.03517, 0.54986, 0, 0, 0.77778],
    8914: [0, 0.54986, 0, 0, 0.66667],
    8915: [0, 0.54986, 0, 0, 0.66667],
    8916: [0, 0.69224, 0, 0, 0.66667],
    8918: [0.0391, 0.5391, 0, 0, 0.77778],
    8919: [0.0391, 0.5391, 0, 0, 0.77778],
    8920: [0.03517, 0.54986, 0, 0, 1.33334],
    8921: [0.03517, 0.54986, 0, 0, 1.33334],
    8922: [0.38569, 0.88569, 0, 0, 0.77778],
    8923: [0.38569, 0.88569, 0, 0, 0.77778],
    8926: [0.13667, 0.63667, 0, 0, 0.77778],
    8927: [0.13667, 0.63667, 0, 0, 0.77778],
    8928: [0.30274, 0.79383, 0, 0, 0.77778],
    8929: [0.30274, 0.79383, 0, 0, 0.77778],
    8934: [0.23222, 0.74111, 0, 0, 0.77778],
    8935: [0.23222, 0.74111, 0, 0, 0.77778],
    8936: [0.23222, 0.74111, 0, 0, 0.77778],
    8937: [0.23222, 0.74111, 0, 0, 0.77778],
    8938: [0.20576, 0.70576, 0, 0, 0.77778],
    8939: [0.20576, 0.70576, 0, 0, 0.77778],
    8940: [0.30274, 0.79383, 0, 0, 0.77778],
    8941: [0.30274, 0.79383, 0, 0, 0.77778],
    8994: [0.19444, 0.69224, 0, 0, 0.77778],
    8995: [0.19444, 0.69224, 0, 0, 0.77778],
    9416: [0.15559, 0.69224, 0, 0, 0.90222],
    9484: [0, 0.69224, 0, 0, 0.5],
    9488: [0, 0.69224, 0, 0, 0.5],
    9492: [0, 0.37788, 0, 0, 0.5],
    9496: [0, 0.37788, 0, 0, 0.5],
    9585: [0.19444, 0.68889, 0, 0, 0.88889],
    9586: [0.19444, 0.74111, 0, 0, 0.88889],
    9632: [0, 0.675, 0, 0, 0.77778],
    9633: [0, 0.675, 0, 0, 0.77778],
    9650: [0, 0.54986, 0, 0, 0.72222],
    9651: [0, 0.54986, 0, 0, 0.72222],
    9654: [0.03517, 0.54986, 0, 0, 0.77778],
    9660: [0, 0.54986, 0, 0, 0.72222],
    9661: [0, 0.54986, 0, 0, 0.72222],
    9664: [0.03517, 0.54986, 0, 0, 0.77778],
    9674: [0.11111, 0.69224, 0, 0, 0.66667],
    9733: [0.19444, 0.69224, 0, 0, 0.94445],
    10003: [0, 0.69224, 0, 0, 0.83334],
    10016: [0, 0.69224, 0, 0, 0.83334],
    10731: [0.11111, 0.69224, 0, 0, 0.66667],
    10846: [0.19444, 0.75583, 0, 0, 0.61111],
    10877: [0.13667, 0.63667, 0, 0, 0.77778],
    10878: [0.13667, 0.63667, 0, 0, 0.77778],
    10885: [0.25583, 0.75583, 0, 0, 0.77778],
    10886: [0.25583, 0.75583, 0, 0, 0.77778],
    10887: [0.13597, 0.63597, 0, 0, 0.77778],
    10888: [0.13597, 0.63597, 0, 0, 0.77778],
    10889: [0.26167, 0.75726, 0, 0, 0.77778],
    10890: [0.26167, 0.75726, 0, 0, 0.77778],
    10891: [0.48256, 0.98256, 0, 0, 0.77778],
    10892: [0.48256, 0.98256, 0, 0, 0.77778],
    10901: [0.13667, 0.63667, 0, 0, 0.77778],
    10902: [0.13667, 0.63667, 0, 0, 0.77778],
    10933: [0.25142, 0.75726, 0, 0, 0.77778],
    10934: [0.25142, 0.75726, 0, 0, 0.77778],
    10935: [0.26167, 0.75726, 0, 0, 0.77778],
    10936: [0.26167, 0.75726, 0, 0, 0.77778],
    10937: [0.26167, 0.75726, 0, 0, 0.77778],
    10938: [0.26167, 0.75726, 0, 0, 0.77778],
    10949: [0.25583, 0.75583, 0, 0, 0.77778],
    10950: [0.25583, 0.75583, 0, 0, 0.77778],
    10955: [0.28481, 0.79383, 0, 0, 0.77778],
    10956: [0.28481, 0.79383, 0, 0, 0.77778],
    57350: [0.08167, 0.58167, 0, 0, 0.22222],
    57351: [0.08167, 0.58167, 0, 0, 0.38889],
    57352: [0.08167, 0.58167, 0, 0, 0.77778],
    57353: [0, 0.43056, 0.04028, 0, 0.66667],
    57356: [0.25142, 0.75726, 0, 0, 0.77778],
    57357: [0.25142, 0.75726, 0, 0, 0.77778],
    57358: [0.41951, 0.91951, 0, 0, 0.77778],
    57359: [0.30274, 0.79383, 0, 0, 0.77778],
    57360: [0.30274, 0.79383, 0, 0, 0.77778],
    57361: [0.41951, 0.91951, 0, 0, 0.77778],
    57366: [0.25142, 0.75726, 0, 0, 0.77778],
    57367: [0.25142, 0.75726, 0, 0, 0.77778],
    57368: [0.25142, 0.75726, 0, 0, 0.77778],
    57369: [0.25142, 0.75726, 0, 0, 0.77778],
    57370: [0.13597, 0.63597, 0, 0, 0.77778],
    57371: [0.13597, 0.63597, 0, 0, 0.77778]
  },
  "Caligraphic-Regular": {
    32: [0, 0, 0, 0, 0.25],
    65: [0, 0.68333, 0, 0.19445, 0.79847],
    66: [0, 0.68333, 0.03041, 0.13889, 0.65681],
    67: [0, 0.68333, 0.05834, 0.13889, 0.52653],
    68: [0, 0.68333, 0.02778, 0.08334, 0.77139],
    69: [0, 0.68333, 0.08944, 0.11111, 0.52778],
    70: [0, 0.68333, 0.09931, 0.11111, 0.71875],
    71: [0.09722, 0.68333, 0.0593, 0.11111, 0.59487],
    72: [0, 0.68333, 965e-5, 0.11111, 0.84452],
    73: [0, 0.68333, 0.07382, 0, 0.54452],
    74: [0.09722, 0.68333, 0.18472, 0.16667, 0.67778],
    75: [0, 0.68333, 0.01445, 0.05556, 0.76195],
    76: [0, 0.68333, 0, 0.13889, 0.68972],
    77: [0, 0.68333, 0, 0.13889, 1.2009],
    78: [0, 0.68333, 0.14736, 0.08334, 0.82049],
    79: [0, 0.68333, 0.02778, 0.11111, 0.79611],
    80: [0, 0.68333, 0.08222, 0.08334, 0.69556],
    81: [0.09722, 0.68333, 0, 0.11111, 0.81667],
    82: [0, 0.68333, 0, 0.08334, 0.8475],
    83: [0, 0.68333, 0.075, 0.13889, 0.60556],
    84: [0, 0.68333, 0.25417, 0, 0.54464],
    85: [0, 0.68333, 0.09931, 0.08334, 0.62583],
    86: [0, 0.68333, 0.08222, 0, 0.61278],
    87: [0, 0.68333, 0.08222, 0.08334, 0.98778],
    88: [0, 0.68333, 0.14643, 0.13889, 0.7133],
    89: [0.09722, 0.68333, 0.08222, 0.08334, 0.66834],
    90: [0, 0.68333, 0.07944, 0.13889, 0.72473],
    160: [0, 0, 0, 0, 0.25]
  },
  "Fraktur-Regular": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69141, 0, 0, 0.29574],
    34: [0, 0.69141, 0, 0, 0.21471],
    38: [0, 0.69141, 0, 0, 0.73786],
    39: [0, 0.69141, 0, 0, 0.21201],
    40: [0.24982, 0.74947, 0, 0, 0.38865],
    41: [0.24982, 0.74947, 0, 0, 0.38865],
    42: [0, 0.62119, 0, 0, 0.27764],
    43: [0.08319, 0.58283, 0, 0, 0.75623],
    44: [0, 0.10803, 0, 0, 0.27764],
    45: [0.08319, 0.58283, 0, 0, 0.75623],
    46: [0, 0.10803, 0, 0, 0.27764],
    47: [0.24982, 0.74947, 0, 0, 0.50181],
    48: [0, 0.47534, 0, 0, 0.50181],
    49: [0, 0.47534, 0, 0, 0.50181],
    50: [0, 0.47534, 0, 0, 0.50181],
    51: [0.18906, 0.47534, 0, 0, 0.50181],
    52: [0.18906, 0.47534, 0, 0, 0.50181],
    53: [0.18906, 0.47534, 0, 0, 0.50181],
    54: [0, 0.69141, 0, 0, 0.50181],
    55: [0.18906, 0.47534, 0, 0, 0.50181],
    56: [0, 0.69141, 0, 0, 0.50181],
    57: [0.18906, 0.47534, 0, 0, 0.50181],
    58: [0, 0.47534, 0, 0, 0.21606],
    59: [0.12604, 0.47534, 0, 0, 0.21606],
    61: [-0.13099, 0.36866, 0, 0, 0.75623],
    63: [0, 0.69141, 0, 0, 0.36245],
    65: [0, 0.69141, 0, 0, 0.7176],
    66: [0, 0.69141, 0, 0, 0.88397],
    67: [0, 0.69141, 0, 0, 0.61254],
    68: [0, 0.69141, 0, 0, 0.83158],
    69: [0, 0.69141, 0, 0, 0.66278],
    70: [0.12604, 0.69141, 0, 0, 0.61119],
    71: [0, 0.69141, 0, 0, 0.78539],
    72: [0.06302, 0.69141, 0, 0, 0.7203],
    73: [0, 0.69141, 0, 0, 0.55448],
    74: [0.12604, 0.69141, 0, 0, 0.55231],
    75: [0, 0.69141, 0, 0, 0.66845],
    76: [0, 0.69141, 0, 0, 0.66602],
    77: [0, 0.69141, 0, 0, 1.04953],
    78: [0, 0.69141, 0, 0, 0.83212],
    79: [0, 0.69141, 0, 0, 0.82699],
    80: [0.18906, 0.69141, 0, 0, 0.82753],
    81: [0.03781, 0.69141, 0, 0, 0.82699],
    82: [0, 0.69141, 0, 0, 0.82807],
    83: [0, 0.69141, 0, 0, 0.82861],
    84: [0, 0.69141, 0, 0, 0.66899],
    85: [0, 0.69141, 0, 0, 0.64576],
    86: [0, 0.69141, 0, 0, 0.83131],
    87: [0, 0.69141, 0, 0, 1.04602],
    88: [0, 0.69141, 0, 0, 0.71922],
    89: [0.18906, 0.69141, 0, 0, 0.83293],
    90: [0.12604, 0.69141, 0, 0, 0.60201],
    91: [0.24982, 0.74947, 0, 0, 0.27764],
    93: [0.24982, 0.74947, 0, 0, 0.27764],
    94: [0, 0.69141, 0, 0, 0.49965],
    97: [0, 0.47534, 0, 0, 0.50046],
    98: [0, 0.69141, 0, 0, 0.51315],
    99: [0, 0.47534, 0, 0, 0.38946],
    100: [0, 0.62119, 0, 0, 0.49857],
    101: [0, 0.47534, 0, 0, 0.40053],
    102: [0.18906, 0.69141, 0, 0, 0.32626],
    103: [0.18906, 0.47534, 0, 0, 0.5037],
    104: [0.18906, 0.69141, 0, 0, 0.52126],
    105: [0, 0.69141, 0, 0, 0.27899],
    106: [0, 0.69141, 0, 0, 0.28088],
    107: [0, 0.69141, 0, 0, 0.38946],
    108: [0, 0.69141, 0, 0, 0.27953],
    109: [0, 0.47534, 0, 0, 0.76676],
    110: [0, 0.47534, 0, 0, 0.52666],
    111: [0, 0.47534, 0, 0, 0.48885],
    112: [0.18906, 0.52396, 0, 0, 0.50046],
    113: [0.18906, 0.47534, 0, 0, 0.48912],
    114: [0, 0.47534, 0, 0, 0.38919],
    115: [0, 0.47534, 0, 0, 0.44266],
    116: [0, 0.62119, 0, 0, 0.33301],
    117: [0, 0.47534, 0, 0, 0.5172],
    118: [0, 0.52396, 0, 0, 0.5118],
    119: [0, 0.52396, 0, 0, 0.77351],
    120: [0.18906, 0.47534, 0, 0, 0.38865],
    121: [0.18906, 0.47534, 0, 0, 0.49884],
    122: [0.18906, 0.47534, 0, 0, 0.39054],
    160: [0, 0, 0, 0, 0.25],
    8216: [0, 0.69141, 0, 0, 0.21471],
    8217: [0, 0.69141, 0, 0, 0.21471],
    58112: [0, 0.62119, 0, 0, 0.49749],
    58113: [0, 0.62119, 0, 0, 0.4983],
    58114: [0.18906, 0.69141, 0, 0, 0.33328],
    58115: [0.18906, 0.69141, 0, 0, 0.32923],
    58116: [0.18906, 0.47534, 0, 0, 0.50343],
    58117: [0, 0.69141, 0, 0, 0.33301],
    58118: [0, 0.62119, 0, 0, 0.33409],
    58119: [0, 0.47534, 0, 0, 0.50073]
  },
  "Main-Bold": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0, 0, 0.35],
    34: [0, 0.69444, 0, 0, 0.60278],
    35: [0.19444, 0.69444, 0, 0, 0.95833],
    36: [0.05556, 0.75, 0, 0, 0.575],
    37: [0.05556, 0.75, 0, 0, 0.95833],
    38: [0, 0.69444, 0, 0, 0.89444],
    39: [0, 0.69444, 0, 0, 0.31944],
    40: [0.25, 0.75, 0, 0, 0.44722],
    41: [0.25, 0.75, 0, 0, 0.44722],
    42: [0, 0.75, 0, 0, 0.575],
    43: [0.13333, 0.63333, 0, 0, 0.89444],
    44: [0.19444, 0.15556, 0, 0, 0.31944],
    45: [0, 0.44444, 0, 0, 0.38333],
    46: [0, 0.15556, 0, 0, 0.31944],
    47: [0.25, 0.75, 0, 0, 0.575],
    48: [0, 0.64444, 0, 0, 0.575],
    49: [0, 0.64444, 0, 0, 0.575],
    50: [0, 0.64444, 0, 0, 0.575],
    51: [0, 0.64444, 0, 0, 0.575],
    52: [0, 0.64444, 0, 0, 0.575],
    53: [0, 0.64444, 0, 0, 0.575],
    54: [0, 0.64444, 0, 0, 0.575],
    55: [0, 0.64444, 0, 0, 0.575],
    56: [0, 0.64444, 0, 0, 0.575],
    57: [0, 0.64444, 0, 0, 0.575],
    58: [0, 0.44444, 0, 0, 0.31944],
    59: [0.19444, 0.44444, 0, 0, 0.31944],
    60: [0.08556, 0.58556, 0, 0, 0.89444],
    61: [-0.10889, 0.39111, 0, 0, 0.89444],
    62: [0.08556, 0.58556, 0, 0, 0.89444],
    63: [0, 0.69444, 0, 0, 0.54305],
    64: [0, 0.69444, 0, 0, 0.89444],
    65: [0, 0.68611, 0, 0, 0.86944],
    66: [0, 0.68611, 0, 0, 0.81805],
    67: [0, 0.68611, 0, 0, 0.83055],
    68: [0, 0.68611, 0, 0, 0.88194],
    69: [0, 0.68611, 0, 0, 0.75555],
    70: [0, 0.68611, 0, 0, 0.72361],
    71: [0, 0.68611, 0, 0, 0.90416],
    72: [0, 0.68611, 0, 0, 0.9],
    73: [0, 0.68611, 0, 0, 0.43611],
    74: [0, 0.68611, 0, 0, 0.59444],
    75: [0, 0.68611, 0, 0, 0.90138],
    76: [0, 0.68611, 0, 0, 0.69166],
    77: [0, 0.68611, 0, 0, 1.09166],
    78: [0, 0.68611, 0, 0, 0.9],
    79: [0, 0.68611, 0, 0, 0.86388],
    80: [0, 0.68611, 0, 0, 0.78611],
    81: [0.19444, 0.68611, 0, 0, 0.86388],
    82: [0, 0.68611, 0, 0, 0.8625],
    83: [0, 0.68611, 0, 0, 0.63889],
    84: [0, 0.68611, 0, 0, 0.8],
    85: [0, 0.68611, 0, 0, 0.88472],
    86: [0, 0.68611, 0.01597, 0, 0.86944],
    87: [0, 0.68611, 0.01597, 0, 1.18888],
    88: [0, 0.68611, 0, 0, 0.86944],
    89: [0, 0.68611, 0.02875, 0, 0.86944],
    90: [0, 0.68611, 0, 0, 0.70277],
    91: [0.25, 0.75, 0, 0, 0.31944],
    92: [0.25, 0.75, 0, 0, 0.575],
    93: [0.25, 0.75, 0, 0, 0.31944],
    94: [0, 0.69444, 0, 0, 0.575],
    95: [0.31, 0.13444, 0.03194, 0, 0.575],
    97: [0, 0.44444, 0, 0, 0.55902],
    98: [0, 0.69444, 0, 0, 0.63889],
    99: [0, 0.44444, 0, 0, 0.51111],
    100: [0, 0.69444, 0, 0, 0.63889],
    101: [0, 0.44444, 0, 0, 0.52708],
    102: [0, 0.69444, 0.10903, 0, 0.35139],
    103: [0.19444, 0.44444, 0.01597, 0, 0.575],
    104: [0, 0.69444, 0, 0, 0.63889],
    105: [0, 0.69444, 0, 0, 0.31944],
    106: [0.19444, 0.69444, 0, 0, 0.35139],
    107: [0, 0.69444, 0, 0, 0.60694],
    108: [0, 0.69444, 0, 0, 0.31944],
    109: [0, 0.44444, 0, 0, 0.95833],
    110: [0, 0.44444, 0, 0, 0.63889],
    111: [0, 0.44444, 0, 0, 0.575],
    112: [0.19444, 0.44444, 0, 0, 0.63889],
    113: [0.19444, 0.44444, 0, 0, 0.60694],
    114: [0, 0.44444, 0, 0, 0.47361],
    115: [0, 0.44444, 0, 0, 0.45361],
    116: [0, 0.63492, 0, 0, 0.44722],
    117: [0, 0.44444, 0, 0, 0.63889],
    118: [0, 0.44444, 0.01597, 0, 0.60694],
    119: [0, 0.44444, 0.01597, 0, 0.83055],
    120: [0, 0.44444, 0, 0, 0.60694],
    121: [0.19444, 0.44444, 0.01597, 0, 0.60694],
    122: [0, 0.44444, 0, 0, 0.51111],
    123: [0.25, 0.75, 0, 0, 0.575],
    124: [0.25, 0.75, 0, 0, 0.31944],
    125: [0.25, 0.75, 0, 0, 0.575],
    126: [0.35, 0.34444, 0, 0, 0.575],
    160: [0, 0, 0, 0, 0.25],
    163: [0, 0.69444, 0, 0, 0.86853],
    168: [0, 0.69444, 0, 0, 0.575],
    172: [0, 0.44444, 0, 0, 0.76666],
    176: [0, 0.69444, 0, 0, 0.86944],
    177: [0.13333, 0.63333, 0, 0, 0.89444],
    184: [0.17014, 0, 0, 0, 0.51111],
    198: [0, 0.68611, 0, 0, 1.04166],
    215: [0.13333, 0.63333, 0, 0, 0.89444],
    216: [0.04861, 0.73472, 0, 0, 0.89444],
    223: [0, 0.69444, 0, 0, 0.59722],
    230: [0, 0.44444, 0, 0, 0.83055],
    247: [0.13333, 0.63333, 0, 0, 0.89444],
    248: [0.09722, 0.54167, 0, 0, 0.575],
    305: [0, 0.44444, 0, 0, 0.31944],
    338: [0, 0.68611, 0, 0, 1.16944],
    339: [0, 0.44444, 0, 0, 0.89444],
    567: [0.19444, 0.44444, 0, 0, 0.35139],
    710: [0, 0.69444, 0, 0, 0.575],
    711: [0, 0.63194, 0, 0, 0.575],
    713: [0, 0.59611, 0, 0, 0.575],
    714: [0, 0.69444, 0, 0, 0.575],
    715: [0, 0.69444, 0, 0, 0.575],
    728: [0, 0.69444, 0, 0, 0.575],
    729: [0, 0.69444, 0, 0, 0.31944],
    730: [0, 0.69444, 0, 0, 0.86944],
    732: [0, 0.69444, 0, 0, 0.575],
    733: [0, 0.69444, 0, 0, 0.575],
    915: [0, 0.68611, 0, 0, 0.69166],
    916: [0, 0.68611, 0, 0, 0.95833],
    920: [0, 0.68611, 0, 0, 0.89444],
    923: [0, 0.68611, 0, 0, 0.80555],
    926: [0, 0.68611, 0, 0, 0.76666],
    928: [0, 0.68611, 0, 0, 0.9],
    931: [0, 0.68611, 0, 0, 0.83055],
    933: [0, 0.68611, 0, 0, 0.89444],
    934: [0, 0.68611, 0, 0, 0.83055],
    936: [0, 0.68611, 0, 0, 0.89444],
    937: [0, 0.68611, 0, 0, 0.83055],
    8211: [0, 0.44444, 0.03194, 0, 0.575],
    8212: [0, 0.44444, 0.03194, 0, 1.14999],
    8216: [0, 0.69444, 0, 0, 0.31944],
    8217: [0, 0.69444, 0, 0, 0.31944],
    8220: [0, 0.69444, 0, 0, 0.60278],
    8221: [0, 0.69444, 0, 0, 0.60278],
    8224: [0.19444, 0.69444, 0, 0, 0.51111],
    8225: [0.19444, 0.69444, 0, 0, 0.51111],
    8242: [0, 0.55556, 0, 0, 0.34444],
    8407: [0, 0.72444, 0.15486, 0, 0.575],
    8463: [0, 0.69444, 0, 0, 0.66759],
    8465: [0, 0.69444, 0, 0, 0.83055],
    8467: [0, 0.69444, 0, 0, 0.47361],
    8472: [0.19444, 0.44444, 0, 0, 0.74027],
    8476: [0, 0.69444, 0, 0, 0.83055],
    8501: [0, 0.69444, 0, 0, 0.70277],
    8592: [-0.10889, 0.39111, 0, 0, 1.14999],
    8593: [0.19444, 0.69444, 0, 0, 0.575],
    8594: [-0.10889, 0.39111, 0, 0, 1.14999],
    8595: [0.19444, 0.69444, 0, 0, 0.575],
    8596: [-0.10889, 0.39111, 0, 0, 1.14999],
    8597: [0.25, 0.75, 0, 0, 0.575],
    8598: [0.19444, 0.69444, 0, 0, 1.14999],
    8599: [0.19444, 0.69444, 0, 0, 1.14999],
    8600: [0.19444, 0.69444, 0, 0, 1.14999],
    8601: [0.19444, 0.69444, 0, 0, 1.14999],
    8636: [-0.10889, 0.39111, 0, 0, 1.14999],
    8637: [-0.10889, 0.39111, 0, 0, 1.14999],
    8640: [-0.10889, 0.39111, 0, 0, 1.14999],
    8641: [-0.10889, 0.39111, 0, 0, 1.14999],
    8656: [-0.10889, 0.39111, 0, 0, 1.14999],
    8657: [0.19444, 0.69444, 0, 0, 0.70277],
    8658: [-0.10889, 0.39111, 0, 0, 1.14999],
    8659: [0.19444, 0.69444, 0, 0, 0.70277],
    8660: [-0.10889, 0.39111, 0, 0, 1.14999],
    8661: [0.25, 0.75, 0, 0, 0.70277],
    8704: [0, 0.69444, 0, 0, 0.63889],
    8706: [0, 0.69444, 0.06389, 0, 0.62847],
    8707: [0, 0.69444, 0, 0, 0.63889],
    8709: [0.05556, 0.75, 0, 0, 0.575],
    8711: [0, 0.68611, 0, 0, 0.95833],
    8712: [0.08556, 0.58556, 0, 0, 0.76666],
    8715: [0.08556, 0.58556, 0, 0, 0.76666],
    8722: [0.13333, 0.63333, 0, 0, 0.89444],
    8723: [0.13333, 0.63333, 0, 0, 0.89444],
    8725: [0.25, 0.75, 0, 0, 0.575],
    8726: [0.25, 0.75, 0, 0, 0.575],
    8727: [-0.02778, 0.47222, 0, 0, 0.575],
    8728: [-0.02639, 0.47361, 0, 0, 0.575],
    8729: [-0.02639, 0.47361, 0, 0, 0.575],
    8730: [0.18, 0.82, 0, 0, 0.95833],
    8733: [0, 0.44444, 0, 0, 0.89444],
    8734: [0, 0.44444, 0, 0, 1.14999],
    8736: [0, 0.69224, 0, 0, 0.72222],
    8739: [0.25, 0.75, 0, 0, 0.31944],
    8741: [0.25, 0.75, 0, 0, 0.575],
    8743: [0, 0.55556, 0, 0, 0.76666],
    8744: [0, 0.55556, 0, 0, 0.76666],
    8745: [0, 0.55556, 0, 0, 0.76666],
    8746: [0, 0.55556, 0, 0, 0.76666],
    8747: [0.19444, 0.69444, 0.12778, 0, 0.56875],
    8764: [-0.10889, 0.39111, 0, 0, 0.89444],
    8768: [0.19444, 0.69444, 0, 0, 0.31944],
    8771: [222e-5, 0.50222, 0, 0, 0.89444],
    8773: [0.027, 0.638, 0, 0, 0.894],
    8776: [0.02444, 0.52444, 0, 0, 0.89444],
    8781: [222e-5, 0.50222, 0, 0, 0.89444],
    8801: [222e-5, 0.50222, 0, 0, 0.89444],
    8804: [0.19667, 0.69667, 0, 0, 0.89444],
    8805: [0.19667, 0.69667, 0, 0, 0.89444],
    8810: [0.08556, 0.58556, 0, 0, 1.14999],
    8811: [0.08556, 0.58556, 0, 0, 1.14999],
    8826: [0.08556, 0.58556, 0, 0, 0.89444],
    8827: [0.08556, 0.58556, 0, 0, 0.89444],
    8834: [0.08556, 0.58556, 0, 0, 0.89444],
    8835: [0.08556, 0.58556, 0, 0, 0.89444],
    8838: [0.19667, 0.69667, 0, 0, 0.89444],
    8839: [0.19667, 0.69667, 0, 0, 0.89444],
    8846: [0, 0.55556, 0, 0, 0.76666],
    8849: [0.19667, 0.69667, 0, 0, 0.89444],
    8850: [0.19667, 0.69667, 0, 0, 0.89444],
    8851: [0, 0.55556, 0, 0, 0.76666],
    8852: [0, 0.55556, 0, 0, 0.76666],
    8853: [0.13333, 0.63333, 0, 0, 0.89444],
    8854: [0.13333, 0.63333, 0, 0, 0.89444],
    8855: [0.13333, 0.63333, 0, 0, 0.89444],
    8856: [0.13333, 0.63333, 0, 0, 0.89444],
    8857: [0.13333, 0.63333, 0, 0, 0.89444],
    8866: [0, 0.69444, 0, 0, 0.70277],
    8867: [0, 0.69444, 0, 0, 0.70277],
    8868: [0, 0.69444, 0, 0, 0.89444],
    8869: [0, 0.69444, 0, 0, 0.89444],
    8900: [-0.02639, 0.47361, 0, 0, 0.575],
    8901: [-0.02639, 0.47361, 0, 0, 0.31944],
    8902: [-0.02778, 0.47222, 0, 0, 0.575],
    8968: [0.25, 0.75, 0, 0, 0.51111],
    8969: [0.25, 0.75, 0, 0, 0.51111],
    8970: [0.25, 0.75, 0, 0, 0.51111],
    8971: [0.25, 0.75, 0, 0, 0.51111],
    8994: [-0.13889, 0.36111, 0, 0, 1.14999],
    8995: [-0.13889, 0.36111, 0, 0, 1.14999],
    9651: [0.19444, 0.69444, 0, 0, 1.02222],
    9657: [-0.02778, 0.47222, 0, 0, 0.575],
    9661: [0.19444, 0.69444, 0, 0, 1.02222],
    9667: [-0.02778, 0.47222, 0, 0, 0.575],
    9711: [0.19444, 0.69444, 0, 0, 1.14999],
    9824: [0.12963, 0.69444, 0, 0, 0.89444],
    9825: [0.12963, 0.69444, 0, 0, 0.89444],
    9826: [0.12963, 0.69444, 0, 0, 0.89444],
    9827: [0.12963, 0.69444, 0, 0, 0.89444],
    9837: [0, 0.75, 0, 0, 0.44722],
    9838: [0.19444, 0.69444, 0, 0, 0.44722],
    9839: [0.19444, 0.69444, 0, 0, 0.44722],
    10216: [0.25, 0.75, 0, 0, 0.44722],
    10217: [0.25, 0.75, 0, 0, 0.44722],
    10815: [0, 0.68611, 0, 0, 0.9],
    10927: [0.19667, 0.69667, 0, 0, 0.89444],
    10928: [0.19667, 0.69667, 0, 0, 0.89444],
    57376: [0.19444, 0.69444, 0, 0, 0]
  },
  "Main-BoldItalic": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0.11417, 0, 0.38611],
    34: [0, 0.69444, 0.07939, 0, 0.62055],
    35: [0.19444, 0.69444, 0.06833, 0, 0.94444],
    37: [0.05556, 0.75, 0.12861, 0, 0.94444],
    38: [0, 0.69444, 0.08528, 0, 0.88555],
    39: [0, 0.69444, 0.12945, 0, 0.35555],
    40: [0.25, 0.75, 0.15806, 0, 0.47333],
    41: [0.25, 0.75, 0.03306, 0, 0.47333],
    42: [0, 0.75, 0.14333, 0, 0.59111],
    43: [0.10333, 0.60333, 0.03306, 0, 0.88555],
    44: [0.19444, 0.14722, 0, 0, 0.35555],
    45: [0, 0.44444, 0.02611, 0, 0.41444],
    46: [0, 0.14722, 0, 0, 0.35555],
    47: [0.25, 0.75, 0.15806, 0, 0.59111],
    48: [0, 0.64444, 0.13167, 0, 0.59111],
    49: [0, 0.64444, 0.13167, 0, 0.59111],
    50: [0, 0.64444, 0.13167, 0, 0.59111],
    51: [0, 0.64444, 0.13167, 0, 0.59111],
    52: [0.19444, 0.64444, 0.13167, 0, 0.59111],
    53: [0, 0.64444, 0.13167, 0, 0.59111],
    54: [0, 0.64444, 0.13167, 0, 0.59111],
    55: [0.19444, 0.64444, 0.13167, 0, 0.59111],
    56: [0, 0.64444, 0.13167, 0, 0.59111],
    57: [0, 0.64444, 0.13167, 0, 0.59111],
    58: [0, 0.44444, 0.06695, 0, 0.35555],
    59: [0.19444, 0.44444, 0.06695, 0, 0.35555],
    61: [-0.10889, 0.39111, 0.06833, 0, 0.88555],
    63: [0, 0.69444, 0.11472, 0, 0.59111],
    64: [0, 0.69444, 0.09208, 0, 0.88555],
    65: [0, 0.68611, 0, 0, 0.86555],
    66: [0, 0.68611, 0.0992, 0, 0.81666],
    67: [0, 0.68611, 0.14208, 0, 0.82666],
    68: [0, 0.68611, 0.09062, 0, 0.87555],
    69: [0, 0.68611, 0.11431, 0, 0.75666],
    70: [0, 0.68611, 0.12903, 0, 0.72722],
    71: [0, 0.68611, 0.07347, 0, 0.89527],
    72: [0, 0.68611, 0.17208, 0, 0.8961],
    73: [0, 0.68611, 0.15681, 0, 0.47166],
    74: [0, 0.68611, 0.145, 0, 0.61055],
    75: [0, 0.68611, 0.14208, 0, 0.89499],
    76: [0, 0.68611, 0, 0, 0.69777],
    77: [0, 0.68611, 0.17208, 0, 1.07277],
    78: [0, 0.68611, 0.17208, 0, 0.8961],
    79: [0, 0.68611, 0.09062, 0, 0.85499],
    80: [0, 0.68611, 0.0992, 0, 0.78721],
    81: [0.19444, 0.68611, 0.09062, 0, 0.85499],
    82: [0, 0.68611, 0.02559, 0, 0.85944],
    83: [0, 0.68611, 0.11264, 0, 0.64999],
    84: [0, 0.68611, 0.12903, 0, 0.7961],
    85: [0, 0.68611, 0.17208, 0, 0.88083],
    86: [0, 0.68611, 0.18625, 0, 0.86555],
    87: [0, 0.68611, 0.18625, 0, 1.15999],
    88: [0, 0.68611, 0.15681, 0, 0.86555],
    89: [0, 0.68611, 0.19803, 0, 0.86555],
    90: [0, 0.68611, 0.14208, 0, 0.70888],
    91: [0.25, 0.75, 0.1875, 0, 0.35611],
    93: [0.25, 0.75, 0.09972, 0, 0.35611],
    94: [0, 0.69444, 0.06709, 0, 0.59111],
    95: [0.31, 0.13444, 0.09811, 0, 0.59111],
    97: [0, 0.44444, 0.09426, 0, 0.59111],
    98: [0, 0.69444, 0.07861, 0, 0.53222],
    99: [0, 0.44444, 0.05222, 0, 0.53222],
    100: [0, 0.69444, 0.10861, 0, 0.59111],
    101: [0, 0.44444, 0.085, 0, 0.53222],
    102: [0.19444, 0.69444, 0.21778, 0, 0.4],
    103: [0.19444, 0.44444, 0.105, 0, 0.53222],
    104: [0, 0.69444, 0.09426, 0, 0.59111],
    105: [0, 0.69326, 0.11387, 0, 0.35555],
    106: [0.19444, 0.69326, 0.1672, 0, 0.35555],
    107: [0, 0.69444, 0.11111, 0, 0.53222],
    108: [0, 0.69444, 0.10861, 0, 0.29666],
    109: [0, 0.44444, 0.09426, 0, 0.94444],
    110: [0, 0.44444, 0.09426, 0, 0.64999],
    111: [0, 0.44444, 0.07861, 0, 0.59111],
    112: [0.19444, 0.44444, 0.07861, 0, 0.59111],
    113: [0.19444, 0.44444, 0.105, 0, 0.53222],
    114: [0, 0.44444, 0.11111, 0, 0.50167],
    115: [0, 0.44444, 0.08167, 0, 0.48694],
    116: [0, 0.63492, 0.09639, 0, 0.385],
    117: [0, 0.44444, 0.09426, 0, 0.62055],
    118: [0, 0.44444, 0.11111, 0, 0.53222],
    119: [0, 0.44444, 0.11111, 0, 0.76777],
    120: [0, 0.44444, 0.12583, 0, 0.56055],
    121: [0.19444, 0.44444, 0.105, 0, 0.56166],
    122: [0, 0.44444, 0.13889, 0, 0.49055],
    126: [0.35, 0.34444, 0.11472, 0, 0.59111],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.69444, 0.11473, 0, 0.59111],
    176: [0, 0.69444, 0, 0, 0.94888],
    184: [0.17014, 0, 0, 0, 0.53222],
    198: [0, 0.68611, 0.11431, 0, 1.02277],
    216: [0.04861, 0.73472, 0.09062, 0, 0.88555],
    223: [0.19444, 0.69444, 0.09736, 0, 0.665],
    230: [0, 0.44444, 0.085, 0, 0.82666],
    248: [0.09722, 0.54167, 0.09458, 0, 0.59111],
    305: [0, 0.44444, 0.09426, 0, 0.35555],
    338: [0, 0.68611, 0.11431, 0, 1.14054],
    339: [0, 0.44444, 0.085, 0, 0.82666],
    567: [0.19444, 0.44444, 0.04611, 0, 0.385],
    710: [0, 0.69444, 0.06709, 0, 0.59111],
    711: [0, 0.63194, 0.08271, 0, 0.59111],
    713: [0, 0.59444, 0.10444, 0, 0.59111],
    714: [0, 0.69444, 0.08528, 0, 0.59111],
    715: [0, 0.69444, 0, 0, 0.59111],
    728: [0, 0.69444, 0.10333, 0, 0.59111],
    729: [0, 0.69444, 0.12945, 0, 0.35555],
    730: [0, 0.69444, 0, 0, 0.94888],
    732: [0, 0.69444, 0.11472, 0, 0.59111],
    733: [0, 0.69444, 0.11472, 0, 0.59111],
    915: [0, 0.68611, 0.12903, 0, 0.69777],
    916: [0, 0.68611, 0, 0, 0.94444],
    920: [0, 0.68611, 0.09062, 0, 0.88555],
    923: [0, 0.68611, 0, 0, 0.80666],
    926: [0, 0.68611, 0.15092, 0, 0.76777],
    928: [0, 0.68611, 0.17208, 0, 0.8961],
    931: [0, 0.68611, 0.11431, 0, 0.82666],
    933: [0, 0.68611, 0.10778, 0, 0.88555],
    934: [0, 0.68611, 0.05632, 0, 0.82666],
    936: [0, 0.68611, 0.10778, 0, 0.88555],
    937: [0, 0.68611, 0.0992, 0, 0.82666],
    8211: [0, 0.44444, 0.09811, 0, 0.59111],
    8212: [0, 0.44444, 0.09811, 0, 1.18221],
    8216: [0, 0.69444, 0.12945, 0, 0.35555],
    8217: [0, 0.69444, 0.12945, 0, 0.35555],
    8220: [0, 0.69444, 0.16772, 0, 0.62055],
    8221: [0, 0.69444, 0.07939, 0, 0.62055]
  },
  "Main-Italic": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0.12417, 0, 0.30667],
    34: [0, 0.69444, 0.06961, 0, 0.51444],
    35: [0.19444, 0.69444, 0.06616, 0, 0.81777],
    37: [0.05556, 0.75, 0.13639, 0, 0.81777],
    38: [0, 0.69444, 0.09694, 0, 0.76666],
    39: [0, 0.69444, 0.12417, 0, 0.30667],
    40: [0.25, 0.75, 0.16194, 0, 0.40889],
    41: [0.25, 0.75, 0.03694, 0, 0.40889],
    42: [0, 0.75, 0.14917, 0, 0.51111],
    43: [0.05667, 0.56167, 0.03694, 0, 0.76666],
    44: [0.19444, 0.10556, 0, 0, 0.30667],
    45: [0, 0.43056, 0.02826, 0, 0.35778],
    46: [0, 0.10556, 0, 0, 0.30667],
    47: [0.25, 0.75, 0.16194, 0, 0.51111],
    48: [0, 0.64444, 0.13556, 0, 0.51111],
    49: [0, 0.64444, 0.13556, 0, 0.51111],
    50: [0, 0.64444, 0.13556, 0, 0.51111],
    51: [0, 0.64444, 0.13556, 0, 0.51111],
    52: [0.19444, 0.64444, 0.13556, 0, 0.51111],
    53: [0, 0.64444, 0.13556, 0, 0.51111],
    54: [0, 0.64444, 0.13556, 0, 0.51111],
    55: [0.19444, 0.64444, 0.13556, 0, 0.51111],
    56: [0, 0.64444, 0.13556, 0, 0.51111],
    57: [0, 0.64444, 0.13556, 0, 0.51111],
    58: [0, 0.43056, 0.0582, 0, 0.30667],
    59: [0.19444, 0.43056, 0.0582, 0, 0.30667],
    61: [-0.13313, 0.36687, 0.06616, 0, 0.76666],
    63: [0, 0.69444, 0.1225, 0, 0.51111],
    64: [0, 0.69444, 0.09597, 0, 0.76666],
    65: [0, 0.68333, 0, 0, 0.74333],
    66: [0, 0.68333, 0.10257, 0, 0.70389],
    67: [0, 0.68333, 0.14528, 0, 0.71555],
    68: [0, 0.68333, 0.09403, 0, 0.755],
    69: [0, 0.68333, 0.12028, 0, 0.67833],
    70: [0, 0.68333, 0.13305, 0, 0.65277],
    71: [0, 0.68333, 0.08722, 0, 0.77361],
    72: [0, 0.68333, 0.16389, 0, 0.74333],
    73: [0, 0.68333, 0.15806, 0, 0.38555],
    74: [0, 0.68333, 0.14028, 0, 0.525],
    75: [0, 0.68333, 0.14528, 0, 0.76888],
    76: [0, 0.68333, 0, 0, 0.62722],
    77: [0, 0.68333, 0.16389, 0, 0.89666],
    78: [0, 0.68333, 0.16389, 0, 0.74333],
    79: [0, 0.68333, 0.09403, 0, 0.76666],
    80: [0, 0.68333, 0.10257, 0, 0.67833],
    81: [0.19444, 0.68333, 0.09403, 0, 0.76666],
    82: [0, 0.68333, 0.03868, 0, 0.72944],
    83: [0, 0.68333, 0.11972, 0, 0.56222],
    84: [0, 0.68333, 0.13305, 0, 0.71555],
    85: [0, 0.68333, 0.16389, 0, 0.74333],
    86: [0, 0.68333, 0.18361, 0, 0.74333],
    87: [0, 0.68333, 0.18361, 0, 0.99888],
    88: [0, 0.68333, 0.15806, 0, 0.74333],
    89: [0, 0.68333, 0.19383, 0, 0.74333],
    90: [0, 0.68333, 0.14528, 0, 0.61333],
    91: [0.25, 0.75, 0.1875, 0, 0.30667],
    93: [0.25, 0.75, 0.10528, 0, 0.30667],
    94: [0, 0.69444, 0.06646, 0, 0.51111],
    95: [0.31, 0.12056, 0.09208, 0, 0.51111],
    97: [0, 0.43056, 0.07671, 0, 0.51111],
    98: [0, 0.69444, 0.06312, 0, 0.46],
    99: [0, 0.43056, 0.05653, 0, 0.46],
    100: [0, 0.69444, 0.10333, 0, 0.51111],
    101: [0, 0.43056, 0.07514, 0, 0.46],
    102: [0.19444, 0.69444, 0.21194, 0, 0.30667],
    103: [0.19444, 0.43056, 0.08847, 0, 0.46],
    104: [0, 0.69444, 0.07671, 0, 0.51111],
    105: [0, 0.65536, 0.1019, 0, 0.30667],
    106: [0.19444, 0.65536, 0.14467, 0, 0.30667],
    107: [0, 0.69444, 0.10764, 0, 0.46],
    108: [0, 0.69444, 0.10333, 0, 0.25555],
    109: [0, 0.43056, 0.07671, 0, 0.81777],
    110: [0, 0.43056, 0.07671, 0, 0.56222],
    111: [0, 0.43056, 0.06312, 0, 0.51111],
    112: [0.19444, 0.43056, 0.06312, 0, 0.51111],
    113: [0.19444, 0.43056, 0.08847, 0, 0.46],
    114: [0, 0.43056, 0.10764, 0, 0.42166],
    115: [0, 0.43056, 0.08208, 0, 0.40889],
    116: [0, 0.61508, 0.09486, 0, 0.33222],
    117: [0, 0.43056, 0.07671, 0, 0.53666],
    118: [0, 0.43056, 0.10764, 0, 0.46],
    119: [0, 0.43056, 0.10764, 0, 0.66444],
    120: [0, 0.43056, 0.12042, 0, 0.46389],
    121: [0.19444, 0.43056, 0.08847, 0, 0.48555],
    122: [0, 0.43056, 0.12292, 0, 0.40889],
    126: [0.35, 0.31786, 0.11585, 0, 0.51111],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.66786, 0.10474, 0, 0.51111],
    176: [0, 0.69444, 0, 0, 0.83129],
    184: [0.17014, 0, 0, 0, 0.46],
    198: [0, 0.68333, 0.12028, 0, 0.88277],
    216: [0.04861, 0.73194, 0.09403, 0, 0.76666],
    223: [0.19444, 0.69444, 0.10514, 0, 0.53666],
    230: [0, 0.43056, 0.07514, 0, 0.71555],
    248: [0.09722, 0.52778, 0.09194, 0, 0.51111],
    338: [0, 0.68333, 0.12028, 0, 0.98499],
    339: [0, 0.43056, 0.07514, 0, 0.71555],
    710: [0, 0.69444, 0.06646, 0, 0.51111],
    711: [0, 0.62847, 0.08295, 0, 0.51111],
    713: [0, 0.56167, 0.10333, 0, 0.51111],
    714: [0, 0.69444, 0.09694, 0, 0.51111],
    715: [0, 0.69444, 0, 0, 0.51111],
    728: [0, 0.69444, 0.10806, 0, 0.51111],
    729: [0, 0.66786, 0.11752, 0, 0.30667],
    730: [0, 0.69444, 0, 0, 0.83129],
    732: [0, 0.66786, 0.11585, 0, 0.51111],
    733: [0, 0.69444, 0.1225, 0, 0.51111],
    915: [0, 0.68333, 0.13305, 0, 0.62722],
    916: [0, 0.68333, 0, 0, 0.81777],
    920: [0, 0.68333, 0.09403, 0, 0.76666],
    923: [0, 0.68333, 0, 0, 0.69222],
    926: [0, 0.68333, 0.15294, 0, 0.66444],
    928: [0, 0.68333, 0.16389, 0, 0.74333],
    931: [0, 0.68333, 0.12028, 0, 0.71555],
    933: [0, 0.68333, 0.11111, 0, 0.76666],
    934: [0, 0.68333, 0.05986, 0, 0.71555],
    936: [0, 0.68333, 0.11111, 0, 0.76666],
    937: [0, 0.68333, 0.10257, 0, 0.71555],
    8211: [0, 0.43056, 0.09208, 0, 0.51111],
    8212: [0, 0.43056, 0.09208, 0, 1.02222],
    8216: [0, 0.69444, 0.12417, 0, 0.30667],
    8217: [0, 0.69444, 0.12417, 0, 0.30667],
    8220: [0, 0.69444, 0.1685, 0, 0.51444],
    8221: [0, 0.69444, 0.06961, 0, 0.51444],
    8463: [0, 0.68889, 0, 0, 0.54028]
  },
  "Main-Regular": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0, 0, 0.27778],
    34: [0, 0.69444, 0, 0, 0.5],
    35: [0.19444, 0.69444, 0, 0, 0.83334],
    36: [0.05556, 0.75, 0, 0, 0.5],
    37: [0.05556, 0.75, 0, 0, 0.83334],
    38: [0, 0.69444, 0, 0, 0.77778],
    39: [0, 0.69444, 0, 0, 0.27778],
    40: [0.25, 0.75, 0, 0, 0.38889],
    41: [0.25, 0.75, 0, 0, 0.38889],
    42: [0, 0.75, 0, 0, 0.5],
    43: [0.08333, 0.58333, 0, 0, 0.77778],
    44: [0.19444, 0.10556, 0, 0, 0.27778],
    45: [0, 0.43056, 0, 0, 0.33333],
    46: [0, 0.10556, 0, 0, 0.27778],
    47: [0.25, 0.75, 0, 0, 0.5],
    48: [0, 0.64444, 0, 0, 0.5],
    49: [0, 0.64444, 0, 0, 0.5],
    50: [0, 0.64444, 0, 0, 0.5],
    51: [0, 0.64444, 0, 0, 0.5],
    52: [0, 0.64444, 0, 0, 0.5],
    53: [0, 0.64444, 0, 0, 0.5],
    54: [0, 0.64444, 0, 0, 0.5],
    55: [0, 0.64444, 0, 0, 0.5],
    56: [0, 0.64444, 0, 0, 0.5],
    57: [0, 0.64444, 0, 0, 0.5],
    58: [0, 0.43056, 0, 0, 0.27778],
    59: [0.19444, 0.43056, 0, 0, 0.27778],
    60: [0.0391, 0.5391, 0, 0, 0.77778],
    61: [-0.13313, 0.36687, 0, 0, 0.77778],
    62: [0.0391, 0.5391, 0, 0, 0.77778],
    63: [0, 0.69444, 0, 0, 0.47222],
    64: [0, 0.69444, 0, 0, 0.77778],
    65: [0, 0.68333, 0, 0, 0.75],
    66: [0, 0.68333, 0, 0, 0.70834],
    67: [0, 0.68333, 0, 0, 0.72222],
    68: [0, 0.68333, 0, 0, 0.76389],
    69: [0, 0.68333, 0, 0, 0.68056],
    70: [0, 0.68333, 0, 0, 0.65278],
    71: [0, 0.68333, 0, 0, 0.78472],
    72: [0, 0.68333, 0, 0, 0.75],
    73: [0, 0.68333, 0, 0, 0.36111],
    74: [0, 0.68333, 0, 0, 0.51389],
    75: [0, 0.68333, 0, 0, 0.77778],
    76: [0, 0.68333, 0, 0, 0.625],
    77: [0, 0.68333, 0, 0, 0.91667],
    78: [0, 0.68333, 0, 0, 0.75],
    79: [0, 0.68333, 0, 0, 0.77778],
    80: [0, 0.68333, 0, 0, 0.68056],
    81: [0.19444, 0.68333, 0, 0, 0.77778],
    82: [0, 0.68333, 0, 0, 0.73611],
    83: [0, 0.68333, 0, 0, 0.55556],
    84: [0, 0.68333, 0, 0, 0.72222],
    85: [0, 0.68333, 0, 0, 0.75],
    86: [0, 0.68333, 0.01389, 0, 0.75],
    87: [0, 0.68333, 0.01389, 0, 1.02778],
    88: [0, 0.68333, 0, 0, 0.75],
    89: [0, 0.68333, 0.025, 0, 0.75],
    90: [0, 0.68333, 0, 0, 0.61111],
    91: [0.25, 0.75, 0, 0, 0.27778],
    92: [0.25, 0.75, 0, 0, 0.5],
    93: [0.25, 0.75, 0, 0, 0.27778],
    94: [0, 0.69444, 0, 0, 0.5],
    95: [0.31, 0.12056, 0.02778, 0, 0.5],
    97: [0, 0.43056, 0, 0, 0.5],
    98: [0, 0.69444, 0, 0, 0.55556],
    99: [0, 0.43056, 0, 0, 0.44445],
    100: [0, 0.69444, 0, 0, 0.55556],
    101: [0, 0.43056, 0, 0, 0.44445],
    102: [0, 0.69444, 0.07778, 0, 0.30556],
    103: [0.19444, 0.43056, 0.01389, 0, 0.5],
    104: [0, 0.69444, 0, 0, 0.55556],
    105: [0, 0.66786, 0, 0, 0.27778],
    106: [0.19444, 0.66786, 0, 0, 0.30556],
    107: [0, 0.69444, 0, 0, 0.52778],
    108: [0, 0.69444, 0, 0, 0.27778],
    109: [0, 0.43056, 0, 0, 0.83334],
    110: [0, 0.43056, 0, 0, 0.55556],
    111: [0, 0.43056, 0, 0, 0.5],
    112: [0.19444, 0.43056, 0, 0, 0.55556],
    113: [0.19444, 0.43056, 0, 0, 0.52778],
    114: [0, 0.43056, 0, 0, 0.39167],
    115: [0, 0.43056, 0, 0, 0.39445],
    116: [0, 0.61508, 0, 0, 0.38889],
    117: [0, 0.43056, 0, 0, 0.55556],
    118: [0, 0.43056, 0.01389, 0, 0.52778],
    119: [0, 0.43056, 0.01389, 0, 0.72222],
    120: [0, 0.43056, 0, 0, 0.52778],
    121: [0.19444, 0.43056, 0.01389, 0, 0.52778],
    122: [0, 0.43056, 0, 0, 0.44445],
    123: [0.25, 0.75, 0, 0, 0.5],
    124: [0.25, 0.75, 0, 0, 0.27778],
    125: [0.25, 0.75, 0, 0, 0.5],
    126: [0.35, 0.31786, 0, 0, 0.5],
    160: [0, 0, 0, 0, 0.25],
    163: [0, 0.69444, 0, 0, 0.76909],
    167: [0.19444, 0.69444, 0, 0, 0.44445],
    168: [0, 0.66786, 0, 0, 0.5],
    172: [0, 0.43056, 0, 0, 0.66667],
    176: [0, 0.69444, 0, 0, 0.75],
    177: [0.08333, 0.58333, 0, 0, 0.77778],
    182: [0.19444, 0.69444, 0, 0, 0.61111],
    184: [0.17014, 0, 0, 0, 0.44445],
    198: [0, 0.68333, 0, 0, 0.90278],
    215: [0.08333, 0.58333, 0, 0, 0.77778],
    216: [0.04861, 0.73194, 0, 0, 0.77778],
    223: [0, 0.69444, 0, 0, 0.5],
    230: [0, 0.43056, 0, 0, 0.72222],
    247: [0.08333, 0.58333, 0, 0, 0.77778],
    248: [0.09722, 0.52778, 0, 0, 0.5],
    305: [0, 0.43056, 0, 0, 0.27778],
    338: [0, 0.68333, 0, 0, 1.01389],
    339: [0, 0.43056, 0, 0, 0.77778],
    567: [0.19444, 0.43056, 0, 0, 0.30556],
    710: [0, 0.69444, 0, 0, 0.5],
    711: [0, 0.62847, 0, 0, 0.5],
    713: [0, 0.56778, 0, 0, 0.5],
    714: [0, 0.69444, 0, 0, 0.5],
    715: [0, 0.69444, 0, 0, 0.5],
    728: [0, 0.69444, 0, 0, 0.5],
    729: [0, 0.66786, 0, 0, 0.27778],
    730: [0, 0.69444, 0, 0, 0.75],
    732: [0, 0.66786, 0, 0, 0.5],
    733: [0, 0.69444, 0, 0, 0.5],
    915: [0, 0.68333, 0, 0, 0.625],
    916: [0, 0.68333, 0, 0, 0.83334],
    920: [0, 0.68333, 0, 0, 0.77778],
    923: [0, 0.68333, 0, 0, 0.69445],
    926: [0, 0.68333, 0, 0, 0.66667],
    928: [0, 0.68333, 0, 0, 0.75],
    931: [0, 0.68333, 0, 0, 0.72222],
    933: [0, 0.68333, 0, 0, 0.77778],
    934: [0, 0.68333, 0, 0, 0.72222],
    936: [0, 0.68333, 0, 0, 0.77778],
    937: [0, 0.68333, 0, 0, 0.72222],
    8211: [0, 0.43056, 0.02778, 0, 0.5],
    8212: [0, 0.43056, 0.02778, 0, 1],
    8216: [0, 0.69444, 0, 0, 0.27778],
    8217: [0, 0.69444, 0, 0, 0.27778],
    8220: [0, 0.69444, 0, 0, 0.5],
    8221: [0, 0.69444, 0, 0, 0.5],
    8224: [0.19444, 0.69444, 0, 0, 0.44445],
    8225: [0.19444, 0.69444, 0, 0, 0.44445],
    8230: [0, 0.123, 0, 0, 1.172],
    8242: [0, 0.55556, 0, 0, 0.275],
    8407: [0, 0.71444, 0.15382, 0, 0.5],
    8463: [0, 0.68889, 0, 0, 0.54028],
    8465: [0, 0.69444, 0, 0, 0.72222],
    8467: [0, 0.69444, 0, 0.11111, 0.41667],
    8472: [0.19444, 0.43056, 0, 0.11111, 0.63646],
    8476: [0, 0.69444, 0, 0, 0.72222],
    8501: [0, 0.69444, 0, 0, 0.61111],
    8592: [-0.13313, 0.36687, 0, 0, 1],
    8593: [0.19444, 0.69444, 0, 0, 0.5],
    8594: [-0.13313, 0.36687, 0, 0, 1],
    8595: [0.19444, 0.69444, 0, 0, 0.5],
    8596: [-0.13313, 0.36687, 0, 0, 1],
    8597: [0.25, 0.75, 0, 0, 0.5],
    8598: [0.19444, 0.69444, 0, 0, 1],
    8599: [0.19444, 0.69444, 0, 0, 1],
    8600: [0.19444, 0.69444, 0, 0, 1],
    8601: [0.19444, 0.69444, 0, 0, 1],
    8614: [0.011, 0.511, 0, 0, 1],
    8617: [0.011, 0.511, 0, 0, 1.126],
    8618: [0.011, 0.511, 0, 0, 1.126],
    8636: [-0.13313, 0.36687, 0, 0, 1],
    8637: [-0.13313, 0.36687, 0, 0, 1],
    8640: [-0.13313, 0.36687, 0, 0, 1],
    8641: [-0.13313, 0.36687, 0, 0, 1],
    8652: [0.011, 0.671, 0, 0, 1],
    8656: [-0.13313, 0.36687, 0, 0, 1],
    8657: [0.19444, 0.69444, 0, 0, 0.61111],
    8658: [-0.13313, 0.36687, 0, 0, 1],
    8659: [0.19444, 0.69444, 0, 0, 0.61111],
    8660: [-0.13313, 0.36687, 0, 0, 1],
    8661: [0.25, 0.75, 0, 0, 0.61111],
    8704: [0, 0.69444, 0, 0, 0.55556],
    8706: [0, 0.69444, 0.05556, 0.08334, 0.5309],
    8707: [0, 0.69444, 0, 0, 0.55556],
    8709: [0.05556, 0.75, 0, 0, 0.5],
    8711: [0, 0.68333, 0, 0, 0.83334],
    8712: [0.0391, 0.5391, 0, 0, 0.66667],
    8715: [0.0391, 0.5391, 0, 0, 0.66667],
    8722: [0.08333, 0.58333, 0, 0, 0.77778],
    8723: [0.08333, 0.58333, 0, 0, 0.77778],
    8725: [0.25, 0.75, 0, 0, 0.5],
    8726: [0.25, 0.75, 0, 0, 0.5],
    8727: [-0.03472, 0.46528, 0, 0, 0.5],
    8728: [-0.05555, 0.44445, 0, 0, 0.5],
    8729: [-0.05555, 0.44445, 0, 0, 0.5],
    8730: [0.2, 0.8, 0, 0, 0.83334],
    8733: [0, 0.43056, 0, 0, 0.77778],
    8734: [0, 0.43056, 0, 0, 1],
    8736: [0, 0.69224, 0, 0, 0.72222],
    8739: [0.25, 0.75, 0, 0, 0.27778],
    8741: [0.25, 0.75, 0, 0, 0.5],
    8743: [0, 0.55556, 0, 0, 0.66667],
    8744: [0, 0.55556, 0, 0, 0.66667],
    8745: [0, 0.55556, 0, 0, 0.66667],
    8746: [0, 0.55556, 0, 0, 0.66667],
    8747: [0.19444, 0.69444, 0.11111, 0, 0.41667],
    8764: [-0.13313, 0.36687, 0, 0, 0.77778],
    8768: [0.19444, 0.69444, 0, 0, 0.27778],
    8771: [-0.03625, 0.46375, 0, 0, 0.77778],
    8773: [-0.022, 0.589, 0, 0, 0.778],
    8776: [-0.01688, 0.48312, 0, 0, 0.77778],
    8781: [-0.03625, 0.46375, 0, 0, 0.77778],
    8784: [-0.133, 0.673, 0, 0, 0.778],
    8801: [-0.03625, 0.46375, 0, 0, 0.77778],
    8804: [0.13597, 0.63597, 0, 0, 0.77778],
    8805: [0.13597, 0.63597, 0, 0, 0.77778],
    8810: [0.0391, 0.5391, 0, 0, 1],
    8811: [0.0391, 0.5391, 0, 0, 1],
    8826: [0.0391, 0.5391, 0, 0, 0.77778],
    8827: [0.0391, 0.5391, 0, 0, 0.77778],
    8834: [0.0391, 0.5391, 0, 0, 0.77778],
    8835: [0.0391, 0.5391, 0, 0, 0.77778],
    8838: [0.13597, 0.63597, 0, 0, 0.77778],
    8839: [0.13597, 0.63597, 0, 0, 0.77778],
    8846: [0, 0.55556, 0, 0, 0.66667],
    8849: [0.13597, 0.63597, 0, 0, 0.77778],
    8850: [0.13597, 0.63597, 0, 0, 0.77778],
    8851: [0, 0.55556, 0, 0, 0.66667],
    8852: [0, 0.55556, 0, 0, 0.66667],
    8853: [0.08333, 0.58333, 0, 0, 0.77778],
    8854: [0.08333, 0.58333, 0, 0, 0.77778],
    8855: [0.08333, 0.58333, 0, 0, 0.77778],
    8856: [0.08333, 0.58333, 0, 0, 0.77778],
    8857: [0.08333, 0.58333, 0, 0, 0.77778],
    8866: [0, 0.69444, 0, 0, 0.61111],
    8867: [0, 0.69444, 0, 0, 0.61111],
    8868: [0, 0.69444, 0, 0, 0.77778],
    8869: [0, 0.69444, 0, 0, 0.77778],
    8872: [0.249, 0.75, 0, 0, 0.867],
    8900: [-0.05555, 0.44445, 0, 0, 0.5],
    8901: [-0.05555, 0.44445, 0, 0, 0.27778],
    8902: [-0.03472, 0.46528, 0, 0, 0.5],
    8904: [5e-3, 0.505, 0, 0, 0.9],
    8942: [0.03, 0.903, 0, 0, 0.278],
    8943: [-0.19, 0.313, 0, 0, 1.172],
    8945: [-0.1, 0.823, 0, 0, 1.282],
    8968: [0.25, 0.75, 0, 0, 0.44445],
    8969: [0.25, 0.75, 0, 0, 0.44445],
    8970: [0.25, 0.75, 0, 0, 0.44445],
    8971: [0.25, 0.75, 0, 0, 0.44445],
    8994: [-0.14236, 0.35764, 0, 0, 1],
    8995: [-0.14236, 0.35764, 0, 0, 1],
    9136: [0.244, 0.744, 0, 0, 0.412],
    9137: [0.244, 0.745, 0, 0, 0.412],
    9651: [0.19444, 0.69444, 0, 0, 0.88889],
    9657: [-0.03472, 0.46528, 0, 0, 0.5],
    9661: [0.19444, 0.69444, 0, 0, 0.88889],
    9667: [-0.03472, 0.46528, 0, 0, 0.5],
    9711: [0.19444, 0.69444, 0, 0, 1],
    9824: [0.12963, 0.69444, 0, 0, 0.77778],
    9825: [0.12963, 0.69444, 0, 0, 0.77778],
    9826: [0.12963, 0.69444, 0, 0, 0.77778],
    9827: [0.12963, 0.69444, 0, 0, 0.77778],
    9837: [0, 0.75, 0, 0, 0.38889],
    9838: [0.19444, 0.69444, 0, 0, 0.38889],
    9839: [0.19444, 0.69444, 0, 0, 0.38889],
    10216: [0.25, 0.75, 0, 0, 0.38889],
    10217: [0.25, 0.75, 0, 0, 0.38889],
    10222: [0.244, 0.744, 0, 0, 0.412],
    10223: [0.244, 0.745, 0, 0, 0.412],
    10229: [0.011, 0.511, 0, 0, 1.609],
    10230: [0.011, 0.511, 0, 0, 1.638],
    10231: [0.011, 0.511, 0, 0, 1.859],
    10232: [0.024, 0.525, 0, 0, 1.609],
    10233: [0.024, 0.525, 0, 0, 1.638],
    10234: [0.024, 0.525, 0, 0, 1.858],
    10236: [0.011, 0.511, 0, 0, 1.638],
    10815: [0, 0.68333, 0, 0, 0.75],
    10927: [0.13597, 0.63597, 0, 0, 0.77778],
    10928: [0.13597, 0.63597, 0, 0, 0.77778],
    57376: [0.19444, 0.69444, 0, 0, 0]
  },
  "Math-BoldItalic": {
    32: [0, 0, 0, 0, 0.25],
    48: [0, 0.44444, 0, 0, 0.575],
    49: [0, 0.44444, 0, 0, 0.575],
    50: [0, 0.44444, 0, 0, 0.575],
    51: [0.19444, 0.44444, 0, 0, 0.575],
    52: [0.19444, 0.44444, 0, 0, 0.575],
    53: [0.19444, 0.44444, 0, 0, 0.575],
    54: [0, 0.64444, 0, 0, 0.575],
    55: [0.19444, 0.44444, 0, 0, 0.575],
    56: [0, 0.64444, 0, 0, 0.575],
    57: [0.19444, 0.44444, 0, 0, 0.575],
    65: [0, 0.68611, 0, 0, 0.86944],
    66: [0, 0.68611, 0.04835, 0, 0.8664],
    67: [0, 0.68611, 0.06979, 0, 0.81694],
    68: [0, 0.68611, 0.03194, 0, 0.93812],
    69: [0, 0.68611, 0.05451, 0, 0.81007],
    70: [0, 0.68611, 0.15972, 0, 0.68889],
    71: [0, 0.68611, 0, 0, 0.88673],
    72: [0, 0.68611, 0.08229, 0, 0.98229],
    73: [0, 0.68611, 0.07778, 0, 0.51111],
    74: [0, 0.68611, 0.10069, 0, 0.63125],
    75: [0, 0.68611, 0.06979, 0, 0.97118],
    76: [0, 0.68611, 0, 0, 0.75555],
    77: [0, 0.68611, 0.11424, 0, 1.14201],
    78: [0, 0.68611, 0.11424, 0, 0.95034],
    79: [0, 0.68611, 0.03194, 0, 0.83666],
    80: [0, 0.68611, 0.15972, 0, 0.72309],
    81: [0.19444, 0.68611, 0, 0, 0.86861],
    82: [0, 0.68611, 421e-5, 0, 0.87235],
    83: [0, 0.68611, 0.05382, 0, 0.69271],
    84: [0, 0.68611, 0.15972, 0, 0.63663],
    85: [0, 0.68611, 0.11424, 0, 0.80027],
    86: [0, 0.68611, 0.25555, 0, 0.67778],
    87: [0, 0.68611, 0.15972, 0, 1.09305],
    88: [0, 0.68611, 0.07778, 0, 0.94722],
    89: [0, 0.68611, 0.25555, 0, 0.67458],
    90: [0, 0.68611, 0.06979, 0, 0.77257],
    97: [0, 0.44444, 0, 0, 0.63287],
    98: [0, 0.69444, 0, 0, 0.52083],
    99: [0, 0.44444, 0, 0, 0.51342],
    100: [0, 0.69444, 0, 0, 0.60972],
    101: [0, 0.44444, 0, 0, 0.55361],
    102: [0.19444, 0.69444, 0.11042, 0, 0.56806],
    103: [0.19444, 0.44444, 0.03704, 0, 0.5449],
    104: [0, 0.69444, 0, 0, 0.66759],
    105: [0, 0.69326, 0, 0, 0.4048],
    106: [0.19444, 0.69326, 0.0622, 0, 0.47083],
    107: [0, 0.69444, 0.01852, 0, 0.6037],
    108: [0, 0.69444, 88e-4, 0, 0.34815],
    109: [0, 0.44444, 0, 0, 1.0324],
    110: [0, 0.44444, 0, 0, 0.71296],
    111: [0, 0.44444, 0, 0, 0.58472],
    112: [0.19444, 0.44444, 0, 0, 0.60092],
    113: [0.19444, 0.44444, 0.03704, 0, 0.54213],
    114: [0, 0.44444, 0.03194, 0, 0.5287],
    115: [0, 0.44444, 0, 0, 0.53125],
    116: [0, 0.63492, 0, 0, 0.41528],
    117: [0, 0.44444, 0, 0, 0.68102],
    118: [0, 0.44444, 0.03704, 0, 0.56666],
    119: [0, 0.44444, 0.02778, 0, 0.83148],
    120: [0, 0.44444, 0, 0, 0.65903],
    121: [0.19444, 0.44444, 0.03704, 0, 0.59028],
    122: [0, 0.44444, 0.04213, 0, 0.55509],
    160: [0, 0, 0, 0, 0.25],
    915: [0, 0.68611, 0.15972, 0, 0.65694],
    916: [0, 0.68611, 0, 0, 0.95833],
    920: [0, 0.68611, 0.03194, 0, 0.86722],
    923: [0, 0.68611, 0, 0, 0.80555],
    926: [0, 0.68611, 0.07458, 0, 0.84125],
    928: [0, 0.68611, 0.08229, 0, 0.98229],
    931: [0, 0.68611, 0.05451, 0, 0.88507],
    933: [0, 0.68611, 0.15972, 0, 0.67083],
    934: [0, 0.68611, 0, 0, 0.76666],
    936: [0, 0.68611, 0.11653, 0, 0.71402],
    937: [0, 0.68611, 0.04835, 0, 0.8789],
    945: [0, 0.44444, 0, 0, 0.76064],
    946: [0.19444, 0.69444, 0.03403, 0, 0.65972],
    947: [0.19444, 0.44444, 0.06389, 0, 0.59003],
    948: [0, 0.69444, 0.03819, 0, 0.52222],
    949: [0, 0.44444, 0, 0, 0.52882],
    950: [0.19444, 0.69444, 0.06215, 0, 0.50833],
    951: [0.19444, 0.44444, 0.03704, 0, 0.6],
    952: [0, 0.69444, 0.03194, 0, 0.5618],
    953: [0, 0.44444, 0, 0, 0.41204],
    954: [0, 0.44444, 0, 0, 0.66759],
    955: [0, 0.69444, 0, 0, 0.67083],
    956: [0.19444, 0.44444, 0, 0, 0.70787],
    957: [0, 0.44444, 0.06898, 0, 0.57685],
    958: [0.19444, 0.69444, 0.03021, 0, 0.50833],
    959: [0, 0.44444, 0, 0, 0.58472],
    960: [0, 0.44444, 0.03704, 0, 0.68241],
    961: [0.19444, 0.44444, 0, 0, 0.6118],
    962: [0.09722, 0.44444, 0.07917, 0, 0.42361],
    963: [0, 0.44444, 0.03704, 0, 0.68588],
    964: [0, 0.44444, 0.13472, 0, 0.52083],
    965: [0, 0.44444, 0.03704, 0, 0.63055],
    966: [0.19444, 0.44444, 0, 0, 0.74722],
    967: [0.19444, 0.44444, 0, 0, 0.71805],
    968: [0.19444, 0.69444, 0.03704, 0, 0.75833],
    969: [0, 0.44444, 0.03704, 0, 0.71782],
    977: [0, 0.69444, 0, 0, 0.69155],
    981: [0.19444, 0.69444, 0, 0, 0.7125],
    982: [0, 0.44444, 0.03194, 0, 0.975],
    1009: [0.19444, 0.44444, 0, 0, 0.6118],
    1013: [0, 0.44444, 0, 0, 0.48333],
    57649: [0, 0.44444, 0, 0, 0.39352],
    57911: [0.19444, 0.44444, 0, 0, 0.43889]
  },
  "Math-Italic": {
    32: [0, 0, 0, 0, 0.25],
    48: [0, 0.43056, 0, 0, 0.5],
    49: [0, 0.43056, 0, 0, 0.5],
    50: [0, 0.43056, 0, 0, 0.5],
    51: [0.19444, 0.43056, 0, 0, 0.5],
    52: [0.19444, 0.43056, 0, 0, 0.5],
    53: [0.19444, 0.43056, 0, 0, 0.5],
    54: [0, 0.64444, 0, 0, 0.5],
    55: [0.19444, 0.43056, 0, 0, 0.5],
    56: [0, 0.64444, 0, 0, 0.5],
    57: [0.19444, 0.43056, 0, 0, 0.5],
    65: [0, 0.68333, 0, 0.13889, 0.75],
    66: [0, 0.68333, 0.05017, 0.08334, 0.75851],
    67: [0, 0.68333, 0.07153, 0.08334, 0.71472],
    68: [0, 0.68333, 0.02778, 0.05556, 0.82792],
    69: [0, 0.68333, 0.05764, 0.08334, 0.7382],
    70: [0, 0.68333, 0.13889, 0.08334, 0.64306],
    71: [0, 0.68333, 0, 0.08334, 0.78625],
    72: [0, 0.68333, 0.08125, 0.05556, 0.83125],
    73: [0, 0.68333, 0.07847, 0.11111, 0.43958],
    74: [0, 0.68333, 0.09618, 0.16667, 0.55451],
    75: [0, 0.68333, 0.07153, 0.05556, 0.84931],
    76: [0, 0.68333, 0, 0.02778, 0.68056],
    77: [0, 0.68333, 0.10903, 0.08334, 0.97014],
    78: [0, 0.68333, 0.10903, 0.08334, 0.80347],
    79: [0, 0.68333, 0.02778, 0.08334, 0.76278],
    80: [0, 0.68333, 0.13889, 0.08334, 0.64201],
    81: [0.19444, 0.68333, 0, 0.08334, 0.79056],
    82: [0, 0.68333, 773e-5, 0.08334, 0.75929],
    83: [0, 0.68333, 0.05764, 0.08334, 0.6132],
    84: [0, 0.68333, 0.13889, 0.08334, 0.58438],
    85: [0, 0.68333, 0.10903, 0.02778, 0.68278],
    86: [0, 0.68333, 0.22222, 0, 0.58333],
    87: [0, 0.68333, 0.13889, 0, 0.94445],
    88: [0, 0.68333, 0.07847, 0.08334, 0.82847],
    89: [0, 0.68333, 0.22222, 0, 0.58056],
    90: [0, 0.68333, 0.07153, 0.08334, 0.68264],
    97: [0, 0.43056, 0, 0, 0.52859],
    98: [0, 0.69444, 0, 0, 0.42917],
    99: [0, 0.43056, 0, 0.05556, 0.43276],
    100: [0, 0.69444, 0, 0.16667, 0.52049],
    101: [0, 0.43056, 0, 0.05556, 0.46563],
    102: [0.19444, 0.69444, 0.10764, 0.16667, 0.48959],
    103: [0.19444, 0.43056, 0.03588, 0.02778, 0.47697],
    104: [0, 0.69444, 0, 0, 0.57616],
    105: [0, 0.65952, 0, 0, 0.34451],
    106: [0.19444, 0.65952, 0.05724, 0, 0.41181],
    107: [0, 0.69444, 0.03148, 0, 0.5206],
    108: [0, 0.69444, 0.01968, 0.08334, 0.29838],
    109: [0, 0.43056, 0, 0, 0.87801],
    110: [0, 0.43056, 0, 0, 0.60023],
    111: [0, 0.43056, 0, 0.05556, 0.48472],
    112: [0.19444, 0.43056, 0, 0.08334, 0.50313],
    113: [0.19444, 0.43056, 0.03588, 0.08334, 0.44641],
    114: [0, 0.43056, 0.02778, 0.05556, 0.45116],
    115: [0, 0.43056, 0, 0.05556, 0.46875],
    116: [0, 0.61508, 0, 0.08334, 0.36111],
    117: [0, 0.43056, 0, 0.02778, 0.57246],
    118: [0, 0.43056, 0.03588, 0.02778, 0.48472],
    119: [0, 0.43056, 0.02691, 0.08334, 0.71592],
    120: [0, 0.43056, 0, 0.02778, 0.57153],
    121: [0.19444, 0.43056, 0.03588, 0.05556, 0.49028],
    122: [0, 0.43056, 0.04398, 0.05556, 0.46505],
    160: [0, 0, 0, 0, 0.25],
    915: [0, 0.68333, 0.13889, 0.08334, 0.61528],
    916: [0, 0.68333, 0, 0.16667, 0.83334],
    920: [0, 0.68333, 0.02778, 0.08334, 0.76278],
    923: [0, 0.68333, 0, 0.16667, 0.69445],
    926: [0, 0.68333, 0.07569, 0.08334, 0.74236],
    928: [0, 0.68333, 0.08125, 0.05556, 0.83125],
    931: [0, 0.68333, 0.05764, 0.08334, 0.77986],
    933: [0, 0.68333, 0.13889, 0.05556, 0.58333],
    934: [0, 0.68333, 0, 0.08334, 0.66667],
    936: [0, 0.68333, 0.11, 0.05556, 0.61222],
    937: [0, 0.68333, 0.05017, 0.08334, 0.7724],
    945: [0, 0.43056, 37e-4, 0.02778, 0.6397],
    946: [0.19444, 0.69444, 0.05278, 0.08334, 0.56563],
    947: [0.19444, 0.43056, 0.05556, 0, 0.51773],
    948: [0, 0.69444, 0.03785, 0.05556, 0.44444],
    949: [0, 0.43056, 0, 0.08334, 0.46632],
    950: [0.19444, 0.69444, 0.07378, 0.08334, 0.4375],
    951: [0.19444, 0.43056, 0.03588, 0.05556, 0.49653],
    952: [0, 0.69444, 0.02778, 0.08334, 0.46944],
    953: [0, 0.43056, 0, 0.05556, 0.35394],
    954: [0, 0.43056, 0, 0, 0.57616],
    955: [0, 0.69444, 0, 0, 0.58334],
    956: [0.19444, 0.43056, 0, 0.02778, 0.60255],
    957: [0, 0.43056, 0.06366, 0.02778, 0.49398],
    958: [0.19444, 0.69444, 0.04601, 0.11111, 0.4375],
    959: [0, 0.43056, 0, 0.05556, 0.48472],
    960: [0, 0.43056, 0.03588, 0, 0.57003],
    961: [0.19444, 0.43056, 0, 0.08334, 0.51702],
    962: [0.09722, 0.43056, 0.07986, 0.08334, 0.36285],
    963: [0, 0.43056, 0.03588, 0, 0.57141],
    964: [0, 0.43056, 0.1132, 0.02778, 0.43715],
    965: [0, 0.43056, 0.03588, 0.02778, 0.54028],
    966: [0.19444, 0.43056, 0, 0.08334, 0.65417],
    967: [0.19444, 0.43056, 0, 0.05556, 0.62569],
    968: [0.19444, 0.69444, 0.03588, 0.11111, 0.65139],
    969: [0, 0.43056, 0.03588, 0, 0.62245],
    977: [0, 0.69444, 0, 0.08334, 0.59144],
    981: [0.19444, 0.69444, 0, 0.08334, 0.59583],
    982: [0, 0.43056, 0.02778, 0, 0.82813],
    1009: [0.19444, 0.43056, 0, 0.08334, 0.51702],
    1013: [0, 0.43056, 0, 0.05556, 0.4059],
    57649: [0, 0.43056, 0, 0.02778, 0.32246],
    57911: [0.19444, 0.43056, 0, 0.08334, 0.38403]
  },
  "SansSerif-Bold": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0, 0, 0.36667],
    34: [0, 0.69444, 0, 0, 0.55834],
    35: [0.19444, 0.69444, 0, 0, 0.91667],
    36: [0.05556, 0.75, 0, 0, 0.55],
    37: [0.05556, 0.75, 0, 0, 1.02912],
    38: [0, 0.69444, 0, 0, 0.83056],
    39: [0, 0.69444, 0, 0, 0.30556],
    40: [0.25, 0.75, 0, 0, 0.42778],
    41: [0.25, 0.75, 0, 0, 0.42778],
    42: [0, 0.75, 0, 0, 0.55],
    43: [0.11667, 0.61667, 0, 0, 0.85556],
    44: [0.10556, 0.13056, 0, 0, 0.30556],
    45: [0, 0.45833, 0, 0, 0.36667],
    46: [0, 0.13056, 0, 0, 0.30556],
    47: [0.25, 0.75, 0, 0, 0.55],
    48: [0, 0.69444, 0, 0, 0.55],
    49: [0, 0.69444, 0, 0, 0.55],
    50: [0, 0.69444, 0, 0, 0.55],
    51: [0, 0.69444, 0, 0, 0.55],
    52: [0, 0.69444, 0, 0, 0.55],
    53: [0, 0.69444, 0, 0, 0.55],
    54: [0, 0.69444, 0, 0, 0.55],
    55: [0, 0.69444, 0, 0, 0.55],
    56: [0, 0.69444, 0, 0, 0.55],
    57: [0, 0.69444, 0, 0, 0.55],
    58: [0, 0.45833, 0, 0, 0.30556],
    59: [0.10556, 0.45833, 0, 0, 0.30556],
    61: [-0.09375, 0.40625, 0, 0, 0.85556],
    63: [0, 0.69444, 0, 0, 0.51945],
    64: [0, 0.69444, 0, 0, 0.73334],
    65: [0, 0.69444, 0, 0, 0.73334],
    66: [0, 0.69444, 0, 0, 0.73334],
    67: [0, 0.69444, 0, 0, 0.70278],
    68: [0, 0.69444, 0, 0, 0.79445],
    69: [0, 0.69444, 0, 0, 0.64167],
    70: [0, 0.69444, 0, 0, 0.61111],
    71: [0, 0.69444, 0, 0, 0.73334],
    72: [0, 0.69444, 0, 0, 0.79445],
    73: [0, 0.69444, 0, 0, 0.33056],
    74: [0, 0.69444, 0, 0, 0.51945],
    75: [0, 0.69444, 0, 0, 0.76389],
    76: [0, 0.69444, 0, 0, 0.58056],
    77: [0, 0.69444, 0, 0, 0.97778],
    78: [0, 0.69444, 0, 0, 0.79445],
    79: [0, 0.69444, 0, 0, 0.79445],
    80: [0, 0.69444, 0, 0, 0.70278],
    81: [0.10556, 0.69444, 0, 0, 0.79445],
    82: [0, 0.69444, 0, 0, 0.70278],
    83: [0, 0.69444, 0, 0, 0.61111],
    84: [0, 0.69444, 0, 0, 0.73334],
    85: [0, 0.69444, 0, 0, 0.76389],
    86: [0, 0.69444, 0.01528, 0, 0.73334],
    87: [0, 0.69444, 0.01528, 0, 1.03889],
    88: [0, 0.69444, 0, 0, 0.73334],
    89: [0, 0.69444, 0.0275, 0, 0.73334],
    90: [0, 0.69444, 0, 0, 0.67223],
    91: [0.25, 0.75, 0, 0, 0.34306],
    93: [0.25, 0.75, 0, 0, 0.34306],
    94: [0, 0.69444, 0, 0, 0.55],
    95: [0.35, 0.10833, 0.03056, 0, 0.55],
    97: [0, 0.45833, 0, 0, 0.525],
    98: [0, 0.69444, 0, 0, 0.56111],
    99: [0, 0.45833, 0, 0, 0.48889],
    100: [0, 0.69444, 0, 0, 0.56111],
    101: [0, 0.45833, 0, 0, 0.51111],
    102: [0, 0.69444, 0.07639, 0, 0.33611],
    103: [0.19444, 0.45833, 0.01528, 0, 0.55],
    104: [0, 0.69444, 0, 0, 0.56111],
    105: [0, 0.69444, 0, 0, 0.25556],
    106: [0.19444, 0.69444, 0, 0, 0.28611],
    107: [0, 0.69444, 0, 0, 0.53056],
    108: [0, 0.69444, 0, 0, 0.25556],
    109: [0, 0.45833, 0, 0, 0.86667],
    110: [0, 0.45833, 0, 0, 0.56111],
    111: [0, 0.45833, 0, 0, 0.55],
    112: [0.19444, 0.45833, 0, 0, 0.56111],
    113: [0.19444, 0.45833, 0, 0, 0.56111],
    114: [0, 0.45833, 0.01528, 0, 0.37222],
    115: [0, 0.45833, 0, 0, 0.42167],
    116: [0, 0.58929, 0, 0, 0.40417],
    117: [0, 0.45833, 0, 0, 0.56111],
    118: [0, 0.45833, 0.01528, 0, 0.5],
    119: [0, 0.45833, 0.01528, 0, 0.74445],
    120: [0, 0.45833, 0, 0, 0.5],
    121: [0.19444, 0.45833, 0.01528, 0, 0.5],
    122: [0, 0.45833, 0, 0, 0.47639],
    126: [0.35, 0.34444, 0, 0, 0.55],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.69444, 0, 0, 0.55],
    176: [0, 0.69444, 0, 0, 0.73334],
    180: [0, 0.69444, 0, 0, 0.55],
    184: [0.17014, 0, 0, 0, 0.48889],
    305: [0, 0.45833, 0, 0, 0.25556],
    567: [0.19444, 0.45833, 0, 0, 0.28611],
    710: [0, 0.69444, 0, 0, 0.55],
    711: [0, 0.63542, 0, 0, 0.55],
    713: [0, 0.63778, 0, 0, 0.55],
    728: [0, 0.69444, 0, 0, 0.55],
    729: [0, 0.69444, 0, 0, 0.30556],
    730: [0, 0.69444, 0, 0, 0.73334],
    732: [0, 0.69444, 0, 0, 0.55],
    733: [0, 0.69444, 0, 0, 0.55],
    915: [0, 0.69444, 0, 0, 0.58056],
    916: [0, 0.69444, 0, 0, 0.91667],
    920: [0, 0.69444, 0, 0, 0.85556],
    923: [0, 0.69444, 0, 0, 0.67223],
    926: [0, 0.69444, 0, 0, 0.73334],
    928: [0, 0.69444, 0, 0, 0.79445],
    931: [0, 0.69444, 0, 0, 0.79445],
    933: [0, 0.69444, 0, 0, 0.85556],
    934: [0, 0.69444, 0, 0, 0.79445],
    936: [0, 0.69444, 0, 0, 0.85556],
    937: [0, 0.69444, 0, 0, 0.79445],
    8211: [0, 0.45833, 0.03056, 0, 0.55],
    8212: [0, 0.45833, 0.03056, 0, 1.10001],
    8216: [0, 0.69444, 0, 0, 0.30556],
    8217: [0, 0.69444, 0, 0, 0.30556],
    8220: [0, 0.69444, 0, 0, 0.55834],
    8221: [0, 0.69444, 0, 0, 0.55834]
  },
  "SansSerif-Italic": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0.05733, 0, 0.31945],
    34: [0, 0.69444, 316e-5, 0, 0.5],
    35: [0.19444, 0.69444, 0.05087, 0, 0.83334],
    36: [0.05556, 0.75, 0.11156, 0, 0.5],
    37: [0.05556, 0.75, 0.03126, 0, 0.83334],
    38: [0, 0.69444, 0.03058, 0, 0.75834],
    39: [0, 0.69444, 0.07816, 0, 0.27778],
    40: [0.25, 0.75, 0.13164, 0, 0.38889],
    41: [0.25, 0.75, 0.02536, 0, 0.38889],
    42: [0, 0.75, 0.11775, 0, 0.5],
    43: [0.08333, 0.58333, 0.02536, 0, 0.77778],
    44: [0.125, 0.08333, 0, 0, 0.27778],
    45: [0, 0.44444, 0.01946, 0, 0.33333],
    46: [0, 0.08333, 0, 0, 0.27778],
    47: [0.25, 0.75, 0.13164, 0, 0.5],
    48: [0, 0.65556, 0.11156, 0, 0.5],
    49: [0, 0.65556, 0.11156, 0, 0.5],
    50: [0, 0.65556, 0.11156, 0, 0.5],
    51: [0, 0.65556, 0.11156, 0, 0.5],
    52: [0, 0.65556, 0.11156, 0, 0.5],
    53: [0, 0.65556, 0.11156, 0, 0.5],
    54: [0, 0.65556, 0.11156, 0, 0.5],
    55: [0, 0.65556, 0.11156, 0, 0.5],
    56: [0, 0.65556, 0.11156, 0, 0.5],
    57: [0, 0.65556, 0.11156, 0, 0.5],
    58: [0, 0.44444, 0.02502, 0, 0.27778],
    59: [0.125, 0.44444, 0.02502, 0, 0.27778],
    61: [-0.13, 0.37, 0.05087, 0, 0.77778],
    63: [0, 0.69444, 0.11809, 0, 0.47222],
    64: [0, 0.69444, 0.07555, 0, 0.66667],
    65: [0, 0.69444, 0, 0, 0.66667],
    66: [0, 0.69444, 0.08293, 0, 0.66667],
    67: [0, 0.69444, 0.11983, 0, 0.63889],
    68: [0, 0.69444, 0.07555, 0, 0.72223],
    69: [0, 0.69444, 0.11983, 0, 0.59722],
    70: [0, 0.69444, 0.13372, 0, 0.56945],
    71: [0, 0.69444, 0.11983, 0, 0.66667],
    72: [0, 0.69444, 0.08094, 0, 0.70834],
    73: [0, 0.69444, 0.13372, 0, 0.27778],
    74: [0, 0.69444, 0.08094, 0, 0.47222],
    75: [0, 0.69444, 0.11983, 0, 0.69445],
    76: [0, 0.69444, 0, 0, 0.54167],
    77: [0, 0.69444, 0.08094, 0, 0.875],
    78: [0, 0.69444, 0.08094, 0, 0.70834],
    79: [0, 0.69444, 0.07555, 0, 0.73611],
    80: [0, 0.69444, 0.08293, 0, 0.63889],
    81: [0.125, 0.69444, 0.07555, 0, 0.73611],
    82: [0, 0.69444, 0.08293, 0, 0.64584],
    83: [0, 0.69444, 0.09205, 0, 0.55556],
    84: [0, 0.69444, 0.13372, 0, 0.68056],
    85: [0, 0.69444, 0.08094, 0, 0.6875],
    86: [0, 0.69444, 0.1615, 0, 0.66667],
    87: [0, 0.69444, 0.1615, 0, 0.94445],
    88: [0, 0.69444, 0.13372, 0, 0.66667],
    89: [0, 0.69444, 0.17261, 0, 0.66667],
    90: [0, 0.69444, 0.11983, 0, 0.61111],
    91: [0.25, 0.75, 0.15942, 0, 0.28889],
    93: [0.25, 0.75, 0.08719, 0, 0.28889],
    94: [0, 0.69444, 0.0799, 0, 0.5],
    95: [0.35, 0.09444, 0.08616, 0, 0.5],
    97: [0, 0.44444, 981e-5, 0, 0.48056],
    98: [0, 0.69444, 0.03057, 0, 0.51667],
    99: [0, 0.44444, 0.08336, 0, 0.44445],
    100: [0, 0.69444, 0.09483, 0, 0.51667],
    101: [0, 0.44444, 0.06778, 0, 0.44445],
    102: [0, 0.69444, 0.21705, 0, 0.30556],
    103: [0.19444, 0.44444, 0.10836, 0, 0.5],
    104: [0, 0.69444, 0.01778, 0, 0.51667],
    105: [0, 0.67937, 0.09718, 0, 0.23889],
    106: [0.19444, 0.67937, 0.09162, 0, 0.26667],
    107: [0, 0.69444, 0.08336, 0, 0.48889],
    108: [0, 0.69444, 0.09483, 0, 0.23889],
    109: [0, 0.44444, 0.01778, 0, 0.79445],
    110: [0, 0.44444, 0.01778, 0, 0.51667],
    111: [0, 0.44444, 0.06613, 0, 0.5],
    112: [0.19444, 0.44444, 0.0389, 0, 0.51667],
    113: [0.19444, 0.44444, 0.04169, 0, 0.51667],
    114: [0, 0.44444, 0.10836, 0, 0.34167],
    115: [0, 0.44444, 0.0778, 0, 0.38333],
    116: [0, 0.57143, 0.07225, 0, 0.36111],
    117: [0, 0.44444, 0.04169, 0, 0.51667],
    118: [0, 0.44444, 0.10836, 0, 0.46111],
    119: [0, 0.44444, 0.10836, 0, 0.68334],
    120: [0, 0.44444, 0.09169, 0, 0.46111],
    121: [0.19444, 0.44444, 0.10836, 0, 0.46111],
    122: [0, 0.44444, 0.08752, 0, 0.43472],
    126: [0.35, 0.32659, 0.08826, 0, 0.5],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.67937, 0.06385, 0, 0.5],
    176: [0, 0.69444, 0, 0, 0.73752],
    184: [0.17014, 0, 0, 0, 0.44445],
    305: [0, 0.44444, 0.04169, 0, 0.23889],
    567: [0.19444, 0.44444, 0.04169, 0, 0.26667],
    710: [0, 0.69444, 0.0799, 0, 0.5],
    711: [0, 0.63194, 0.08432, 0, 0.5],
    713: [0, 0.60889, 0.08776, 0, 0.5],
    714: [0, 0.69444, 0.09205, 0, 0.5],
    715: [0, 0.69444, 0, 0, 0.5],
    728: [0, 0.69444, 0.09483, 0, 0.5],
    729: [0, 0.67937, 0.07774, 0, 0.27778],
    730: [0, 0.69444, 0, 0, 0.73752],
    732: [0, 0.67659, 0.08826, 0, 0.5],
    733: [0, 0.69444, 0.09205, 0, 0.5],
    915: [0, 0.69444, 0.13372, 0, 0.54167],
    916: [0, 0.69444, 0, 0, 0.83334],
    920: [0, 0.69444, 0.07555, 0, 0.77778],
    923: [0, 0.69444, 0, 0, 0.61111],
    926: [0, 0.69444, 0.12816, 0, 0.66667],
    928: [0, 0.69444, 0.08094, 0, 0.70834],
    931: [0, 0.69444, 0.11983, 0, 0.72222],
    933: [0, 0.69444, 0.09031, 0, 0.77778],
    934: [0, 0.69444, 0.04603, 0, 0.72222],
    936: [0, 0.69444, 0.09031, 0, 0.77778],
    937: [0, 0.69444, 0.08293, 0, 0.72222],
    8211: [0, 0.44444, 0.08616, 0, 0.5],
    8212: [0, 0.44444, 0.08616, 0, 1],
    8216: [0, 0.69444, 0.07816, 0, 0.27778],
    8217: [0, 0.69444, 0.07816, 0, 0.27778],
    8220: [0, 0.69444, 0.14205, 0, 0.5],
    8221: [0, 0.69444, 316e-5, 0, 0.5]
  },
  "SansSerif-Regular": {
    32: [0, 0, 0, 0, 0.25],
    33: [0, 0.69444, 0, 0, 0.31945],
    34: [0, 0.69444, 0, 0, 0.5],
    35: [0.19444, 0.69444, 0, 0, 0.83334],
    36: [0.05556, 0.75, 0, 0, 0.5],
    37: [0.05556, 0.75, 0, 0, 0.83334],
    38: [0, 0.69444, 0, 0, 0.75834],
    39: [0, 0.69444, 0, 0, 0.27778],
    40: [0.25, 0.75, 0, 0, 0.38889],
    41: [0.25, 0.75, 0, 0, 0.38889],
    42: [0, 0.75, 0, 0, 0.5],
    43: [0.08333, 0.58333, 0, 0, 0.77778],
    44: [0.125, 0.08333, 0, 0, 0.27778],
    45: [0, 0.44444, 0, 0, 0.33333],
    46: [0, 0.08333, 0, 0, 0.27778],
    47: [0.25, 0.75, 0, 0, 0.5],
    48: [0, 0.65556, 0, 0, 0.5],
    49: [0, 0.65556, 0, 0, 0.5],
    50: [0, 0.65556, 0, 0, 0.5],
    51: [0, 0.65556, 0, 0, 0.5],
    52: [0, 0.65556, 0, 0, 0.5],
    53: [0, 0.65556, 0, 0, 0.5],
    54: [0, 0.65556, 0, 0, 0.5],
    55: [0, 0.65556, 0, 0, 0.5],
    56: [0, 0.65556, 0, 0, 0.5],
    57: [0, 0.65556, 0, 0, 0.5],
    58: [0, 0.44444, 0, 0, 0.27778],
    59: [0.125, 0.44444, 0, 0, 0.27778],
    61: [-0.13, 0.37, 0, 0, 0.77778],
    63: [0, 0.69444, 0, 0, 0.47222],
    64: [0, 0.69444, 0, 0, 0.66667],
    65: [0, 0.69444, 0, 0, 0.66667],
    66: [0, 0.69444, 0, 0, 0.66667],
    67: [0, 0.69444, 0, 0, 0.63889],
    68: [0, 0.69444, 0, 0, 0.72223],
    69: [0, 0.69444, 0, 0, 0.59722],
    70: [0, 0.69444, 0, 0, 0.56945],
    71: [0, 0.69444, 0, 0, 0.66667],
    72: [0, 0.69444, 0, 0, 0.70834],
    73: [0, 0.69444, 0, 0, 0.27778],
    74: [0, 0.69444, 0, 0, 0.47222],
    75: [0, 0.69444, 0, 0, 0.69445],
    76: [0, 0.69444, 0, 0, 0.54167],
    77: [0, 0.69444, 0, 0, 0.875],
    78: [0, 0.69444, 0, 0, 0.70834],
    79: [0, 0.69444, 0, 0, 0.73611],
    80: [0, 0.69444, 0, 0, 0.63889],
    81: [0.125, 0.69444, 0, 0, 0.73611],
    82: [0, 0.69444, 0, 0, 0.64584],
    83: [0, 0.69444, 0, 0, 0.55556],
    84: [0, 0.69444, 0, 0, 0.68056],
    85: [0, 0.69444, 0, 0, 0.6875],
    86: [0, 0.69444, 0.01389, 0, 0.66667],
    87: [0, 0.69444, 0.01389, 0, 0.94445],
    88: [0, 0.69444, 0, 0, 0.66667],
    89: [0, 0.69444, 0.025, 0, 0.66667],
    90: [0, 0.69444, 0, 0, 0.61111],
    91: [0.25, 0.75, 0, 0, 0.28889],
    93: [0.25, 0.75, 0, 0, 0.28889],
    94: [0, 0.69444, 0, 0, 0.5],
    95: [0.35, 0.09444, 0.02778, 0, 0.5],
    97: [0, 0.44444, 0, 0, 0.48056],
    98: [0, 0.69444, 0, 0, 0.51667],
    99: [0, 0.44444, 0, 0, 0.44445],
    100: [0, 0.69444, 0, 0, 0.51667],
    101: [0, 0.44444, 0, 0, 0.44445],
    102: [0, 0.69444, 0.06944, 0, 0.30556],
    103: [0.19444, 0.44444, 0.01389, 0, 0.5],
    104: [0, 0.69444, 0, 0, 0.51667],
    105: [0, 0.67937, 0, 0, 0.23889],
    106: [0.19444, 0.67937, 0, 0, 0.26667],
    107: [0, 0.69444, 0, 0, 0.48889],
    108: [0, 0.69444, 0, 0, 0.23889],
    109: [0, 0.44444, 0, 0, 0.79445],
    110: [0, 0.44444, 0, 0, 0.51667],
    111: [0, 0.44444, 0, 0, 0.5],
    112: [0.19444, 0.44444, 0, 0, 0.51667],
    113: [0.19444, 0.44444, 0, 0, 0.51667],
    114: [0, 0.44444, 0.01389, 0, 0.34167],
    115: [0, 0.44444, 0, 0, 0.38333],
    116: [0, 0.57143, 0, 0, 0.36111],
    117: [0, 0.44444, 0, 0, 0.51667],
    118: [0, 0.44444, 0.01389, 0, 0.46111],
    119: [0, 0.44444, 0.01389, 0, 0.68334],
    120: [0, 0.44444, 0, 0, 0.46111],
    121: [0.19444, 0.44444, 0.01389, 0, 0.46111],
    122: [0, 0.44444, 0, 0, 0.43472],
    126: [0.35, 0.32659, 0, 0, 0.5],
    160: [0, 0, 0, 0, 0.25],
    168: [0, 0.67937, 0, 0, 0.5],
    176: [0, 0.69444, 0, 0, 0.66667],
    184: [0.17014, 0, 0, 0, 0.44445],
    305: [0, 0.44444, 0, 0, 0.23889],
    567: [0.19444, 0.44444, 0, 0, 0.26667],
    710: [0, 0.69444, 0, 0, 0.5],
    711: [0, 0.63194, 0, 0, 0.5],
    713: [0, 0.60889, 0, 0, 0.5],
    714: [0, 0.69444, 0, 0, 0.5],
    715: [0, 0.69444, 0, 0, 0.5],
    728: [0, 0.69444, 0, 0, 0.5],
    729: [0, 0.67937, 0, 0, 0.27778],
    730: [0, 0.69444, 0, 0, 0.66667],
    732: [0, 0.67659, 0, 0, 0.5],
    733: [0, 0.69444, 0, 0, 0.5],
    915: [0, 0.69444, 0, 0, 0.54167],
    916: [0, 0.69444, 0, 0, 0.83334],
    920: [0, 0.69444, 0, 0, 0.77778],
    923: [0, 0.69444, 0, 0, 0.61111],
    926: [0, 0.69444, 0, 0, 0.66667],
    928: [0, 0.69444, 0, 0, 0.70834],
    931: [0, 0.69444, 0, 0, 0.72222],
    933: [0, 0.69444, 0, 0, 0.77778],
    934: [0, 0.69444, 0, 0, 0.72222],
    936: [0, 0.69444, 0, 0, 0.77778],
    937: [0, 0.69444, 0, 0, 0.72222],
    8211: [0, 0.44444, 0.02778, 0, 0.5],
    8212: [0, 0.44444, 0.02778, 0, 1],
    8216: [0, 0.69444, 0, 0, 0.27778],
    8217: [0, 0.69444, 0, 0, 0.27778],
    8220: [0, 0.69444, 0, 0, 0.5],
    8221: [0, 0.69444, 0, 0, 0.5]
  },
  "Script-Regular": {
    32: [0, 0, 0, 0, 0.25],
    65: [0, 0.7, 0.22925, 0, 0.80253],
    66: [0, 0.7, 0.04087, 0, 0.90757],
    67: [0, 0.7, 0.1689, 0, 0.66619],
    68: [0, 0.7, 0.09371, 0, 0.77443],
    69: [0, 0.7, 0.18583, 0, 0.56162],
    70: [0, 0.7, 0.13634, 0, 0.89544],
    71: [0, 0.7, 0.17322, 0, 0.60961],
    72: [0, 0.7, 0.29694, 0, 0.96919],
    73: [0, 0.7, 0.19189, 0, 0.80907],
    74: [0.27778, 0.7, 0.19189, 0, 1.05159],
    75: [0, 0.7, 0.31259, 0, 0.91364],
    76: [0, 0.7, 0.19189, 0, 0.87373],
    77: [0, 0.7, 0.15981, 0, 1.08031],
    78: [0, 0.7, 0.3525, 0, 0.9015],
    79: [0, 0.7, 0.08078, 0, 0.73787],
    80: [0, 0.7, 0.08078, 0, 1.01262],
    81: [0, 0.7, 0.03305, 0, 0.88282],
    82: [0, 0.7, 0.06259, 0, 0.85],
    83: [0, 0.7, 0.19189, 0, 0.86767],
    84: [0, 0.7, 0.29087, 0, 0.74697],
    85: [0, 0.7, 0.25815, 0, 0.79996],
    86: [0, 0.7, 0.27523, 0, 0.62204],
    87: [0, 0.7, 0.27523, 0, 0.80532],
    88: [0, 0.7, 0.26006, 0, 0.94445],
    89: [0, 0.7, 0.2939, 0, 0.70961],
    90: [0, 0.7, 0.24037, 0, 0.8212],
    160: [0, 0, 0, 0, 0.25]
  },
  "Size1-Regular": {
    32: [0, 0, 0, 0, 0.25],
    40: [0.35001, 0.85, 0, 0, 0.45834],
    41: [0.35001, 0.85, 0, 0, 0.45834],
    47: [0.35001, 0.85, 0, 0, 0.57778],
    91: [0.35001, 0.85, 0, 0, 0.41667],
    92: [0.35001, 0.85, 0, 0, 0.57778],
    93: [0.35001, 0.85, 0, 0, 0.41667],
    123: [0.35001, 0.85, 0, 0, 0.58334],
    125: [0.35001, 0.85, 0, 0, 0.58334],
    160: [0, 0, 0, 0, 0.25],
    710: [0, 0.72222, 0, 0, 0.55556],
    732: [0, 0.72222, 0, 0, 0.55556],
    770: [0, 0.72222, 0, 0, 0.55556],
    771: [0, 0.72222, 0, 0, 0.55556],
    8214: [-99e-5, 0.601, 0, 0, 0.77778],
    8593: [1e-5, 0.6, 0, 0, 0.66667],
    8595: [1e-5, 0.6, 0, 0, 0.66667],
    8657: [1e-5, 0.6, 0, 0, 0.77778],
    8659: [1e-5, 0.6, 0, 0, 0.77778],
    8719: [0.25001, 0.75, 0, 0, 0.94445],
    8720: [0.25001, 0.75, 0, 0, 0.94445],
    8721: [0.25001, 0.75, 0, 0, 1.05556],
    8730: [0.35001, 0.85, 0, 0, 1],
    8739: [-599e-5, 0.606, 0, 0, 0.33333],
    8741: [-599e-5, 0.606, 0, 0, 0.55556],
    8747: [0.30612, 0.805, 0.19445, 0, 0.47222],
    8748: [0.306, 0.805, 0.19445, 0, 0.47222],
    8749: [0.306, 0.805, 0.19445, 0, 0.47222],
    8750: [0.30612, 0.805, 0.19445, 0, 0.47222],
    8896: [0.25001, 0.75, 0, 0, 0.83334],
    8897: [0.25001, 0.75, 0, 0, 0.83334],
    8898: [0.25001, 0.75, 0, 0, 0.83334],
    8899: [0.25001, 0.75, 0, 0, 0.83334],
    8968: [0.35001, 0.85, 0, 0, 0.47222],
    8969: [0.35001, 0.85, 0, 0, 0.47222],
    8970: [0.35001, 0.85, 0, 0, 0.47222],
    8971: [0.35001, 0.85, 0, 0, 0.47222],
    9168: [-99e-5, 0.601, 0, 0, 0.66667],
    10216: [0.35001, 0.85, 0, 0, 0.47222],
    10217: [0.35001, 0.85, 0, 0, 0.47222],
    10752: [0.25001, 0.75, 0, 0, 1.11111],
    10753: [0.25001, 0.75, 0, 0, 1.11111],
    10754: [0.25001, 0.75, 0, 0, 1.11111],
    10756: [0.25001, 0.75, 0, 0, 0.83334],
    10758: [0.25001, 0.75, 0, 0, 0.83334]
  },
  "Size2-Regular": {
    32: [0, 0, 0, 0, 0.25],
    40: [0.65002, 1.15, 0, 0, 0.59722],
    41: [0.65002, 1.15, 0, 0, 0.59722],
    47: [0.65002, 1.15, 0, 0, 0.81111],
    91: [0.65002, 1.15, 0, 0, 0.47222],
    92: [0.65002, 1.15, 0, 0, 0.81111],
    93: [0.65002, 1.15, 0, 0, 0.47222],
    123: [0.65002, 1.15, 0, 0, 0.66667],
    125: [0.65002, 1.15, 0, 0, 0.66667],
    160: [0, 0, 0, 0, 0.25],
    710: [0, 0.75, 0, 0, 1],
    732: [0, 0.75, 0, 0, 1],
    770: [0, 0.75, 0, 0, 1],
    771: [0, 0.75, 0, 0, 1],
    8719: [0.55001, 1.05, 0, 0, 1.27778],
    8720: [0.55001, 1.05, 0, 0, 1.27778],
    8721: [0.55001, 1.05, 0, 0, 1.44445],
    8730: [0.65002, 1.15, 0, 0, 1],
    8747: [0.86225, 1.36, 0.44445, 0, 0.55556],
    8748: [0.862, 1.36, 0.44445, 0, 0.55556],
    8749: [0.862, 1.36, 0.44445, 0, 0.55556],
    8750: [0.86225, 1.36, 0.44445, 0, 0.55556],
    8896: [0.55001, 1.05, 0, 0, 1.11111],
    8897: [0.55001, 1.05, 0, 0, 1.11111],
    8898: [0.55001, 1.05, 0, 0, 1.11111],
    8899: [0.55001, 1.05, 0, 0, 1.11111],
    8968: [0.65002, 1.15, 0, 0, 0.52778],
    8969: [0.65002, 1.15, 0, 0, 0.52778],
    8970: [0.65002, 1.15, 0, 0, 0.52778],
    8971: [0.65002, 1.15, 0, 0, 0.52778],
    10216: [0.65002, 1.15, 0, 0, 0.61111],
    10217: [0.65002, 1.15, 0, 0, 0.61111],
    10752: [0.55001, 1.05, 0, 0, 1.51112],
    10753: [0.55001, 1.05, 0, 0, 1.51112],
    10754: [0.55001, 1.05, 0, 0, 1.51112],
    10756: [0.55001, 1.05, 0, 0, 1.11111],
    10758: [0.55001, 1.05, 0, 0, 1.11111]
  },
  "Size3-Regular": {
    32: [0, 0, 0, 0, 0.25],
    40: [0.95003, 1.45, 0, 0, 0.73611],
    41: [0.95003, 1.45, 0, 0, 0.73611],
    47: [0.95003, 1.45, 0, 0, 1.04445],
    91: [0.95003, 1.45, 0, 0, 0.52778],
    92: [0.95003, 1.45, 0, 0, 1.04445],
    93: [0.95003, 1.45, 0, 0, 0.52778],
    123: [0.95003, 1.45, 0, 0, 0.75],
    125: [0.95003, 1.45, 0, 0, 0.75],
    160: [0, 0, 0, 0, 0.25],
    710: [0, 0.75, 0, 0, 1.44445],
    732: [0, 0.75, 0, 0, 1.44445],
    770: [0, 0.75, 0, 0, 1.44445],
    771: [0, 0.75, 0, 0, 1.44445],
    8730: [0.95003, 1.45, 0, 0, 1],
    8968: [0.95003, 1.45, 0, 0, 0.58334],
    8969: [0.95003, 1.45, 0, 0, 0.58334],
    8970: [0.95003, 1.45, 0, 0, 0.58334],
    8971: [0.95003, 1.45, 0, 0, 0.58334],
    10216: [0.95003, 1.45, 0, 0, 0.75],
    10217: [0.95003, 1.45, 0, 0, 0.75]
  },
  "Size4-Regular": {
    32: [0, 0, 0, 0, 0.25],
    40: [1.25003, 1.75, 0, 0, 0.79167],
    41: [1.25003, 1.75, 0, 0, 0.79167],
    47: [1.25003, 1.75, 0, 0, 1.27778],
    91: [1.25003, 1.75, 0, 0, 0.58334],
    92: [1.25003, 1.75, 0, 0, 1.27778],
    93: [1.25003, 1.75, 0, 0, 0.58334],
    123: [1.25003, 1.75, 0, 0, 0.80556],
    125: [1.25003, 1.75, 0, 0, 0.80556],
    160: [0, 0, 0, 0, 0.25],
    710: [0, 0.825, 0, 0, 1.8889],
    732: [0, 0.825, 0, 0, 1.8889],
    770: [0, 0.825, 0, 0, 1.8889],
    771: [0, 0.825, 0, 0, 1.8889],
    8730: [1.25003, 1.75, 0, 0, 1],
    8968: [1.25003, 1.75, 0, 0, 0.63889],
    8969: [1.25003, 1.75, 0, 0, 0.63889],
    8970: [1.25003, 1.75, 0, 0, 0.63889],
    8971: [1.25003, 1.75, 0, 0, 0.63889],
    9115: [0.64502, 1.155, 0, 0, 0.875],
    9116: [1e-5, 0.6, 0, 0, 0.875],
    9117: [0.64502, 1.155, 0, 0, 0.875],
    9118: [0.64502, 1.155, 0, 0, 0.875],
    9119: [1e-5, 0.6, 0, 0, 0.875],
    9120: [0.64502, 1.155, 0, 0, 0.875],
    9121: [0.64502, 1.155, 0, 0, 0.66667],
    9122: [-99e-5, 0.601, 0, 0, 0.66667],
    9123: [0.64502, 1.155, 0, 0, 0.66667],
    9124: [0.64502, 1.155, 0, 0, 0.66667],
    9125: [-99e-5, 0.601, 0, 0, 0.66667],
    9126: [0.64502, 1.155, 0, 0, 0.66667],
    9127: [1e-5, 0.9, 0, 0, 0.88889],
    9128: [0.65002, 1.15, 0, 0, 0.88889],
    9129: [0.90001, 0, 0, 0, 0.88889],
    9130: [0, 0.3, 0, 0, 0.88889],
    9131: [1e-5, 0.9, 0, 0, 0.88889],
    9132: [0.65002, 1.15, 0, 0, 0.88889],
    9133: [0.90001, 0, 0, 0, 0.88889],
    9143: [0.88502, 0.915, 0, 0, 1.05556],
    10216: [1.25003, 1.75, 0, 0, 0.80556],
    10217: [1.25003, 1.75, 0, 0, 0.80556],
    57344: [-499e-5, 0.605, 0, 0, 1.05556],
    57345: [-499e-5, 0.605, 0, 0, 1.05556],
    57680: [0, 0.12, 0, 0, 0.45],
    57681: [0, 0.12, 0, 0, 0.45],
    57682: [0, 0.12, 0, 0, 0.45],
    57683: [0, 0.12, 0, 0, 0.45]
  },
  "Typewriter-Regular": {
    32: [0, 0, 0, 0, 0.525],
    33: [0, 0.61111, 0, 0, 0.525],
    34: [0, 0.61111, 0, 0, 0.525],
    35: [0, 0.61111, 0, 0, 0.525],
    36: [0.08333, 0.69444, 0, 0, 0.525],
    37: [0.08333, 0.69444, 0, 0, 0.525],
    38: [0, 0.61111, 0, 0, 0.525],
    39: [0, 0.61111, 0, 0, 0.525],
    40: [0.08333, 0.69444, 0, 0, 0.525],
    41: [0.08333, 0.69444, 0, 0, 0.525],
    42: [0, 0.52083, 0, 0, 0.525],
    43: [-0.08056, 0.53055, 0, 0, 0.525],
    44: [0.13889, 0.125, 0, 0, 0.525],
    45: [-0.08056, 0.53055, 0, 0, 0.525],
    46: [0, 0.125, 0, 0, 0.525],
    47: [0.08333, 0.69444, 0, 0, 0.525],
    48: [0, 0.61111, 0, 0, 0.525],
    49: [0, 0.61111, 0, 0, 0.525],
    50: [0, 0.61111, 0, 0, 0.525],
    51: [0, 0.61111, 0, 0, 0.525],
    52: [0, 0.61111, 0, 0, 0.525],
    53: [0, 0.61111, 0, 0, 0.525],
    54: [0, 0.61111, 0, 0, 0.525],
    55: [0, 0.61111, 0, 0, 0.525],
    56: [0, 0.61111, 0, 0, 0.525],
    57: [0, 0.61111, 0, 0, 0.525],
    58: [0, 0.43056, 0, 0, 0.525],
    59: [0.13889, 0.43056, 0, 0, 0.525],
    60: [-0.05556, 0.55556, 0, 0, 0.525],
    61: [-0.19549, 0.41562, 0, 0, 0.525],
    62: [-0.05556, 0.55556, 0, 0, 0.525],
    63: [0, 0.61111, 0, 0, 0.525],
    64: [0, 0.61111, 0, 0, 0.525],
    65: [0, 0.61111, 0, 0, 0.525],
    66: [0, 0.61111, 0, 0, 0.525],
    67: [0, 0.61111, 0, 0, 0.525],
    68: [0, 0.61111, 0, 0, 0.525],
    69: [0, 0.61111, 0, 0, 0.525],
    70: [0, 0.61111, 0, 0, 0.525],
    71: [0, 0.61111, 0, 0, 0.525],
    72: [0, 0.61111, 0, 0, 0.525],
    73: [0, 0.61111, 0, 0, 0.525],
    74: [0, 0.61111, 0, 0, 0.525],
    75: [0, 0.61111, 0, 0, 0.525],
    76: [0, 0.61111, 0, 0, 0.525],
    77: [0, 0.61111, 0, 0, 0.525],
    78: [0, 0.61111, 0, 0, 0.525],
    79: [0, 0.61111, 0, 0, 0.525],
    80: [0, 0.61111, 0, 0, 0.525],
    81: [0.13889, 0.61111, 0, 0, 0.525],
    82: [0, 0.61111, 0, 0, 0.525],
    83: [0, 0.61111, 0, 0, 0.525],
    84: [0, 0.61111, 0, 0, 0.525],
    85: [0, 0.61111, 0, 0, 0.525],
    86: [0, 0.61111, 0, 0, 0.525],
    87: [0, 0.61111, 0, 0, 0.525],
    88: [0, 0.61111, 0, 0, 0.525],
    89: [0, 0.61111, 0, 0, 0.525],
    90: [0, 0.61111, 0, 0, 0.525],
    91: [0.08333, 0.69444, 0, 0, 0.525],
    92: [0.08333, 0.69444, 0, 0, 0.525],
    93: [0.08333, 0.69444, 0, 0, 0.525],
    94: [0, 0.61111, 0, 0, 0.525],
    95: [0.09514, 0, 0, 0, 0.525],
    96: [0, 0.61111, 0, 0, 0.525],
    97: [0, 0.43056, 0, 0, 0.525],
    98: [0, 0.61111, 0, 0, 0.525],
    99: [0, 0.43056, 0, 0, 0.525],
    100: [0, 0.61111, 0, 0, 0.525],
    101: [0, 0.43056, 0, 0, 0.525],
    102: [0, 0.61111, 0, 0, 0.525],
    103: [0.22222, 0.43056, 0, 0, 0.525],
    104: [0, 0.61111, 0, 0, 0.525],
    105: [0, 0.61111, 0, 0, 0.525],
    106: [0.22222, 0.61111, 0, 0, 0.525],
    107: [0, 0.61111, 0, 0, 0.525],
    108: [0, 0.61111, 0, 0, 0.525],
    109: [0, 0.43056, 0, 0, 0.525],
    110: [0, 0.43056, 0, 0, 0.525],
    111: [0, 0.43056, 0, 0, 0.525],
    112: [0.22222, 0.43056, 0, 0, 0.525],
    113: [0.22222, 0.43056, 0, 0, 0.525],
    114: [0, 0.43056, 0, 0, 0.525],
    115: [0, 0.43056, 0, 0, 0.525],
    116: [0, 0.55358, 0, 0, 0.525],
    117: [0, 0.43056, 0, 0, 0.525],
    118: [0, 0.43056, 0, 0, 0.525],
    119: [0, 0.43056, 0, 0, 0.525],
    120: [0, 0.43056, 0, 0, 0.525],
    121: [0.22222, 0.43056, 0, 0, 0.525],
    122: [0, 0.43056, 0, 0, 0.525],
    123: [0.08333, 0.69444, 0, 0, 0.525],
    124: [0.08333, 0.69444, 0, 0, 0.525],
    125: [0.08333, 0.69444, 0, 0, 0.525],
    126: [0, 0.61111, 0, 0, 0.525],
    127: [0, 0.61111, 0, 0, 0.525],
    160: [0, 0, 0, 0, 0.525],
    176: [0, 0.61111, 0, 0, 0.525],
    184: [0.19445, 0, 0, 0, 0.525],
    305: [0, 0.43056, 0, 0, 0.525],
    567: [0.22222, 0.43056, 0, 0, 0.525],
    711: [0, 0.56597, 0, 0, 0.525],
    713: [0, 0.56555, 0, 0, 0.525],
    714: [0, 0.61111, 0, 0, 0.525],
    715: [0, 0.61111, 0, 0, 0.525],
    728: [0, 0.61111, 0, 0, 0.525],
    730: [0, 0.61111, 0, 0, 0.525],
    770: [0, 0.61111, 0, 0, 0.525],
    771: [0, 0.61111, 0, 0, 0.525],
    776: [0, 0.61111, 0, 0, 0.525],
    915: [0, 0.61111, 0, 0, 0.525],
    916: [0, 0.61111, 0, 0, 0.525],
    920: [0, 0.61111, 0, 0, 0.525],
    923: [0, 0.61111, 0, 0, 0.525],
    926: [0, 0.61111, 0, 0, 0.525],
    928: [0, 0.61111, 0, 0, 0.525],
    931: [0, 0.61111, 0, 0, 0.525],
    933: [0, 0.61111, 0, 0, 0.525],
    934: [0, 0.61111, 0, 0, 0.525],
    936: [0, 0.61111, 0, 0, 0.525],
    937: [0, 0.61111, 0, 0, 0.525],
    8216: [0, 0.61111, 0, 0, 0.525],
    8217: [0, 0.61111, 0, 0, 0.525],
    8242: [0, 0.61111, 0, 0, 0.525],
    9251: [0.11111, 0.21944, 0, 0, 0.525]
  }
}, Ur = {
  slant: [0.25, 0.25, 0.25],
  // sigma1
  space: [0, 0, 0],
  // sigma2
  stretch: [0, 0, 0],
  // sigma3
  shrink: [0, 0, 0],
  // sigma4
  xHeight: [0.431, 0.431, 0.431],
  // sigma5
  quad: [1, 1.171, 1.472],
  // sigma6
  extraSpace: [0, 0, 0],
  // sigma7
  num1: [0.677, 0.732, 0.925],
  // sigma8
  num2: [0.394, 0.384, 0.387],
  // sigma9
  num3: [0.444, 0.471, 0.504],
  // sigma10
  denom1: [0.686, 0.752, 1.025],
  // sigma11
  denom2: [0.345, 0.344, 0.532],
  // sigma12
  sup1: [0.413, 0.503, 0.504],
  // sigma13
  sup2: [0.363, 0.431, 0.404],
  // sigma14
  sup3: [0.289, 0.286, 0.294],
  // sigma15
  sub1: [0.15, 0.143, 0.2],
  // sigma16
  sub2: [0.247, 0.286, 0.4],
  // sigma17
  supDrop: [0.386, 0.353, 0.494],
  // sigma18
  subDrop: [0.05, 0.071, 0.1],
  // sigma19
  delim1: [2.39, 1.7, 1.98],
  // sigma20
  delim2: [1.01, 1.157, 1.42],
  // sigma21
  axisHeight: [0.25, 0.25, 0.25],
  // sigma22
  // These font metrics are extracted from TeX by using tftopl on cmex10.tfm;
  // they correspond to the font parameters of the extension fonts (family 3).
  // See the TeXbook, page 441. In AMSTeX, the extension fonts scale; to
  // match cmex7, we'd use cmex7.tfm values for script and scriptscript
  // values.
  defaultRuleThickness: [0.04, 0.049, 0.049],
  // xi8; cmex7: 0.049
  bigOpSpacing1: [0.111, 0.111, 0.111],
  // xi9
  bigOpSpacing2: [0.166, 0.166, 0.166],
  // xi10
  bigOpSpacing3: [0.2, 0.2, 0.2],
  // xi11
  bigOpSpacing4: [0.6, 0.611, 0.611],
  // xi12; cmex7: 0.611
  bigOpSpacing5: [0.1, 0.143, 0.143],
  // xi13; cmex7: 0.143
  // The \sqrt rule width is taken from the height of the surd character.
  // Since we use the same font at all sizes, this thickness doesn't scale.
  sqrtRuleThickness: [0.04, 0.04, 0.04],
  // This value determines how large a pt is, for metrics which are defined
  // in terms of pts.
  // This value is also used in katex.scss; if you change it make sure the
  // values match.
  ptPerEm: [10, 10, 10],
  // The space between adjacent `|` columns in an array definition. From
  // `\showthe\doublerulesep` in LaTeX. Equals 2.0 / ptPerEm.
  doubleRuleSep: [0.2, 0.2, 0.2],
  // The width of separator lines in {array} environments. From
  // `\showthe\arrayrulewidth` in LaTeX. Equals 0.4 / ptPerEm.
  arrayRuleWidth: [0.04, 0.04, 0.04],
  // Two values from LaTeX source2e:
  fboxsep: [0.3, 0.3, 0.3],
  //        3 pt / ptPerEm
  fboxrule: [0.04, 0.04, 0.04]
  // 0.4 pt / ptPerEm
}, cl = {
  // Latin-1
  Å: "A",
  Ð: "D",
  Þ: "o",
  å: "a",
  ð: "d",
  þ: "o",
  // Cyrillic
  А: "A",
  Б: "B",
  В: "B",
  Г: "F",
  Д: "A",
  Е: "E",
  Ж: "K",
  З: "3",
  И: "N",
  Й: "N",
  К: "K",
  Л: "N",
  М: "M",
  Н: "H",
  О: "O",
  П: "N",
  Р: "P",
  С: "C",
  Т: "T",
  У: "y",
  Ф: "O",
  Х: "X",
  Ц: "U",
  Ч: "h",
  Ш: "W",
  Щ: "W",
  Ъ: "B",
  Ы: "X",
  Ь: "B",
  Э: "3",
  Ю: "X",
  Я: "R",
  а: "a",
  б: "b",
  в: "a",
  г: "r",
  д: "y",
  е: "e",
  ж: "m",
  з: "e",
  и: "n",
  й: "n",
  к: "n",
  л: "n",
  м: "m",
  н: "n",
  о: "o",
  п: "n",
  р: "p",
  с: "c",
  т: "o",
  у: "y",
  ф: "b",
  х: "x",
  ц: "n",
  ч: "n",
  ш: "w",
  щ: "w",
  ъ: "a",
  ы: "m",
  ь: "a",
  э: "e",
  ю: "m",
  я: "r"
};
function Tc(n, e) {
  Pt[n] = e;
}
function hi(n, e, t) {
  if (!Pt[e])
    throw new Error("Font metrics not found for font: " + e + ".");
  var r = n.charCodeAt(0), a = Pt[e][r];
  if (!a && n[0] in cl && (r = cl[n[0]].charCodeAt(0), a = Pt[e][r]), !a && t === "text" && Co(r) && (a = Pt[e][77]), a)
    return {
      depth: a[0],
      height: a[1],
      italic: a[2],
      skew: a[3],
      width: a[4]
    };
}
var ta = {};
function Cc(n) {
  var e;
  if (n >= 5 ? e = 0 : n >= 3 ? e = 1 : e = 2, !ta[e]) {
    var t = ta[e] = {
      cssEmPerMu: Ur.quad[e] / 18
    };
    for (var r in Ur)
      Ur.hasOwnProperty(r) && (t[r] = Ur[r][e]);
  }
  return ta[e];
}
var Mc = [
  // Each element contains [textsize, scriptsize, scriptscriptsize].
  // The size mappings are taken from TeX with \normalsize=10pt.
  [1, 1, 1],
  // size1: [5, 5, 5]              \tiny
  [2, 1, 1],
  // size2: [6, 5, 5]
  [3, 1, 1],
  // size3: [7, 5, 5]              \scriptsize
  [4, 2, 1],
  // size4: [8, 6, 5]              \footnotesize
  [5, 2, 1],
  // size5: [9, 6, 5]              \small
  [6, 3, 1],
  // size6: [10, 7, 5]             \normalsize
  [7, 4, 2],
  // size7: [12, 8, 6]             \large
  [8, 6, 3],
  // size8: [14.4, 10, 7]          \Large
  [9, 7, 6],
  // size9: [17.28, 12, 10]        \LARGE
  [10, 8, 7],
  // size10: [20.74, 14.4, 12]     \huge
  [11, 10, 9]
  // size11: [24.88, 20.74, 17.28] \HUGE
], hl = [
  // fontMetrics.js:getGlobalMetrics also uses size indexes, so if
  // you change size indexes, change that function.
  0.5,
  0.6,
  0.7,
  0.8,
  0.9,
  1,
  1.2,
  1.44,
  1.728,
  2.074,
  2.488
], fl = function(e, t) {
  return t.size < 2 ? e : Mc[e - 1][t.size - 1];
};
class s0 {
  // A font family applies to a group of fonts (i.e. SansSerif), while a font
  // represents a specific font (i.e. SansSerif Bold).
  // See: https://tex.stackexchange.com/questions/22350/difference-between-textrm-and-mathrm
  /**
   * The base size index.
   */
  constructor(e) {
    this.style = void 0, this.color = void 0, this.size = void 0, this.textSize = void 0, this.phantom = void 0, this.font = void 0, this.fontFamily = void 0, this.fontWeight = void 0, this.fontShape = void 0, this.sizeMultiplier = void 0, this.maxSize = void 0, this.minRuleThickness = void 0, this._fontMetrics = void 0, this.style = e.style, this.color = e.color, this.size = e.size || s0.BASESIZE, this.textSize = e.textSize || this.size, this.phantom = !!e.phantom, this.font = e.font || "", this.fontFamily = e.fontFamily || "", this.fontWeight = e.fontWeight || "", this.fontShape = e.fontShape || "", this.sizeMultiplier = hl[this.size - 1], this.maxSize = e.maxSize, this.minRuleThickness = e.minRuleThickness, this._fontMetrics = void 0;
  }
  /**
   * Returns a new options object with the same properties as "this".  Properties
   * from "extension" will be copied to the new options object.
   */
  extend(e) {
    var t = {
      style: this.style,
      size: this.size,
      textSize: this.textSize,
      color: this.color,
      phantom: this.phantom,
      font: this.font,
      fontFamily: this.fontFamily,
      fontWeight: this.fontWeight,
      fontShape: this.fontShape,
      maxSize: this.maxSize,
      minRuleThickness: this.minRuleThickness
    };
    for (var r in e)
      e.hasOwnProperty(r) && (t[r] = e[r]);
    return new s0(t);
  }
  /**
   * Return an options object with the given style. If `this.style === style`,
   * returns `this`.
   */
  havingStyle(e) {
    return this.style === e ? this : this.extend({
      style: e,
      size: fl(this.textSize, e)
    });
  }
  /**
   * Return an options object with a cramped version of the current style. If
   * the current style is cramped, returns `this`.
   */
  havingCrampedStyle() {
    return this.havingStyle(this.style.cramp());
  }
  /**
   * Return an options object with the given size and in at least `\textstyle`.
   * Returns `this` if appropriate.
   */
  havingSize(e) {
    return this.size === e && this.textSize === e ? this : this.extend({
      style: this.style.text(),
      size: e,
      textSize: e,
      sizeMultiplier: hl[e - 1]
    });
  }
  /**
   * Like `this.havingSize(BASESIZE).havingStyle(style)`. If `style` is omitted,
   * changes to at least `\textstyle`.
   */
  havingBaseStyle(e) {
    e = e || this.style.text();
    var t = fl(s0.BASESIZE, e);
    return this.size === t && this.textSize === s0.BASESIZE && this.style === e ? this : this.extend({
      style: e,
      size: t
    });
  }
  /**
   * Remove the effect of sizing changes such as \Huge.
   * Keep the effect of the current style, such as \scriptstyle.
   */
  havingBaseSizing() {
    var e;
    switch (this.style.id) {
      case 4:
      case 5:
        e = 3;
        break;
      case 6:
      case 7:
        e = 1;
        break;
      default:
        e = 6;
    }
    return this.extend({
      style: this.style.text(),
      size: e
    });
  }
  /**
   * Create a new options object with the given color.
   */
  withColor(e) {
    return this.extend({
      color: e
    });
  }
  /**
   * Create a new options object with "phantom" set to true.
   */
  withPhantom() {
    return this.extend({
      phantom: !0
    });
  }
  /**
   * Creates a new options object with the given math font or old text font.
   * @type {[type]}
   */
  withFont(e) {
    return this.extend({
      font: e
    });
  }
  /**
   * Create a new options objects with the given fontFamily.
   */
  withTextFontFamily(e) {
    return this.extend({
      fontFamily: e,
      font: ""
    });
  }
  /**
   * Creates a new options object with the given font weight
   */
  withTextFontWeight(e) {
    return this.extend({
      fontWeight: e,
      font: ""
    });
  }
  /**
   * Creates a new options object with the given font weight
   */
  withTextFontShape(e) {
    return this.extend({
      fontShape: e,
      font: ""
    });
  }
  /**
   * Return the CSS sizing classes required to switch from enclosing options
   * `oldOptions` to `this`. Returns an array of classes.
   */
  sizingClasses(e) {
    return e.size !== this.size ? ["sizing", "reset-size" + e.size, "size" + this.size] : [];
  }
  /**
   * Return the CSS sizing classes required to switch to the base size. Like
   * `this.havingSize(BASESIZE).sizingClasses(this)`.
   */
  baseSizingClasses() {
    return this.size !== s0.BASESIZE ? ["sizing", "reset-size" + this.size, "size" + s0.BASESIZE] : [];
  }
  /**
   * Return the font metrics for this size.
   */
  fontMetrics() {
    return this._fontMetrics || (this._fontMetrics = Cc(this.size)), this._fontMetrics;
  }
  /**
   * Gets the CSS color of the current options object
   */
  getColor() {
    return this.phantom ? "transparent" : this.color;
  }
}
s0.BASESIZE = 6;
var Pa = {
  // https://en.wikibooks.org/wiki/LaTeX/Lengths and
  // https://tex.stackexchange.com/a/8263
  pt: 1,
  // TeX point
  mm: 7227 / 2540,
  // millimeter
  cm: 7227 / 254,
  // centimeter
  in: 72.27,
  // inch
  bp: 803 / 800,
  // big (PostScript) points
  pc: 12,
  // pica
  dd: 1238 / 1157,
  // didot
  cc: 14856 / 1157,
  // cicero (12 didot)
  nd: 685 / 642,
  // new didot
  nc: 1370 / 107,
  // new cicero (12 new didot)
  sp: 1 / 65536,
  // scaled point (TeX's internal smallest unit)
  // https://tex.stackexchange.com/a/41371
  px: 803 / 800
  // \pdfpxdimen defaults to 1 bp in pdfTeX and LuaTeX
}, zc = {
  ex: !0,
  em: !0,
  mu: !0
}, Mo = function(e) {
  return typeof e != "string" && (e = e.unit), e in Pa || e in zc || e === "ex";
}, we = function(e, t) {
  var r;
  if (e.unit in Pa)
    r = Pa[e.unit] / t.fontMetrics().ptPerEm / t.sizeMultiplier;
  else if (e.unit === "mu")
    r = t.fontMetrics().cssEmPerMu;
  else {
    var a;
    if (t.style.isTight() ? a = t.havingStyle(t.style.text()) : a = t, e.unit === "ex")
      r = a.fontMetrics().xHeight;
    else if (e.unit === "em")
      r = a.fontMetrics().quad;
    else
      throw new L("Invalid unit: '" + e.unit + "'");
    a !== t && (r *= a.sizeMultiplier / t.sizeMultiplier);
  }
  return Math.min(e.number * r, t.maxSize);
}, P = function(e) {
  return +e.toFixed(4) + "em";
}, D0 = function(e) {
  return e.filter((t) => t).join(" ");
}, zo = function(e, t, r) {
  if (this.classes = e || [], this.attributes = {}, this.height = 0, this.depth = 0, this.maxFontSize = 0, this.style = r || {}, t) {
    t.style.isTight() && this.classes.push("mtight");
    var a = t.getColor();
    a && (this.style.color = a);
  }
}, Bo = function(e) {
  var t = document.createElement(e);
  t.className = D0(this.classes);
  for (var r in this.style)
    this.style.hasOwnProperty(r) && (t.style[r] = this.style[r]);
  for (var a in this.attributes)
    this.attributes.hasOwnProperty(a) && t.setAttribute(a, this.attributes[a]);
  for (var i = 0; i < this.children.length; i++)
    t.appendChild(this.children[i].toNode());
  return t;
}, No = function(e) {
  var t = "<" + e;
  this.classes.length && (t += ' class="' + j.escape(D0(this.classes)) + '"');
  var r = "";
  for (var a in this.style)
    this.style.hasOwnProperty(a) && (r += j.hyphenate(a) + ":" + this.style[a] + ";");
  r && (t += ' style="' + j.escape(r) + '"');
  for (var i in this.attributes)
    this.attributes.hasOwnProperty(i) && (t += " " + i + '="' + j.escape(this.attributes[i]) + '"');
  t += ">";
  for (var l = 0; l < this.children.length; l++)
    t += this.children[l].toMarkup();
  return t += "</" + e + ">", t;
};
class Mr {
  constructor(e, t, r, a) {
    this.children = void 0, this.attributes = void 0, this.classes = void 0, this.height = void 0, this.depth = void 0, this.width = void 0, this.maxFontSize = void 0, this.style = void 0, zo.call(this, e, r, a), this.children = t || [];
  }
  /**
   * Sets an arbitrary attribute on the span. Warning: use this wisely. Not
   * all browsers support attributes the same, and having too many custom
   * attributes is probably bad.
   */
  setAttribute(e, t) {
    this.attributes[e] = t;
  }
  hasClass(e) {
    return j.contains(this.classes, e);
  }
  toNode() {
    return Bo.call(this, "span");
  }
  toMarkup() {
    return No.call(this, "span");
  }
}
class fi {
  constructor(e, t, r, a) {
    this.children = void 0, this.attributes = void 0, this.classes = void 0, this.height = void 0, this.depth = void 0, this.maxFontSize = void 0, this.style = void 0, zo.call(this, t, a), this.children = r || [], this.setAttribute("href", e);
  }
  setAttribute(e, t) {
    this.attributes[e] = t;
  }
  hasClass(e) {
    return j.contains(this.classes, e);
  }
  toNode() {
    return Bo.call(this, "a");
  }
  toMarkup() {
    return No.call(this, "a");
  }
}
class Bc {
  constructor(e, t, r) {
    this.src = void 0, this.alt = void 0, this.classes = void 0, this.height = void 0, this.depth = void 0, this.maxFontSize = void 0, this.style = void 0, this.alt = t, this.src = e, this.classes = ["mord"], this.style = r;
  }
  hasClass(e) {
    return j.contains(this.classes, e);
  }
  toNode() {
    var e = document.createElement("img");
    e.src = this.src, e.alt = this.alt, e.className = "mord";
    for (var t in this.style)
      this.style.hasOwnProperty(t) && (e.style[t] = this.style[t]);
    return e;
  }
  toMarkup() {
    var e = '<img src="' + j.escape(this.src) + '"' + (' alt="' + j.escape(this.alt) + '"'), t = "";
    for (var r in this.style)
      this.style.hasOwnProperty(r) && (t += j.hyphenate(r) + ":" + this.style[r] + ";");
    return t && (e += ' style="' + j.escape(t) + '"'), e += "'/>", e;
  }
}
var Nc = {
  î: "ı̂",
  ï: "ı̈",
  í: "ı́",
  // 'ī': '\u0131\u0304', // enable when we add Extended Latin
  ì: "ı̀"
};
class dt {
  constructor(e, t, r, a, i, l, s, o) {
    this.text = void 0, this.height = void 0, this.depth = void 0, this.italic = void 0, this.skew = void 0, this.width = void 0, this.maxFontSize = void 0, this.classes = void 0, this.style = void 0, this.text = e, this.height = t || 0, this.depth = r || 0, this.italic = a || 0, this.skew = i || 0, this.width = l || 0, this.classes = s || [], this.style = o || {}, this.maxFontSize = 0;
    var c = bc(this.text.charCodeAt(0));
    c && this.classes.push(c + "_fallback"), /[îïíì]/.test(this.text) && (this.text = Nc[this.text]);
  }
  hasClass(e) {
    return j.contains(this.classes, e);
  }
  /**
   * Creates a text node or span from a symbol node. Note that a span is only
   * created if it is needed.
   */
  toNode() {
    var e = document.createTextNode(this.text), t = null;
    this.italic > 0 && (t = document.createElement("span"), t.style.marginRight = P(this.italic)), this.classes.length > 0 && (t = t || document.createElement("span"), t.className = D0(this.classes));
    for (var r in this.style)
      this.style.hasOwnProperty(r) && (t = t || document.createElement("span"), t.style[r] = this.style[r]);
    return t ? (t.appendChild(e), t) : e;
  }
  /**
   * Creates markup for a symbol node.
   */
  toMarkup() {
    var e = !1, t = "<span";
    this.classes.length && (e = !0, t += ' class="', t += j.escape(D0(this.classes)), t += '"');
    var r = "";
    this.italic > 0 && (r += "margin-right:" + this.italic + "em;");
    for (var a in this.style)
      this.style.hasOwnProperty(a) && (r += j.hyphenate(a) + ":" + this.style[a] + ";");
    r && (e = !0, t += ' style="' + j.escape(r) + '"');
    var i = j.escape(this.text);
    return e ? (t += ">", t += i, t += "</span>", t) : i;
  }
}
class h0 {
  constructor(e, t) {
    this.children = void 0, this.attributes = void 0, this.children = e || [], this.attributes = t || {};
  }
  toNode() {
    var e = "http://www.w3.org/2000/svg", t = document.createElementNS(e, "svg");
    for (var r in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, r) && t.setAttribute(r, this.attributes[r]);
    for (var a = 0; a < this.children.length; a++)
      t.appendChild(this.children[a].toNode());
    return t;
  }
  toMarkup() {
    var e = '<svg xmlns="http://www.w3.org/2000/svg"';
    for (var t in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, t) && (e += " " + t + '="' + j.escape(this.attributes[t]) + '"');
    e += ">";
    for (var r = 0; r < this.children.length; r++)
      e += this.children[r].toMarkup();
    return e += "</svg>", e;
  }
}
class x0 {
  constructor(e, t) {
    this.pathName = void 0, this.alternate = void 0, this.pathName = e, this.alternate = t;
  }
  toNode() {
    var e = "http://www.w3.org/2000/svg", t = document.createElementNS(e, "path");
    return this.alternate ? t.setAttribute("d", this.alternate) : t.setAttribute("d", ul[this.pathName]), t;
  }
  toMarkup() {
    return this.alternate ? '<path d="' + j.escape(this.alternate) + '"/>' : '<path d="' + j.escape(ul[this.pathName]) + '"/>';
  }
}
class Ha {
  constructor(e) {
    this.attributes = void 0, this.attributes = e || {};
  }
  toNode() {
    var e = "http://www.w3.org/2000/svg", t = document.createElementNS(e, "line");
    for (var r in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, r) && t.setAttribute(r, this.attributes[r]);
    return t;
  }
  toMarkup() {
    var e = "<line";
    for (var t in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, t) && (e += " " + t + '="' + j.escape(this.attributes[t]) + '"');
    return e += "/>", e;
  }
}
function ml(n) {
  if (n instanceof dt)
    return n;
  throw new Error("Expected symbolNode but got " + String(n) + ".");
}
function Rc(n) {
  if (n instanceof Mr)
    return n;
  throw new Error("Expected span<HtmlDomNode> but got " + String(n) + ".");
}
var Ic = {
  bin: 1,
  close: 1,
  inner: 1,
  open: 1,
  punct: 1,
  rel: 1
}, Lc = {
  "accent-token": 1,
  mathord: 1,
  "op-token": 1,
  spacing: 1,
  textord: 1
}, de = {
  math: {},
  text: {}
};
function u(n, e, t, r, a, i) {
  de[n][a] = {
    font: e,
    group: t,
    replace: r
  }, i && r && (de[n][r] = de[n][a]);
}
var h = "math", N = "text", m = "main", w = "ams", ve = "accent-token", V = "bin", Xe = "close", lr = "inner", K = "mathord", Fe = "op-token", st = "open", Rn = "punct", _ = "rel", d0 = "spacing", x = "textord";
u(h, m, _, "≡", "\\equiv", !0);
u(h, m, _, "≺", "\\prec", !0);
u(h, m, _, "≻", "\\succ", !0);
u(h, m, _, "∼", "\\sim", !0);
u(h, m, _, "⊥", "\\perp");
u(h, m, _, "⪯", "\\preceq", !0);
u(h, m, _, "⪰", "\\succeq", !0);
u(h, m, _, "≃", "\\simeq", !0);
u(h, m, _, "∣", "\\mid", !0);
u(h, m, _, "≪", "\\ll", !0);
u(h, m, _, "≫", "\\gg", !0);
u(h, m, _, "≍", "\\asymp", !0);
u(h, m, _, "∥", "\\parallel");
u(h, m, _, "⋈", "\\bowtie", !0);
u(h, m, _, "⌣", "\\smile", !0);
u(h, m, _, "⊑", "\\sqsubseteq", !0);
u(h, m, _, "⊒", "\\sqsupseteq", !0);
u(h, m, _, "≐", "\\doteq", !0);
u(h, m, _, "⌢", "\\frown", !0);
u(h, m, _, "∋", "\\ni", !0);
u(h, m, _, "∝", "\\propto", !0);
u(h, m, _, "⊢", "\\vdash", !0);
u(h, m, _, "⊣", "\\dashv", !0);
u(h, m, _, "∋", "\\owns");
u(h, m, Rn, ".", "\\ldotp");
u(h, m, Rn, "⋅", "\\cdotp");
u(h, m, x, "#", "\\#");
u(N, m, x, "#", "\\#");
u(h, m, x, "&", "\\&");
u(N, m, x, "&", "\\&");
u(h, m, x, "ℵ", "\\aleph", !0);
u(h, m, x, "∀", "\\forall", !0);
u(h, m, x, "ℏ", "\\hbar", !0);
u(h, m, x, "∃", "\\exists", !0);
u(h, m, x, "∇", "\\nabla", !0);
u(h, m, x, "♭", "\\flat", !0);
u(h, m, x, "ℓ", "\\ell", !0);
u(h, m, x, "♮", "\\natural", !0);
u(h, m, x, "♣", "\\clubsuit", !0);
u(h, m, x, "℘", "\\wp", !0);
u(h, m, x, "♯", "\\sharp", !0);
u(h, m, x, "♢", "\\diamondsuit", !0);
u(h, m, x, "ℜ", "\\Re", !0);
u(h, m, x, "♡", "\\heartsuit", !0);
u(h, m, x, "ℑ", "\\Im", !0);
u(h, m, x, "♠", "\\spadesuit", !0);
u(h, m, x, "§", "\\S", !0);
u(N, m, x, "§", "\\S");
u(h, m, x, "¶", "\\P", !0);
u(N, m, x, "¶", "\\P");
u(h, m, x, "†", "\\dag");
u(N, m, x, "†", "\\dag");
u(N, m, x, "†", "\\textdagger");
u(h, m, x, "‡", "\\ddag");
u(N, m, x, "‡", "\\ddag");
u(N, m, x, "‡", "\\textdaggerdbl");
u(h, m, Xe, "⎱", "\\rmoustache", !0);
u(h, m, st, "⎰", "\\lmoustache", !0);
u(h, m, Xe, "⟯", "\\rgroup", !0);
u(h, m, st, "⟮", "\\lgroup", !0);
u(h, m, V, "∓", "\\mp", !0);
u(h, m, V, "⊖", "\\ominus", !0);
u(h, m, V, "⊎", "\\uplus", !0);
u(h, m, V, "⊓", "\\sqcap", !0);
u(h, m, V, "∗", "\\ast");
u(h, m, V, "⊔", "\\sqcup", !0);
u(h, m, V, "◯", "\\bigcirc", !0);
u(h, m, V, "∙", "\\bullet", !0);
u(h, m, V, "‡", "\\ddagger");
u(h, m, V, "≀", "\\wr", !0);
u(h, m, V, "⨿", "\\amalg");
u(h, m, V, "&", "\\And");
u(h, m, _, "⟵", "\\longleftarrow", !0);
u(h, m, _, "⇐", "\\Leftarrow", !0);
u(h, m, _, "⟸", "\\Longleftarrow", !0);
u(h, m, _, "⟶", "\\longrightarrow", !0);
u(h, m, _, "⇒", "\\Rightarrow", !0);
u(h, m, _, "⟹", "\\Longrightarrow", !0);
u(h, m, _, "↔", "\\leftrightarrow", !0);
u(h, m, _, "⟷", "\\longleftrightarrow", !0);
u(h, m, _, "⇔", "\\Leftrightarrow", !0);
u(h, m, _, "⟺", "\\Longleftrightarrow", !0);
u(h, m, _, "↦", "\\mapsto", !0);
u(h, m, _, "⟼", "\\longmapsto", !0);
u(h, m, _, "↗", "\\nearrow", !0);
u(h, m, _, "↩", "\\hookleftarrow", !0);
u(h, m, _, "↪", "\\hookrightarrow", !0);
u(h, m, _, "↘", "\\searrow", !0);
u(h, m, _, "↼", "\\leftharpoonup", !0);
u(h, m, _, "⇀", "\\rightharpoonup", !0);
u(h, m, _, "↙", "\\swarrow", !0);
u(h, m, _, "↽", "\\leftharpoondown", !0);
u(h, m, _, "⇁", "\\rightharpoondown", !0);
u(h, m, _, "↖", "\\nwarrow", !0);
u(h, m, _, "⇌", "\\rightleftharpoons", !0);
u(h, w, _, "≮", "\\nless", !0);
u(h, w, _, "", "\\@nleqslant");
u(h, w, _, "", "\\@nleqq");
u(h, w, _, "⪇", "\\lneq", !0);
u(h, w, _, "≨", "\\lneqq", !0);
u(h, w, _, "", "\\@lvertneqq");
u(h, w, _, "⋦", "\\lnsim", !0);
u(h, w, _, "⪉", "\\lnapprox", !0);
u(h, w, _, "⊀", "\\nprec", !0);
u(h, w, _, "⋠", "\\npreceq", !0);
u(h, w, _, "⋨", "\\precnsim", !0);
u(h, w, _, "⪹", "\\precnapprox", !0);
u(h, w, _, "≁", "\\nsim", !0);
u(h, w, _, "", "\\@nshortmid");
u(h, w, _, "∤", "\\nmid", !0);
u(h, w, _, "⊬", "\\nvdash", !0);
u(h, w, _, "⊭", "\\nvDash", !0);
u(h, w, _, "⋪", "\\ntriangleleft");
u(h, w, _, "⋬", "\\ntrianglelefteq", !0);
u(h, w, _, "⊊", "\\subsetneq", !0);
u(h, w, _, "", "\\@varsubsetneq");
u(h, w, _, "⫋", "\\subsetneqq", !0);
u(h, w, _, "", "\\@varsubsetneqq");
u(h, w, _, "≯", "\\ngtr", !0);
u(h, w, _, "", "\\@ngeqslant");
u(h, w, _, "", "\\@ngeqq");
u(h, w, _, "⪈", "\\gneq", !0);
u(h, w, _, "≩", "\\gneqq", !0);
u(h, w, _, "", "\\@gvertneqq");
u(h, w, _, "⋧", "\\gnsim", !0);
u(h, w, _, "⪊", "\\gnapprox", !0);
u(h, w, _, "⊁", "\\nsucc", !0);
u(h, w, _, "⋡", "\\nsucceq", !0);
u(h, w, _, "⋩", "\\succnsim", !0);
u(h, w, _, "⪺", "\\succnapprox", !0);
u(h, w, _, "≆", "\\ncong", !0);
u(h, w, _, "", "\\@nshortparallel");
u(h, w, _, "∦", "\\nparallel", !0);
u(h, w, _, "⊯", "\\nVDash", !0);
u(h, w, _, "⋫", "\\ntriangleright");
u(h, w, _, "⋭", "\\ntrianglerighteq", !0);
u(h, w, _, "", "\\@nsupseteqq");
u(h, w, _, "⊋", "\\supsetneq", !0);
u(h, w, _, "", "\\@varsupsetneq");
u(h, w, _, "⫌", "\\supsetneqq", !0);
u(h, w, _, "", "\\@varsupsetneqq");
u(h, w, _, "⊮", "\\nVdash", !0);
u(h, w, _, "⪵", "\\precneqq", !0);
u(h, w, _, "⪶", "\\succneqq", !0);
u(h, w, _, "", "\\@nsubseteqq");
u(h, w, V, "⊴", "\\unlhd");
u(h, w, V, "⊵", "\\unrhd");
u(h, w, _, "↚", "\\nleftarrow", !0);
u(h, w, _, "↛", "\\nrightarrow", !0);
u(h, w, _, "⇍", "\\nLeftarrow", !0);
u(h, w, _, "⇏", "\\nRightarrow", !0);
u(h, w, _, "↮", "\\nleftrightarrow", !0);
u(h, w, _, "⇎", "\\nLeftrightarrow", !0);
u(h, w, _, "△", "\\vartriangle");
u(h, w, x, "ℏ", "\\hslash");
u(h, w, x, "▽", "\\triangledown");
u(h, w, x, "◊", "\\lozenge");
u(h, w, x, "Ⓢ", "\\circledS");
u(h, w, x, "®", "\\circledR");
u(N, w, x, "®", "\\circledR");
u(h, w, x, "∡", "\\measuredangle", !0);
u(h, w, x, "∄", "\\nexists");
u(h, w, x, "℧", "\\mho");
u(h, w, x, "Ⅎ", "\\Finv", !0);
u(h, w, x, "⅁", "\\Game", !0);
u(h, w, x, "‵", "\\backprime");
u(h, w, x, "▲", "\\blacktriangle");
u(h, w, x, "▼", "\\blacktriangledown");
u(h, w, x, "■", "\\blacksquare");
u(h, w, x, "⧫", "\\blacklozenge");
u(h, w, x, "★", "\\bigstar");
u(h, w, x, "∢", "\\sphericalangle", !0);
u(h, w, x, "∁", "\\complement", !0);
u(h, w, x, "ð", "\\eth", !0);
u(N, m, x, "ð", "ð");
u(h, w, x, "╱", "\\diagup");
u(h, w, x, "╲", "\\diagdown");
u(h, w, x, "□", "\\square");
u(h, w, x, "□", "\\Box");
u(h, w, x, "◊", "\\Diamond");
u(h, w, x, "¥", "\\yen", !0);
u(N, w, x, "¥", "\\yen", !0);
u(h, w, x, "✓", "\\checkmark", !0);
u(N, w, x, "✓", "\\checkmark");
u(h, w, x, "ℶ", "\\beth", !0);
u(h, w, x, "ℸ", "\\daleth", !0);
u(h, w, x, "ℷ", "\\gimel", !0);
u(h, w, x, "ϝ", "\\digamma", !0);
u(h, w, x, "ϰ", "\\varkappa");
u(h, w, st, "┌", "\\@ulcorner", !0);
u(h, w, Xe, "┐", "\\@urcorner", !0);
u(h, w, st, "└", "\\@llcorner", !0);
u(h, w, Xe, "┘", "\\@lrcorner", !0);
u(h, w, _, "≦", "\\leqq", !0);
u(h, w, _, "⩽", "\\leqslant", !0);
u(h, w, _, "⪕", "\\eqslantless", !0);
u(h, w, _, "≲", "\\lesssim", !0);
u(h, w, _, "⪅", "\\lessapprox", !0);
u(h, w, _, "≊", "\\approxeq", !0);
u(h, w, V, "⋖", "\\lessdot");
u(h, w, _, "⋘", "\\lll", !0);
u(h, w, _, "≶", "\\lessgtr", !0);
u(h, w, _, "⋚", "\\lesseqgtr", !0);
u(h, w, _, "⪋", "\\lesseqqgtr", !0);
u(h, w, _, "≑", "\\doteqdot");
u(h, w, _, "≓", "\\risingdotseq", !0);
u(h, w, _, "≒", "\\fallingdotseq", !0);
u(h, w, _, "∽", "\\backsim", !0);
u(h, w, _, "⋍", "\\backsimeq", !0);
u(h, w, _, "⫅", "\\subseteqq", !0);
u(h, w, _, "⋐", "\\Subset", !0);
u(h, w, _, "⊏", "\\sqsubset", !0);
u(h, w, _, "≼", "\\preccurlyeq", !0);
u(h, w, _, "⋞", "\\curlyeqprec", !0);
u(h, w, _, "≾", "\\precsim", !0);
u(h, w, _, "⪷", "\\precapprox", !0);
u(h, w, _, "⊲", "\\vartriangleleft");
u(h, w, _, "⊴", "\\trianglelefteq");
u(h, w, _, "⊨", "\\vDash", !0);
u(h, w, _, "⊪", "\\Vvdash", !0);
u(h, w, _, "⌣", "\\smallsmile");
u(h, w, _, "⌢", "\\smallfrown");
u(h, w, _, "≏", "\\bumpeq", !0);
u(h, w, _, "≎", "\\Bumpeq", !0);
u(h, w, _, "≧", "\\geqq", !0);
u(h, w, _, "⩾", "\\geqslant", !0);
u(h, w, _, "⪖", "\\eqslantgtr", !0);
u(h, w, _, "≳", "\\gtrsim", !0);
u(h, w, _, "⪆", "\\gtrapprox", !0);
u(h, w, V, "⋗", "\\gtrdot");
u(h, w, _, "⋙", "\\ggg", !0);
u(h, w, _, "≷", "\\gtrless", !0);
u(h, w, _, "⋛", "\\gtreqless", !0);
u(h, w, _, "⪌", "\\gtreqqless", !0);
u(h, w, _, "≖", "\\eqcirc", !0);
u(h, w, _, "≗", "\\circeq", !0);
u(h, w, _, "≜", "\\triangleq", !0);
u(h, w, _, "∼", "\\thicksim");
u(h, w, _, "≈", "\\thickapprox");
u(h, w, _, "⫆", "\\supseteqq", !0);
u(h, w, _, "⋑", "\\Supset", !0);
u(h, w, _, "⊐", "\\sqsupset", !0);
u(h, w, _, "≽", "\\succcurlyeq", !0);
u(h, w, _, "⋟", "\\curlyeqsucc", !0);
u(h, w, _, "≿", "\\succsim", !0);
u(h, w, _, "⪸", "\\succapprox", !0);
u(h, w, _, "⊳", "\\vartriangleright");
u(h, w, _, "⊵", "\\trianglerighteq");
u(h, w, _, "⊩", "\\Vdash", !0);
u(h, w, _, "∣", "\\shortmid");
u(h, w, _, "∥", "\\shortparallel");
u(h, w, _, "≬", "\\between", !0);
u(h, w, _, "⋔", "\\pitchfork", !0);
u(h, w, _, "∝", "\\varpropto");
u(h, w, _, "◀", "\\blacktriangleleft");
u(h, w, _, "∴", "\\therefore", !0);
u(h, w, _, "∍", "\\backepsilon");
u(h, w, _, "▶", "\\blacktriangleright");
u(h, w, _, "∵", "\\because", !0);
u(h, w, _, "⋘", "\\llless");
u(h, w, _, "⋙", "\\gggtr");
u(h, w, V, "⊲", "\\lhd");
u(h, w, V, "⊳", "\\rhd");
u(h, w, _, "≂", "\\eqsim", !0);
u(h, m, _, "⋈", "\\Join");
u(h, w, _, "≑", "\\Doteq", !0);
u(h, w, V, "∔", "\\dotplus", !0);
u(h, w, V, "∖", "\\smallsetminus");
u(h, w, V, "⋒", "\\Cap", !0);
u(h, w, V, "⋓", "\\Cup", !0);
u(h, w, V, "⩞", "\\doublebarwedge", !0);
u(h, w, V, "⊟", "\\boxminus", !0);
u(h, w, V, "⊞", "\\boxplus", !0);
u(h, w, V, "⋇", "\\divideontimes", !0);
u(h, w, V, "⋉", "\\ltimes", !0);
u(h, w, V, "⋊", "\\rtimes", !0);
u(h, w, V, "⋋", "\\leftthreetimes", !0);
u(h, w, V, "⋌", "\\rightthreetimes", !0);
u(h, w, V, "⋏", "\\curlywedge", !0);
u(h, w, V, "⋎", "\\curlyvee", !0);
u(h, w, V, "⊝", "\\circleddash", !0);
u(h, w, V, "⊛", "\\circledast", !0);
u(h, w, V, "⋅", "\\centerdot");
u(h, w, V, "⊺", "\\intercal", !0);
u(h, w, V, "⋒", "\\doublecap");
u(h, w, V, "⋓", "\\doublecup");
u(h, w, V, "⊠", "\\boxtimes", !0);
u(h, w, _, "⇢", "\\dashrightarrow", !0);
u(h, w, _, "⇠", "\\dashleftarrow", !0);
u(h, w, _, "⇇", "\\leftleftarrows", !0);
u(h, w, _, "⇆", "\\leftrightarrows", !0);
u(h, w, _, "⇚", "\\Lleftarrow", !0);
u(h, w, _, "↞", "\\twoheadleftarrow", !0);
u(h, w, _, "↢", "\\leftarrowtail", !0);
u(h, w, _, "↫", "\\looparrowleft", !0);
u(h, w, _, "⇋", "\\leftrightharpoons", !0);
u(h, w, _, "↶", "\\curvearrowleft", !0);
u(h, w, _, "↺", "\\circlearrowleft", !0);
u(h, w, _, "↰", "\\Lsh", !0);
u(h, w, _, "⇈", "\\upuparrows", !0);
u(h, w, _, "↿", "\\upharpoonleft", !0);
u(h, w, _, "⇃", "\\downharpoonleft", !0);
u(h, m, _, "⊶", "\\origof", !0);
u(h, m, _, "⊷", "\\imageof", !0);
u(h, w, _, "⊸", "\\multimap", !0);
u(h, w, _, "↭", "\\leftrightsquigarrow", !0);
u(h, w, _, "⇉", "\\rightrightarrows", !0);
u(h, w, _, "⇄", "\\rightleftarrows", !0);
u(h, w, _, "↠", "\\twoheadrightarrow", !0);
u(h, w, _, "↣", "\\rightarrowtail", !0);
u(h, w, _, "↬", "\\looparrowright", !0);
u(h, w, _, "↷", "\\curvearrowright", !0);
u(h, w, _, "↻", "\\circlearrowright", !0);
u(h, w, _, "↱", "\\Rsh", !0);
u(h, w, _, "⇊", "\\downdownarrows", !0);
u(h, w, _, "↾", "\\upharpoonright", !0);
u(h, w, _, "⇂", "\\downharpoonright", !0);
u(h, w, _, "⇝", "\\rightsquigarrow", !0);
u(h, w, _, "⇝", "\\leadsto");
u(h, w, _, "⇛", "\\Rrightarrow", !0);
u(h, w, _, "↾", "\\restriction");
u(h, m, x, "‘", "`");
u(h, m, x, "$", "\\$");
u(N, m, x, "$", "\\$");
u(N, m, x, "$", "\\textdollar");
u(h, m, x, "%", "\\%");
u(N, m, x, "%", "\\%");
u(h, m, x, "_", "\\_");
u(N, m, x, "_", "\\_");
u(N, m, x, "_", "\\textunderscore");
u(h, m, x, "∠", "\\angle", !0);
u(h, m, x, "∞", "\\infty", !0);
u(h, m, x, "′", "\\prime");
u(h, m, x, "△", "\\triangle");
u(h, m, x, "Γ", "\\Gamma", !0);
u(h, m, x, "Δ", "\\Delta", !0);
u(h, m, x, "Θ", "\\Theta", !0);
u(h, m, x, "Λ", "\\Lambda", !0);
u(h, m, x, "Ξ", "\\Xi", !0);
u(h, m, x, "Π", "\\Pi", !0);
u(h, m, x, "Σ", "\\Sigma", !0);
u(h, m, x, "Υ", "\\Upsilon", !0);
u(h, m, x, "Φ", "\\Phi", !0);
u(h, m, x, "Ψ", "\\Psi", !0);
u(h, m, x, "Ω", "\\Omega", !0);
u(h, m, x, "A", "Α");
u(h, m, x, "B", "Β");
u(h, m, x, "E", "Ε");
u(h, m, x, "Z", "Ζ");
u(h, m, x, "H", "Η");
u(h, m, x, "I", "Ι");
u(h, m, x, "K", "Κ");
u(h, m, x, "M", "Μ");
u(h, m, x, "N", "Ν");
u(h, m, x, "O", "Ο");
u(h, m, x, "P", "Ρ");
u(h, m, x, "T", "Τ");
u(h, m, x, "X", "Χ");
u(h, m, x, "¬", "\\neg", !0);
u(h, m, x, "¬", "\\lnot");
u(h, m, x, "⊤", "\\top");
u(h, m, x, "⊥", "\\bot");
u(h, m, x, "∅", "\\emptyset");
u(h, w, x, "∅", "\\varnothing");
u(h, m, K, "α", "\\alpha", !0);
u(h, m, K, "β", "\\beta", !0);
u(h, m, K, "γ", "\\gamma", !0);
u(h, m, K, "δ", "\\delta", !0);
u(h, m, K, "ϵ", "\\epsilon", !0);
u(h, m, K, "ζ", "\\zeta", !0);
u(h, m, K, "η", "\\eta", !0);
u(h, m, K, "θ", "\\theta", !0);
u(h, m, K, "ι", "\\iota", !0);
u(h, m, K, "κ", "\\kappa", !0);
u(h, m, K, "λ", "\\lambda", !0);
u(h, m, K, "μ", "\\mu", !0);
u(h, m, K, "ν", "\\nu", !0);
u(h, m, K, "ξ", "\\xi", !0);
u(h, m, K, "ο", "\\omicron", !0);
u(h, m, K, "π", "\\pi", !0);
u(h, m, K, "ρ", "\\rho", !0);
u(h, m, K, "σ", "\\sigma", !0);
u(h, m, K, "τ", "\\tau", !0);
u(h, m, K, "υ", "\\upsilon", !0);
u(h, m, K, "ϕ", "\\phi", !0);
u(h, m, K, "χ", "\\chi", !0);
u(h, m, K, "ψ", "\\psi", !0);
u(h, m, K, "ω", "\\omega", !0);
u(h, m, K, "ε", "\\varepsilon", !0);
u(h, m, K, "ϑ", "\\vartheta", !0);
u(h, m, K, "ϖ", "\\varpi", !0);
u(h, m, K, "ϱ", "\\varrho", !0);
u(h, m, K, "ς", "\\varsigma", !0);
u(h, m, K, "φ", "\\varphi", !0);
u(h, m, V, "∗", "*", !0);
u(h, m, V, "+", "+");
u(h, m, V, "−", "-", !0);
u(h, m, V, "⋅", "\\cdot", !0);
u(h, m, V, "∘", "\\circ", !0);
u(h, m, V, "÷", "\\div", !0);
u(h, m, V, "±", "\\pm", !0);
u(h, m, V, "×", "\\times", !0);
u(h, m, V, "∩", "\\cap", !0);
u(h, m, V, "∪", "\\cup", !0);
u(h, m, V, "∖", "\\setminus", !0);
u(h, m, V, "∧", "\\land");
u(h, m, V, "∨", "\\lor");
u(h, m, V, "∧", "\\wedge", !0);
u(h, m, V, "∨", "\\vee", !0);
u(h, m, x, "√", "\\surd");
u(h, m, st, "⟨", "\\langle", !0);
u(h, m, st, "∣", "\\lvert");
u(h, m, st, "∥", "\\lVert");
u(h, m, Xe, "?", "?");
u(h, m, Xe, "!", "!");
u(h, m, Xe, "⟩", "\\rangle", !0);
u(h, m, Xe, "∣", "\\rvert");
u(h, m, Xe, "∥", "\\rVert");
u(h, m, _, "=", "=");
u(h, m, _, ":", ":");
u(h, m, _, "≈", "\\approx", !0);
u(h, m, _, "≅", "\\cong", !0);
u(h, m, _, "≥", "\\ge");
u(h, m, _, "≥", "\\geq", !0);
u(h, m, _, "←", "\\gets");
u(h, m, _, ">", "\\gt", !0);
u(h, m, _, "∈", "\\in", !0);
u(h, m, _, "", "\\@not");
u(h, m, _, "⊂", "\\subset", !0);
u(h, m, _, "⊃", "\\supset", !0);
u(h, m, _, "⊆", "\\subseteq", !0);
u(h, m, _, "⊇", "\\supseteq", !0);
u(h, w, _, "⊈", "\\nsubseteq", !0);
u(h, w, _, "⊉", "\\nsupseteq", !0);
u(h, m, _, "⊨", "\\models");
u(h, m, _, "←", "\\leftarrow", !0);
u(h, m, _, "≤", "\\le");
u(h, m, _, "≤", "\\leq", !0);
u(h, m, _, "<", "\\lt", !0);
u(h, m, _, "→", "\\rightarrow", !0);
u(h, m, _, "→", "\\to");
u(h, w, _, "≱", "\\ngeq", !0);
u(h, w, _, "≰", "\\nleq", !0);
u(h, m, d0, " ", "\\ ");
u(h, m, d0, " ", "\\space");
u(h, m, d0, " ", "\\nobreakspace");
u(N, m, d0, " ", "\\ ");
u(N, m, d0, " ", " ");
u(N, m, d0, " ", "\\space");
u(N, m, d0, " ", "\\nobreakspace");
u(h, m, d0, null, "\\nobreak");
u(h, m, d0, null, "\\allowbreak");
u(h, m, Rn, ",", ",");
u(h, m, Rn, ";", ";");
u(h, w, V, "⊼", "\\barwedge", !0);
u(h, w, V, "⊻", "\\veebar", !0);
u(h, m, V, "⊙", "\\odot", !0);
u(h, m, V, "⊕", "\\oplus", !0);
u(h, m, V, "⊗", "\\otimes", !0);
u(h, m, x, "∂", "\\partial", !0);
u(h, m, V, "⊘", "\\oslash", !0);
u(h, w, V, "⊚", "\\circledcirc", !0);
u(h, w, V, "⊡", "\\boxdot", !0);
u(h, m, V, "△", "\\bigtriangleup");
u(h, m, V, "▽", "\\bigtriangledown");
u(h, m, V, "†", "\\dagger");
u(h, m, V, "⋄", "\\diamond");
u(h, m, V, "⋆", "\\star");
u(h, m, V, "◃", "\\triangleleft");
u(h, m, V, "▹", "\\triangleright");
u(h, m, st, "{", "\\{");
u(N, m, x, "{", "\\{");
u(N, m, x, "{", "\\textbraceleft");
u(h, m, Xe, "}", "\\}");
u(N, m, x, "}", "\\}");
u(N, m, x, "}", "\\textbraceright");
u(h, m, st, "{", "\\lbrace");
u(h, m, Xe, "}", "\\rbrace");
u(h, m, st, "[", "\\lbrack", !0);
u(N, m, x, "[", "\\lbrack", !0);
u(h, m, Xe, "]", "\\rbrack", !0);
u(N, m, x, "]", "\\rbrack", !0);
u(h, m, st, "(", "\\lparen", !0);
u(h, m, Xe, ")", "\\rparen", !0);
u(N, m, x, "<", "\\textless", !0);
u(N, m, x, ">", "\\textgreater", !0);
u(h, m, st, "⌊", "\\lfloor", !0);
u(h, m, Xe, "⌋", "\\rfloor", !0);
u(h, m, st, "⌈", "\\lceil", !0);
u(h, m, Xe, "⌉", "\\rceil", !0);
u(h, m, x, "\\", "\\backslash");
u(h, m, x, "∣", "|");
u(h, m, x, "∣", "\\vert");
u(N, m, x, "|", "\\textbar", !0);
u(h, m, x, "∥", "\\|");
u(h, m, x, "∥", "\\Vert");
u(N, m, x, "∥", "\\textbardbl");
u(N, m, x, "~", "\\textasciitilde");
u(N, m, x, "\\", "\\textbackslash");
u(N, m, x, "^", "\\textasciicircum");
u(h, m, _, "↑", "\\uparrow", !0);
u(h, m, _, "⇑", "\\Uparrow", !0);
u(h, m, _, "↓", "\\downarrow", !0);
u(h, m, _, "⇓", "\\Downarrow", !0);
u(h, m, _, "↕", "\\updownarrow", !0);
u(h, m, _, "⇕", "\\Updownarrow", !0);
u(h, m, Fe, "∐", "\\coprod");
u(h, m, Fe, "⋁", "\\bigvee");
u(h, m, Fe, "⋀", "\\bigwedge");
u(h, m, Fe, "⨄", "\\biguplus");
u(h, m, Fe, "⋂", "\\bigcap");
u(h, m, Fe, "⋃", "\\bigcup");
u(h, m, Fe, "∫", "\\int");
u(h, m, Fe, "∫", "\\intop");
u(h, m, Fe, "∬", "\\iint");
u(h, m, Fe, "∭", "\\iiint");
u(h, m, Fe, "∏", "\\prod");
u(h, m, Fe, "∑", "\\sum");
u(h, m, Fe, "⨂", "\\bigotimes");
u(h, m, Fe, "⨁", "\\bigoplus");
u(h, m, Fe, "⨀", "\\bigodot");
u(h, m, Fe, "∮", "\\oint");
u(h, m, Fe, "∯", "\\oiint");
u(h, m, Fe, "∰", "\\oiiint");
u(h, m, Fe, "⨆", "\\bigsqcup");
u(h, m, Fe, "∫", "\\smallint");
u(N, m, lr, "…", "\\textellipsis");
u(h, m, lr, "…", "\\mathellipsis");
u(N, m, lr, "…", "\\ldots", !0);
u(h, m, lr, "…", "\\ldots", !0);
u(h, m, lr, "⋯", "\\@cdots", !0);
u(h, m, lr, "⋱", "\\ddots", !0);
u(h, m, x, "⋮", "\\varvdots");
u(N, m, x, "⋮", "\\varvdots");
u(h, m, ve, "ˊ", "\\acute");
u(h, m, ve, "ˋ", "\\grave");
u(h, m, ve, "¨", "\\ddot");
u(h, m, ve, "~", "\\tilde");
u(h, m, ve, "ˉ", "\\bar");
u(h, m, ve, "˘", "\\breve");
u(h, m, ve, "ˇ", "\\check");
u(h, m, ve, "^", "\\hat");
u(h, m, ve, "⃗", "\\vec");
u(h, m, ve, "˙", "\\dot");
u(h, m, ve, "˚", "\\mathring");
u(h, m, K, "", "\\@imath");
u(h, m, K, "", "\\@jmath");
u(h, m, x, "ı", "ı");
u(h, m, x, "ȷ", "ȷ");
u(N, m, x, "ı", "\\i", !0);
u(N, m, x, "ȷ", "\\j", !0);
u(N, m, x, "ß", "\\ss", !0);
u(N, m, x, "æ", "\\ae", !0);
u(N, m, x, "œ", "\\oe", !0);
u(N, m, x, "ø", "\\o", !0);
u(N, m, x, "Æ", "\\AE", !0);
u(N, m, x, "Œ", "\\OE", !0);
u(N, m, x, "Ø", "\\O", !0);
u(N, m, ve, "ˊ", "\\'");
u(N, m, ve, "ˋ", "\\`");
u(N, m, ve, "ˆ", "\\^");
u(N, m, ve, "˜", "\\~");
u(N, m, ve, "ˉ", "\\=");
u(N, m, ve, "˘", "\\u");
u(N, m, ve, "˙", "\\.");
u(N, m, ve, "¸", "\\c");
u(N, m, ve, "˚", "\\r");
u(N, m, ve, "ˇ", "\\v");
u(N, m, ve, "¨", '\\"');
u(N, m, ve, "˝", "\\H");
u(N, m, ve, "◯", "\\textcircled");
var Ro = {
  "--": !0,
  "---": !0,
  "``": !0,
  "''": !0
};
u(N, m, x, "–", "--", !0);
u(N, m, x, "–", "\\textendash");
u(N, m, x, "—", "---", !0);
u(N, m, x, "—", "\\textemdash");
u(N, m, x, "‘", "`", !0);
u(N, m, x, "‘", "\\textquoteleft");
u(N, m, x, "’", "'", !0);
u(N, m, x, "’", "\\textquoteright");
u(N, m, x, "“", "``", !0);
u(N, m, x, "“", "\\textquotedblleft");
u(N, m, x, "”", "''", !0);
u(N, m, x, "”", "\\textquotedblright");
u(h, m, x, "°", "\\degree", !0);
u(N, m, x, "°", "\\degree");
u(N, m, x, "°", "\\textdegree", !0);
u(h, m, x, "£", "\\pounds");
u(h, m, x, "£", "\\mathsterling", !0);
u(N, m, x, "£", "\\pounds");
u(N, m, x, "£", "\\textsterling", !0);
u(h, w, x, "✠", "\\maltese");
u(N, w, x, "✠", "\\maltese");
var dl = '0123456789/@."';
for (var ra = 0; ra < dl.length; ra++) {
  var pl = dl.charAt(ra);
  u(h, m, x, pl, pl);
}
var gl = '0123456789!@*()-=+";:?/.,';
for (var na = 0; na < gl.length; na++) {
  var vl = gl.charAt(na);
  u(N, m, x, vl, vl);
}
var xn = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
for (var aa = 0; aa < xn.length; aa++) {
  var Gr = xn.charAt(aa);
  u(h, m, K, Gr, Gr), u(N, m, x, Gr, Gr);
}
u(h, w, x, "C", "ℂ");
u(N, w, x, "C", "ℂ");
u(h, w, x, "H", "ℍ");
u(N, w, x, "H", "ℍ");
u(h, w, x, "N", "ℕ");
u(N, w, x, "N", "ℕ");
u(h, w, x, "P", "ℙ");
u(N, w, x, "P", "ℙ");
u(h, w, x, "Q", "ℚ");
u(N, w, x, "Q", "ℚ");
u(h, w, x, "R", "ℝ");
u(N, w, x, "R", "ℝ");
u(h, w, x, "Z", "ℤ");
u(N, w, x, "Z", "ℤ");
u(h, m, K, "h", "ℎ");
u(N, m, K, "h", "ℎ");
var J = "";
for (var He = 0; He < xn.length; He++) {
  var De = xn.charAt(He);
  J = String.fromCharCode(55349, 56320 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56372 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56424 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56580 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56684 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56736 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56788 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56840 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56944 + He), u(h, m, K, De, J), u(N, m, x, De, J), He < 26 && (J = String.fromCharCode(55349, 56632 + He), u(h, m, K, De, J), u(N, m, x, De, J), J = String.fromCharCode(55349, 56476 + He), u(h, m, K, De, J), u(N, m, x, De, J));
}
J = "𝕜";
u(h, m, K, "k", J);
u(N, m, x, "k", J);
for (var E0 = 0; E0 < 10; E0++) {
  var g0 = E0.toString();
  J = String.fromCharCode(55349, 57294 + E0), u(h, m, K, g0, J), u(N, m, x, g0, J), J = String.fromCharCode(55349, 57314 + E0), u(h, m, K, g0, J), u(N, m, x, g0, J), J = String.fromCharCode(55349, 57324 + E0), u(h, m, K, g0, J), u(N, m, x, g0, J), J = String.fromCharCode(55349, 57334 + E0), u(h, m, K, g0, J), u(N, m, x, g0, J);
}
var Ua = "ÐÞþ";
for (var ia = 0; ia < Ua.length; ia++) {
  var Vr = Ua.charAt(ia);
  u(h, m, K, Vr, Vr), u(N, m, x, Vr, Vr);
}
var Wr = [
  ["mathbf", "textbf", "Main-Bold"],
  // A-Z bold upright
  ["mathbf", "textbf", "Main-Bold"],
  // a-z bold upright
  ["mathnormal", "textit", "Math-Italic"],
  // A-Z italic
  ["mathnormal", "textit", "Math-Italic"],
  // a-z italic
  ["boldsymbol", "boldsymbol", "Main-BoldItalic"],
  // A-Z bold italic
  ["boldsymbol", "boldsymbol", "Main-BoldItalic"],
  // a-z bold italic
  // Map fancy A-Z letters to script, not calligraphic.
  // This aligns with unicode-math and math fonts (except Cambria Math).
  ["mathscr", "textscr", "Script-Regular"],
  // A-Z script
  ["", "", ""],
  // a-z script.  No font
  ["", "", ""],
  // A-Z bold script. No font
  ["", "", ""],
  // a-z bold script. No font
  ["mathfrak", "textfrak", "Fraktur-Regular"],
  // A-Z Fraktur
  ["mathfrak", "textfrak", "Fraktur-Regular"],
  // a-z Fraktur
  ["mathbb", "textbb", "AMS-Regular"],
  // A-Z double-struck
  ["mathbb", "textbb", "AMS-Regular"],
  // k double-struck
  // Note that we are using a bold font, but font metrics for regular Fraktur.
  ["mathboldfrak", "textboldfrak", "Fraktur-Regular"],
  // A-Z bold Fraktur
  ["mathboldfrak", "textboldfrak", "Fraktur-Regular"],
  // a-z bold Fraktur
  ["mathsf", "textsf", "SansSerif-Regular"],
  // A-Z sans-serif
  ["mathsf", "textsf", "SansSerif-Regular"],
  // a-z sans-serif
  ["mathboldsf", "textboldsf", "SansSerif-Bold"],
  // A-Z bold sans-serif
  ["mathboldsf", "textboldsf", "SansSerif-Bold"],
  // a-z bold sans-serif
  ["mathitsf", "textitsf", "SansSerif-Italic"],
  // A-Z italic sans-serif
  ["mathitsf", "textitsf", "SansSerif-Italic"],
  // a-z italic sans-serif
  ["", "", ""],
  // A-Z bold italic sans. No font
  ["", "", ""],
  // a-z bold italic sans. No font
  ["mathtt", "texttt", "Typewriter-Regular"],
  // A-Z monospace
  ["mathtt", "texttt", "Typewriter-Regular"]
  // a-z monospace
], bl = [
  ["mathbf", "textbf", "Main-Bold"],
  // 0-9 bold
  ["", "", ""],
  // 0-9 double-struck. No KaTeX font.
  ["mathsf", "textsf", "SansSerif-Regular"],
  // 0-9 sans-serif
  ["mathboldsf", "textboldsf", "SansSerif-Bold"],
  // 0-9 bold sans-serif
  ["mathtt", "texttt", "Typewriter-Regular"]
  // 0-9 monospace
], Oc = function(e, t) {
  var r = e.charCodeAt(0), a = e.charCodeAt(1), i = (r - 55296) * 1024 + (a - 56320) + 65536, l = t === "math" ? 0 : 1;
  if (119808 <= i && i < 120484) {
    var s = Math.floor((i - 119808) / 26);
    return [Wr[s][2], Wr[s][l]];
  } else if (120782 <= i && i <= 120831) {
    var o = Math.floor((i - 120782) / 10);
    return [bl[o][2], bl[o][l]];
  } else {
    if (i === 120485 || i === 120486)
      return [Wr[0][2], Wr[0][l]];
    if (120486 < i && i < 120782)
      return ["", ""];
    throw new L("Unsupported character: " + e);
  }
}, In = function(e, t, r) {
  return de[r][e] && de[r][e].replace && (e = de[r][e].replace), {
    value: e,
    metrics: hi(e, t, r)
  };
}, Ft = function(e, t, r, a, i) {
  var l = In(e, t, r), s = l.metrics;
  e = l.value;
  var o;
  if (s) {
    var c = s.italic;
    (r === "text" || a && a.font === "mathit") && (c = 0), o = new dt(e, s.height, s.depth, c, s.skew, s.width, i);
  } else
    typeof console < "u" && console.warn("No character metrics " + ("for '" + e + "' in style '" + t + "' and mode '" + r + "'")), o = new dt(e, 0, 0, 0, 0, 0, i);
  if (a) {
    o.maxFontSize = a.sizeMultiplier, a.style.isTight() && o.classes.push("mtight");
    var f = a.getColor();
    f && (o.style.color = f);
  }
  return o;
}, qc = function(e, t, r, a) {
  return a === void 0 && (a = []), r.font === "boldsymbol" && In(e, "Main-Bold", t).metrics ? Ft(e, "Main-Bold", t, r, a.concat(["mathbf"])) : e === "\\" || de[t][e].font === "main" ? Ft(e, "Main-Regular", t, r, a) : Ft(e, "AMS-Regular", t, r, a.concat(["amsrm"]));
}, Pc = function(e, t, r, a, i) {
  return i !== "textord" && In(e, "Math-BoldItalic", t).metrics ? {
    fontName: "Math-BoldItalic",
    fontClass: "boldsymbol"
  } : {
    fontName: "Main-Bold",
    fontClass: "mathbf"
  };
}, Hc = function(e, t, r) {
  var a = e.mode, i = e.text, l = ["mord"], s = a === "math" || a === "text" && t.font, o = s ? t.font : t.fontFamily, c = "", f = "";
  if (i.charCodeAt(0) === 55349 && ([c, f] = Oc(i, a)), c.length > 0)
    return Ft(i, c, a, t, l.concat(f));
  if (o) {
    var d, g;
    if (o === "boldsymbol") {
      var v = Pc(i, a, t, l, r);
      d = v.fontName, g = [v.fontClass];
    } else s ? (d = Oo[o].fontName, g = [o]) : (d = Xr(o, t.fontWeight, t.fontShape), g = [o, t.fontWeight, t.fontShape]);
    if (In(i, d, a).metrics)
      return Ft(i, d, a, t, l.concat(g));
    if (Ro.hasOwnProperty(i) && d.slice(0, 10) === "Typewriter") {
      for (var y = [], k = 0; k < i.length; k++)
        y.push(Ft(i[k], d, a, t, l.concat(g)));
      return Lo(y);
    }
  }
  if (r === "mathord")
    return Ft(i, "Math-Italic", a, t, l.concat(["mathnormal"]));
  if (r === "textord") {
    var E = de[a][i] && de[a][i].font;
    if (E === "ams") {
      var A = Xr("amsrm", t.fontWeight, t.fontShape);
      return Ft(i, A, a, t, l.concat("amsrm", t.fontWeight, t.fontShape));
    } else if (E === "main" || !E) {
      var D = Xr("textrm", t.fontWeight, t.fontShape);
      return Ft(i, D, a, t, l.concat(t.fontWeight, t.fontShape));
    } else {
      var b = Xr(E, t.fontWeight, t.fontShape);
      return Ft(i, b, a, t, l.concat(b, t.fontWeight, t.fontShape));
    }
  } else
    throw new Error("unexpected type: " + r + " in makeOrd");
}, Uc = (n, e) => {
  if (D0(n.classes) !== D0(e.classes) || n.skew !== e.skew || n.maxFontSize !== e.maxFontSize)
    return !1;
  if (n.classes.length === 1) {
    var t = n.classes[0];
    if (t === "mbin" || t === "mord")
      return !1;
  }
  for (var r in n.style)
    if (n.style.hasOwnProperty(r) && n.style[r] !== e.style[r])
      return !1;
  for (var a in e.style)
    if (e.style.hasOwnProperty(a) && n.style[a] !== e.style[a])
      return !1;
  return !0;
}, Gc = (n) => {
  for (var e = 0; e < n.length - 1; e++) {
    var t = n[e], r = n[e + 1];
    t instanceof dt && r instanceof dt && Uc(t, r) && (t.text += r.text, t.height = Math.max(t.height, r.height), t.depth = Math.max(t.depth, r.depth), t.italic = r.italic, n.splice(e + 1, 1), e--);
  }
  return n;
}, mi = function(e) {
  for (var t = 0, r = 0, a = 0, i = 0; i < e.children.length; i++) {
    var l = e.children[i];
    l.height > t && (t = l.height), l.depth > r && (r = l.depth), l.maxFontSize > a && (a = l.maxFontSize);
  }
  e.height = t, e.depth = r, e.maxFontSize = a;
}, Qe = function(e, t, r, a) {
  var i = new Mr(e, t, r, a);
  return mi(i), i;
}, Io = (n, e, t, r) => new Mr(n, e, t, r), Vc = function(e, t, r) {
  var a = Qe([e], [], t);
  return a.height = Math.max(r || t.fontMetrics().defaultRuleThickness, t.minRuleThickness), a.style.borderBottomWidth = P(a.height), a.maxFontSize = 1, a;
}, Wc = function(e, t, r, a) {
  var i = new fi(e, t, r, a);
  return mi(i), i;
}, Lo = function(e) {
  var t = new Cr(e);
  return mi(t), t;
}, Xc = function(e, t) {
  return e instanceof Cr ? Qe([], [e], t) : e;
}, Yc = function(e) {
  if (e.positionType === "individualShift") {
    for (var t = e.children, r = [t[0]], a = -t[0].shift - t[0].elem.depth, i = a, l = 1; l < t.length; l++) {
      var s = -t[l].shift - i - t[l].elem.depth, o = s - (t[l - 1].elem.height + t[l - 1].elem.depth);
      i = i + s, r.push({
        type: "kern",
        size: o
      }), r.push(t[l]);
    }
    return {
      children: r,
      depth: a
    };
  }
  var c;
  if (e.positionType === "top") {
    for (var f = e.positionData, d = 0; d < e.children.length; d++) {
      var g = e.children[d];
      f -= g.type === "kern" ? g.size : g.elem.height + g.elem.depth;
    }
    c = f;
  } else if (e.positionType === "bottom")
    c = -e.positionData;
  else {
    var v = e.children[0];
    if (v.type !== "elem")
      throw new Error('First child must have type "elem".');
    if (e.positionType === "shift")
      c = -v.elem.depth - e.positionData;
    else if (e.positionType === "firstBaseline")
      c = -v.elem.depth;
    else
      throw new Error("Invalid positionType " + e.positionType + ".");
  }
  return {
    children: e.children,
    depth: c
  };
}, jc = function(e, t) {
  for (var {
    children: r,
    depth: a
  } = Yc(e), i = 0, l = 0; l < r.length; l++) {
    var s = r[l];
    if (s.type === "elem") {
      var o = s.elem;
      i = Math.max(i, o.maxFontSize, o.height);
    }
  }
  i += 2;
  var c = Qe(["pstrut"], []);
  c.style.height = P(i);
  for (var f = [], d = a, g = a, v = a, y = 0; y < r.length; y++) {
    var k = r[y];
    if (k.type === "kern")
      v += k.size;
    else {
      var E = k.elem, A = k.wrapperClasses || [], D = k.wrapperStyle || {}, b = Qe(A, [c, E], void 0, D);
      b.style.top = P(-i - v - E.depth), k.marginLeft && (b.style.marginLeft = k.marginLeft), k.marginRight && (b.style.marginRight = k.marginRight), f.push(b), v += E.height + E.depth;
    }
    d = Math.min(d, v), g = Math.max(g, v);
  }
  var F = Qe(["vlist"], f);
  F.style.height = P(g);
  var T;
  if (d < 0) {
    var M = Qe([], []), z = Qe(["vlist"], [M]);
    z.style.height = P(-d);
    var O = Qe(["vlist-s"], [new dt("​")]);
    T = [Qe(["vlist-r"], [F, O]), Qe(["vlist-r"], [z])];
  } else
    T = [Qe(["vlist-r"], [F])];
  var R = Qe(["vlist-t"], T);
  return T.length === 2 && R.classes.push("vlist-t2"), R.height = g, R.depth = -d, R;
}, Zc = (n, e) => {
  var t = Qe(["mspace"], [], e), r = we(n, e);
  return t.style.marginRight = P(r), t;
}, Xr = function(e, t, r) {
  var a = "";
  switch (e) {
    case "amsrm":
      a = "AMS";
      break;
    case "textrm":
      a = "Main";
      break;
    case "textsf":
      a = "SansSerif";
      break;
    case "texttt":
      a = "Typewriter";
      break;
    default:
      a = e;
  }
  var i;
  return t === "textbf" && r === "textit" ? i = "BoldItalic" : t === "textbf" ? i = "Bold" : t === "textit" ? i = "Italic" : i = "Regular", a + "-" + i;
}, Oo = {
  // styles
  mathbf: {
    variant: "bold",
    fontName: "Main-Bold"
  },
  mathrm: {
    variant: "normal",
    fontName: "Main-Regular"
  },
  textit: {
    variant: "italic",
    fontName: "Main-Italic"
  },
  mathit: {
    variant: "italic",
    fontName: "Main-Italic"
  },
  mathnormal: {
    variant: "italic",
    fontName: "Math-Italic"
  },
  mathsfit: {
    variant: "sans-serif-italic",
    fontName: "SansSerif-Italic"
  },
  // "boldsymbol" is missing because they require the use of multiple fonts:
  // Math-BoldItalic and Main-Bold.  This is handled by a special case in
  // makeOrd which ends up calling boldsymbol.
  // families
  mathbb: {
    variant: "double-struck",
    fontName: "AMS-Regular"
  },
  mathcal: {
    variant: "script",
    fontName: "Caligraphic-Regular"
  },
  mathfrak: {
    variant: "fraktur",
    fontName: "Fraktur-Regular"
  },
  mathscr: {
    variant: "script",
    fontName: "Script-Regular"
  },
  mathsf: {
    variant: "sans-serif",
    fontName: "SansSerif-Regular"
  },
  mathtt: {
    variant: "monospace",
    fontName: "Typewriter-Regular"
  }
}, qo = {
  //   path, width, height
  vec: ["vec", 0.471, 0.714],
  // values from the font glyph
  oiintSize1: ["oiintSize1", 0.957, 0.499],
  // oval to overlay the integrand
  oiintSize2: ["oiintSize2", 1.472, 0.659],
  oiiintSize1: ["oiiintSize1", 1.304, 0.499],
  oiiintSize2: ["oiiintSize2", 1.98, 0.659]
}, Kc = function(e, t) {
  var [r, a, i] = qo[e], l = new x0(r), s = new h0([l], {
    width: P(a),
    height: P(i),
    // Override CSS rule `.katex svg { width: 100% }`
    style: "width:" + P(a),
    viewBox: "0 0 " + 1e3 * a + " " + 1e3 * i,
    preserveAspectRatio: "xMinYMin"
  }), o = Io(["overlay"], [s], t);
  return o.height = i, o.style.height = P(i), o.style.width = P(a), o;
}, C = {
  fontMap: Oo,
  makeSymbol: Ft,
  mathsym: qc,
  makeSpan: Qe,
  makeSvgSpan: Io,
  makeLineSpan: Vc,
  makeAnchor: Wc,
  makeFragment: Lo,
  wrapFragment: Xc,
  makeVList: jc,
  makeOrd: Hc,
  makeGlue: Zc,
  staticSvg: Kc,
  svgData: qo,
  tryCombineChars: Gc
}, be = {
  number: 3,
  unit: "mu"
}, F0 = {
  number: 4,
  unit: "mu"
}, n0 = {
  number: 5,
  unit: "mu"
}, Qc = {
  mord: {
    mop: be,
    mbin: F0,
    mrel: n0,
    minner: be
  },
  mop: {
    mord: be,
    mop: be,
    mrel: n0,
    minner: be
  },
  mbin: {
    mord: F0,
    mop: F0,
    mopen: F0,
    minner: F0
  },
  mrel: {
    mord: n0,
    mop: n0,
    mopen: n0,
    minner: n0
  },
  mopen: {},
  mclose: {
    mop: be,
    mbin: F0,
    mrel: n0,
    minner: be
  },
  mpunct: {
    mord: be,
    mop: be,
    mrel: n0,
    mopen: be,
    mclose: be,
    mpunct: be,
    minner: be
  },
  minner: {
    mord: be,
    mop: be,
    mbin: F0,
    mrel: n0,
    mopen: be,
    mpunct: be,
    minner: be
  }
}, Jc = {
  mord: {
    mop: be
  },
  mop: {
    mord: be,
    mop: be
  },
  mbin: {},
  mrel: {},
  mopen: {},
  mclose: {
    mop: be
  },
  mpunct: {},
  minner: {
    mop: be
  }
}, Po = {}, An = {}, Sn = {};
function G(n) {
  for (var {
    type: e,
    names: t,
    props: r,
    handler: a,
    htmlBuilder: i,
    mathmlBuilder: l
  } = n, s = {
    type: e,
    numArgs: r.numArgs,
    argTypes: r.argTypes,
    allowedInArgument: !!r.allowedInArgument,
    allowedInText: !!r.allowedInText,
    allowedInMath: r.allowedInMath === void 0 ? !0 : r.allowedInMath,
    numOptionalArgs: r.numOptionalArgs || 0,
    infix: !!r.infix,
    primitive: !!r.primitive,
    handler: a
  }, o = 0; o < t.length; ++o)
    Po[t[o]] = s;
  e && (i && (An[e] = i), l && (Sn[e] = l));
}
function q0(n) {
  var {
    type: e,
    htmlBuilder: t,
    mathmlBuilder: r
  } = n;
  G({
    type: e,
    names: [],
    props: {
      numArgs: 0
    },
    handler() {
      throw new Error("Should never be called.");
    },
    htmlBuilder: t,
    mathmlBuilder: r
  });
}
var En = function(e) {
  return e.type === "ordgroup" && e.body.length === 1 ? e.body[0] : e;
}, Ae = function(e) {
  return e.type === "ordgroup" ? e.body : [e];
}, f0 = C.makeSpan, $c = ["leftmost", "mbin", "mopen", "mrel", "mop", "mpunct"], e4 = ["rightmost", "mrel", "mclose", "mpunct"], t4 = {
  display: Q.DISPLAY,
  text: Q.TEXT,
  script: Q.SCRIPT,
  scriptscript: Q.SCRIPTSCRIPT
}, r4 = {
  mord: "mord",
  mop: "mop",
  mbin: "mbin",
  mrel: "mrel",
  mopen: "mopen",
  mclose: "mclose",
  mpunct: "mpunct",
  minner: "minner"
}, Me = function(e, t, r, a) {
  a === void 0 && (a = [null, null]);
  for (var i = [], l = 0; l < e.length; l++) {
    var s = ie(e[l], t);
    if (s instanceof Cr) {
      var o = s.children;
      i.push(...o);
    } else
      i.push(s);
  }
  if (C.tryCombineChars(i), !r)
    return i;
  var c = t;
  if (e.length === 1) {
    var f = e[0];
    f.type === "sizing" ? c = t.havingSize(f.size) : f.type === "styling" && (c = t.havingStyle(t4[f.style]));
  }
  var d = f0([a[0] || "leftmost"], [], t), g = f0([a[1] || "rightmost"], [], t), v = r === "root";
  return yl(i, (y, k) => {
    var E = k.classes[0], A = y.classes[0];
    E === "mbin" && j.contains(e4, A) ? k.classes[0] = "mord" : A === "mbin" && j.contains($c, E) && (y.classes[0] = "mord");
  }, {
    node: d
  }, g, v), yl(i, (y, k) => {
    var E = Ga(k), A = Ga(y), D = E && A ? y.hasClass("mtight") ? Jc[E][A] : Qc[E][A] : null;
    if (D)
      return C.makeGlue(D, c);
  }, {
    node: d
  }, g, v), i;
}, yl = function n(e, t, r, a, i) {
  a && e.push(a);
  for (var l = 0; l < e.length; l++) {
    var s = e[l], o = Ho(s);
    if (o) {
      n(o.children, t, r, null, i);
      continue;
    }
    var c = !s.hasClass("mspace");
    if (c) {
      var f = t(s, r.node);
      f && (r.insertAfter ? r.insertAfter(f) : (e.unshift(f), l++));
    }
    c ? r.node = s : i && s.hasClass("newline") && (r.node = f0(["leftmost"])), r.insertAfter = /* @__PURE__ */ ((d) => (g) => {
      e.splice(d + 1, 0, g), l++;
    })(l);
  }
  a && e.pop();
}, Ho = function(e) {
  return e instanceof Cr || e instanceof fi || e instanceof Mr && e.hasClass("enclosing") ? e : null;
}, n4 = function n(e, t) {
  var r = Ho(e);
  if (r) {
    var a = r.children;
    if (a.length) {
      if (t === "right")
        return n(a[a.length - 1], "right");
      if (t === "left")
        return n(a[0], "left");
    }
  }
  return e;
}, Ga = function(e, t) {
  return e ? (t && (e = n4(e, t)), r4[e.classes[0]] || null) : null;
}, Er = function(e, t) {
  var r = ["nulldelimiter"].concat(e.baseSizingClasses());
  return f0(t.concat(r));
}, ie = function(e, t, r) {
  if (!e)
    return f0();
  if (An[e.type]) {
    var a = An[e.type](e, t);
    if (r && t.size !== r.size) {
      a = f0(t.sizingClasses(r), [a], t);
      var i = t.sizeMultiplier / r.sizeMultiplier;
      a.height *= i, a.depth *= i;
    }
    return a;
  } else
    throw new L("Got group of unknown type: '" + e.type + "'");
};
function Yr(n, e) {
  var t = f0(["base"], n, e), r = f0(["strut"]);
  return r.style.height = P(t.height + t.depth), t.depth && (r.style.verticalAlign = P(-t.depth)), t.children.unshift(r), t;
}
function Va(n, e) {
  var t = null;
  n.length === 1 && n[0].type === "tag" && (t = n[0].tag, n = n[0].body);
  var r = Me(n, e, "root"), a;
  r.length === 2 && r[1].hasClass("tag") && (a = r.pop());
  for (var i = [], l = [], s = 0; s < r.length; s++)
    if (l.push(r[s]), r[s].hasClass("mbin") || r[s].hasClass("mrel") || r[s].hasClass("allowbreak")) {
      for (var o = !1; s < r.length - 1 && r[s + 1].hasClass("mspace") && !r[s + 1].hasClass("newline"); )
        s++, l.push(r[s]), r[s].hasClass("nobreak") && (o = !0);
      o || (i.push(Yr(l, e)), l = []);
    } else r[s].hasClass("newline") && (l.pop(), l.length > 0 && (i.push(Yr(l, e)), l = []), i.push(r[s]));
  l.length > 0 && i.push(Yr(l, e));
  var c;
  t ? (c = Yr(Me(t, e, !0)), c.classes = ["tag"], i.push(c)) : a && i.push(a);
  var f = f0(["katex-html"], i);
  if (f.setAttribute("aria-hidden", "true"), c) {
    var d = c.children[0];
    d.style.height = P(f.height + f.depth), f.depth && (d.style.verticalAlign = P(-f.depth));
  }
  return f;
}
function Uo(n) {
  return new Cr(n);
}
class it {
  constructor(e, t, r) {
    this.type = void 0, this.attributes = void 0, this.children = void 0, this.classes = void 0, this.type = e, this.attributes = {}, this.children = t || [], this.classes = r || [];
  }
  /**
   * Sets an attribute on a MathML node. MathML depends on attributes to convey a
   * semantic content, so this is used heavily.
   */
  setAttribute(e, t) {
    this.attributes[e] = t;
  }
  /**
   * Gets an attribute on a MathML node.
   */
  getAttribute(e) {
    return this.attributes[e];
  }
  /**
   * Converts the math node into a MathML-namespaced DOM element.
   */
  toNode() {
    var e = document.createElementNS("http://www.w3.org/1998/Math/MathML", this.type);
    for (var t in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, t) && e.setAttribute(t, this.attributes[t]);
    this.classes.length > 0 && (e.className = D0(this.classes));
    for (var r = 0; r < this.children.length; r++)
      if (this.children[r] instanceof Ht && this.children[r + 1] instanceof Ht) {
        for (var a = this.children[r].toText() + this.children[++r].toText(); this.children[r + 1] instanceof Ht; )
          a += this.children[++r].toText();
        e.appendChild(new Ht(a).toNode());
      } else
        e.appendChild(this.children[r].toNode());
    return e;
  }
  /**
   * Converts the math node into an HTML markup string.
   */
  toMarkup() {
    var e = "<" + this.type;
    for (var t in this.attributes)
      Object.prototype.hasOwnProperty.call(this.attributes, t) && (e += " " + t + '="', e += j.escape(this.attributes[t]), e += '"');
    this.classes.length > 0 && (e += ' class ="' + j.escape(D0(this.classes)) + '"'), e += ">";
    for (var r = 0; r < this.children.length; r++)
      e += this.children[r].toMarkup();
    return e += "</" + this.type + ">", e;
  }
  /**
   * Converts the math node into a string, similar to innerText, but escaped.
   */
  toText() {
    return this.children.map((e) => e.toText()).join("");
  }
}
class Ht {
  constructor(e) {
    this.text = void 0, this.text = e;
  }
  /**
   * Converts the text node into a DOM text node.
   */
  toNode() {
    return document.createTextNode(this.text);
  }
  /**
   * Converts the text node into escaped HTML markup
   * (representing the text itself).
   */
  toMarkup() {
    return j.escape(this.toText());
  }
  /**
   * Converts the text node into a string
   * (representing the text itself).
   */
  toText() {
    return this.text;
  }
}
class a4 {
  /**
   * Create a Space node with width given in CSS ems.
   */
  constructor(e) {
    this.width = void 0, this.character = void 0, this.width = e, e >= 0.05555 && e <= 0.05556 ? this.character = " " : e >= 0.1666 && e <= 0.1667 ? this.character = " " : e >= 0.2222 && e <= 0.2223 ? this.character = " " : e >= 0.2777 && e <= 0.2778 ? this.character = "  " : e >= -0.05556 && e <= -0.05555 ? this.character = " ⁣" : e >= -0.1667 && e <= -0.1666 ? this.character = " ⁣" : e >= -0.2223 && e <= -0.2222 ? this.character = " ⁣" : e >= -0.2778 && e <= -0.2777 ? this.character = " ⁣" : this.character = null;
  }
  /**
   * Converts the math node into a MathML-namespaced DOM element.
   */
  toNode() {
    if (this.character)
      return document.createTextNode(this.character);
    var e = document.createElementNS("http://www.w3.org/1998/Math/MathML", "mspace");
    return e.setAttribute("width", P(this.width)), e;
  }
  /**
   * Converts the math node into an HTML markup string.
   */
  toMarkup() {
    return this.character ? "<mtext>" + this.character + "</mtext>" : '<mspace width="' + P(this.width) + '"/>';
  }
  /**
   * Converts the math node into a string, similar to innerText.
   */
  toText() {
    return this.character ? this.character : " ";
  }
}
var I = {
  MathNode: it,
  TextNode: Ht,
  SpaceNode: a4,
  newDocumentFragment: Uo
}, pt = function(e, t, r) {
  return de[t][e] && de[t][e].replace && e.charCodeAt(0) !== 55349 && !(Ro.hasOwnProperty(e) && r && (r.fontFamily && r.fontFamily.slice(4, 6) === "tt" || r.font && r.font.slice(4, 6) === "tt")) && (e = de[t][e].replace), new I.TextNode(e);
}, di = function(e) {
  return e.length === 1 ? e[0] : new I.MathNode("mrow", e);
}, pi = function(e, t) {
  if (t.fontFamily === "texttt")
    return "monospace";
  if (t.fontFamily === "textsf")
    return t.fontShape === "textit" && t.fontWeight === "textbf" ? "sans-serif-bold-italic" : t.fontShape === "textit" ? "sans-serif-italic" : t.fontWeight === "textbf" ? "bold-sans-serif" : "sans-serif";
  if (t.fontShape === "textit" && t.fontWeight === "textbf")
    return "bold-italic";
  if (t.fontShape === "textit")
    return "italic";
  if (t.fontWeight === "textbf")
    return "bold";
  var r = t.font;
  if (!r || r === "mathnormal")
    return null;
  var a = e.mode;
  if (r === "mathit")
    return "italic";
  if (r === "boldsymbol")
    return e.type === "textord" ? "bold" : "bold-italic";
  if (r === "mathbf")
    return "bold";
  if (r === "mathbb")
    return "double-struck";
  if (r === "mathsfit")
    return "sans-serif-italic";
  if (r === "mathfrak")
    return "fraktur";
  if (r === "mathscr" || r === "mathcal")
    return "script";
  if (r === "mathsf")
    return "sans-serif";
  if (r === "mathtt")
    return "monospace";
  var i = e.text;
  if (j.contains(["\\imath", "\\jmath"], i))
    return null;
  de[a][i] && de[a][i].replace && (i = de[a][i].replace);
  var l = C.fontMap[r].fontName;
  return hi(i, l, a) ? C.fontMap[r].variant : null;
};
function la(n) {
  if (!n)
    return !1;
  if (n.type === "mi" && n.children.length === 1) {
    var e = n.children[0];
    return e instanceof Ht && e.text === ".";
  } else if (n.type === "mo" && n.children.length === 1 && n.getAttribute("separator") === "true" && n.getAttribute("lspace") === "0em" && n.getAttribute("rspace") === "0em") {
    var t = n.children[0];
    return t instanceof Ht && t.text === ",";
  } else
    return !1;
}
var $e = function(e, t, r) {
  if (e.length === 1) {
    var a = me(e[0], t);
    return r && a instanceof it && a.type === "mo" && (a.setAttribute("lspace", "0em"), a.setAttribute("rspace", "0em")), [a];
  }
  for (var i = [], l, s = 0; s < e.length; s++) {
    var o = me(e[s], t);
    if (o instanceof it && l instanceof it) {
      if (o.type === "mtext" && l.type === "mtext" && o.getAttribute("mathvariant") === l.getAttribute("mathvariant")) {
        l.children.push(...o.children);
        continue;
      } else if (o.type === "mn" && l.type === "mn") {
        l.children.push(...o.children);
        continue;
      } else if (la(o) && l.type === "mn") {
        l.children.push(...o.children);
        continue;
      } else if (o.type === "mn" && la(l))
        o.children = [...l.children, ...o.children], i.pop();
      else if ((o.type === "msup" || o.type === "msub") && o.children.length >= 1 && (l.type === "mn" || la(l))) {
        var c = o.children[0];
        c instanceof it && c.type === "mn" && (c.children = [...l.children, ...c.children], i.pop());
      } else if (l.type === "mi" && l.children.length === 1) {
        var f = l.children[0];
        if (f instanceof Ht && f.text === "̸" && (o.type === "mo" || o.type === "mi" || o.type === "mn")) {
          var d = o.children[0];
          d instanceof Ht && d.text.length > 0 && (d.text = d.text.slice(0, 1) + "̸" + d.text.slice(1), i.pop());
        }
      }
    }
    i.push(o), l = o;
  }
  return i;
}, A0 = function(e, t, r) {
  return di($e(e, t, r));
}, me = function(e, t) {
  if (!e)
    return new I.MathNode("mrow");
  if (Sn[e.type]) {
    var r = Sn[e.type](e, t);
    return r;
  } else
    throw new L("Got group of unknown type: '" + e.type + "'");
};
function wl(n, e, t, r, a) {
  var i = $e(n, t), l;
  i.length === 1 && i[0] instanceof it && j.contains(["mrow", "mtable"], i[0].type) ? l = i[0] : l = new I.MathNode("mrow", i);
  var s = new I.MathNode("annotation", [new I.TextNode(e)]);
  s.setAttribute("encoding", "application/x-tex");
  var o = new I.MathNode("semantics", [l, s]), c = new I.MathNode("math", [o]);
  c.setAttribute("xmlns", "http://www.w3.org/1998/Math/MathML"), r && c.setAttribute("display", "block");
  var f = a ? "katex" : "katex-mathml";
  return C.makeSpan([f], [c]);
}
var Go = function(e) {
  return new s0({
    style: e.displayMode ? Q.DISPLAY : Q.TEXT,
    maxSize: e.maxSize,
    minRuleThickness: e.minRuleThickness
  });
}, Vo = function(e, t) {
  if (t.displayMode) {
    var r = ["katex-display"];
    t.leqno && r.push("leqno"), t.fleqn && r.push("fleqn"), e = C.makeSpan(r, [e]);
  }
  return e;
}, i4 = function(e, t, r) {
  var a = Go(r), i;
  if (r.output === "mathml")
    return wl(e, t, a, r.displayMode, !0);
  if (r.output === "html") {
    var l = Va(e, a);
    i = C.makeSpan(["katex"], [l]);
  } else {
    var s = wl(e, t, a, r.displayMode, !1), o = Va(e, a);
    i = C.makeSpan(["katex"], [s, o]);
  }
  return Vo(i, r);
}, l4 = function(e, t, r) {
  var a = Go(r), i = Va(e, a), l = C.makeSpan(["katex"], [i]);
  return Vo(l, r);
}, s4 = {
  widehat: "^",
  widecheck: "ˇ",
  widetilde: "~",
  utilde: "~",
  overleftarrow: "←",
  underleftarrow: "←",
  xleftarrow: "←",
  overrightarrow: "→",
  underrightarrow: "→",
  xrightarrow: "→",
  underbrace: "⏟",
  overbrace: "⏞",
  overgroup: "⏠",
  undergroup: "⏡",
  overleftrightarrow: "↔",
  underleftrightarrow: "↔",
  xleftrightarrow: "↔",
  Overrightarrow: "⇒",
  xRightarrow: "⇒",
  overleftharpoon: "↼",
  xleftharpoonup: "↼",
  overrightharpoon: "⇀",
  xrightharpoonup: "⇀",
  xLeftarrow: "⇐",
  xLeftrightarrow: "⇔",
  xhookleftarrow: "↩",
  xhookrightarrow: "↪",
  xmapsto: "↦",
  xrightharpoondown: "⇁",
  xleftharpoondown: "↽",
  xrightleftharpoons: "⇌",
  xleftrightharpoons: "⇋",
  xtwoheadleftarrow: "↞",
  xtwoheadrightarrow: "↠",
  xlongequal: "=",
  xtofrom: "⇄",
  xrightleftarrows: "⇄",
  xrightequilibrium: "⇌",
  // Not a perfect match.
  xleftequilibrium: "⇋",
  // None better available.
  "\\cdrightarrow": "→",
  "\\cdleftarrow": "←",
  "\\cdlongequal": "="
}, o4 = function(e) {
  var t = new I.MathNode("mo", [new I.TextNode(s4[e.replace(/^\\/, "")])]);
  return t.setAttribute("stretchy", "true"), t;
}, u4 = {
  //   path(s), minWidth, height, align
  overrightarrow: [["rightarrow"], 0.888, 522, "xMaxYMin"],
  overleftarrow: [["leftarrow"], 0.888, 522, "xMinYMin"],
  underrightarrow: [["rightarrow"], 0.888, 522, "xMaxYMin"],
  underleftarrow: [["leftarrow"], 0.888, 522, "xMinYMin"],
  xrightarrow: [["rightarrow"], 1.469, 522, "xMaxYMin"],
  "\\cdrightarrow": [["rightarrow"], 3, 522, "xMaxYMin"],
  // CD minwwidth2.5pc
  xleftarrow: [["leftarrow"], 1.469, 522, "xMinYMin"],
  "\\cdleftarrow": [["leftarrow"], 3, 522, "xMinYMin"],
  Overrightarrow: [["doublerightarrow"], 0.888, 560, "xMaxYMin"],
  xRightarrow: [["doublerightarrow"], 1.526, 560, "xMaxYMin"],
  xLeftarrow: [["doubleleftarrow"], 1.526, 560, "xMinYMin"],
  overleftharpoon: [["leftharpoon"], 0.888, 522, "xMinYMin"],
  xleftharpoonup: [["leftharpoon"], 0.888, 522, "xMinYMin"],
  xleftharpoondown: [["leftharpoondown"], 0.888, 522, "xMinYMin"],
  overrightharpoon: [["rightharpoon"], 0.888, 522, "xMaxYMin"],
  xrightharpoonup: [["rightharpoon"], 0.888, 522, "xMaxYMin"],
  xrightharpoondown: [["rightharpoondown"], 0.888, 522, "xMaxYMin"],
  xlongequal: [["longequal"], 0.888, 334, "xMinYMin"],
  "\\cdlongequal": [["longequal"], 3, 334, "xMinYMin"],
  xtwoheadleftarrow: [["twoheadleftarrow"], 0.888, 334, "xMinYMin"],
  xtwoheadrightarrow: [["twoheadrightarrow"], 0.888, 334, "xMaxYMin"],
  overleftrightarrow: [["leftarrow", "rightarrow"], 0.888, 522],
  overbrace: [["leftbrace", "midbrace", "rightbrace"], 1.6, 548],
  underbrace: [["leftbraceunder", "midbraceunder", "rightbraceunder"], 1.6, 548],
  underleftrightarrow: [["leftarrow", "rightarrow"], 0.888, 522],
  xleftrightarrow: [["leftarrow", "rightarrow"], 1.75, 522],
  xLeftrightarrow: [["doubleleftarrow", "doublerightarrow"], 1.75, 560],
  xrightleftharpoons: [["leftharpoondownplus", "rightharpoonplus"], 1.75, 716],
  xleftrightharpoons: [["leftharpoonplus", "rightharpoondownplus"], 1.75, 716],
  xhookleftarrow: [["leftarrow", "righthook"], 1.08, 522],
  xhookrightarrow: [["lefthook", "rightarrow"], 1.08, 522],
  overlinesegment: [["leftlinesegment", "rightlinesegment"], 0.888, 522],
  underlinesegment: [["leftlinesegment", "rightlinesegment"], 0.888, 522],
  overgroup: [["leftgroup", "rightgroup"], 0.888, 342],
  undergroup: [["leftgroupunder", "rightgroupunder"], 0.888, 342],
  xmapsto: [["leftmapsto", "rightarrow"], 1.5, 522],
  xtofrom: [["leftToFrom", "rightToFrom"], 1.75, 528],
  // The next three arrows are from the mhchem package.
  // In mhchem.sty, min-length is 2.0em. But these arrows might appear in the
  // document as \xrightarrow or \xrightleftharpoons. Those have
  // min-length = 1.75em, so we set min-length on these next three to match.
  xrightleftarrows: [["baraboveleftarrow", "rightarrowabovebar"], 1.75, 901],
  xrightequilibrium: [["baraboveshortleftharpoon", "rightharpoonaboveshortbar"], 1.75, 716],
  xleftequilibrium: [["shortbaraboveleftharpoon", "shortrightharpoonabovebar"], 1.75, 716]
}, c4 = function(e) {
  return e.type === "ordgroup" ? e.body.length : 1;
}, h4 = function(e, t) {
  function r() {
    var s = 4e5, o = e.label.slice(1);
    if (j.contains(["widehat", "widecheck", "widetilde", "utilde"], o)) {
      var c = e, f = c4(c.base), d, g, v;
      if (f > 5)
        o === "widehat" || o === "widecheck" ? (d = 420, s = 2364, v = 0.42, g = o + "4") : (d = 312, s = 2340, v = 0.34, g = "tilde4");
      else {
        var y = [1, 1, 2, 2, 3, 3][f];
        o === "widehat" || o === "widecheck" ? (s = [0, 1062, 2364, 2364, 2364][y], d = [0, 239, 300, 360, 420][y], v = [0, 0.24, 0.3, 0.3, 0.36, 0.42][y], g = o + y) : (s = [0, 600, 1033, 2339, 2340][y], d = [0, 260, 286, 306, 312][y], v = [0, 0.26, 0.286, 0.3, 0.306, 0.34][y], g = "tilde" + y);
      }
      var k = new x0(g), E = new h0([k], {
        width: "100%",
        height: P(v),
        viewBox: "0 0 " + s + " " + d,
        preserveAspectRatio: "none"
      });
      return {
        span: C.makeSvgSpan([], [E], t),
        minWidth: 0,
        height: v
      };
    } else {
      var A = [], D = u4[o], [b, F, T] = D, M = T / 1e3, z = b.length, O, R;
      if (z === 1) {
        var B = D[3];
        O = ["hide-tail"], R = [B];
      } else if (z === 2)
        O = ["halfarrow-left", "halfarrow-right"], R = ["xMinYMin", "xMaxYMin"];
      else if (z === 3)
        O = ["brace-left", "brace-center", "brace-right"], R = ["xMinYMin", "xMidYMin", "xMaxYMin"];
      else
        throw new Error(`Correct katexImagesData or update code here to support
                    ` + z + " children.");
      for (var X = 0; X < z; X++) {
        var $ = new x0(b[X]), Te = new h0([$], {
          width: "400em",
          height: P(M),
          viewBox: "0 0 " + s + " " + T,
          preserveAspectRatio: R[X] + " slice"
        }), se = C.makeSvgSpan([O[X]], [Te], t);
        if (z === 1)
          return {
            span: se,
            minWidth: F,
            height: M
          };
        se.style.height = P(M), A.push(se);
      }
      return {
        span: C.makeSpan(["stretchy"], A, t),
        minWidth: F,
        height: M
      };
    }
  }
  var {
    span: a,
    minWidth: i,
    height: l
  } = r();
  return a.height = l, a.style.height = P(l), i > 0 && (a.style.minWidth = P(i)), a;
}, f4 = function(e, t, r, a, i) {
  var l, s = e.height + e.depth + r + a;
  if (/fbox|color|angl/.test(t)) {
    if (l = C.makeSpan(["stretchy", t], [], i), t === "fbox") {
      var o = i.color && i.getColor();
      o && (l.style.borderColor = o);
    }
  } else {
    var c = [];
    /^[bx]cancel$/.test(t) && c.push(new Ha({
      x1: "0",
      y1: "0",
      x2: "100%",
      y2: "100%",
      "stroke-width": "0.046em"
    })), /^x?cancel$/.test(t) && c.push(new Ha({
      x1: "0",
      y1: "100%",
      x2: "100%",
      y2: "0",
      "stroke-width": "0.046em"
    }));
    var f = new h0(c, {
      width: "100%",
      height: P(s)
    });
    l = C.makeSvgSpan([], [f], i);
  }
  return l.height = s, l.style.height = P(s), l;
}, m0 = {
  encloseSpan: f4,
  mathMLnode: o4,
  svgSpan: h4
};
function te(n, e) {
  if (!n || n.type !== e)
    throw new Error("Expected node of type " + e + ", but got " + (n ? "node of type " + n.type : String(n)));
  return n;
}
function gi(n) {
  var e = Ln(n);
  if (!e)
    throw new Error("Expected node of symbol group type, but got " + (n ? "node of type " + n.type : String(n)));
  return e;
}
function Ln(n) {
  return n && (n.type === "atom" || Lc.hasOwnProperty(n.type)) ? n : null;
}
var vi = (n, e) => {
  var t, r, a;
  n && n.type === "supsub" ? (r = te(n.base, "accent"), t = r.base, n.base = t, a = Rc(ie(n, e)), n.base = r) : (r = te(n, "accent"), t = r.base);
  var i = ie(t, e.havingCrampedStyle()), l = r.isShifty && j.isCharacterBox(t), s = 0;
  if (l) {
    var o = j.getBaseElem(t), c = ie(o, e.havingCrampedStyle());
    s = ml(c).skew;
  }
  var f = r.label === "\\c", d = f ? i.height + i.depth : Math.min(i.height, e.fontMetrics().xHeight), g;
  if (r.isStretchy)
    g = m0.svgSpan(r, e), g = C.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: i
      }, {
        type: "elem",
        elem: g,
        wrapperClasses: ["svg-align"],
        wrapperStyle: s > 0 ? {
          width: "calc(100% - " + P(2 * s) + ")",
          marginLeft: P(2 * s)
        } : void 0
      }]
    }, e);
  else {
    var v, y;
    r.label === "\\vec" ? (v = C.staticSvg("vec", e), y = C.svgData.vec[1]) : (v = C.makeOrd({
      mode: r.mode,
      text: r.label
    }, e, "textord"), v = ml(v), v.italic = 0, y = v.width, f && (d += v.depth)), g = C.makeSpan(["accent-body"], [v]);
    var k = r.label === "\\textcircled";
    k && (g.classes.push("accent-full"), d = i.height);
    var E = s;
    k || (E -= y / 2), g.style.left = P(E), r.label === "\\textcircled" && (g.style.top = ".2em"), g = C.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: i
      }, {
        type: "kern",
        size: -d
      }, {
        type: "elem",
        elem: g
      }]
    }, e);
  }
  var A = C.makeSpan(["mord", "accent"], [g], e);
  return a ? (a.children[0] = A, a.height = Math.max(A.height, a.height), a.classes[0] = "mord", a) : A;
}, Wo = (n, e) => {
  var t = n.isStretchy ? m0.mathMLnode(n.label) : new I.MathNode("mo", [pt(n.label, n.mode)]), r = new I.MathNode("mover", [me(n.base, e), t]);
  return r.setAttribute("accent", "true"), r;
}, m4 = new RegExp(["\\acute", "\\grave", "\\ddot", "\\tilde", "\\bar", "\\breve", "\\check", "\\hat", "\\vec", "\\dot", "\\mathring"].map((n) => "\\" + n).join("|"));
G({
  type: "accent",
  names: ["\\acute", "\\grave", "\\ddot", "\\tilde", "\\bar", "\\breve", "\\check", "\\hat", "\\vec", "\\dot", "\\mathring", "\\widecheck", "\\widehat", "\\widetilde", "\\overrightarrow", "\\overleftarrow", "\\Overrightarrow", "\\overleftrightarrow", "\\overgroup", "\\overlinesegment", "\\overleftharpoon", "\\overrightharpoon"],
  props: {
    numArgs: 1
  },
  handler: (n, e) => {
    var t = En(e[0]), r = !m4.test(n.funcName), a = !r || n.funcName === "\\widehat" || n.funcName === "\\widetilde" || n.funcName === "\\widecheck";
    return {
      type: "accent",
      mode: n.parser.mode,
      label: n.funcName,
      isStretchy: r,
      isShifty: a,
      base: t
    };
  },
  htmlBuilder: vi,
  mathmlBuilder: Wo
});
G({
  type: "accent",
  names: ["\\'", "\\`", "\\^", "\\~", "\\=", "\\u", "\\.", '\\"', "\\c", "\\r", "\\H", "\\v", "\\textcircled"],
  props: {
    numArgs: 1,
    allowedInText: !0,
    allowedInMath: !0,
    // unless in strict mode
    argTypes: ["primitive"]
  },
  handler: (n, e) => {
    var t = e[0], r = n.parser.mode;
    return r === "math" && (n.parser.settings.reportNonstrict("mathVsTextAccents", "LaTeX's accent " + n.funcName + " works only in text mode"), r = "text"), {
      type: "accent",
      mode: r,
      label: n.funcName,
      isStretchy: !1,
      isShifty: !0,
      base: t
    };
  },
  htmlBuilder: vi,
  mathmlBuilder: Wo
});
G({
  type: "accentUnder",
  names: ["\\underleftarrow", "\\underrightarrow", "\\underleftrightarrow", "\\undergroup", "\\underlinesegment", "\\utilde"],
  props: {
    numArgs: 1
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "accentUnder",
      mode: t.mode,
      label: r,
      base: a
    };
  },
  htmlBuilder: (n, e) => {
    var t = ie(n.base, e), r = m0.svgSpan(n, e), a = n.label === "\\utilde" ? 0.12 : 0, i = C.makeVList({
      positionType: "top",
      positionData: t.height,
      children: [{
        type: "elem",
        elem: r,
        wrapperClasses: ["svg-align"]
      }, {
        type: "kern",
        size: a
      }, {
        type: "elem",
        elem: t
      }]
    }, e);
    return C.makeSpan(["mord", "accentunder"], [i], e);
  },
  mathmlBuilder: (n, e) => {
    var t = m0.mathMLnode(n.label), r = new I.MathNode("munder", [me(n.base, e), t]);
    return r.setAttribute("accentunder", "true"), r;
  }
});
var jr = (n) => {
  var e = new I.MathNode("mpadded", n ? [n] : []);
  return e.setAttribute("width", "+0.6em"), e.setAttribute("lspace", "0.3em"), e;
};
G({
  type: "xArrow",
  names: [
    "\\xleftarrow",
    "\\xrightarrow",
    "\\xLeftarrow",
    "\\xRightarrow",
    "\\xleftrightarrow",
    "\\xLeftrightarrow",
    "\\xhookleftarrow",
    "\\xhookrightarrow",
    "\\xmapsto",
    "\\xrightharpoondown",
    "\\xrightharpoonup",
    "\\xleftharpoondown",
    "\\xleftharpoonup",
    "\\xrightleftharpoons",
    "\\xleftrightharpoons",
    "\\xlongequal",
    "\\xtwoheadrightarrow",
    "\\xtwoheadleftarrow",
    "\\xtofrom",
    // The next 3 functions are here to support the mhchem extension.
    // Direct use of these functions is discouraged and may break someday.
    "\\xrightleftarrows",
    "\\xrightequilibrium",
    "\\xleftequilibrium",
    // The next 3 functions are here only to support the {CD} environment.
    "\\\\cdrightarrow",
    "\\\\cdleftarrow",
    "\\\\cdlongequal"
  ],
  props: {
    numArgs: 1,
    numOptionalArgs: 1
  },
  handler(n, e, t) {
    var {
      parser: r,
      funcName: a
    } = n;
    return {
      type: "xArrow",
      mode: r.mode,
      label: a,
      body: e[0],
      below: t[0]
    };
  },
  // Flow is unable to correctly infer the type of `group`, even though it's
  // unambiguously determined from the passed-in `type` above.
  htmlBuilder(n, e) {
    var t = e.style, r = e.havingStyle(t.sup()), a = C.wrapFragment(ie(n.body, r, e), e), i = n.label.slice(0, 2) === "\\x" ? "x" : "cd";
    a.classes.push(i + "-arrow-pad");
    var l;
    n.below && (r = e.havingStyle(t.sub()), l = C.wrapFragment(ie(n.below, r, e), e), l.classes.push(i + "-arrow-pad"));
    var s = m0.svgSpan(n, e), o = -e.fontMetrics().axisHeight + 0.5 * s.height, c = -e.fontMetrics().axisHeight - 0.5 * s.height - 0.111;
    (a.depth > 0.25 || n.label === "\\xleftequilibrium") && (c -= a.depth);
    var f;
    if (l) {
      var d = -e.fontMetrics().axisHeight + l.height + 0.5 * s.height + 0.111;
      f = C.makeVList({
        positionType: "individualShift",
        children: [{
          type: "elem",
          elem: a,
          shift: c
        }, {
          type: "elem",
          elem: s,
          shift: o
        }, {
          type: "elem",
          elem: l,
          shift: d
        }]
      }, e);
    } else
      f = C.makeVList({
        positionType: "individualShift",
        children: [{
          type: "elem",
          elem: a,
          shift: c
        }, {
          type: "elem",
          elem: s,
          shift: o
        }]
      }, e);
    return f.children[0].children[0].children[1].classes.push("svg-align"), C.makeSpan(["mrel", "x-arrow"], [f], e);
  },
  mathmlBuilder(n, e) {
    var t = m0.mathMLnode(n.label);
    t.setAttribute("minsize", n.label.charAt(0) === "x" ? "1.75em" : "3.0em");
    var r;
    if (n.body) {
      var a = jr(me(n.body, e));
      if (n.below) {
        var i = jr(me(n.below, e));
        r = new I.MathNode("munderover", [t, i, a]);
      } else
        r = new I.MathNode("mover", [t, a]);
    } else if (n.below) {
      var l = jr(me(n.below, e));
      r = new I.MathNode("munder", [t, l]);
    } else
      r = jr(), r = new I.MathNode("mover", [t, r]);
    return r;
  }
});
var d4 = C.makeSpan;
function Xo(n, e) {
  var t = Me(n.body, e, !0);
  return d4([n.mclass], t, e);
}
function Yo(n, e) {
  var t, r = $e(n.body, e);
  return n.mclass === "minner" ? t = new I.MathNode("mpadded", r) : n.mclass === "mord" ? n.isCharacterBox ? (t = r[0], t.type = "mi") : t = new I.MathNode("mi", r) : (n.isCharacterBox ? (t = r[0], t.type = "mo") : t = new I.MathNode("mo", r), n.mclass === "mbin" ? (t.attributes.lspace = "0.22em", t.attributes.rspace = "0.22em") : n.mclass === "mpunct" ? (t.attributes.lspace = "0em", t.attributes.rspace = "0.17em") : n.mclass === "mopen" || n.mclass === "mclose" ? (t.attributes.lspace = "0em", t.attributes.rspace = "0em") : n.mclass === "minner" && (t.attributes.lspace = "0.0556em", t.attributes.width = "+0.1111em")), t;
}
G({
  type: "mclass",
  names: ["\\mathord", "\\mathbin", "\\mathrel", "\\mathopen", "\\mathclose", "\\mathpunct", "\\mathinner"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "mclass",
      mode: t.mode,
      mclass: "m" + r.slice(5),
      // TODO(kevinb): don't prefix with 'm'
      body: Ae(a),
      isCharacterBox: j.isCharacterBox(a)
    };
  },
  htmlBuilder: Xo,
  mathmlBuilder: Yo
});
var On = (n) => {
  var e = n.type === "ordgroup" && n.body.length ? n.body[0] : n;
  return e.type === "atom" && (e.family === "bin" || e.family === "rel") ? "m" + e.family : "mord";
};
G({
  type: "mclass",
  names: ["\\@binrel"],
  props: {
    numArgs: 2
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "mclass",
      mode: t.mode,
      mclass: On(e[0]),
      body: Ae(e[1]),
      isCharacterBox: j.isCharacterBox(e[1])
    };
  }
});
G({
  type: "mclass",
  names: ["\\stackrel", "\\overset", "\\underset"],
  props: {
    numArgs: 2
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[1], i = e[0], l;
    r !== "\\stackrel" ? l = On(a) : l = "mrel";
    var s = {
      type: "op",
      mode: a.mode,
      limits: !0,
      alwaysHandleSupSub: !0,
      parentIsSupSub: !1,
      symbol: !1,
      suppressBaseShift: r !== "\\stackrel",
      body: Ae(a)
    }, o = {
      type: "supsub",
      mode: i.mode,
      base: s,
      sup: r === "\\underset" ? null : i,
      sub: r === "\\underset" ? i : null
    };
    return {
      type: "mclass",
      mode: t.mode,
      mclass: l,
      body: [o],
      isCharacterBox: j.isCharacterBox(o)
    };
  },
  htmlBuilder: Xo,
  mathmlBuilder: Yo
});
G({
  type: "pmb",
  names: ["\\pmb"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "pmb",
      mode: t.mode,
      mclass: On(e[0]),
      body: Ae(e[0])
    };
  },
  htmlBuilder(n, e) {
    var t = Me(n.body, e, !0), r = C.makeSpan([n.mclass], t, e);
    return r.style.textShadow = "0.02em 0.01em 0.04px", r;
  },
  mathmlBuilder(n, e) {
    var t = $e(n.body, e), r = new I.MathNode("mstyle", t);
    return r.setAttribute("style", "text-shadow: 0.02em 0.01em 0.04px"), r;
  }
});
var p4 = {
  ">": "\\\\cdrightarrow",
  "<": "\\\\cdleftarrow",
  "=": "\\\\cdlongequal",
  A: "\\uparrow",
  V: "\\downarrow",
  "|": "\\Vert",
  ".": "no arrow"
}, kl = () => ({
  type: "styling",
  body: [],
  mode: "math",
  style: "display"
}), _l = (n) => n.type === "textord" && n.text === "@", g4 = (n, e) => (n.type === "mathord" || n.type === "atom") && n.text === e;
function v4(n, e, t) {
  var r = p4[n];
  switch (r) {
    case "\\\\cdrightarrow":
    case "\\\\cdleftarrow":
      return t.callFunction(r, [e[0]], [e[1]]);
    case "\\uparrow":
    case "\\downarrow": {
      var a = t.callFunction("\\\\cdleft", [e[0]], []), i = {
        type: "atom",
        text: r,
        mode: "math",
        family: "rel"
      }, l = t.callFunction("\\Big", [i], []), s = t.callFunction("\\\\cdright", [e[1]], []), o = {
        type: "ordgroup",
        mode: "math",
        body: [a, l, s]
      };
      return t.callFunction("\\\\cdparent", [o], []);
    }
    case "\\\\cdlongequal":
      return t.callFunction("\\\\cdlongequal", [], []);
    case "\\Vert": {
      var c = {
        type: "textord",
        text: "\\Vert",
        mode: "math"
      };
      return t.callFunction("\\Big", [c], []);
    }
    default:
      return {
        type: "textord",
        text: " ",
        mode: "math"
      };
  }
}
function b4(n) {
  var e = [];
  for (n.gullet.beginGroup(), n.gullet.macros.set("\\cr", "\\\\\\relax"), n.gullet.beginGroup(); ; ) {
    e.push(n.parseExpression(!1, "\\\\")), n.gullet.endGroup(), n.gullet.beginGroup();
    var t = n.fetch().text;
    if (t === "&" || t === "\\\\")
      n.consume();
    else if (t === "\\end") {
      e[e.length - 1].length === 0 && e.pop();
      break;
    } else
      throw new L("Expected \\\\ or \\cr or \\end", n.nextToken);
  }
  for (var r = [], a = [r], i = 0; i < e.length; i++) {
    for (var l = e[i], s = kl(), o = 0; o < l.length; o++)
      if (!_l(l[o]))
        s.body.push(l[o]);
      else {
        r.push(s), o += 1;
        var c = gi(l[o]).text, f = new Array(2);
        if (f[0] = {
          type: "ordgroup",
          mode: "math",
          body: []
        }, f[1] = {
          type: "ordgroup",
          mode: "math",
          body: []
        }, !("=|.".indexOf(c) > -1)) if ("<>AV".indexOf(c) > -1)
          for (var d = 0; d < 2; d++) {
            for (var g = !0, v = o + 1; v < l.length; v++) {
              if (g4(l[v], c)) {
                g = !1, o = v;
                break;
              }
              if (_l(l[v]))
                throw new L("Missing a " + c + " character to complete a CD arrow.", l[v]);
              f[d].body.push(l[v]);
            }
            if (g)
              throw new L("Missing a " + c + " character to complete a CD arrow.", l[o]);
          }
        else
          throw new L('Expected one of "<>AV=|." after @', l[o]);
        var y = v4(c, f, n), k = {
          type: "styling",
          body: [y],
          mode: "math",
          style: "display"
          // CD is always displaystyle.
        };
        r.push(k), s = kl();
      }
    i % 2 === 0 ? r.push(s) : r.shift(), r = [], a.push(r);
  }
  n.gullet.endGroup(), n.gullet.endGroup();
  var E = new Array(a[0].length).fill({
    type: "align",
    align: "c",
    pregap: 0.25,
    // CD package sets \enskip between columns.
    postgap: 0.25
    // So pre and post each get half an \enskip, i.e. 0.25em.
  });
  return {
    type: "array",
    mode: "math",
    body: a,
    arraystretch: 1,
    addJot: !0,
    rowGaps: [null],
    cols: E,
    colSeparationType: "CD",
    hLinesBeforeRow: new Array(a.length + 1).fill([])
  };
}
G({
  type: "cdlabel",
  names: ["\\\\cdleft", "\\\\cdright"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n;
    return {
      type: "cdlabel",
      mode: t.mode,
      side: r.slice(4),
      label: e[0]
    };
  },
  htmlBuilder(n, e) {
    var t = e.havingStyle(e.style.sup()), r = C.wrapFragment(ie(n.label, t, e), e);
    return r.classes.push("cd-label-" + n.side), r.style.bottom = P(0.8 - r.depth), r.height = 0, r.depth = 0, r;
  },
  mathmlBuilder(n, e) {
    var t = new I.MathNode("mrow", [me(n.label, e)]);
    return t = new I.MathNode("mpadded", [t]), t.setAttribute("width", "0"), n.side === "left" && t.setAttribute("lspace", "-1width"), t.setAttribute("voffset", "0.7em"), t = new I.MathNode("mstyle", [t]), t.setAttribute("displaystyle", "false"), t.setAttribute("scriptlevel", "1"), t;
  }
});
G({
  type: "cdlabelparent",
  names: ["\\\\cdparent"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "cdlabelparent",
      mode: t.mode,
      fragment: e[0]
    };
  },
  htmlBuilder(n, e) {
    var t = C.wrapFragment(ie(n.fragment, e), e);
    return t.classes.push("cd-vert-arrow"), t;
  },
  mathmlBuilder(n, e) {
    return new I.MathNode("mrow", [me(n.fragment, e)]);
  }
});
G({
  type: "textord",
  names: ["\\@char"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler(n, e) {
    for (var {
      parser: t
    } = n, r = te(e[0], "ordgroup"), a = r.body, i = "", l = 0; l < a.length; l++) {
      var s = te(a[l], "textord");
      i += s.text;
    }
    var o = parseInt(i), c;
    if (isNaN(o))
      throw new L("\\@char has non-numeric argument " + i);
    if (o < 0 || o >= 1114111)
      throw new L("\\@char with invalid code point " + i);
    return o <= 65535 ? c = String.fromCharCode(o) : (o -= 65536, c = String.fromCharCode((o >> 10) + 55296, (o & 1023) + 56320)), {
      type: "textord",
      mode: t.mode,
      text: c
    };
  }
});
var jo = (n, e) => {
  var t = Me(n.body, e.withColor(n.color), !1);
  return C.makeFragment(t);
}, Zo = (n, e) => {
  var t = $e(n.body, e.withColor(n.color)), r = new I.MathNode("mstyle", t);
  return r.setAttribute("mathcolor", n.color), r;
};
G({
  type: "color",
  names: ["\\textcolor"],
  props: {
    numArgs: 2,
    allowedInText: !0,
    argTypes: ["color", "original"]
  },
  handler(n, e) {
    var {
      parser: t
    } = n, r = te(e[0], "color-token").color, a = e[1];
    return {
      type: "color",
      mode: t.mode,
      color: r,
      body: Ae(a)
    };
  },
  htmlBuilder: jo,
  mathmlBuilder: Zo
});
G({
  type: "color",
  names: ["\\color"],
  props: {
    numArgs: 1,
    allowedInText: !0,
    argTypes: ["color"]
  },
  handler(n, e) {
    var {
      parser: t,
      breakOnTokenText: r
    } = n, a = te(e[0], "color-token").color;
    t.gullet.macros.set("\\current@color", a);
    var i = t.parseExpression(!0, r);
    return {
      type: "color",
      mode: t.mode,
      color: a,
      body: i
    };
  },
  htmlBuilder: jo,
  mathmlBuilder: Zo
});
G({
  type: "cr",
  names: ["\\\\"],
  props: {
    numArgs: 0,
    numOptionalArgs: 0,
    allowedInText: !0
  },
  handler(n, e, t) {
    var {
      parser: r
    } = n, a = r.gullet.future().text === "[" ? r.parseSizeGroup(!0) : null, i = !r.settings.displayMode || !r.settings.useStrictBehavior("newLineInDisplayMode", "In LaTeX, \\\\ or \\newline does nothing in display mode");
    return {
      type: "cr",
      mode: r.mode,
      newLine: i,
      size: a && te(a, "size").value
    };
  },
  // The following builders are called only at the top level,
  // not within tabular/array environments.
  htmlBuilder(n, e) {
    var t = C.makeSpan(["mspace"], [], e);
    return n.newLine && (t.classes.push("newline"), n.size && (t.style.marginTop = P(we(n.size, e)))), t;
  },
  mathmlBuilder(n, e) {
    var t = new I.MathNode("mspace");
    return n.newLine && (t.setAttribute("linebreak", "newline"), n.size && t.setAttribute("height", P(we(n.size, e)))), t;
  }
});
var Wa = {
  "\\global": "\\global",
  "\\long": "\\\\globallong",
  "\\\\globallong": "\\\\globallong",
  "\\def": "\\gdef",
  "\\gdef": "\\gdef",
  "\\edef": "\\xdef",
  "\\xdef": "\\xdef",
  "\\let": "\\\\globallet",
  "\\futurelet": "\\\\globalfuture"
}, Ko = (n) => {
  var e = n.text;
  if (/^(?:[\\{}$&#^_]|EOF)$/.test(e))
    throw new L("Expected a control sequence", n);
  return e;
}, y4 = (n) => {
  var e = n.gullet.popToken();
  return e.text === "=" && (e = n.gullet.popToken(), e.text === " " && (e = n.gullet.popToken())), e;
}, Qo = (n, e, t, r) => {
  var a = n.gullet.macros.get(t.text);
  a == null && (t.noexpand = !0, a = {
    tokens: [t],
    numArgs: 0,
    // reproduce the same behavior in expansion
    unexpandable: !n.gullet.isExpandable(t.text)
  }), n.gullet.macros.set(e, a, r);
};
G({
  type: "internal",
  names: [
    "\\global",
    "\\long",
    "\\\\globallong"
    // can’t be entered directly
  ],
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n;
    e.consumeSpaces();
    var r = e.fetch();
    if (Wa[r.text])
      return (t === "\\global" || t === "\\\\globallong") && (r.text = Wa[r.text]), te(e.parseFunction(), "internal");
    throw new L("Invalid token after macro prefix", r);
  }
});
G({
  type: "internal",
  names: ["\\def", "\\gdef", "\\edef", "\\xdef"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    primitive: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n, r = e.gullet.popToken(), a = r.text;
    if (/^(?:[\\{}$&#^_]|EOF)$/.test(a))
      throw new L("Expected a control sequence", r);
    for (var i = 0, l, s = [[]]; e.gullet.future().text !== "{"; )
      if (r = e.gullet.popToken(), r.text === "#") {
        if (e.gullet.future().text === "{") {
          l = e.gullet.future(), s[i].push("{");
          break;
        }
        if (r = e.gullet.popToken(), !/^[1-9]$/.test(r.text))
          throw new L('Invalid argument number "' + r.text + '"');
        if (parseInt(r.text) !== i + 1)
          throw new L('Argument number "' + r.text + '" out of order');
        i++, s.push([]);
      } else {
        if (r.text === "EOF")
          throw new L("Expected a macro definition");
        s[i].push(r.text);
      }
    var {
      tokens: o
    } = e.gullet.consumeArg();
    return l && o.unshift(l), (t === "\\edef" || t === "\\xdef") && (o = e.gullet.expandTokens(o), o.reverse()), e.gullet.macros.set(a, {
      tokens: o,
      numArgs: i,
      delimiters: s
    }, t === Wa[t]), {
      type: "internal",
      mode: e.mode
    };
  }
});
G({
  type: "internal",
  names: [
    "\\let",
    "\\\\globallet"
    // can’t be entered directly
  ],
  props: {
    numArgs: 0,
    allowedInText: !0,
    primitive: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n, r = Ko(e.gullet.popToken());
    e.gullet.consumeSpaces();
    var a = y4(e);
    return Qo(e, r, a, t === "\\\\globallet"), {
      type: "internal",
      mode: e.mode
    };
  }
});
G({
  type: "internal",
  names: [
    "\\futurelet",
    "\\\\globalfuture"
    // can’t be entered directly
  ],
  props: {
    numArgs: 0,
    allowedInText: !0,
    primitive: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n, r = Ko(e.gullet.popToken()), a = e.gullet.popToken(), i = e.gullet.popToken();
    return Qo(e, r, i, t === "\\\\globalfuture"), e.gullet.pushToken(i), e.gullet.pushToken(a), {
      type: "internal",
      mode: e.mode
    };
  }
});
var br = function(e, t, r) {
  var a = de.math[e] && de.math[e].replace, i = hi(a || e, t, r);
  if (!i)
    throw new Error("Unsupported symbol " + e + " and font size " + t + ".");
  return i;
}, bi = function(e, t, r, a) {
  var i = r.havingBaseStyle(t), l = C.makeSpan(a.concat(i.sizingClasses(r)), [e], r), s = i.sizeMultiplier / r.sizeMultiplier;
  return l.height *= s, l.depth *= s, l.maxFontSize = i.sizeMultiplier, l;
}, Jo = function(e, t, r) {
  var a = t.havingBaseStyle(r), i = (1 - t.sizeMultiplier / a.sizeMultiplier) * t.fontMetrics().axisHeight;
  e.classes.push("delimcenter"), e.style.top = P(i), e.height -= i, e.depth += i;
}, w4 = function(e, t, r, a, i, l) {
  var s = C.makeSymbol(e, "Main-Regular", i, a), o = bi(s, t, a, l);
  return r && Jo(o, a, t), o;
}, k4 = function(e, t, r, a) {
  return C.makeSymbol(e, "Size" + t + "-Regular", r, a);
}, $o = function(e, t, r, a, i, l) {
  var s = k4(e, t, i, a), o = bi(C.makeSpan(["delimsizing", "size" + t], [s], a), Q.TEXT, a, l);
  return r && Jo(o, a, Q.TEXT), o;
}, sa = function(e, t, r) {
  var a;
  t === "Size1-Regular" ? a = "delim-size1" : a = "delim-size4";
  var i = C.makeSpan(["delimsizinginner", a], [C.makeSpan([], [C.makeSymbol(e, t, r)])]);
  return {
    type: "elem",
    elem: i
  };
}, oa = function(e, t, r) {
  var a = Pt["Size4-Regular"][e.charCodeAt(0)] ? Pt["Size4-Regular"][e.charCodeAt(0)][4] : Pt["Size1-Regular"][e.charCodeAt(0)][4], i = new x0("inner", Ec(e, Math.round(1e3 * t))), l = new h0([i], {
    width: P(a),
    height: P(t),
    // Override CSS rule `.katex svg { width: 100% }`
    style: "width:" + P(a),
    viewBox: "0 0 " + 1e3 * a + " " + Math.round(1e3 * t),
    preserveAspectRatio: "xMinYMin"
  }), s = C.makeSvgSpan([], [l], r);
  return s.height = t, s.style.height = P(t), s.style.width = P(a), {
    type: "elem",
    elem: s
  };
}, Xa = 8e-3, Zr = {
  type: "kern",
  size: -1 * Xa
}, _4 = ["|", "\\lvert", "\\rvert", "\\vert"], D4 = ["\\|", "\\lVert", "\\rVert", "\\Vert"], eu = function(e, t, r, a, i, l) {
  var s, o, c, f, d = "", g = 0;
  s = c = f = e, o = null;
  var v = "Size1-Regular";
  e === "\\uparrow" ? c = f = "⏐" : e === "\\Uparrow" ? c = f = "‖" : e === "\\downarrow" ? s = c = "⏐" : e === "\\Downarrow" ? s = c = "‖" : e === "\\updownarrow" ? (s = "\\uparrow", c = "⏐", f = "\\downarrow") : e === "\\Updownarrow" ? (s = "\\Uparrow", c = "‖", f = "\\Downarrow") : j.contains(_4, e) ? (c = "∣", d = "vert", g = 333) : j.contains(D4, e) ? (c = "∥", d = "doublevert", g = 556) : e === "[" || e === "\\lbrack" ? (s = "⎡", c = "⎢", f = "⎣", v = "Size4-Regular", d = "lbrack", g = 667) : e === "]" || e === "\\rbrack" ? (s = "⎤", c = "⎥", f = "⎦", v = "Size4-Regular", d = "rbrack", g = 667) : e === "\\lfloor" || e === "⌊" ? (c = s = "⎢", f = "⎣", v = "Size4-Regular", d = "lfloor", g = 667) : e === "\\lceil" || e === "⌈" ? (s = "⎡", c = f = "⎢", v = "Size4-Regular", d = "lceil", g = 667) : e === "\\rfloor" || e === "⌋" ? (c = s = "⎥", f = "⎦", v = "Size4-Regular", d = "rfloor", g = 667) : e === "\\rceil" || e === "⌉" ? (s = "⎤", c = f = "⎥", v = "Size4-Regular", d = "rceil", g = 667) : e === "(" || e === "\\lparen" ? (s = "⎛", c = "⎜", f = "⎝", v = "Size4-Regular", d = "lparen", g = 875) : e === ")" || e === "\\rparen" ? (s = "⎞", c = "⎟", f = "⎠", v = "Size4-Regular", d = "rparen", g = 875) : e === "\\{" || e === "\\lbrace" ? (s = "⎧", o = "⎨", f = "⎩", c = "⎪", v = "Size4-Regular") : e === "\\}" || e === "\\rbrace" ? (s = "⎫", o = "⎬", f = "⎭", c = "⎪", v = "Size4-Regular") : e === "\\lgroup" || e === "⟮" ? (s = "⎧", f = "⎩", c = "⎪", v = "Size4-Regular") : e === "\\rgroup" || e === "⟯" ? (s = "⎫", f = "⎭", c = "⎪", v = "Size4-Regular") : e === "\\lmoustache" || e === "⎰" ? (s = "⎧", f = "⎭", c = "⎪", v = "Size4-Regular") : (e === "\\rmoustache" || e === "⎱") && (s = "⎫", f = "⎩", c = "⎪", v = "Size4-Regular");
  var y = br(s, v, i), k = y.height + y.depth, E = br(c, v, i), A = E.height + E.depth, D = br(f, v, i), b = D.height + D.depth, F = 0, T = 1;
  if (o !== null) {
    var M = br(o, v, i);
    F = M.height + M.depth, T = 2;
  }
  var z = k + b + F, O = Math.max(0, Math.ceil((t - z) / (T * A))), R = z + O * T * A, B = a.fontMetrics().axisHeight;
  r && (B *= a.sizeMultiplier);
  var X = R / 2 - B, $ = [];
  if (d.length > 0) {
    var Te = R - k - b, se = Math.round(R * 1e3), U = Fc(d, Math.round(Te * 1e3)), le = new x0(d, U), Se = (g / 1e3).toFixed(3) + "em", ue = (se / 1e3).toFixed(3) + "em", Ce = new h0([le], {
      width: Se,
      height: ue,
      viewBox: "0 0 " + g + " " + se
    }), xe = C.makeSvgSpan([], [Ce], a);
    xe.height = se / 1e3, xe.style.width = Se, xe.style.height = ue, $.push({
      type: "elem",
      elem: xe
    });
  } else {
    if ($.push(sa(f, v, i)), $.push(Zr), o === null) {
      var re = R - k - b + 2 * Xa;
      $.push(oa(c, re, a));
    } else {
      var oe = (R - k - b - F) / 2 + 2 * Xa;
      $.push(oa(c, oe, a)), $.push(Zr), $.push(sa(o, v, i)), $.push(Zr), $.push(oa(c, oe, a));
    }
    $.push(Zr), $.push(sa(s, v, i));
  }
  var fe = a.havingBaseStyle(Q.TEXT), Ne = C.makeVList({
    positionType: "bottom",
    positionData: X,
    children: $
  }, fe);
  return bi(C.makeSpan(["delimsizing", "mult"], [Ne], fe), Q.TEXT, a, l);
}, ua = 80, ca = 0.08, ha = function(e, t, r, a, i) {
  var l = Sc(e, a, r), s = new x0(e, l), o = new h0([s], {
    // Note: 1000:1 ratio of viewBox to document em width.
    width: "400em",
    height: P(t),
    viewBox: "0 0 400000 " + r,
    preserveAspectRatio: "xMinYMin slice"
  });
  return C.makeSvgSpan(["hide-tail"], [o], i);
}, x4 = function(e, t) {
  var r = t.havingBaseSizing(), a = au("\\surd", e * r.sizeMultiplier, nu, r), i = r.sizeMultiplier, l = Math.max(0, t.minRuleThickness - t.fontMetrics().sqrtRuleThickness), s, o = 0, c = 0, f = 0, d;
  return a.type === "small" ? (f = 1e3 + 1e3 * l + ua, e < 1 ? i = 1 : e < 1.4 && (i = 0.7), o = (1 + l + ca) / i, c = (1 + l) / i, s = ha("sqrtMain", o, f, l, t), s.style.minWidth = "0.853em", d = 0.833 / i) : a.type === "large" ? (f = (1e3 + ua) * wr[a.size], c = (wr[a.size] + l) / i, o = (wr[a.size] + l + ca) / i, s = ha("sqrtSize" + a.size, o, f, l, t), s.style.minWidth = "1.02em", d = 1 / i) : (o = e + l + ca, c = e + l, f = Math.floor(1e3 * e + l) + ua, s = ha("sqrtTall", o, f, l, t), s.style.minWidth = "0.742em", d = 1.056), s.height = c, s.style.height = P(o), {
    span: s,
    advanceWidth: d,
    // Calculate the actual line width.
    // This actually should depend on the chosen font -- e.g. \boldmath
    // should use the thicker surd symbols from e.g. KaTeX_Main-Bold, and
    // have thicker rules.
    ruleWidth: (t.fontMetrics().sqrtRuleThickness + l) * i
  };
}, tu = ["(", "\\lparen", ")", "\\rparen", "[", "\\lbrack", "]", "\\rbrack", "\\{", "\\lbrace", "\\}", "\\rbrace", "\\lfloor", "\\rfloor", "⌊", "⌋", "\\lceil", "\\rceil", "⌈", "⌉", "\\surd"], A4 = ["\\uparrow", "\\downarrow", "\\updownarrow", "\\Uparrow", "\\Downarrow", "\\Updownarrow", "|", "\\|", "\\vert", "\\Vert", "\\lvert", "\\rvert", "\\lVert", "\\rVert", "\\lgroup", "\\rgroup", "⟮", "⟯", "\\lmoustache", "\\rmoustache", "⎰", "⎱"], ru = ["<", ">", "\\langle", "\\rangle", "/", "\\backslash", "\\lt", "\\gt"], wr = [0, 1.2, 1.8, 2.4, 3], S4 = function(e, t, r, a, i) {
  if (e === "<" || e === "\\lt" || e === "⟨" ? e = "\\langle" : (e === ">" || e === "\\gt" || e === "⟩") && (e = "\\rangle"), j.contains(tu, e) || j.contains(ru, e))
    return $o(e, t, !1, r, a, i);
  if (j.contains(A4, e))
    return eu(e, wr[t], !1, r, a, i);
  throw new L("Illegal delimiter: '" + e + "'");
}, E4 = [{
  type: "small",
  style: Q.SCRIPTSCRIPT
}, {
  type: "small",
  style: Q.SCRIPT
}, {
  type: "small",
  style: Q.TEXT
}, {
  type: "large",
  size: 1
}, {
  type: "large",
  size: 2
}, {
  type: "large",
  size: 3
}, {
  type: "large",
  size: 4
}], F4 = [{
  type: "small",
  style: Q.SCRIPTSCRIPT
}, {
  type: "small",
  style: Q.SCRIPT
}, {
  type: "small",
  style: Q.TEXT
}, {
  type: "stack"
}], nu = [{
  type: "small",
  style: Q.SCRIPTSCRIPT
}, {
  type: "small",
  style: Q.SCRIPT
}, {
  type: "small",
  style: Q.TEXT
}, {
  type: "large",
  size: 1
}, {
  type: "large",
  size: 2
}, {
  type: "large",
  size: 3
}, {
  type: "large",
  size: 4
}, {
  type: "stack"
}], T4 = function(e) {
  if (e.type === "small")
    return "Main-Regular";
  if (e.type === "large")
    return "Size" + e.size + "-Regular";
  if (e.type === "stack")
    return "Size4-Regular";
  throw new Error("Add support for delim type '" + e.type + "' here.");
}, au = function(e, t, r, a) {
  for (var i = Math.min(2, 3 - a.style.size), l = i; l < r.length && r[l].type !== "stack"; l++) {
    var s = br(e, T4(r[l]), "math"), o = s.height + s.depth;
    if (r[l].type === "small") {
      var c = a.havingBaseStyle(r[l].style);
      o *= c.sizeMultiplier;
    }
    if (o > t)
      return r[l];
  }
  return r[r.length - 1];
}, iu = function(e, t, r, a, i, l) {
  e === "<" || e === "\\lt" || e === "⟨" ? e = "\\langle" : (e === ">" || e === "\\gt" || e === "⟩") && (e = "\\rangle");
  var s;
  j.contains(ru, e) ? s = E4 : j.contains(tu, e) ? s = nu : s = F4;
  var o = au(e, t, s, a);
  return o.type === "small" ? w4(e, o.style, r, a, i, l) : o.type === "large" ? $o(e, o.size, r, a, i, l) : eu(e, t, r, a, i, l);
}, C4 = function(e, t, r, a, i, l) {
  var s = a.fontMetrics().axisHeight * a.sizeMultiplier, o = 901, c = 5 / a.fontMetrics().ptPerEm, f = Math.max(t - s, r + s), d = Math.max(
    // In real TeX, calculations are done using integral values which are
    // 65536 per pt, or 655360 per em. So, the division here truncates in
    // TeX but doesn't here, producing different results. If we wanted to
    // exactly match TeX's calculation, we could do
    //   Math.floor(655360 * maxDistFromAxis / 500) *
    //    delimiterFactor / 655360
    // (To see the difference, compare
    //    x^{x^{\left(\rule{0.1em}{0.68em}\right)}}
    // in TeX and KaTeX)
    f / 500 * o,
    2 * f - c
  );
  return iu(e, d, !0, a, i, l);
}, c0 = {
  sqrtImage: x4,
  sizedDelim: S4,
  sizeToMaxHeight: wr,
  customSizedDelim: iu,
  leftRightDelim: C4
}, Dl = {
  "\\bigl": {
    mclass: "mopen",
    size: 1
  },
  "\\Bigl": {
    mclass: "mopen",
    size: 2
  },
  "\\biggl": {
    mclass: "mopen",
    size: 3
  },
  "\\Biggl": {
    mclass: "mopen",
    size: 4
  },
  "\\bigr": {
    mclass: "mclose",
    size: 1
  },
  "\\Bigr": {
    mclass: "mclose",
    size: 2
  },
  "\\biggr": {
    mclass: "mclose",
    size: 3
  },
  "\\Biggr": {
    mclass: "mclose",
    size: 4
  },
  "\\bigm": {
    mclass: "mrel",
    size: 1
  },
  "\\Bigm": {
    mclass: "mrel",
    size: 2
  },
  "\\biggm": {
    mclass: "mrel",
    size: 3
  },
  "\\Biggm": {
    mclass: "mrel",
    size: 4
  },
  "\\big": {
    mclass: "mord",
    size: 1
  },
  "\\Big": {
    mclass: "mord",
    size: 2
  },
  "\\bigg": {
    mclass: "mord",
    size: 3
  },
  "\\Bigg": {
    mclass: "mord",
    size: 4
  }
}, M4 = ["(", "\\lparen", ")", "\\rparen", "[", "\\lbrack", "]", "\\rbrack", "\\{", "\\lbrace", "\\}", "\\rbrace", "\\lfloor", "\\rfloor", "⌊", "⌋", "\\lceil", "\\rceil", "⌈", "⌉", "<", ">", "\\langle", "⟨", "\\rangle", "⟩", "\\lt", "\\gt", "\\lvert", "\\rvert", "\\lVert", "\\rVert", "\\lgroup", "\\rgroup", "⟮", "⟯", "\\lmoustache", "\\rmoustache", "⎰", "⎱", "/", "\\backslash", "|", "\\vert", "\\|", "\\Vert", "\\uparrow", "\\Uparrow", "\\downarrow", "\\Downarrow", "\\updownarrow", "\\Updownarrow", "."];
function qn(n, e) {
  var t = Ln(n);
  if (t && j.contains(M4, t.text))
    return t;
  throw t ? new L("Invalid delimiter '" + t.text + "' after '" + e.funcName + "'", n) : new L("Invalid delimiter type '" + n.type + "'", n);
}
G({
  type: "delimsizing",
  names: ["\\bigl", "\\Bigl", "\\biggl", "\\Biggl", "\\bigr", "\\Bigr", "\\biggr", "\\Biggr", "\\bigm", "\\Bigm", "\\biggm", "\\Biggm", "\\big", "\\Big", "\\bigg", "\\Bigg"],
  props: {
    numArgs: 1,
    argTypes: ["primitive"]
  },
  handler: (n, e) => {
    var t = qn(e[0], n);
    return {
      type: "delimsizing",
      mode: n.parser.mode,
      size: Dl[n.funcName].size,
      mclass: Dl[n.funcName].mclass,
      delim: t.text
    };
  },
  htmlBuilder: (n, e) => n.delim === "." ? C.makeSpan([n.mclass]) : c0.sizedDelim(n.delim, n.size, e, n.mode, [n.mclass]),
  mathmlBuilder: (n) => {
    var e = [];
    n.delim !== "." && e.push(pt(n.delim, n.mode));
    var t = new I.MathNode("mo", e);
    n.mclass === "mopen" || n.mclass === "mclose" ? t.setAttribute("fence", "true") : t.setAttribute("fence", "false"), t.setAttribute("stretchy", "true");
    var r = P(c0.sizeToMaxHeight[n.size]);
    return t.setAttribute("minsize", r), t.setAttribute("maxsize", r), t;
  }
});
function xl(n) {
  if (!n.body)
    throw new Error("Bug: The leftright ParseNode wasn't fully parsed.");
}
G({
  type: "leftright-right",
  names: ["\\right"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler: (n, e) => {
    var t = n.parser.gullet.macros.get("\\current@color");
    if (t && typeof t != "string")
      throw new L("\\current@color set to non-string in \\right");
    return {
      type: "leftright-right",
      mode: n.parser.mode,
      delim: qn(e[0], n).text,
      color: t
      // undefined if not set via \color
    };
  }
});
G({
  type: "leftright",
  names: ["\\left"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler: (n, e) => {
    var t = qn(e[0], n), r = n.parser;
    ++r.leftrightDepth;
    var a = r.parseExpression(!1);
    --r.leftrightDepth, r.expect("\\right", !1);
    var i = te(r.parseFunction(), "leftright-right");
    return {
      type: "leftright",
      mode: r.mode,
      body: a,
      left: t.text,
      right: i.delim,
      rightColor: i.color
    };
  },
  htmlBuilder: (n, e) => {
    xl(n);
    for (var t = Me(n.body, e, !0, ["mopen", "mclose"]), r = 0, a = 0, i = !1, l = 0; l < t.length; l++)
      t[l].isMiddle ? i = !0 : (r = Math.max(t[l].height, r), a = Math.max(t[l].depth, a));
    r *= e.sizeMultiplier, a *= e.sizeMultiplier;
    var s;
    if (n.left === "." ? s = Er(e, ["mopen"]) : s = c0.leftRightDelim(n.left, r, a, e, n.mode, ["mopen"]), t.unshift(s), i)
      for (var o = 1; o < t.length; o++) {
        var c = t[o], f = c.isMiddle;
        f && (t[o] = c0.leftRightDelim(f.delim, r, a, f.options, n.mode, []));
      }
    var d;
    if (n.right === ".")
      d = Er(e, ["mclose"]);
    else {
      var g = n.rightColor ? e.withColor(n.rightColor) : e;
      d = c0.leftRightDelim(n.right, r, a, g, n.mode, ["mclose"]);
    }
    return t.push(d), C.makeSpan(["minner"], t, e);
  },
  mathmlBuilder: (n, e) => {
    xl(n);
    var t = $e(n.body, e);
    if (n.left !== ".") {
      var r = new I.MathNode("mo", [pt(n.left, n.mode)]);
      r.setAttribute("fence", "true"), t.unshift(r);
    }
    if (n.right !== ".") {
      var a = new I.MathNode("mo", [pt(n.right, n.mode)]);
      a.setAttribute("fence", "true"), n.rightColor && a.setAttribute("mathcolor", n.rightColor), t.push(a);
    }
    return di(t);
  }
});
G({
  type: "middle",
  names: ["\\middle"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler: (n, e) => {
    var t = qn(e[0], n);
    if (!n.parser.leftrightDepth)
      throw new L("\\middle without preceding \\left", t);
    return {
      type: "middle",
      mode: n.parser.mode,
      delim: t.text
    };
  },
  htmlBuilder: (n, e) => {
    var t;
    if (n.delim === ".")
      t = Er(e, []);
    else {
      t = c0.sizedDelim(n.delim, 1, e, n.mode, []);
      var r = {
        delim: n.delim,
        options: e
      };
      t.isMiddle = r;
    }
    return t;
  },
  mathmlBuilder: (n, e) => {
    var t = n.delim === "\\vert" || n.delim === "|" ? pt("|", "text") : pt(n.delim, n.mode), r = new I.MathNode("mo", [t]);
    return r.setAttribute("fence", "true"), r.setAttribute("lspace", "0.05em"), r.setAttribute("rspace", "0.05em"), r;
  }
});
var yi = (n, e) => {
  var t = C.wrapFragment(ie(n.body, e), e), r = n.label.slice(1), a = e.sizeMultiplier, i, l = 0, s = j.isCharacterBox(n.body);
  if (r === "sout")
    i = C.makeSpan(["stretchy", "sout"]), i.height = e.fontMetrics().defaultRuleThickness / a, l = -0.5 * e.fontMetrics().xHeight;
  else if (r === "phase") {
    var o = we({
      number: 0.6,
      unit: "pt"
    }, e), c = we({
      number: 0.35,
      unit: "ex"
    }, e), f = e.havingBaseSizing();
    a = a / f.sizeMultiplier;
    var d = t.height + t.depth + o + c;
    t.style.paddingLeft = P(d / 2 + o);
    var g = Math.floor(1e3 * d * a), v = xc(g), y = new h0([new x0("phase", v)], {
      width: "400em",
      height: P(g / 1e3),
      viewBox: "0 0 400000 " + g,
      preserveAspectRatio: "xMinYMin slice"
    });
    i = C.makeSvgSpan(["hide-tail"], [y], e), i.style.height = P(d), l = t.depth + o + c;
  } else {
    /cancel/.test(r) ? s || t.classes.push("cancel-pad") : r === "angl" ? t.classes.push("anglpad") : t.classes.push("boxpad");
    var k = 0, E = 0, A = 0;
    /box/.test(r) ? (A = Math.max(
      e.fontMetrics().fboxrule,
      // default
      e.minRuleThickness
      // User override.
    ), k = e.fontMetrics().fboxsep + (r === "colorbox" ? 0 : A), E = k) : r === "angl" ? (A = Math.max(e.fontMetrics().defaultRuleThickness, e.minRuleThickness), k = 4 * A, E = Math.max(0, 0.25 - t.depth)) : (k = s ? 0.2 : 0, E = k), i = m0.encloseSpan(t, r, k, E, e), /fbox|boxed|fcolorbox/.test(r) ? (i.style.borderStyle = "solid", i.style.borderWidth = P(A)) : r === "angl" && A !== 0.049 && (i.style.borderTopWidth = P(A), i.style.borderRightWidth = P(A)), l = t.depth + E, n.backgroundColor && (i.style.backgroundColor = n.backgroundColor, n.borderColor && (i.style.borderColor = n.borderColor));
  }
  var D;
  if (n.backgroundColor)
    D = C.makeVList({
      positionType: "individualShift",
      children: [
        // Put the color background behind inner;
        {
          type: "elem",
          elem: i,
          shift: l
        },
        {
          type: "elem",
          elem: t,
          shift: 0
        }
      ]
    }, e);
  else {
    var b = /cancel|phase/.test(r) ? ["svg-align"] : [];
    D = C.makeVList({
      positionType: "individualShift",
      children: [
        // Write the \cancel stroke on top of inner.
        {
          type: "elem",
          elem: t,
          shift: 0
        },
        {
          type: "elem",
          elem: i,
          shift: l,
          wrapperClasses: b
        }
      ]
    }, e);
  }
  return /cancel/.test(r) && (D.height = t.height, D.depth = t.depth), /cancel/.test(r) && !s ? C.makeSpan(["mord", "cancel-lap"], [D], e) : C.makeSpan(["mord"], [D], e);
}, wi = (n, e) => {
  var t = 0, r = new I.MathNode(n.label.indexOf("colorbox") > -1 ? "mpadded" : "menclose", [me(n.body, e)]);
  switch (n.label) {
    case "\\cancel":
      r.setAttribute("notation", "updiagonalstrike");
      break;
    case "\\bcancel":
      r.setAttribute("notation", "downdiagonalstrike");
      break;
    case "\\phase":
      r.setAttribute("notation", "phasorangle");
      break;
    case "\\sout":
      r.setAttribute("notation", "horizontalstrike");
      break;
    case "\\fbox":
      r.setAttribute("notation", "box");
      break;
    case "\\angl":
      r.setAttribute("notation", "actuarial");
      break;
    case "\\fcolorbox":
    case "\\colorbox":
      if (t = e.fontMetrics().fboxsep * e.fontMetrics().ptPerEm, r.setAttribute("width", "+" + 2 * t + "pt"), r.setAttribute("height", "+" + 2 * t + "pt"), r.setAttribute("lspace", t + "pt"), r.setAttribute("voffset", t + "pt"), n.label === "\\fcolorbox") {
        var a = Math.max(
          e.fontMetrics().fboxrule,
          // default
          e.minRuleThickness
          // user override
        );
        r.setAttribute("style", "border: " + a + "em solid " + String(n.borderColor));
      }
      break;
    case "\\xcancel":
      r.setAttribute("notation", "updiagonalstrike downdiagonalstrike");
      break;
  }
  return n.backgroundColor && r.setAttribute("mathbackground", n.backgroundColor), r;
};
G({
  type: "enclose",
  names: ["\\colorbox"],
  props: {
    numArgs: 2,
    allowedInText: !0,
    argTypes: ["color", "text"]
  },
  handler(n, e, t) {
    var {
      parser: r,
      funcName: a
    } = n, i = te(e[0], "color-token").color, l = e[1];
    return {
      type: "enclose",
      mode: r.mode,
      label: a,
      backgroundColor: i,
      body: l
    };
  },
  htmlBuilder: yi,
  mathmlBuilder: wi
});
G({
  type: "enclose",
  names: ["\\fcolorbox"],
  props: {
    numArgs: 3,
    allowedInText: !0,
    argTypes: ["color", "color", "text"]
  },
  handler(n, e, t) {
    var {
      parser: r,
      funcName: a
    } = n, i = te(e[0], "color-token").color, l = te(e[1], "color-token").color, s = e[2];
    return {
      type: "enclose",
      mode: r.mode,
      label: a,
      backgroundColor: l,
      borderColor: i,
      body: s
    };
  },
  htmlBuilder: yi,
  mathmlBuilder: wi
});
G({
  type: "enclose",
  names: ["\\fbox"],
  props: {
    numArgs: 1,
    argTypes: ["hbox"],
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "enclose",
      mode: t.mode,
      label: "\\fbox",
      body: e[0]
    };
  }
});
G({
  type: "enclose",
  names: ["\\cancel", "\\bcancel", "\\xcancel", "\\sout", "\\phase"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "enclose",
      mode: t.mode,
      label: r,
      body: a
    };
  },
  htmlBuilder: yi,
  mathmlBuilder: wi
});
G({
  type: "enclose",
  names: ["\\angl"],
  props: {
    numArgs: 1,
    argTypes: ["hbox"],
    allowedInText: !1
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "enclose",
      mode: t.mode,
      label: "\\angl",
      body: e[0]
    };
  }
});
var lu = {};
function jt(n) {
  for (var {
    type: e,
    names: t,
    props: r,
    handler: a,
    htmlBuilder: i,
    mathmlBuilder: l
  } = n, s = {
    type: e,
    numArgs: r.numArgs || 0,
    allowedInText: !1,
    numOptionalArgs: 0,
    handler: a
  }, o = 0; o < t.length; ++o)
    lu[t[o]] = s;
  i && (An[e] = i), l && (Sn[e] = l);
}
var su = {};
function p(n, e) {
  su[n] = e;
}
function Al(n) {
  var e = [];
  n.consumeSpaces();
  var t = n.fetch().text;
  for (t === "\\relax" && (n.consume(), n.consumeSpaces(), t = n.fetch().text); t === "\\hline" || t === "\\hdashline"; )
    n.consume(), e.push(t === "\\hdashline"), n.consumeSpaces(), t = n.fetch().text;
  return e;
}
var Pn = (n) => {
  var e = n.parser.settings;
  if (!e.displayMode)
    throw new L("{" + n.envName + "} can be used only in display mode.");
};
function ki(n) {
  if (n.indexOf("ed") === -1)
    return n.indexOf("*") === -1;
}
function S0(n, e, t) {
  var {
    hskipBeforeAndAfter: r,
    addJot: a,
    cols: i,
    arraystretch: l,
    colSeparationType: s,
    autoTag: o,
    singleRow: c,
    emptySingleRow: f,
    maxNumCols: d,
    leqno: g
  } = e;
  if (n.gullet.beginGroup(), c || n.gullet.macros.set("\\cr", "\\\\\\relax"), !l) {
    var v = n.gullet.expandMacroAsText("\\arraystretch");
    if (v == null)
      l = 1;
    else if (l = parseFloat(v), !l || l < 0)
      throw new L("Invalid \\arraystretch: " + v);
  }
  n.gullet.beginGroup();
  var y = [], k = [y], E = [], A = [], D = o != null ? [] : void 0;
  function b() {
    o && n.gullet.macros.set("\\@eqnsw", "1", !0);
  }
  function F() {
    D && (n.gullet.macros.get("\\df@tag") ? (D.push(n.subparse([new mt("\\df@tag")])), n.gullet.macros.set("\\df@tag", void 0, !0)) : D.push(!!o && n.gullet.macros.get("\\@eqnsw") === "1"));
  }
  for (b(), A.push(Al(n)); ; ) {
    var T = n.parseExpression(!1, c ? "\\end" : "\\\\");
    n.gullet.endGroup(), n.gullet.beginGroup(), T = {
      type: "ordgroup",
      mode: n.mode,
      body: T
    }, t && (T = {
      type: "styling",
      mode: n.mode,
      style: t,
      body: [T]
    }), y.push(T);
    var M = n.fetch().text;
    if (M === "&") {
      if (d && y.length === d) {
        if (c || s)
          throw new L("Too many tab characters: &", n.nextToken);
        n.settings.reportNonstrict("textEnv", "Too few columns specified in the {array} column argument.");
      }
      n.consume();
    } else if (M === "\\end") {
      F(), y.length === 1 && T.type === "styling" && T.body[0].body.length === 0 && (k.length > 1 || !f) && k.pop(), A.length < k.length + 1 && A.push([]);
      break;
    } else if (M === "\\\\") {
      n.consume();
      var z = void 0;
      n.gullet.future().text !== " " && (z = n.parseSizeGroup(!0)), E.push(z ? z.value : null), F(), A.push(Al(n)), y = [], k.push(y), b();
    } else
      throw new L("Expected & or \\\\ or \\cr or \\end", n.nextToken);
  }
  return n.gullet.endGroup(), n.gullet.endGroup(), {
    type: "array",
    mode: n.mode,
    addJot: a,
    arraystretch: l,
    body: k,
    cols: i,
    rowGaps: E,
    hskipBeforeAndAfter: r,
    hLinesBeforeRow: A,
    colSeparationType: s,
    tags: D,
    leqno: g
  };
}
function _i(n) {
  return n.slice(0, 1) === "d" ? "display" : "text";
}
var Zt = function(e, t) {
  var r, a, i = e.body.length, l = e.hLinesBeforeRow, s = 0, o = new Array(i), c = [], f = Math.max(
    // From LaTeX \showthe\arrayrulewidth. Equals 0.04 em.
    t.fontMetrics().arrayRuleWidth,
    t.minRuleThickness
    // User override.
  ), d = 1 / t.fontMetrics().ptPerEm, g = 5 * d;
  if (e.colSeparationType && e.colSeparationType === "small") {
    var v = t.havingStyle(Q.SCRIPT).sizeMultiplier;
    g = 0.2778 * (v / t.sizeMultiplier);
  }
  var y = e.colSeparationType === "CD" ? we({
    number: 3,
    unit: "ex"
  }, t) : 12 * d, k = 3 * d, E = e.arraystretch * y, A = 0.7 * E, D = 0.3 * E, b = 0;
  function F($t) {
    for (var e0 = 0; e0 < $t.length; ++e0)
      e0 > 0 && (b += 0.25), c.push({
        pos: b,
        isDashed: $t[e0]
      });
  }
  for (F(l[0]), r = 0; r < e.body.length; ++r) {
    var T = e.body[r], M = A, z = D;
    s < T.length && (s = T.length);
    var O = new Array(T.length);
    for (a = 0; a < T.length; ++a) {
      var R = ie(T[a], t);
      z < R.depth && (z = R.depth), M < R.height && (M = R.height), O[a] = R;
    }
    var B = e.rowGaps[r], X = 0;
    B && (X = we(B, t), X > 0 && (X += D, z < X && (z = X), X = 0)), e.addJot && (z += k), O.height = M, O.depth = z, b += M, O.pos = b, b += z + X, o[r] = O, F(l[r + 1]);
  }
  var $ = b / 2 + t.fontMetrics().axisHeight, Te = e.cols || [], se = [], U, le, Se = [];
  if (e.tags && e.tags.some(($t) => $t))
    for (r = 0; r < i; ++r) {
      var ue = o[r], Ce = ue.pos - $, xe = e.tags[r], re = void 0;
      xe === !0 ? re = C.makeSpan(["eqn-num"], [], t) : xe === !1 ? re = C.makeSpan([], [], t) : re = C.makeSpan([], Me(xe, t, !0), t), re.depth = ue.depth, re.height = ue.height, Se.push({
        type: "elem",
        elem: re,
        shift: Ce
      });
    }
  for (
    a = 0, le = 0;
    // Continue while either there are more columns or more column
    // descriptions, so trailing separators don't get lost.
    a < s || le < Te.length;
    ++a, ++le
  ) {
    for (var oe = Te[le] || {}, fe = !0; oe.type === "separator"; ) {
      if (fe || (U = C.makeSpan(["arraycolsep"], []), U.style.width = P(t.fontMetrics().doubleRuleSep), se.push(U)), oe.separator === "|" || oe.separator === ":") {
        var Ne = oe.separator === "|" ? "solid" : "dashed", H = C.makeSpan(["vertical-separator"], [], t);
        H.style.height = P(b), H.style.borderRightWidth = P(f), H.style.borderRightStyle = Ne, H.style.margin = "0 " + P(-f / 2);
        var et = b - $;
        et && (H.style.verticalAlign = P(-et)), se.push(H);
      } else
        throw new L("Invalid separator type: " + oe.separator);
      le++, oe = Te[le] || {}, fe = !1;
    }
    if (!(a >= s)) {
      var qe = void 0;
      (a > 0 || e.hskipBeforeAndAfter) && (qe = j.deflt(oe.pregap, g), qe !== 0 && (U = C.makeSpan(["arraycolsep"], []), U.style.width = P(qe), se.push(U)));
      var tt = [];
      for (r = 0; r < i; ++r) {
        var yt = o[r], wt = yt[a];
        if (wt) {
          var Qt = yt.pos - $;
          wt.depth = yt.depth, wt.height = yt.height, tt.push({
            type: "elem",
            elem: wt,
            shift: Qt
          });
        }
      }
      tt = C.makeVList({
        positionType: "individualShift",
        children: tt
      }, t), tt = C.makeSpan(["col-align-" + (oe.align || "c")], [tt]), se.push(tt), (a < s - 1 || e.hskipBeforeAndAfter) && (qe = j.deflt(oe.postgap, g), qe !== 0 && (U = C.makeSpan(["arraycolsep"], []), U.style.width = P(qe), se.push(U)));
    }
  }
  if (o = C.makeSpan(["mtable"], se), c.length > 0) {
    for (var Bt = C.makeLineSpan("hline", t, f), Jt = C.makeLineSpan("hdashline", t, f), kt = [{
      type: "elem",
      elem: o,
      shift: 0
    }]; c.length > 0; ) {
      var H0 = c.pop(), U0 = H0.pos - $;
      H0.isDashed ? kt.push({
        type: "elem",
        elem: Jt,
        shift: U0
      }) : kt.push({
        type: "elem",
        elem: Bt,
        shift: U0
      });
    }
    o = C.makeVList({
      positionType: "individualShift",
      children: kt
    }, t);
  }
  if (Se.length === 0)
    return C.makeSpan(["mord"], [o], t);
  var Nt = C.makeVList({
    positionType: "individualShift",
    children: Se
  }, t);
  return Nt = C.makeSpan(["tag"], [Nt], t), C.makeFragment([o, Nt]);
}, z4 = {
  c: "center ",
  l: "left ",
  r: "right "
}, Kt = function(e, t) {
  for (var r = [], a = new I.MathNode("mtd", [], ["mtr-glue"]), i = new I.MathNode("mtd", [], ["mml-eqn-num"]), l = 0; l < e.body.length; l++) {
    for (var s = e.body[l], o = [], c = 0; c < s.length; c++)
      o.push(new I.MathNode("mtd", [me(s[c], t)]));
    e.tags && e.tags[l] && (o.unshift(a), o.push(a), e.leqno ? o.unshift(i) : o.push(i)), r.push(new I.MathNode("mtr", o));
  }
  var f = new I.MathNode("mtable", r), d = e.arraystretch === 0.5 ? 0.1 : 0.16 + e.arraystretch - 1 + (e.addJot ? 0.09 : 0);
  f.setAttribute("rowspacing", P(d));
  var g = "", v = "";
  if (e.cols && e.cols.length > 0) {
    var y = e.cols, k = "", E = !1, A = 0, D = y.length;
    y[0].type === "separator" && (g += "top ", A = 1), y[y.length - 1].type === "separator" && (g += "bottom ", D -= 1);
    for (var b = A; b < D; b++)
      y[b].type === "align" ? (v += z4[y[b].align], E && (k += "none "), E = !0) : y[b].type === "separator" && E && (k += y[b].separator === "|" ? "solid " : "dashed ", E = !1);
    f.setAttribute("columnalign", v.trim()), /[sd]/.test(k) && f.setAttribute("columnlines", k.trim());
  }
  if (e.colSeparationType === "align") {
    for (var F = e.cols || [], T = "", M = 1; M < F.length; M++)
      T += M % 2 ? "0em " : "1em ";
    f.setAttribute("columnspacing", T.trim());
  } else e.colSeparationType === "alignat" || e.colSeparationType === "gather" ? f.setAttribute("columnspacing", "0em") : e.colSeparationType === "small" ? f.setAttribute("columnspacing", "0.2778em") : e.colSeparationType === "CD" ? f.setAttribute("columnspacing", "0.5em") : f.setAttribute("columnspacing", "1em");
  var z = "", O = e.hLinesBeforeRow;
  g += O[0].length > 0 ? "left " : "", g += O[O.length - 1].length > 0 ? "right " : "";
  for (var R = 1; R < O.length - 1; R++)
    z += O[R].length === 0 ? "none " : O[R][0] ? "dashed " : "solid ";
  return /[sd]/.test(z) && f.setAttribute("rowlines", z.trim()), g !== "" && (f = new I.MathNode("menclose", [f]), f.setAttribute("notation", g.trim())), e.arraystretch && e.arraystretch < 1 && (f = new I.MathNode("mstyle", [f]), f.setAttribute("scriptlevel", "1")), f;
}, ou = function(e, t) {
  e.envName.indexOf("ed") === -1 && Pn(e);
  var r = [], a = e.envName.indexOf("at") > -1 ? "alignat" : "align", i = e.envName === "split", l = S0(e.parser, {
    cols: r,
    addJot: !0,
    autoTag: i ? void 0 : ki(e.envName),
    emptySingleRow: !0,
    colSeparationType: a,
    maxNumCols: i ? 2 : void 0,
    leqno: e.parser.settings.leqno
  }, "display"), s, o = 0, c = {
    type: "ordgroup",
    mode: e.mode,
    body: []
  };
  if (t[0] && t[0].type === "ordgroup") {
    for (var f = "", d = 0; d < t[0].body.length; d++) {
      var g = te(t[0].body[d], "textord");
      f += g.text;
    }
    s = Number(f), o = s * 2;
  }
  var v = !o;
  l.body.forEach(function(A) {
    for (var D = 1; D < A.length; D += 2) {
      var b = te(A[D], "styling"), F = te(b.body[0], "ordgroup");
      F.body.unshift(c);
    }
    if (v)
      o < A.length && (o = A.length);
    else {
      var T = A.length / 2;
      if (s < T)
        throw new L("Too many math in a row: " + ("expected " + s + ", but got " + T), A[0]);
    }
  });
  for (var y = 0; y < o; ++y) {
    var k = "r", E = 0;
    y % 2 === 1 ? k = "l" : y > 0 && v && (E = 1), r[y] = {
      type: "align",
      align: k,
      pregap: E,
      postgap: 0
    };
  }
  return l.colSeparationType = v ? "align" : "alignat", l;
};
jt({
  type: "array",
  names: ["array", "darray"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var t = Ln(e[0]), r = t ? [e[0]] : te(e[0], "ordgroup").body, a = r.map(function(l) {
      var s = gi(l), o = s.text;
      if ("lcr".indexOf(o) !== -1)
        return {
          type: "align",
          align: o
        };
      if (o === "|")
        return {
          type: "separator",
          separator: "|"
        };
      if (o === ":")
        return {
          type: "separator",
          separator: ":"
        };
      throw new L("Unknown column alignment: " + o, l);
    }), i = {
      cols: a,
      hskipBeforeAndAfter: !0,
      // \@preamble in lttab.dtx
      maxNumCols: a.length
    };
    return S0(n.parser, i, _i(n.envName));
  },
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["matrix", "pmatrix", "bmatrix", "Bmatrix", "vmatrix", "Vmatrix", "matrix*", "pmatrix*", "bmatrix*", "Bmatrix*", "vmatrix*", "Vmatrix*"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var e = {
      matrix: null,
      pmatrix: ["(", ")"],
      bmatrix: ["[", "]"],
      Bmatrix: ["\\{", "\\}"],
      vmatrix: ["|", "|"],
      Vmatrix: ["\\Vert", "\\Vert"]
    }[n.envName.replace("*", "")], t = "c", r = {
      hskipBeforeAndAfter: !1,
      cols: [{
        type: "align",
        align: t
      }]
    };
    if (n.envName.charAt(n.envName.length - 1) === "*") {
      var a = n.parser;
      if (a.consumeSpaces(), a.fetch().text === "[") {
        if (a.consume(), a.consumeSpaces(), t = a.fetch().text, "lcr".indexOf(t) === -1)
          throw new L("Expected l or c or r", a.nextToken);
        a.consume(), a.consumeSpaces(), a.expect("]"), a.consume(), r.cols = [{
          type: "align",
          align: t
        }];
      }
    }
    var i = S0(n.parser, r, _i(n.envName)), l = Math.max(0, ...i.body.map((s) => s.length));
    return i.cols = new Array(l).fill({
      type: "align",
      align: t
    }), e ? {
      type: "leftright",
      mode: n.mode,
      body: [i],
      left: e[0],
      right: e[1],
      rightColor: void 0
      // \right uninfluenced by \color in array
    } : i;
  },
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["smallmatrix"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var e = {
      arraystretch: 0.5
    }, t = S0(n.parser, e, "script");
    return t.colSeparationType = "small", t;
  },
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["subarray"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var t = Ln(e[0]), r = t ? [e[0]] : te(e[0], "ordgroup").body, a = r.map(function(l) {
      var s = gi(l), o = s.text;
      if ("lc".indexOf(o) !== -1)
        return {
          type: "align",
          align: o
        };
      throw new L("Unknown column alignment: " + o, l);
    });
    if (a.length > 1)
      throw new L("{subarray} can contain only one column");
    var i = {
      cols: a,
      hskipBeforeAndAfter: !1,
      arraystretch: 0.5
    };
    if (i = S0(n.parser, i, "script"), i.body.length > 0 && i.body[0].length > 1)
      throw new L("{subarray} can contain only one column");
    return i;
  },
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["cases", "dcases", "rcases", "drcases"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var e = {
      arraystretch: 1.2,
      cols: [{
        type: "align",
        align: "l",
        pregap: 0,
        // TODO(kevinb) get the current style.
        // For now we use the metrics for TEXT style which is what we were
        // doing before.  Before attempting to get the current style we
        // should look at TeX's behavior especially for \over and matrices.
        postgap: 1
        /* 1em quad */
      }, {
        type: "align",
        align: "l",
        pregap: 0,
        postgap: 0
      }]
    }, t = S0(n.parser, e, _i(n.envName));
    return {
      type: "leftright",
      mode: n.mode,
      body: [t],
      left: n.envName.indexOf("r") > -1 ? "." : "\\{",
      right: n.envName.indexOf("r") > -1 ? "\\}" : ".",
      rightColor: void 0
    };
  },
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["align", "align*", "aligned", "split"],
  props: {
    numArgs: 0
  },
  handler: ou,
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["gathered", "gather", "gather*"],
  props: {
    numArgs: 0
  },
  handler(n) {
    j.contains(["gather", "gather*"], n.envName) && Pn(n);
    var e = {
      cols: [{
        type: "align",
        align: "c"
      }],
      addJot: !0,
      colSeparationType: "gather",
      autoTag: ki(n.envName),
      emptySingleRow: !0,
      leqno: n.parser.settings.leqno
    };
    return S0(n.parser, e, "display");
  },
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["alignat", "alignat*", "alignedat"],
  props: {
    numArgs: 1
  },
  handler: ou,
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["equation", "equation*"],
  props: {
    numArgs: 0
  },
  handler(n) {
    Pn(n);
    var e = {
      autoTag: ki(n.envName),
      emptySingleRow: !0,
      singleRow: !0,
      maxNumCols: 1,
      leqno: n.parser.settings.leqno
    };
    return S0(n.parser, e, "display");
  },
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
jt({
  type: "array",
  names: ["CD"],
  props: {
    numArgs: 0
  },
  handler(n) {
    return Pn(n), b4(n.parser);
  },
  htmlBuilder: Zt,
  mathmlBuilder: Kt
});
p("\\nonumber", "\\gdef\\@eqnsw{0}");
p("\\notag", "\\nonumber");
G({
  type: "text",
  // Doesn't matter what this is.
  names: ["\\hline", "\\hdashline"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    allowedInMath: !0
  },
  handler(n, e) {
    throw new L(n.funcName + " valid only within array environment");
  }
});
var Sl = lu;
G({
  type: "environment",
  names: ["\\begin", "\\end"],
  props: {
    numArgs: 1,
    argTypes: ["text"]
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    if (a.type !== "ordgroup")
      throw new L("Invalid environment name", a);
    for (var i = "", l = 0; l < a.body.length; ++l)
      i += te(a.body[l], "textord").text;
    if (r === "\\begin") {
      if (!Sl.hasOwnProperty(i))
        throw new L("No such environment: " + i, a);
      var s = Sl[i], {
        args: o,
        optArgs: c
      } = t.parseArguments("\\begin{" + i + "}", s), f = {
        mode: t.mode,
        envName: i,
        parser: t
      }, d = s.handler(f, o, c);
      t.expect("\\end", !1);
      var g = t.nextToken, v = te(t.parseFunction(), "environment");
      if (v.name !== i)
        throw new L("Mismatch: \\begin{" + i + "} matched by \\end{" + v.name + "}", g);
      return d;
    }
    return {
      type: "environment",
      mode: t.mode,
      name: i,
      nameGroup: a
    };
  }
});
var uu = (n, e) => {
  var t = n.font, r = e.withFont(t);
  return ie(n.body, r);
}, cu = (n, e) => {
  var t = n.font, r = e.withFont(t);
  return me(n.body, r);
}, El = {
  "\\Bbb": "\\mathbb",
  "\\bold": "\\mathbf",
  "\\frak": "\\mathfrak",
  "\\bm": "\\boldsymbol"
};
G({
  type: "font",
  names: [
    // styles, except \boldsymbol defined below
    "\\mathrm",
    "\\mathit",
    "\\mathbf",
    "\\mathnormal",
    "\\mathsfit",
    // families
    "\\mathbb",
    "\\mathcal",
    "\\mathfrak",
    "\\mathscr",
    "\\mathsf",
    "\\mathtt",
    // aliases, except \bm defined below
    "\\Bbb",
    "\\bold",
    "\\frak"
  ],
  props: {
    numArgs: 1,
    allowedInArgument: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = En(e[0]), i = r;
    return i in El && (i = El[i]), {
      type: "font",
      mode: t.mode,
      font: i.slice(1),
      body: a
    };
  },
  htmlBuilder: uu,
  mathmlBuilder: cu
});
G({
  type: "mclass",
  names: ["\\boldsymbol", "\\bm"],
  props: {
    numArgs: 1
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0], a = j.isCharacterBox(r);
    return {
      type: "mclass",
      mode: t.mode,
      mclass: On(r),
      body: [{
        type: "font",
        mode: t.mode,
        font: "boldsymbol",
        body: r
      }],
      isCharacterBox: a
    };
  }
});
G({
  type: "font",
  names: ["\\rm", "\\sf", "\\tt", "\\bf", "\\it", "\\cal"],
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r,
      breakOnTokenText: a
    } = n, {
      mode: i
    } = t, l = t.parseExpression(!0, a), s = "math" + r.slice(1);
    return {
      type: "font",
      mode: i,
      font: s,
      body: {
        type: "ordgroup",
        mode: t.mode,
        body: l
      }
    };
  },
  htmlBuilder: uu,
  mathmlBuilder: cu
});
var hu = (n, e) => {
  var t = e;
  return n === "display" ? t = t.id >= Q.SCRIPT.id ? t.text() : Q.DISPLAY : n === "text" && t.size === Q.DISPLAY.size ? t = Q.TEXT : n === "script" ? t = Q.SCRIPT : n === "scriptscript" && (t = Q.SCRIPTSCRIPT), t;
}, Di = (n, e) => {
  var t = hu(n.size, e.style), r = t.fracNum(), a = t.fracDen(), i;
  i = e.havingStyle(r);
  var l = ie(n.numer, i, e);
  if (n.continued) {
    var s = 8.5 / e.fontMetrics().ptPerEm, o = 3.5 / e.fontMetrics().ptPerEm;
    l.height = l.height < s ? s : l.height, l.depth = l.depth < o ? o : l.depth;
  }
  i = e.havingStyle(a);
  var c = ie(n.denom, i, e), f, d, g;
  n.hasBarLine ? (n.barSize ? (d = we(n.barSize, e), f = C.makeLineSpan("frac-line", e, d)) : f = C.makeLineSpan("frac-line", e), d = f.height, g = f.height) : (f = null, d = 0, g = e.fontMetrics().defaultRuleThickness);
  var v, y, k;
  t.size === Q.DISPLAY.size || n.size === "display" ? (v = e.fontMetrics().num1, d > 0 ? y = 3 * g : y = 7 * g, k = e.fontMetrics().denom1) : (d > 0 ? (v = e.fontMetrics().num2, y = g) : (v = e.fontMetrics().num3, y = 3 * g), k = e.fontMetrics().denom2);
  var E;
  if (f) {
    var D = e.fontMetrics().axisHeight;
    v - l.depth - (D + 0.5 * d) < y && (v += y - (v - l.depth - (D + 0.5 * d))), D - 0.5 * d - (c.height - k) < y && (k += y - (D - 0.5 * d - (c.height - k)));
    var b = -(D - 0.5 * d);
    E = C.makeVList({
      positionType: "individualShift",
      children: [{
        type: "elem",
        elem: c,
        shift: k
      }, {
        type: "elem",
        elem: f,
        shift: b
      }, {
        type: "elem",
        elem: l,
        shift: -v
      }]
    }, e);
  } else {
    var A = v - l.depth - (c.height - k);
    A < y && (v += 0.5 * (y - A), k += 0.5 * (y - A)), E = C.makeVList({
      positionType: "individualShift",
      children: [{
        type: "elem",
        elem: c,
        shift: k
      }, {
        type: "elem",
        elem: l,
        shift: -v
      }]
    }, e);
  }
  i = e.havingStyle(t), E.height *= i.sizeMultiplier / e.sizeMultiplier, E.depth *= i.sizeMultiplier / e.sizeMultiplier;
  var F;
  t.size === Q.DISPLAY.size ? F = e.fontMetrics().delim1 : t.size === Q.SCRIPTSCRIPT.size ? F = e.havingStyle(Q.SCRIPT).fontMetrics().delim2 : F = e.fontMetrics().delim2;
  var T, M;
  return n.leftDelim == null ? T = Er(e, ["mopen"]) : T = c0.customSizedDelim(n.leftDelim, F, !0, e.havingStyle(t), n.mode, ["mopen"]), n.continued ? M = C.makeSpan([]) : n.rightDelim == null ? M = Er(e, ["mclose"]) : M = c0.customSizedDelim(n.rightDelim, F, !0, e.havingStyle(t), n.mode, ["mclose"]), C.makeSpan(["mord"].concat(i.sizingClasses(e)), [T, C.makeSpan(["mfrac"], [E]), M], e);
}, xi = (n, e) => {
  var t = new I.MathNode("mfrac", [me(n.numer, e), me(n.denom, e)]);
  if (!n.hasBarLine)
    t.setAttribute("linethickness", "0px");
  else if (n.barSize) {
    var r = we(n.barSize, e);
    t.setAttribute("linethickness", P(r));
  }
  var a = hu(n.size, e.style);
  if (a.size !== e.style.size) {
    t = new I.MathNode("mstyle", [t]);
    var i = a.size === Q.DISPLAY.size ? "true" : "false";
    t.setAttribute("displaystyle", i), t.setAttribute("scriptlevel", "0");
  }
  if (n.leftDelim != null || n.rightDelim != null) {
    var l = [];
    if (n.leftDelim != null) {
      var s = new I.MathNode("mo", [new I.TextNode(n.leftDelim.replace("\\", ""))]);
      s.setAttribute("fence", "true"), l.push(s);
    }
    if (l.push(t), n.rightDelim != null) {
      var o = new I.MathNode("mo", [new I.TextNode(n.rightDelim.replace("\\", ""))]);
      o.setAttribute("fence", "true"), l.push(o);
    }
    return di(l);
  }
  return t;
};
G({
  type: "genfrac",
  names: [
    "\\dfrac",
    "\\frac",
    "\\tfrac",
    "\\dbinom",
    "\\binom",
    "\\tbinom",
    "\\\\atopfrac",
    // can’t be entered directly
    "\\\\bracefrac",
    "\\\\brackfrac"
    // ditto
  ],
  props: {
    numArgs: 2,
    allowedInArgument: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0], i = e[1], l, s = null, o = null, c = "auto";
    switch (r) {
      case "\\dfrac":
      case "\\frac":
      case "\\tfrac":
        l = !0;
        break;
      case "\\\\atopfrac":
        l = !1;
        break;
      case "\\dbinom":
      case "\\binom":
      case "\\tbinom":
        l = !1, s = "(", o = ")";
        break;
      case "\\\\bracefrac":
        l = !1, s = "\\{", o = "\\}";
        break;
      case "\\\\brackfrac":
        l = !1, s = "[", o = "]";
        break;
      default:
        throw new Error("Unrecognized genfrac command");
    }
    switch (r) {
      case "\\dfrac":
      case "\\dbinom":
        c = "display";
        break;
      case "\\tfrac":
      case "\\tbinom":
        c = "text";
        break;
    }
    return {
      type: "genfrac",
      mode: t.mode,
      continued: !1,
      numer: a,
      denom: i,
      hasBarLine: l,
      leftDelim: s,
      rightDelim: o,
      size: c,
      barSize: null
    };
  },
  htmlBuilder: Di,
  mathmlBuilder: xi
});
G({
  type: "genfrac",
  names: ["\\cfrac"],
  props: {
    numArgs: 2
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0], i = e[1];
    return {
      type: "genfrac",
      mode: t.mode,
      continued: !0,
      numer: a,
      denom: i,
      hasBarLine: !0,
      leftDelim: null,
      rightDelim: null,
      size: "display",
      barSize: null
    };
  }
});
G({
  type: "infix",
  names: ["\\over", "\\choose", "\\atop", "\\brace", "\\brack"],
  props: {
    numArgs: 0,
    infix: !0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t,
      token: r
    } = n, a;
    switch (t) {
      case "\\over":
        a = "\\frac";
        break;
      case "\\choose":
        a = "\\binom";
        break;
      case "\\atop":
        a = "\\\\atopfrac";
        break;
      case "\\brace":
        a = "\\\\bracefrac";
        break;
      case "\\brack":
        a = "\\\\brackfrac";
        break;
      default:
        throw new Error("Unrecognized infix genfrac command");
    }
    return {
      type: "infix",
      mode: e.mode,
      replaceWith: a,
      token: r
    };
  }
});
var Fl = ["display", "text", "script", "scriptscript"], Tl = function(e) {
  var t = null;
  return e.length > 0 && (t = e, t = t === "." ? null : t), t;
};
G({
  type: "genfrac",
  names: ["\\genfrac"],
  props: {
    numArgs: 6,
    allowedInArgument: !0,
    argTypes: ["math", "math", "size", "text", "math", "math"]
  },
  handler(n, e) {
    var {
      parser: t
    } = n, r = e[4], a = e[5], i = En(e[0]), l = i.type === "atom" && i.family === "open" ? Tl(i.text) : null, s = En(e[1]), o = s.type === "atom" && s.family === "close" ? Tl(s.text) : null, c = te(e[2], "size"), f, d = null;
    c.isBlank ? f = !0 : (d = c.value, f = d.number > 0);
    var g = "auto", v = e[3];
    if (v.type === "ordgroup") {
      if (v.body.length > 0) {
        var y = te(v.body[0], "textord");
        g = Fl[Number(y.text)];
      }
    } else
      v = te(v, "textord"), g = Fl[Number(v.text)];
    return {
      type: "genfrac",
      mode: t.mode,
      numer: r,
      denom: a,
      continued: !1,
      hasBarLine: f,
      barSize: d,
      leftDelim: l,
      rightDelim: o,
      size: g
    };
  },
  htmlBuilder: Di,
  mathmlBuilder: xi
});
G({
  type: "infix",
  names: ["\\above"],
  props: {
    numArgs: 1,
    argTypes: ["size"],
    infix: !0
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r,
      token: a
    } = n;
    return {
      type: "infix",
      mode: t.mode,
      replaceWith: "\\\\abovefrac",
      size: te(e[0], "size").value,
      token: a
    };
  }
});
G({
  type: "genfrac",
  names: ["\\\\abovefrac"],
  props: {
    numArgs: 3,
    argTypes: ["math", "size", "math"]
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0], i = uc(te(e[1], "infix").size), l = e[2], s = i.number > 0;
    return {
      type: "genfrac",
      mode: t.mode,
      numer: a,
      denom: l,
      continued: !1,
      hasBarLine: s,
      barSize: i,
      leftDelim: null,
      rightDelim: null,
      size: "auto"
    };
  },
  htmlBuilder: Di,
  mathmlBuilder: xi
});
var fu = (n, e) => {
  var t = e.style, r, a;
  n.type === "supsub" ? (r = n.sup ? ie(n.sup, e.havingStyle(t.sup()), e) : ie(n.sub, e.havingStyle(t.sub()), e), a = te(n.base, "horizBrace")) : a = te(n, "horizBrace");
  var i = ie(a.base, e.havingBaseStyle(Q.DISPLAY)), l = m0.svgSpan(a, e), s;
  if (a.isOver ? (s = C.makeVList({
    positionType: "firstBaseline",
    children: [{
      type: "elem",
      elem: i
    }, {
      type: "kern",
      size: 0.1
    }, {
      type: "elem",
      elem: l
    }]
  }, e), s.children[0].children[0].children[1].classes.push("svg-align")) : (s = C.makeVList({
    positionType: "bottom",
    positionData: i.depth + 0.1 + l.height,
    children: [{
      type: "elem",
      elem: l
    }, {
      type: "kern",
      size: 0.1
    }, {
      type: "elem",
      elem: i
    }]
  }, e), s.children[0].children[0].children[0].classes.push("svg-align")), r) {
    var o = C.makeSpan(["mord", a.isOver ? "mover" : "munder"], [s], e);
    a.isOver ? s = C.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: o
      }, {
        type: "kern",
        size: 0.2
      }, {
        type: "elem",
        elem: r
      }]
    }, e) : s = C.makeVList({
      positionType: "bottom",
      positionData: o.depth + 0.2 + r.height + r.depth,
      children: [{
        type: "elem",
        elem: r
      }, {
        type: "kern",
        size: 0.2
      }, {
        type: "elem",
        elem: o
      }]
    }, e);
  }
  return C.makeSpan(["mord", a.isOver ? "mover" : "munder"], [s], e);
}, B4 = (n, e) => {
  var t = m0.mathMLnode(n.label);
  return new I.MathNode(n.isOver ? "mover" : "munder", [me(n.base, e), t]);
};
G({
  type: "horizBrace",
  names: ["\\overbrace", "\\underbrace"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n;
    return {
      type: "horizBrace",
      mode: t.mode,
      label: r,
      isOver: /^\\over/.test(r),
      base: e[0]
    };
  },
  htmlBuilder: fu,
  mathmlBuilder: B4
});
G({
  type: "href",
  names: ["\\href"],
  props: {
    numArgs: 2,
    argTypes: ["url", "original"],
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[1], a = te(e[0], "url").url;
    return t.settings.isTrusted({
      command: "\\href",
      url: a
    }) ? {
      type: "href",
      mode: t.mode,
      href: a,
      body: Ae(r)
    } : t.formatUnsupportedCmd("\\href");
  },
  htmlBuilder: (n, e) => {
    var t = Me(n.body, e, !1);
    return C.makeAnchor(n.href, [], t, e);
  },
  mathmlBuilder: (n, e) => {
    var t = A0(n.body, e);
    return t instanceof it || (t = new it("mrow", [t])), t.setAttribute("href", n.href), t;
  }
});
G({
  type: "href",
  names: ["\\url"],
  props: {
    numArgs: 1,
    argTypes: ["url"],
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = te(e[0], "url").url;
    if (!t.settings.isTrusted({
      command: "\\url",
      url: r
    }))
      return t.formatUnsupportedCmd("\\url");
    for (var a = [], i = 0; i < r.length; i++) {
      var l = r[i];
      l === "~" && (l = "\\textasciitilde"), a.push({
        type: "textord",
        mode: "text",
        text: l
      });
    }
    var s = {
      type: "text",
      mode: t.mode,
      font: "\\texttt",
      body: a
    };
    return {
      type: "href",
      mode: t.mode,
      href: r,
      body: Ae(s)
    };
  }
});
G({
  type: "hbox",
  names: ["\\hbox"],
  props: {
    numArgs: 1,
    argTypes: ["text"],
    allowedInText: !0,
    primitive: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "hbox",
      mode: t.mode,
      body: Ae(e[0])
    };
  },
  htmlBuilder(n, e) {
    var t = Me(n.body, e, !1);
    return C.makeFragment(t);
  },
  mathmlBuilder(n, e) {
    return new I.MathNode("mrow", $e(n.body, e));
  }
});
G({
  type: "html",
  names: ["\\htmlClass", "\\htmlId", "\\htmlStyle", "\\htmlData"],
  props: {
    numArgs: 2,
    argTypes: ["raw", "original"],
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r,
      token: a
    } = n, i = te(e[0], "raw").string, l = e[1];
    t.settings.strict && t.settings.reportNonstrict("htmlExtension", "HTML extension is disabled on strict mode");
    var s, o = {};
    switch (r) {
      case "\\htmlClass":
        o.class = i, s = {
          command: "\\htmlClass",
          class: i
        };
        break;
      case "\\htmlId":
        o.id = i, s = {
          command: "\\htmlId",
          id: i
        };
        break;
      case "\\htmlStyle":
        o.style = i, s = {
          command: "\\htmlStyle",
          style: i
        };
        break;
      case "\\htmlData": {
        for (var c = i.split(","), f = 0; f < c.length; f++) {
          var d = c[f].split("=");
          if (d.length !== 2)
            throw new L("Error parsing key-value for \\htmlData");
          o["data-" + d[0].trim()] = d[1].trim();
        }
        s = {
          command: "\\htmlData",
          attributes: o
        };
        break;
      }
      default:
        throw new Error("Unrecognized html command");
    }
    return t.settings.isTrusted(s) ? {
      type: "html",
      mode: t.mode,
      attributes: o,
      body: Ae(l)
    } : t.formatUnsupportedCmd(r);
  },
  htmlBuilder: (n, e) => {
    var t = Me(n.body, e, !1), r = ["enclosing"];
    n.attributes.class && r.push(...n.attributes.class.trim().split(/\s+/));
    var a = C.makeSpan(r, t, e);
    for (var i in n.attributes)
      i !== "class" && n.attributes.hasOwnProperty(i) && a.setAttribute(i, n.attributes[i]);
    return a;
  },
  mathmlBuilder: (n, e) => A0(n.body, e)
});
G({
  type: "htmlmathml",
  names: ["\\html@mathml"],
  props: {
    numArgs: 2,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n;
    return {
      type: "htmlmathml",
      mode: t.mode,
      html: Ae(e[0]),
      mathml: Ae(e[1])
    };
  },
  htmlBuilder: (n, e) => {
    var t = Me(n.html, e, !1);
    return C.makeFragment(t);
  },
  mathmlBuilder: (n, e) => A0(n.mathml, e)
});
var fa = function(e) {
  if (/^[-+]? *(\d+(\.\d*)?|\.\d+)$/.test(e))
    return {
      number: +e,
      unit: "bp"
    };
  var t = /([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(e);
  if (!t)
    throw new L("Invalid size: '" + e + "' in \\includegraphics");
  var r = {
    number: +(t[1] + t[2]),
    // sign + magnitude, cast to number
    unit: t[3]
  };
  if (!Mo(r))
    throw new L("Invalid unit: '" + r.unit + "' in \\includegraphics.");
  return r;
};
G({
  type: "includegraphics",
  names: ["\\includegraphics"],
  props: {
    numArgs: 1,
    numOptionalArgs: 1,
    argTypes: ["raw", "url"],
    allowedInText: !1
  },
  handler: (n, e, t) => {
    var {
      parser: r
    } = n, a = {
      number: 0,
      unit: "em"
    }, i = {
      number: 0.9,
      unit: "em"
    }, l = {
      number: 0,
      unit: "em"
    }, s = "";
    if (t[0])
      for (var o = te(t[0], "raw").string, c = o.split(","), f = 0; f < c.length; f++) {
        var d = c[f].split("=");
        if (d.length === 2) {
          var g = d[1].trim();
          switch (d[0].trim()) {
            case "alt":
              s = g;
              break;
            case "width":
              a = fa(g);
              break;
            case "height":
              i = fa(g);
              break;
            case "totalheight":
              l = fa(g);
              break;
            default:
              throw new L("Invalid key: '" + d[0] + "' in \\includegraphics.");
          }
        }
      }
    var v = te(e[0], "url").url;
    return s === "" && (s = v, s = s.replace(/^.*[\\/]/, ""), s = s.substring(0, s.lastIndexOf("."))), r.settings.isTrusted({
      command: "\\includegraphics",
      url: v
    }) ? {
      type: "includegraphics",
      mode: r.mode,
      alt: s,
      width: a,
      height: i,
      totalheight: l,
      src: v
    } : r.formatUnsupportedCmd("\\includegraphics");
  },
  htmlBuilder: (n, e) => {
    var t = we(n.height, e), r = 0;
    n.totalheight.number > 0 && (r = we(n.totalheight, e) - t);
    var a = 0;
    n.width.number > 0 && (a = we(n.width, e));
    var i = {
      height: P(t + r)
    };
    a > 0 && (i.width = P(a)), r > 0 && (i.verticalAlign = P(-r));
    var l = new Bc(n.src, n.alt, i);
    return l.height = t, l.depth = r, l;
  },
  mathmlBuilder: (n, e) => {
    var t = new I.MathNode("mglyph", []);
    t.setAttribute("alt", n.alt);
    var r = we(n.height, e), a = 0;
    if (n.totalheight.number > 0 && (a = we(n.totalheight, e) - r, t.setAttribute("valign", P(-a))), t.setAttribute("height", P(r + a)), n.width.number > 0) {
      var i = we(n.width, e);
      t.setAttribute("width", P(i));
    }
    return t.setAttribute("src", n.src), t;
  }
});
G({
  type: "kern",
  names: ["\\kern", "\\mkern", "\\hskip", "\\mskip"],
  props: {
    numArgs: 1,
    argTypes: ["size"],
    primitive: !0,
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = te(e[0], "size");
    if (t.settings.strict) {
      var i = r[1] === "m", l = a.value.unit === "mu";
      i ? (l || t.settings.reportNonstrict("mathVsTextUnits", "LaTeX's " + r + " supports only mu units, " + ("not " + a.value.unit + " units")), t.mode !== "math" && t.settings.reportNonstrict("mathVsTextUnits", "LaTeX's " + r + " works only in math mode")) : l && t.settings.reportNonstrict("mathVsTextUnits", "LaTeX's " + r + " doesn't support mu units");
    }
    return {
      type: "kern",
      mode: t.mode,
      dimension: a.value
    };
  },
  htmlBuilder(n, e) {
    return C.makeGlue(n.dimension, e);
  },
  mathmlBuilder(n, e) {
    var t = we(n.dimension, e);
    return new I.SpaceNode(t);
  }
});
G({
  type: "lap",
  names: ["\\mathllap", "\\mathrlap", "\\mathclap"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "lap",
      mode: t.mode,
      alignment: r.slice(5),
      body: a
    };
  },
  htmlBuilder: (n, e) => {
    var t;
    n.alignment === "clap" ? (t = C.makeSpan([], [ie(n.body, e)]), t = C.makeSpan(["inner"], [t], e)) : t = C.makeSpan(["inner"], [ie(n.body, e)]);
    var r = C.makeSpan(["fix"], []), a = C.makeSpan([n.alignment], [t, r], e), i = C.makeSpan(["strut"]);
    return i.style.height = P(a.height + a.depth), a.depth && (i.style.verticalAlign = P(-a.depth)), a.children.unshift(i), a = C.makeSpan(["thinbox"], [a], e), C.makeSpan(["mord", "vbox"], [a], e);
  },
  mathmlBuilder: (n, e) => {
    var t = new I.MathNode("mpadded", [me(n.body, e)]);
    if (n.alignment !== "rlap") {
      var r = n.alignment === "llap" ? "-1" : "-0.5";
      t.setAttribute("lspace", r + "width");
    }
    return t.setAttribute("width", "0px"), t;
  }
});
G({
  type: "styling",
  names: ["\\(", "$"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    allowedInMath: !1
  },
  handler(n, e) {
    var {
      funcName: t,
      parser: r
    } = n, a = r.mode;
    r.switchMode("math");
    var i = t === "\\(" ? "\\)" : "$", l = r.parseExpression(!1, i);
    return r.expect(i), r.switchMode(a), {
      type: "styling",
      mode: r.mode,
      style: "text",
      body: l
    };
  }
});
G({
  type: "text",
  // Doesn't matter what this is.
  names: ["\\)", "\\]"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    allowedInMath: !1
  },
  handler(n, e) {
    throw new L("Mismatched " + n.funcName);
  }
});
var Cl = (n, e) => {
  switch (e.style.size) {
    case Q.DISPLAY.size:
      return n.display;
    case Q.TEXT.size:
      return n.text;
    case Q.SCRIPT.size:
      return n.script;
    case Q.SCRIPTSCRIPT.size:
      return n.scriptscript;
    default:
      return n.text;
  }
};
G({
  type: "mathchoice",
  names: ["\\mathchoice"],
  props: {
    numArgs: 4,
    primitive: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n;
    return {
      type: "mathchoice",
      mode: t.mode,
      display: Ae(e[0]),
      text: Ae(e[1]),
      script: Ae(e[2]),
      scriptscript: Ae(e[3])
    };
  },
  htmlBuilder: (n, e) => {
    var t = Cl(n, e), r = Me(t, e, !1);
    return C.makeFragment(r);
  },
  mathmlBuilder: (n, e) => {
    var t = Cl(n, e);
    return A0(t, e);
  }
});
var mu = (n, e, t, r, a, i, l) => {
  n = C.makeSpan([], [n]);
  var s = t && j.isCharacterBox(t), o, c;
  if (e) {
    var f = ie(e, r.havingStyle(a.sup()), r);
    c = {
      elem: f,
      kern: Math.max(r.fontMetrics().bigOpSpacing1, r.fontMetrics().bigOpSpacing3 - f.depth)
    };
  }
  if (t) {
    var d = ie(t, r.havingStyle(a.sub()), r);
    o = {
      elem: d,
      kern: Math.max(r.fontMetrics().bigOpSpacing2, r.fontMetrics().bigOpSpacing4 - d.height)
    };
  }
  var g;
  if (c && o) {
    var v = r.fontMetrics().bigOpSpacing5 + o.elem.height + o.elem.depth + o.kern + n.depth + l;
    g = C.makeVList({
      positionType: "bottom",
      positionData: v,
      children: [{
        type: "kern",
        size: r.fontMetrics().bigOpSpacing5
      }, {
        type: "elem",
        elem: o.elem,
        marginLeft: P(-i)
      }, {
        type: "kern",
        size: o.kern
      }, {
        type: "elem",
        elem: n
      }, {
        type: "kern",
        size: c.kern
      }, {
        type: "elem",
        elem: c.elem,
        marginLeft: P(i)
      }, {
        type: "kern",
        size: r.fontMetrics().bigOpSpacing5
      }]
    }, r);
  } else if (o) {
    var y = n.height - l;
    g = C.makeVList({
      positionType: "top",
      positionData: y,
      children: [{
        type: "kern",
        size: r.fontMetrics().bigOpSpacing5
      }, {
        type: "elem",
        elem: o.elem,
        marginLeft: P(-i)
      }, {
        type: "kern",
        size: o.kern
      }, {
        type: "elem",
        elem: n
      }]
    }, r);
  } else if (c) {
    var k = n.depth + l;
    g = C.makeVList({
      positionType: "bottom",
      positionData: k,
      children: [{
        type: "elem",
        elem: n
      }, {
        type: "kern",
        size: c.kern
      }, {
        type: "elem",
        elem: c.elem,
        marginLeft: P(i)
      }, {
        type: "kern",
        size: r.fontMetrics().bigOpSpacing5
      }]
    }, r);
  } else
    return n;
  var E = [g];
  if (o && i !== 0 && !s) {
    var A = C.makeSpan(["mspace"], [], r);
    A.style.marginRight = P(i), E.unshift(A);
  }
  return C.makeSpan(["mop", "op-limits"], E, r);
}, du = ["\\smallint"], sr = (n, e) => {
  var t, r, a = !1, i;
  n.type === "supsub" ? (t = n.sup, r = n.sub, i = te(n.base, "op"), a = !0) : i = te(n, "op");
  var l = e.style, s = !1;
  l.size === Q.DISPLAY.size && i.symbol && !j.contains(du, i.name) && (s = !0);
  var o;
  if (i.symbol) {
    var c = s ? "Size2-Regular" : "Size1-Regular", f = "";
    if ((i.name === "\\oiint" || i.name === "\\oiiint") && (f = i.name.slice(1), i.name = f === "oiint" ? "\\iint" : "\\iiint"), o = C.makeSymbol(i.name, c, "math", e, ["mop", "op-symbol", s ? "large-op" : "small-op"]), f.length > 0) {
      var d = o.italic, g = C.staticSvg(f + "Size" + (s ? "2" : "1"), e);
      o = C.makeVList({
        positionType: "individualShift",
        children: [{
          type: "elem",
          elem: o,
          shift: 0
        }, {
          type: "elem",
          elem: g,
          shift: s ? 0.08 : 0
        }]
      }, e), i.name = "\\" + f, o.classes.unshift("mop"), o.italic = d;
    }
  } else if (i.body) {
    var v = Me(i.body, e, !0);
    v.length === 1 && v[0] instanceof dt ? (o = v[0], o.classes[0] = "mop") : o = C.makeSpan(["mop"], v, e);
  } else {
    for (var y = [], k = 1; k < i.name.length; k++)
      y.push(C.mathsym(i.name[k], i.mode, e));
    o = C.makeSpan(["mop"], y, e);
  }
  var E = 0, A = 0;
  return (o instanceof dt || i.name === "\\oiint" || i.name === "\\oiiint") && !i.suppressBaseShift && (E = (o.height - o.depth) / 2 - e.fontMetrics().axisHeight, A = o.italic), a ? mu(o, t, r, e, l, A, E) : (E && (o.style.position = "relative", o.style.top = P(E)), o);
}, zr = (n, e) => {
  var t;
  if (n.symbol)
    t = new it("mo", [pt(n.name, n.mode)]), j.contains(du, n.name) && t.setAttribute("largeop", "false");
  else if (n.body)
    t = new it("mo", $e(n.body, e));
  else {
    t = new it("mi", [new Ht(n.name.slice(1))]);
    var r = new it("mo", [pt("⁡", "text")]);
    n.parentIsSupSub ? t = new it("mrow", [t, r]) : t = Uo([t, r]);
  }
  return t;
}, N4 = {
  "∏": "\\prod",
  "∐": "\\coprod",
  "∑": "\\sum",
  "⋀": "\\bigwedge",
  "⋁": "\\bigvee",
  "⋂": "\\bigcap",
  "⋃": "\\bigcup",
  "⨀": "\\bigodot",
  "⨁": "\\bigoplus",
  "⨂": "\\bigotimes",
  "⨄": "\\biguplus",
  "⨆": "\\bigsqcup"
};
G({
  type: "op",
  names: ["\\coprod", "\\bigvee", "\\bigwedge", "\\biguplus", "\\bigcap", "\\bigcup", "\\intop", "\\prod", "\\sum", "\\bigotimes", "\\bigoplus", "\\bigodot", "\\bigsqcup", "\\smallint", "∏", "∐", "∑", "⋀", "⋁", "⋂", "⋃", "⨀", "⨁", "⨂", "⨄", "⨆"],
  props: {
    numArgs: 0
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = r;
    return a.length === 1 && (a = N4[a]), {
      type: "op",
      mode: t.mode,
      limits: !0,
      parentIsSupSub: !1,
      symbol: !0,
      name: a
    };
  },
  htmlBuilder: sr,
  mathmlBuilder: zr
});
G({
  type: "op",
  names: ["\\mathop"],
  props: {
    numArgs: 1,
    primitive: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "op",
      mode: t.mode,
      limits: !1,
      parentIsSupSub: !1,
      symbol: !1,
      body: Ae(r)
    };
  },
  htmlBuilder: sr,
  mathmlBuilder: zr
});
var R4 = {
  "∫": "\\int",
  "∬": "\\iint",
  "∭": "\\iiint",
  "∮": "\\oint",
  "∯": "\\oiint",
  "∰": "\\oiiint"
};
G({
  type: "op",
  names: ["\\arcsin", "\\arccos", "\\arctan", "\\arctg", "\\arcctg", "\\arg", "\\ch", "\\cos", "\\cosec", "\\cosh", "\\cot", "\\cotg", "\\coth", "\\csc", "\\ctg", "\\cth", "\\deg", "\\dim", "\\exp", "\\hom", "\\ker", "\\lg", "\\ln", "\\log", "\\sec", "\\sin", "\\sinh", "\\sh", "\\tan", "\\tanh", "\\tg", "\\th"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n;
    return {
      type: "op",
      mode: e.mode,
      limits: !1,
      parentIsSupSub: !1,
      symbol: !1,
      name: t
    };
  },
  htmlBuilder: sr,
  mathmlBuilder: zr
});
G({
  type: "op",
  names: ["\\det", "\\gcd", "\\inf", "\\lim", "\\max", "\\min", "\\Pr", "\\sup"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n;
    return {
      type: "op",
      mode: e.mode,
      limits: !0,
      parentIsSupSub: !1,
      symbol: !1,
      name: t
    };
  },
  htmlBuilder: sr,
  mathmlBuilder: zr
});
G({
  type: "op",
  names: ["\\int", "\\iint", "\\iiint", "\\oint", "\\oiint", "\\oiiint", "∫", "∬", "∭", "∮", "∯", "∰"],
  props: {
    numArgs: 0
  },
  handler(n) {
    var {
      parser: e,
      funcName: t
    } = n, r = t;
    return r.length === 1 && (r = R4[r]), {
      type: "op",
      mode: e.mode,
      limits: !1,
      parentIsSupSub: !1,
      symbol: !0,
      name: r
    };
  },
  htmlBuilder: sr,
  mathmlBuilder: zr
});
var pu = (n, e) => {
  var t, r, a = !1, i;
  n.type === "supsub" ? (t = n.sup, r = n.sub, i = te(n.base, "operatorname"), a = !0) : i = te(n, "operatorname");
  var l;
  if (i.body.length > 0) {
    for (var s = i.body.map((d) => {
      var g = d.text;
      return typeof g == "string" ? {
        type: "textord",
        mode: d.mode,
        text: g
      } : d;
    }), o = Me(s, e.withFont("mathrm"), !0), c = 0; c < o.length; c++) {
      var f = o[c];
      f instanceof dt && (f.text = f.text.replace(/\u2212/, "-").replace(/\u2217/, "*"));
    }
    l = C.makeSpan(["mop"], o, e);
  } else
    l = C.makeSpan(["mop"], [], e);
  return a ? mu(l, t, r, e, e.style, 0, 0) : l;
}, I4 = (n, e) => {
  for (var t = $e(n.body, e.withFont("mathrm")), r = !0, a = 0; a < t.length; a++) {
    var i = t[a];
    if (!(i instanceof I.SpaceNode)) if (i instanceof I.MathNode)
      switch (i.type) {
        case "mi":
        case "mn":
        case "ms":
        case "mspace":
        case "mtext":
          break;
        case "mo": {
          var l = i.children[0];
          i.children.length === 1 && l instanceof I.TextNode ? l.text = l.text.replace(/\u2212/, "-").replace(/\u2217/, "*") : r = !1;
          break;
        }
        default:
          r = !1;
      }
    else
      r = !1;
  }
  if (r) {
    var s = t.map((f) => f.toText()).join("");
    t = [new I.TextNode(s)];
  }
  var o = new I.MathNode("mi", t);
  o.setAttribute("mathvariant", "normal");
  var c = new I.MathNode("mo", [pt("⁡", "text")]);
  return n.parentIsSupSub ? new I.MathNode("mrow", [o, c]) : I.newDocumentFragment([o, c]);
};
G({
  type: "operatorname",
  names: ["\\operatorname@", "\\operatornamewithlimits"],
  props: {
    numArgs: 1
  },
  handler: (n, e) => {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "operatorname",
      mode: t.mode,
      body: Ae(a),
      alwaysHandleSupSub: r === "\\operatornamewithlimits",
      limits: !1,
      parentIsSupSub: !1
    };
  },
  htmlBuilder: pu,
  mathmlBuilder: I4
});
p("\\operatorname", "\\@ifstar\\operatornamewithlimits\\operatorname@");
q0({
  type: "ordgroup",
  htmlBuilder(n, e) {
    return n.semisimple ? C.makeFragment(Me(n.body, e, !1)) : C.makeSpan(["mord"], Me(n.body, e, !0), e);
  },
  mathmlBuilder(n, e) {
    return A0(n.body, e, !0);
  }
});
G({
  type: "overline",
  names: ["\\overline"],
  props: {
    numArgs: 1
  },
  handler(n, e) {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "overline",
      mode: t.mode,
      body: r
    };
  },
  htmlBuilder(n, e) {
    var t = ie(n.body, e.havingCrampedStyle()), r = C.makeLineSpan("overline-line", e), a = e.fontMetrics().defaultRuleThickness, i = C.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: t
      }, {
        type: "kern",
        size: 3 * a
      }, {
        type: "elem",
        elem: r
      }, {
        type: "kern",
        size: a
      }]
    }, e);
    return C.makeSpan(["mord", "overline"], [i], e);
  },
  mathmlBuilder(n, e) {
    var t = new I.MathNode("mo", [new I.TextNode("‾")]);
    t.setAttribute("stretchy", "true");
    var r = new I.MathNode("mover", [me(n.body, e), t]);
    return r.setAttribute("accent", "true"), r;
  }
});
G({
  type: "phantom",
  names: ["\\phantom"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "phantom",
      mode: t.mode,
      body: Ae(r)
    };
  },
  htmlBuilder: (n, e) => {
    var t = Me(n.body, e.withPhantom(), !1);
    return C.makeFragment(t);
  },
  mathmlBuilder: (n, e) => {
    var t = $e(n.body, e);
    return new I.MathNode("mphantom", t);
  }
});
G({
  type: "hphantom",
  names: ["\\hphantom"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "hphantom",
      mode: t.mode,
      body: r
    };
  },
  htmlBuilder: (n, e) => {
    var t = C.makeSpan([], [ie(n.body, e.withPhantom())]);
    if (t.height = 0, t.depth = 0, t.children)
      for (var r = 0; r < t.children.length; r++)
        t.children[r].height = 0, t.children[r].depth = 0;
    return t = C.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: t
      }]
    }, e), C.makeSpan(["mord"], [t], e);
  },
  mathmlBuilder: (n, e) => {
    var t = $e(Ae(n.body), e), r = new I.MathNode("mphantom", t), a = new I.MathNode("mpadded", [r]);
    return a.setAttribute("height", "0px"), a.setAttribute("depth", "0px"), a;
  }
});
G({
  type: "vphantom",
  names: ["\\vphantom"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      parser: t
    } = n, r = e[0];
    return {
      type: "vphantom",
      mode: t.mode,
      body: r
    };
  },
  htmlBuilder: (n, e) => {
    var t = C.makeSpan(["inner"], [ie(n.body, e.withPhantom())]), r = C.makeSpan(["fix"], []);
    return C.makeSpan(["mord", "rlap"], [t, r], e);
  },
  mathmlBuilder: (n, e) => {
    var t = $e(Ae(n.body), e), r = new I.MathNode("mphantom", t), a = new I.MathNode("mpadded", [r]);
    return a.setAttribute("width", "0px"), a;
  }
});
G({
  type: "raisebox",
  names: ["\\raisebox"],
  props: {
    numArgs: 2,
    argTypes: ["size", "hbox"],
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n, r = te(e[0], "size").value, a = e[1];
    return {
      type: "raisebox",
      mode: t.mode,
      dy: r,
      body: a
    };
  },
  htmlBuilder(n, e) {
    var t = ie(n.body, e), r = we(n.dy, e);
    return C.makeVList({
      positionType: "shift",
      positionData: -r,
      children: [{
        type: "elem",
        elem: t
      }]
    }, e);
  },
  mathmlBuilder(n, e) {
    var t = new I.MathNode("mpadded", [me(n.body, e)]), r = n.dy.number + n.dy.unit;
    return t.setAttribute("voffset", r), t;
  }
});
G({
  type: "internal",
  names: ["\\relax"],
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler(n) {
    var {
      parser: e
    } = n;
    return {
      type: "internal",
      mode: e.mode
    };
  }
});
G({
  type: "rule",
  names: ["\\rule"],
  props: {
    numArgs: 2,
    numOptionalArgs: 1,
    allowedInText: !0,
    allowedInMath: !0,
    argTypes: ["size", "size", "size"]
  },
  handler(n, e, t) {
    var {
      parser: r
    } = n, a = t[0], i = te(e[0], "size"), l = te(e[1], "size");
    return {
      type: "rule",
      mode: r.mode,
      shift: a && te(a, "size").value,
      width: i.value,
      height: l.value
    };
  },
  htmlBuilder(n, e) {
    var t = C.makeSpan(["mord", "rule"], [], e), r = we(n.width, e), a = we(n.height, e), i = n.shift ? we(n.shift, e) : 0;
    return t.style.borderRightWidth = P(r), t.style.borderTopWidth = P(a), t.style.bottom = P(i), t.width = r, t.height = a + i, t.depth = -i, t.maxFontSize = a * 1.125 * e.sizeMultiplier, t;
  },
  mathmlBuilder(n, e) {
    var t = we(n.width, e), r = we(n.height, e), a = n.shift ? we(n.shift, e) : 0, i = e.color && e.getColor() || "black", l = new I.MathNode("mspace");
    l.setAttribute("mathbackground", i), l.setAttribute("width", P(t)), l.setAttribute("height", P(r));
    var s = new I.MathNode("mpadded", [l]);
    return a >= 0 ? s.setAttribute("height", P(a)) : (s.setAttribute("height", P(a)), s.setAttribute("depth", P(-a))), s.setAttribute("voffset", P(a)), s;
  }
});
function gu(n, e, t) {
  for (var r = Me(n, e, !1), a = e.sizeMultiplier / t.sizeMultiplier, i = 0; i < r.length; i++) {
    var l = r[i].classes.indexOf("sizing");
    l < 0 ? Array.prototype.push.apply(r[i].classes, e.sizingClasses(t)) : r[i].classes[l + 1] === "reset-size" + e.size && (r[i].classes[l + 1] = "reset-size" + t.size), r[i].height *= a, r[i].depth *= a;
  }
  return C.makeFragment(r);
}
var Ml = ["\\tiny", "\\sixptsize", "\\scriptsize", "\\footnotesize", "\\small", "\\normalsize", "\\large", "\\Large", "\\LARGE", "\\huge", "\\Huge"], L4 = (n, e) => {
  var t = e.havingSize(n.size);
  return gu(n.body, t, e);
};
G({
  type: "sizing",
  names: Ml,
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler: (n, e) => {
    var {
      breakOnTokenText: t,
      funcName: r,
      parser: a
    } = n, i = a.parseExpression(!1, t);
    return {
      type: "sizing",
      mode: a.mode,
      // Figure out what size to use based on the list of functions above
      size: Ml.indexOf(r) + 1,
      body: i
    };
  },
  htmlBuilder: L4,
  mathmlBuilder: (n, e) => {
    var t = e.havingSize(n.size), r = $e(n.body, t), a = new I.MathNode("mstyle", r);
    return a.setAttribute("mathsize", P(t.sizeMultiplier)), a;
  }
});
G({
  type: "smash",
  names: ["\\smash"],
  props: {
    numArgs: 1,
    numOptionalArgs: 1,
    allowedInText: !0
  },
  handler: (n, e, t) => {
    var {
      parser: r
    } = n, a = !1, i = !1, l = t[0] && te(t[0], "ordgroup");
    if (l)
      for (var s = "", o = 0; o < l.body.length; ++o) {
        var c = l.body[o];
        if (s = c.text, s === "t")
          a = !0;
        else if (s === "b")
          i = !0;
        else {
          a = !1, i = !1;
          break;
        }
      }
    else
      a = !0, i = !0;
    var f = e[0];
    return {
      type: "smash",
      mode: r.mode,
      body: f,
      smashHeight: a,
      smashDepth: i
    };
  },
  htmlBuilder: (n, e) => {
    var t = C.makeSpan([], [ie(n.body, e)]);
    if (!n.smashHeight && !n.smashDepth)
      return t;
    if (n.smashHeight && (t.height = 0, t.children))
      for (var r = 0; r < t.children.length; r++)
        t.children[r].height = 0;
    if (n.smashDepth && (t.depth = 0, t.children))
      for (var a = 0; a < t.children.length; a++)
        t.children[a].depth = 0;
    var i = C.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: t
      }]
    }, e);
    return C.makeSpan(["mord"], [i], e);
  },
  mathmlBuilder: (n, e) => {
    var t = new I.MathNode("mpadded", [me(n.body, e)]);
    return n.smashHeight && t.setAttribute("height", "0px"), n.smashDepth && t.setAttribute("depth", "0px"), t;
  }
});
G({
  type: "sqrt",
  names: ["\\sqrt"],
  props: {
    numArgs: 1,
    numOptionalArgs: 1
  },
  handler(n, e, t) {
    var {
      parser: r
    } = n, a = t[0], i = e[0];
    return {
      type: "sqrt",
      mode: r.mode,
      body: i,
      index: a
    };
  },
  htmlBuilder(n, e) {
    var t = ie(n.body, e.havingCrampedStyle());
    t.height === 0 && (t.height = e.fontMetrics().xHeight), t = C.wrapFragment(t, e);
    var r = e.fontMetrics(), a = r.defaultRuleThickness, i = a;
    e.style.id < Q.TEXT.id && (i = e.fontMetrics().xHeight);
    var l = a + i / 4, s = t.height + t.depth + l + a, {
      span: o,
      ruleWidth: c,
      advanceWidth: f
    } = c0.sqrtImage(s, e), d = o.height - c;
    d > t.height + t.depth + l && (l = (l + d - t.height - t.depth) / 2);
    var g = o.height - t.height - l - c;
    t.style.paddingLeft = P(f);
    var v = C.makeVList({
      positionType: "firstBaseline",
      children: [{
        type: "elem",
        elem: t,
        wrapperClasses: ["svg-align"]
      }, {
        type: "kern",
        size: -(t.height + g)
      }, {
        type: "elem",
        elem: o
      }, {
        type: "kern",
        size: c
      }]
    }, e);
    if (n.index) {
      var y = e.havingStyle(Q.SCRIPTSCRIPT), k = ie(n.index, y, e), E = 0.6 * (v.height - v.depth), A = C.makeVList({
        positionType: "shift",
        positionData: -E,
        children: [{
          type: "elem",
          elem: k
        }]
      }, e), D = C.makeSpan(["root"], [A]);
      return C.makeSpan(["mord", "sqrt"], [D, v], e);
    } else
      return C.makeSpan(["mord", "sqrt"], [v], e);
  },
  mathmlBuilder(n, e) {
    var {
      body: t,
      index: r
    } = n;
    return r ? new I.MathNode("mroot", [me(t, e), me(r, e)]) : new I.MathNode("msqrt", [me(t, e)]);
  }
});
var zl = {
  display: Q.DISPLAY,
  text: Q.TEXT,
  script: Q.SCRIPT,
  scriptscript: Q.SCRIPTSCRIPT
};
G({
  type: "styling",
  names: ["\\displaystyle", "\\textstyle", "\\scriptstyle", "\\scriptscriptstyle"],
  props: {
    numArgs: 0,
    allowedInText: !0,
    primitive: !0
  },
  handler(n, e) {
    var {
      breakOnTokenText: t,
      funcName: r,
      parser: a
    } = n, i = a.parseExpression(!0, t), l = r.slice(1, r.length - 5);
    return {
      type: "styling",
      mode: a.mode,
      // Figure out what style to use by pulling out the style from
      // the function name
      style: l,
      body: i
    };
  },
  htmlBuilder(n, e) {
    var t = zl[n.style], r = e.havingStyle(t).withFont("");
    return gu(n.body, r, e);
  },
  mathmlBuilder(n, e) {
    var t = zl[n.style], r = e.havingStyle(t), a = $e(n.body, r), i = new I.MathNode("mstyle", a), l = {
      display: ["0", "true"],
      text: ["0", "false"],
      script: ["1", "false"],
      scriptscript: ["2", "false"]
    }, s = l[n.style];
    return i.setAttribute("scriptlevel", s[0]), i.setAttribute("displaystyle", s[1]), i;
  }
});
var O4 = function(e, t) {
  var r = e.base;
  if (r)
    if (r.type === "op") {
      var a = r.limits && (t.style.size === Q.DISPLAY.size || r.alwaysHandleSupSub);
      return a ? sr : null;
    } else if (r.type === "operatorname") {
      var i = r.alwaysHandleSupSub && (t.style.size === Q.DISPLAY.size || r.limits);
      return i ? pu : null;
    } else {
      if (r.type === "accent")
        return j.isCharacterBox(r.base) ? vi : null;
      if (r.type === "horizBrace") {
        var l = !e.sub;
        return l === r.isOver ? fu : null;
      } else
        return null;
    }
  else return null;
};
q0({
  type: "supsub",
  htmlBuilder(n, e) {
    var t = O4(n, e);
    if (t)
      return t(n, e);
    var {
      base: r,
      sup: a,
      sub: i
    } = n, l = ie(r, e), s, o, c = e.fontMetrics(), f = 0, d = 0, g = r && j.isCharacterBox(r);
    if (a) {
      var v = e.havingStyle(e.style.sup());
      s = ie(a, v, e), g || (f = l.height - v.fontMetrics().supDrop * v.sizeMultiplier / e.sizeMultiplier);
    }
    if (i) {
      var y = e.havingStyle(e.style.sub());
      o = ie(i, y, e), g || (d = l.depth + y.fontMetrics().subDrop * y.sizeMultiplier / e.sizeMultiplier);
    }
    var k;
    e.style === Q.DISPLAY ? k = c.sup1 : e.style.cramped ? k = c.sup3 : k = c.sup2;
    var E = e.sizeMultiplier, A = P(0.5 / c.ptPerEm / E), D = null;
    if (o) {
      var b = n.base && n.base.type === "op" && n.base.name && (n.base.name === "\\oiint" || n.base.name === "\\oiiint");
      (l instanceof dt || b) && (D = P(-l.italic));
    }
    var F;
    if (s && o) {
      f = Math.max(f, k, s.depth + 0.25 * c.xHeight), d = Math.max(d, c.sub2);
      var T = c.defaultRuleThickness, M = 4 * T;
      if (f - s.depth - (o.height - d) < M) {
        d = M - (f - s.depth) + o.height;
        var z = 0.8 * c.xHeight - (f - s.depth);
        z > 0 && (f += z, d -= z);
      }
      var O = [{
        type: "elem",
        elem: o,
        shift: d,
        marginRight: A,
        marginLeft: D
      }, {
        type: "elem",
        elem: s,
        shift: -f,
        marginRight: A
      }];
      F = C.makeVList({
        positionType: "individualShift",
        children: O
      }, e);
    } else if (o) {
      d = Math.max(d, c.sub1, o.height - 0.8 * c.xHeight);
      var R = [{
        type: "elem",
        elem: o,
        marginLeft: D,
        marginRight: A
      }];
      F = C.makeVList({
        positionType: "shift",
        positionData: d,
        children: R
      }, e);
    } else if (s)
      f = Math.max(f, k, s.depth + 0.25 * c.xHeight), F = C.makeVList({
        positionType: "shift",
        positionData: -f,
        children: [{
          type: "elem",
          elem: s,
          marginRight: A
        }]
      }, e);
    else
      throw new Error("supsub must have either sup or sub.");
    var B = Ga(l, "right") || "mord";
    return C.makeSpan([B], [l, C.makeSpan(["msupsub"], [F])], e);
  },
  mathmlBuilder(n, e) {
    var t = !1, r, a;
    n.base && n.base.type === "horizBrace" && (a = !!n.sup, a === n.base.isOver && (t = !0, r = n.base.isOver)), n.base && (n.base.type === "op" || n.base.type === "operatorname") && (n.base.parentIsSupSub = !0);
    var i = [me(n.base, e)];
    n.sub && i.push(me(n.sub, e)), n.sup && i.push(me(n.sup, e));
    var l;
    if (t)
      l = r ? "mover" : "munder";
    else if (n.sub)
      if (n.sup) {
        var c = n.base;
        c && c.type === "op" && c.limits && e.style === Q.DISPLAY || c && c.type === "operatorname" && c.alwaysHandleSupSub && (e.style === Q.DISPLAY || c.limits) ? l = "munderover" : l = "msubsup";
      } else {
        var o = n.base;
        o && o.type === "op" && o.limits && (e.style === Q.DISPLAY || o.alwaysHandleSupSub) || o && o.type === "operatorname" && o.alwaysHandleSupSub && (o.limits || e.style === Q.DISPLAY) ? l = "munder" : l = "msub";
      }
    else {
      var s = n.base;
      s && s.type === "op" && s.limits && (e.style === Q.DISPLAY || s.alwaysHandleSupSub) || s && s.type === "operatorname" && s.alwaysHandleSupSub && (s.limits || e.style === Q.DISPLAY) ? l = "mover" : l = "msup";
    }
    return new I.MathNode(l, i);
  }
});
q0({
  type: "atom",
  htmlBuilder(n, e) {
    return C.mathsym(n.text, n.mode, e, ["m" + n.family]);
  },
  mathmlBuilder(n, e) {
    var t = new I.MathNode("mo", [pt(n.text, n.mode)]);
    if (n.family === "bin") {
      var r = pi(n, e);
      r === "bold-italic" && t.setAttribute("mathvariant", r);
    } else n.family === "punct" ? t.setAttribute("separator", "true") : (n.family === "open" || n.family === "close") && t.setAttribute("stretchy", "false");
    return t;
  }
});
var vu = {
  mi: "italic",
  mn: "normal",
  mtext: "normal"
};
q0({
  type: "mathord",
  htmlBuilder(n, e) {
    return C.makeOrd(n, e, "mathord");
  },
  mathmlBuilder(n, e) {
    var t = new I.MathNode("mi", [pt(n.text, n.mode, e)]), r = pi(n, e) || "italic";
    return r !== vu[t.type] && t.setAttribute("mathvariant", r), t;
  }
});
q0({
  type: "textord",
  htmlBuilder(n, e) {
    return C.makeOrd(n, e, "textord");
  },
  mathmlBuilder(n, e) {
    var t = pt(n.text, n.mode, e), r = pi(n, e) || "normal", a;
    return n.mode === "text" ? a = new I.MathNode("mtext", [t]) : /[0-9]/.test(n.text) ? a = new I.MathNode("mn", [t]) : n.text === "\\prime" ? a = new I.MathNode("mo", [t]) : a = new I.MathNode("mi", [t]), r !== vu[a.type] && a.setAttribute("mathvariant", r), a;
  }
});
var ma = {
  "\\nobreak": "nobreak",
  "\\allowbreak": "allowbreak"
}, da = {
  " ": {},
  "\\ ": {},
  "~": {
    className: "nobreak"
  },
  "\\space": {},
  "\\nobreakspace": {
    className: "nobreak"
  }
};
q0({
  type: "spacing",
  htmlBuilder(n, e) {
    if (da.hasOwnProperty(n.text)) {
      var t = da[n.text].className || "";
      if (n.mode === "text") {
        var r = C.makeOrd(n, e, "textord");
        return r.classes.push(t), r;
      } else
        return C.makeSpan(["mspace", t], [C.mathsym(n.text, n.mode, e)], e);
    } else {
      if (ma.hasOwnProperty(n.text))
        return C.makeSpan(["mspace", ma[n.text]], [], e);
      throw new L('Unknown type of space "' + n.text + '"');
    }
  },
  mathmlBuilder(n, e) {
    var t;
    if (da.hasOwnProperty(n.text))
      t = new I.MathNode("mtext", [new I.TextNode(" ")]);
    else {
      if (ma.hasOwnProperty(n.text))
        return new I.MathNode("mspace");
      throw new L('Unknown type of space "' + n.text + '"');
    }
    return t;
  }
});
var Bl = () => {
  var n = new I.MathNode("mtd", []);
  return n.setAttribute("width", "50%"), n;
};
q0({
  type: "tag",
  mathmlBuilder(n, e) {
    var t = new I.MathNode("mtable", [new I.MathNode("mtr", [Bl(), new I.MathNode("mtd", [A0(n.body, e)]), Bl(), new I.MathNode("mtd", [A0(n.tag, e)])])]);
    return t.setAttribute("width", "100%"), t;
  }
});
var Nl = {
  "\\text": void 0,
  "\\textrm": "textrm",
  "\\textsf": "textsf",
  "\\texttt": "texttt",
  "\\textnormal": "textrm"
}, Rl = {
  "\\textbf": "textbf",
  "\\textmd": "textmd"
}, q4 = {
  "\\textit": "textit",
  "\\textup": "textup"
}, Il = (n, e) => {
  var t = n.font;
  if (t) {
    if (Nl[t])
      return e.withTextFontFamily(Nl[t]);
    if (Rl[t])
      return e.withTextFontWeight(Rl[t]);
    if (t === "\\emph")
      return e.fontShape === "textit" ? e.withTextFontShape("textup") : e.withTextFontShape("textit");
  } else return e;
  return e.withTextFontShape(q4[t]);
};
G({
  type: "text",
  names: [
    // Font families
    "\\text",
    "\\textrm",
    "\\textsf",
    "\\texttt",
    "\\textnormal",
    // Font weights
    "\\textbf",
    "\\textmd",
    // Font Shapes
    "\\textit",
    "\\textup",
    "\\emph"
  ],
  props: {
    numArgs: 1,
    argTypes: ["text"],
    allowedInArgument: !0,
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t,
      funcName: r
    } = n, a = e[0];
    return {
      type: "text",
      mode: t.mode,
      body: Ae(a),
      font: r
    };
  },
  htmlBuilder(n, e) {
    var t = Il(n, e), r = Me(n.body, t, !0);
    return C.makeSpan(["mord", "text"], r, t);
  },
  mathmlBuilder(n, e) {
    var t = Il(n, e);
    return A0(n.body, t);
  }
});
G({
  type: "underline",
  names: ["\\underline"],
  props: {
    numArgs: 1,
    allowedInText: !0
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "underline",
      mode: t.mode,
      body: e[0]
    };
  },
  htmlBuilder(n, e) {
    var t = ie(n.body, e), r = C.makeLineSpan("underline-line", e), a = e.fontMetrics().defaultRuleThickness, i = C.makeVList({
      positionType: "top",
      positionData: t.height,
      children: [{
        type: "kern",
        size: a
      }, {
        type: "elem",
        elem: r
      }, {
        type: "kern",
        size: 3 * a
      }, {
        type: "elem",
        elem: t
      }]
    }, e);
    return C.makeSpan(["mord", "underline"], [i], e);
  },
  mathmlBuilder(n, e) {
    var t = new I.MathNode("mo", [new I.TextNode("‾")]);
    t.setAttribute("stretchy", "true");
    var r = new I.MathNode("munder", [me(n.body, e), t]);
    return r.setAttribute("accentunder", "true"), r;
  }
});
G({
  type: "vcenter",
  names: ["\\vcenter"],
  props: {
    numArgs: 1,
    argTypes: ["original"],
    // In LaTeX, \vcenter can act only on a box.
    allowedInText: !1
  },
  handler(n, e) {
    var {
      parser: t
    } = n;
    return {
      type: "vcenter",
      mode: t.mode,
      body: e[0]
    };
  },
  htmlBuilder(n, e) {
    var t = ie(n.body, e), r = e.fontMetrics().axisHeight, a = 0.5 * (t.height - r - (t.depth + r));
    return C.makeVList({
      positionType: "shift",
      positionData: a,
      children: [{
        type: "elem",
        elem: t
      }]
    }, e);
  },
  mathmlBuilder(n, e) {
    return new I.MathNode("mpadded", [me(n.body, e)], ["vcenter"]);
  }
});
G({
  type: "verb",
  names: ["\\verb"],
  props: {
    numArgs: 0,
    allowedInText: !0
  },
  handler(n, e, t) {
    throw new L("\\verb ended by end of line instead of matching delimiter");
  },
  htmlBuilder(n, e) {
    for (var t = Ll(n), r = [], a = e.havingStyle(e.style.text()), i = 0; i < t.length; i++) {
      var l = t[i];
      l === "~" && (l = "\\textasciitilde"), r.push(C.makeSymbol(l, "Typewriter-Regular", n.mode, a, ["mord", "texttt"]));
    }
    return C.makeSpan(["mord", "text"].concat(a.sizingClasses(e)), C.tryCombineChars(r), a);
  },
  mathmlBuilder(n, e) {
    var t = new I.TextNode(Ll(n)), r = new I.MathNode("mtext", [t]);
    return r.setAttribute("mathvariant", "monospace"), r;
  }
});
var Ll = (n) => n.body.replace(/ /g, n.star ? "␣" : " "), w0 = Po, bu = `[ \r
	]`, P4 = "\\\\[a-zA-Z@]+", H4 = "\\\\[^\uD800-\uDFFF]", U4 = "(" + P4 + ")" + bu + "*", G4 = `\\\\(
|[ \r	]+
?)[ \r	]*`, Ya = "[̀-ͯ]", V4 = new RegExp(Ya + "+$"), W4 = "(" + bu + "+)|" + // whitespace
(G4 + "|") + // \whitespace
"([!-\\[\\]-‧‪-퟿豈-]" + // single codepoint
(Ya + "*") + // ...plus accents
"|[\uD800-\uDBFF][\uDC00-\uDFFF]" + // surrogate pair
(Ya + "*") + // ...plus accents
"|\\\\verb\\*([^]).*?\\4|\\\\verb([^*a-zA-Z]).*?\\5" + // \verb unstarred
("|" + U4) + // \macroName + spaces
("|" + H4 + ")");
class Ol {
  // Category codes. The lexer only supports comment characters (14) for now.
  // MacroExpander additionally distinguishes active (13).
  constructor(e, t) {
    this.input = void 0, this.settings = void 0, this.tokenRegex = void 0, this.catcodes = void 0, this.input = e, this.settings = t, this.tokenRegex = new RegExp(W4, "g"), this.catcodes = {
      "%": 14,
      // comment character
      "~": 13
      // active character
    };
  }
  setCatcode(e, t) {
    this.catcodes[e] = t;
  }
  /**
   * This function lexes a single token.
   */
  lex() {
    var e = this.input, t = this.tokenRegex.lastIndex;
    if (t === e.length)
      return new mt("EOF", new nt(this, t, t));
    var r = this.tokenRegex.exec(e);
    if (r === null || r.index !== t)
      throw new L("Unexpected character: '" + e[t] + "'", new mt(e[t], new nt(this, t, t + 1)));
    var a = r[6] || r[3] || (r[2] ? "\\ " : " ");
    if (this.catcodes[a] === 14) {
      var i = e.indexOf(`
`, this.tokenRegex.lastIndex);
      return i === -1 ? (this.tokenRegex.lastIndex = e.length, this.settings.reportNonstrict("commentAtEnd", "% comment has no terminating newline; LaTeX would fail because of commenting the end of math mode (e.g. $)")) : this.tokenRegex.lastIndex = i + 1, this.lex();
    }
    return new mt(a, new nt(this, t, this.tokenRegex.lastIndex));
  }
}
class X4 {
  /**
   * Both arguments are optional.  The first argument is an object of
   * built-in mappings which never change.  The second argument is an object
   * of initial (global-level) mappings, which will constantly change
   * according to any global/top-level `set`s done.
   */
  constructor(e, t) {
    e === void 0 && (e = {}), t === void 0 && (t = {}), this.current = void 0, this.builtins = void 0, this.undefStack = void 0, this.current = t, this.builtins = e, this.undefStack = [];
  }
  /**
   * Start a new nested group, affecting future local `set`s.
   */
  beginGroup() {
    this.undefStack.push({});
  }
  /**
   * End current nested group, restoring values before the group began.
   */
  endGroup() {
    if (this.undefStack.length === 0)
      throw new L("Unbalanced namespace destruction: attempt to pop global namespace; please report this as a bug");
    var e = this.undefStack.pop();
    for (var t in e)
      e.hasOwnProperty(t) && (e[t] == null ? delete this.current[t] : this.current[t] = e[t]);
  }
  /**
   * Ends all currently nested groups (if any), restoring values before the
   * groups began.  Useful in case of an error in the middle of parsing.
   */
  endGroups() {
    for (; this.undefStack.length > 0; )
      this.endGroup();
  }
  /**
   * Detect whether `name` has a definition.  Equivalent to
   * `get(name) != null`.
   */
  has(e) {
    return this.current.hasOwnProperty(e) || this.builtins.hasOwnProperty(e);
  }
  /**
   * Get the current value of a name, or `undefined` if there is no value.
   *
   * Note: Do not use `if (namespace.get(...))` to detect whether a macro
   * is defined, as the definition may be the empty string which evaluates
   * to `false` in JavaScript.  Use `if (namespace.get(...) != null)` or
   * `if (namespace.has(...))`.
   */
  get(e) {
    return this.current.hasOwnProperty(e) ? this.current[e] : this.builtins[e];
  }
  /**
   * Set the current value of a name, and optionally set it globally too.
   * Local set() sets the current value and (when appropriate) adds an undo
   * operation to the undo stack.  Global set() may change the undo
   * operation at every level, so takes time linear in their number.
   * A value of undefined means to delete existing definitions.
   */
  set(e, t, r) {
    if (r === void 0 && (r = !1), r) {
      for (var a = 0; a < this.undefStack.length; a++)
        delete this.undefStack[a][e];
      this.undefStack.length > 0 && (this.undefStack[this.undefStack.length - 1][e] = t);
    } else {
      var i = this.undefStack[this.undefStack.length - 1];
      i && !i.hasOwnProperty(e) && (i[e] = this.current[e]);
    }
    t == null ? delete this.current[e] : this.current[e] = t;
  }
}
var Y4 = su;
p("\\noexpand", function(n) {
  var e = n.popToken();
  return n.isExpandable(e.text) && (e.noexpand = !0, e.treatAsRelax = !0), {
    tokens: [e],
    numArgs: 0
  };
});
p("\\expandafter", function(n) {
  var e = n.popToken();
  return n.expandOnce(!0), {
    tokens: [e],
    numArgs: 0
  };
});
p("\\@firstoftwo", function(n) {
  var e = n.consumeArgs(2);
  return {
    tokens: e[0],
    numArgs: 0
  };
});
p("\\@secondoftwo", function(n) {
  var e = n.consumeArgs(2);
  return {
    tokens: e[1],
    numArgs: 0
  };
});
p("\\@ifnextchar", function(n) {
  var e = n.consumeArgs(3);
  n.consumeSpaces();
  var t = n.future();
  return e[0].length === 1 && e[0][0].text === t.text ? {
    tokens: e[1],
    numArgs: 0
  } : {
    tokens: e[2],
    numArgs: 0
  };
});
p("\\@ifstar", "\\@ifnextchar *{\\@firstoftwo{#1}}");
p("\\TextOrMath", function(n) {
  var e = n.consumeArgs(2);
  return n.mode === "text" ? {
    tokens: e[0],
    numArgs: 0
  } : {
    tokens: e[1],
    numArgs: 0
  };
});
var ql = {
  0: 0,
  1: 1,
  2: 2,
  3: 3,
  4: 4,
  5: 5,
  6: 6,
  7: 7,
  8: 8,
  9: 9,
  a: 10,
  A: 10,
  b: 11,
  B: 11,
  c: 12,
  C: 12,
  d: 13,
  D: 13,
  e: 14,
  E: 14,
  f: 15,
  F: 15
};
p("\\char", function(n) {
  var e = n.popToken(), t, r = "";
  if (e.text === "'")
    t = 8, e = n.popToken();
  else if (e.text === '"')
    t = 16, e = n.popToken();
  else if (e.text === "`")
    if (e = n.popToken(), e.text[0] === "\\")
      r = e.text.charCodeAt(1);
    else {
      if (e.text === "EOF")
        throw new L("\\char` missing argument");
      r = e.text.charCodeAt(0);
    }
  else
    t = 10;
  if (t) {
    if (r = ql[e.text], r == null || r >= t)
      throw new L("Invalid base-" + t + " digit " + e.text);
    for (var a; (a = ql[n.future().text]) != null && a < t; )
      r *= t, r += a, n.popToken();
  }
  return "\\@char{" + r + "}";
});
var Ai = (n, e, t) => {
  var r = n.consumeArg().tokens;
  if (r.length !== 1)
    throw new L("\\newcommand's first argument must be a macro name");
  var a = r[0].text, i = n.isDefined(a);
  if (i && !e)
    throw new L("\\newcommand{" + a + "} attempting to redefine " + (a + "; use \\renewcommand"));
  if (!i && !t)
    throw new L("\\renewcommand{" + a + "} when command " + a + " does not yet exist; use \\newcommand");
  var l = 0;
  if (r = n.consumeArg().tokens, r.length === 1 && r[0].text === "[") {
    for (var s = "", o = n.expandNextToken(); o.text !== "]" && o.text !== "EOF"; )
      s += o.text, o = n.expandNextToken();
    if (!s.match(/^\s*[0-9]+\s*$/))
      throw new L("Invalid number of arguments: " + s);
    l = parseInt(s), r = n.consumeArg().tokens;
  }
  return n.macros.set(a, {
    tokens: r,
    numArgs: l
  }), "";
};
p("\\newcommand", (n) => Ai(n, !1, !0));
p("\\renewcommand", (n) => Ai(n, !0, !1));
p("\\providecommand", (n) => Ai(n, !0, !0));
p("\\message", (n) => {
  var e = n.consumeArgs(1)[0];
  return console.log(e.reverse().map((t) => t.text).join("")), "";
});
p("\\errmessage", (n) => {
  var e = n.consumeArgs(1)[0];
  return console.error(e.reverse().map((t) => t.text).join("")), "";
});
p("\\show", (n) => {
  var e = n.popToken(), t = e.text;
  return console.log(e, n.macros.get(t), w0[t], de.math[t], de.text[t]), "";
});
p("\\bgroup", "{");
p("\\egroup", "}");
p("~", "\\nobreakspace");
p("\\lq", "`");
p("\\rq", "'");
p("\\aa", "\\r a");
p("\\AA", "\\r A");
p("\\textcopyright", "\\html@mathml{\\textcircled{c}}{\\char`©}");
p("\\copyright", "\\TextOrMath{\\textcopyright}{\\text{\\textcopyright}}");
p("\\textregistered", "\\html@mathml{\\textcircled{\\scriptsize R}}{\\char`®}");
p("ℬ", "\\mathscr{B}");
p("ℰ", "\\mathscr{E}");
p("ℱ", "\\mathscr{F}");
p("ℋ", "\\mathscr{H}");
p("ℐ", "\\mathscr{I}");
p("ℒ", "\\mathscr{L}");
p("ℳ", "\\mathscr{M}");
p("ℛ", "\\mathscr{R}");
p("ℭ", "\\mathfrak{C}");
p("ℌ", "\\mathfrak{H}");
p("ℨ", "\\mathfrak{Z}");
p("\\Bbbk", "\\Bbb{k}");
p("·", "\\cdotp");
p("\\llap", "\\mathllap{\\textrm{#1}}");
p("\\rlap", "\\mathrlap{\\textrm{#1}}");
p("\\clap", "\\mathclap{\\textrm{#1}}");
p("\\mathstrut", "\\vphantom{(}");
p("\\underbar", "\\underline{\\text{#1}}");
p("\\not", '\\html@mathml{\\mathrel{\\mathrlap\\@not}}{\\char"338}');
p("\\neq", "\\html@mathml{\\mathrel{\\not=}}{\\mathrel{\\char`≠}}");
p("\\ne", "\\neq");
p("≠", "\\neq");
p("\\notin", "\\html@mathml{\\mathrel{{\\in}\\mathllap{/\\mskip1mu}}}{\\mathrel{\\char`∉}}");
p("∉", "\\notin");
p("≘", "\\html@mathml{\\mathrel{=\\kern{-1em}\\raisebox{0.4em}{$\\scriptsize\\frown$}}}{\\mathrel{\\char`≘}}");
p("≙", "\\html@mathml{\\stackrel{\\tiny\\wedge}{=}}{\\mathrel{\\char`≘}}");
p("≚", "\\html@mathml{\\stackrel{\\tiny\\vee}{=}}{\\mathrel{\\char`≚}}");
p("≛", "\\html@mathml{\\stackrel{\\scriptsize\\star}{=}}{\\mathrel{\\char`≛}}");
p("≝", "\\html@mathml{\\stackrel{\\tiny\\mathrm{def}}{=}}{\\mathrel{\\char`≝}}");
p("≞", "\\html@mathml{\\stackrel{\\tiny\\mathrm{m}}{=}}{\\mathrel{\\char`≞}}");
p("≟", "\\html@mathml{\\stackrel{\\tiny?}{=}}{\\mathrel{\\char`≟}}");
p("⟂", "\\perp");
p("‼", "\\mathclose{!\\mkern-0.8mu!}");
p("∌", "\\notni");
p("⌜", "\\ulcorner");
p("⌝", "\\urcorner");
p("⌞", "\\llcorner");
p("⌟", "\\lrcorner");
p("©", "\\copyright");
p("®", "\\textregistered");
p("️", "\\textregistered");
p("\\ulcorner", '\\html@mathml{\\@ulcorner}{\\mathop{\\char"231c}}');
p("\\urcorner", '\\html@mathml{\\@urcorner}{\\mathop{\\char"231d}}');
p("\\llcorner", '\\html@mathml{\\@llcorner}{\\mathop{\\char"231e}}');
p("\\lrcorner", '\\html@mathml{\\@lrcorner}{\\mathop{\\char"231f}}');
p("\\vdots", "{\\varvdots\\rule{0pt}{15pt}}");
p("⋮", "\\vdots");
p("\\varGamma", "\\mathit{\\Gamma}");
p("\\varDelta", "\\mathit{\\Delta}");
p("\\varTheta", "\\mathit{\\Theta}");
p("\\varLambda", "\\mathit{\\Lambda}");
p("\\varXi", "\\mathit{\\Xi}");
p("\\varPi", "\\mathit{\\Pi}");
p("\\varSigma", "\\mathit{\\Sigma}");
p("\\varUpsilon", "\\mathit{\\Upsilon}");
p("\\varPhi", "\\mathit{\\Phi}");
p("\\varPsi", "\\mathit{\\Psi}");
p("\\varOmega", "\\mathit{\\Omega}");
p("\\substack", "\\begin{subarray}{c}#1\\end{subarray}");
p("\\colon", "\\nobreak\\mskip2mu\\mathpunct{}\\mathchoice{\\mkern-3mu}{\\mkern-3mu}{}{}{:}\\mskip6mu\\relax");
p("\\boxed", "\\fbox{$\\displaystyle{#1}$}");
p("\\iff", "\\DOTSB\\;\\Longleftrightarrow\\;");
p("\\implies", "\\DOTSB\\;\\Longrightarrow\\;");
p("\\impliedby", "\\DOTSB\\;\\Longleftarrow\\;");
p("\\dddot", "{\\overset{\\raisebox{-0.1ex}{\\normalsize ...}}{#1}}");
p("\\ddddot", "{\\overset{\\raisebox{-0.1ex}{\\normalsize ....}}{#1}}");
var Pl = {
  ",": "\\dotsc",
  "\\not": "\\dotsb",
  // \keybin@ checks for the following:
  "+": "\\dotsb",
  "=": "\\dotsb",
  "<": "\\dotsb",
  ">": "\\dotsb",
  "-": "\\dotsb",
  "*": "\\dotsb",
  ":": "\\dotsb",
  // Symbols whose definition starts with \DOTSB:
  "\\DOTSB": "\\dotsb",
  "\\coprod": "\\dotsb",
  "\\bigvee": "\\dotsb",
  "\\bigwedge": "\\dotsb",
  "\\biguplus": "\\dotsb",
  "\\bigcap": "\\dotsb",
  "\\bigcup": "\\dotsb",
  "\\prod": "\\dotsb",
  "\\sum": "\\dotsb",
  "\\bigotimes": "\\dotsb",
  "\\bigoplus": "\\dotsb",
  "\\bigodot": "\\dotsb",
  "\\bigsqcup": "\\dotsb",
  "\\And": "\\dotsb",
  "\\longrightarrow": "\\dotsb",
  "\\Longrightarrow": "\\dotsb",
  "\\longleftarrow": "\\dotsb",
  "\\Longleftarrow": "\\dotsb",
  "\\longleftrightarrow": "\\dotsb",
  "\\Longleftrightarrow": "\\dotsb",
  "\\mapsto": "\\dotsb",
  "\\longmapsto": "\\dotsb",
  "\\hookrightarrow": "\\dotsb",
  "\\doteq": "\\dotsb",
  // Symbols whose definition starts with \mathbin:
  "\\mathbin": "\\dotsb",
  // Symbols whose definition starts with \mathrel:
  "\\mathrel": "\\dotsb",
  "\\relbar": "\\dotsb",
  "\\Relbar": "\\dotsb",
  "\\xrightarrow": "\\dotsb",
  "\\xleftarrow": "\\dotsb",
  // Symbols whose definition starts with \DOTSI:
  "\\DOTSI": "\\dotsi",
  "\\int": "\\dotsi",
  "\\oint": "\\dotsi",
  "\\iint": "\\dotsi",
  "\\iiint": "\\dotsi",
  "\\iiiint": "\\dotsi",
  "\\idotsint": "\\dotsi",
  // Symbols whose definition starts with \DOTSX:
  "\\DOTSX": "\\dotsx"
};
p("\\dots", function(n) {
  var e = "\\dotso", t = n.expandAfterFuture().text;
  return t in Pl ? e = Pl[t] : (t.slice(0, 4) === "\\not" || t in de.math && j.contains(["bin", "rel"], de.math[t].group)) && (e = "\\dotsb"), e;
});
var Si = {
  // \rightdelim@ checks for the following:
  ")": !0,
  "]": !0,
  "\\rbrack": !0,
  "\\}": !0,
  "\\rbrace": !0,
  "\\rangle": !0,
  "\\rceil": !0,
  "\\rfloor": !0,
  "\\rgroup": !0,
  "\\rmoustache": !0,
  "\\right": !0,
  "\\bigr": !0,
  "\\biggr": !0,
  "\\Bigr": !0,
  "\\Biggr": !0,
  // \extra@ also tests for the following:
  $: !0,
  // \extrap@ checks for the following:
  ";": !0,
  ".": !0,
  ",": !0
};
p("\\dotso", function(n) {
  var e = n.future().text;
  return e in Si ? "\\ldots\\," : "\\ldots";
});
p("\\dotsc", function(n) {
  var e = n.future().text;
  return e in Si && e !== "," ? "\\ldots\\," : "\\ldots";
});
p("\\cdots", function(n) {
  var e = n.future().text;
  return e in Si ? "\\@cdots\\," : "\\@cdots";
});
p("\\dotsb", "\\cdots");
p("\\dotsm", "\\cdots");
p("\\dotsi", "\\!\\cdots");
p("\\dotsx", "\\ldots\\,");
p("\\DOTSI", "\\relax");
p("\\DOTSB", "\\relax");
p("\\DOTSX", "\\relax");
p("\\tmspace", "\\TextOrMath{\\kern#1#3}{\\mskip#1#2}\\relax");
p("\\,", "\\tmspace+{3mu}{.1667em}");
p("\\thinspace", "\\,");
p("\\>", "\\mskip{4mu}");
p("\\:", "\\tmspace+{4mu}{.2222em}");
p("\\medspace", "\\:");
p("\\;", "\\tmspace+{5mu}{.2777em}");
p("\\thickspace", "\\;");
p("\\!", "\\tmspace-{3mu}{.1667em}");
p("\\negthinspace", "\\!");
p("\\negmedspace", "\\tmspace-{4mu}{.2222em}");
p("\\negthickspace", "\\tmspace-{5mu}{.277em}");
p("\\enspace", "\\kern.5em ");
p("\\enskip", "\\hskip.5em\\relax");
p("\\quad", "\\hskip1em\\relax");
p("\\qquad", "\\hskip2em\\relax");
p("\\tag", "\\@ifstar\\tag@literal\\tag@paren");
p("\\tag@paren", "\\tag@literal{({#1})}");
p("\\tag@literal", (n) => {
  if (n.macros.get("\\df@tag"))
    throw new L("Multiple \\tag");
  return "\\gdef\\df@tag{\\text{#1}}";
});
p("\\bmod", "\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}\\mathbin{\\rm mod}\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}");
p("\\pod", "\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern8mu}{\\mkern8mu}{\\mkern8mu}(#1)");
p("\\pmod", "\\pod{{\\rm mod}\\mkern6mu#1}");
p("\\mod", "\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern12mu}{\\mkern12mu}{\\mkern12mu}{\\rm mod}\\,\\,#1");
p("\\newline", "\\\\\\relax");
p("\\TeX", "\\textrm{\\html@mathml{T\\kern-.1667em\\raisebox{-.5ex}{E}\\kern-.125emX}{TeX}}");
var yu = P(Pt["Main-Regular"][84][1] - 0.7 * Pt["Main-Regular"][65][1]);
p("\\LaTeX", "\\textrm{\\html@mathml{" + ("L\\kern-.36em\\raisebox{" + yu + "}{\\scriptstyle A}") + "\\kern-.15em\\TeX}{LaTeX}}");
p("\\KaTeX", "\\textrm{\\html@mathml{" + ("K\\kern-.17em\\raisebox{" + yu + "}{\\scriptstyle A}") + "\\kern-.15em\\TeX}{KaTeX}}");
p("\\hspace", "\\@ifstar\\@hspacer\\@hspace");
p("\\@hspace", "\\hskip #1\\relax");
p("\\@hspacer", "\\rule{0pt}{0pt}\\hskip #1\\relax");
p("\\ordinarycolon", ":");
p("\\vcentcolon", "\\mathrel{\\mathop\\ordinarycolon}");
p("\\dblcolon", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-.9mu}\\vcentcolon}}{\\mathop{\\char"2237}}');
p("\\coloneqq", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2254}}');
p("\\Coloneqq", '\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2237\\char"3d}}');
p("\\coloneq", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"3a\\char"2212}}');
p("\\Coloneq", '\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"2237\\char"2212}}');
p("\\eqqcolon", '\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2255}}');
p("\\Eqqcolon", '\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"3d\\char"2237}}');
p("\\eqcolon", '\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2239}}');
p("\\Eqcolon", '\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"2212\\char"2237}}');
p("\\colonapprox", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"3a\\char"2248}}');
p("\\Colonapprox", '\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"2237\\char"2248}}');
p("\\colonsim", '\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"3a\\char"223c}}');
p("\\Colonsim", '\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"2237\\char"223c}}');
p("∷", "\\dblcolon");
p("∹", "\\eqcolon");
p("≔", "\\coloneqq");
p("≕", "\\eqqcolon");
p("⩴", "\\Coloneqq");
p("\\ratio", "\\vcentcolon");
p("\\coloncolon", "\\dblcolon");
p("\\colonequals", "\\coloneqq");
p("\\coloncolonequals", "\\Coloneqq");
p("\\equalscolon", "\\eqqcolon");
p("\\equalscoloncolon", "\\Eqqcolon");
p("\\colonminus", "\\coloneq");
p("\\coloncolonminus", "\\Coloneq");
p("\\minuscolon", "\\eqcolon");
p("\\minuscoloncolon", "\\Eqcolon");
p("\\coloncolonapprox", "\\Colonapprox");
p("\\coloncolonsim", "\\Colonsim");
p("\\simcolon", "\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\vcentcolon}");
p("\\simcoloncolon", "\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\dblcolon}");
p("\\approxcolon", "\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\vcentcolon}");
p("\\approxcoloncolon", "\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\dblcolon}");
p("\\notni", "\\html@mathml{\\not\\ni}{\\mathrel{\\char`∌}}");
p("\\limsup", "\\DOTSB\\operatorname*{lim\\,sup}");
p("\\liminf", "\\DOTSB\\operatorname*{lim\\,inf}");
p("\\injlim", "\\DOTSB\\operatorname*{inj\\,lim}");
p("\\projlim", "\\DOTSB\\operatorname*{proj\\,lim}");
p("\\varlimsup", "\\DOTSB\\operatorname*{\\overline{lim}}");
p("\\varliminf", "\\DOTSB\\operatorname*{\\underline{lim}}");
p("\\varinjlim", "\\DOTSB\\operatorname*{\\underrightarrow{lim}}");
p("\\varprojlim", "\\DOTSB\\operatorname*{\\underleftarrow{lim}}");
p("\\gvertneqq", "\\html@mathml{\\@gvertneqq}{≩}");
p("\\lvertneqq", "\\html@mathml{\\@lvertneqq}{≨}");
p("\\ngeqq", "\\html@mathml{\\@ngeqq}{≱}");
p("\\ngeqslant", "\\html@mathml{\\@ngeqslant}{≱}");
p("\\nleqq", "\\html@mathml{\\@nleqq}{≰}");
p("\\nleqslant", "\\html@mathml{\\@nleqslant}{≰}");
p("\\nshortmid", "\\html@mathml{\\@nshortmid}{∤}");
p("\\nshortparallel", "\\html@mathml{\\@nshortparallel}{∦}");
p("\\nsubseteqq", "\\html@mathml{\\@nsubseteqq}{⊈}");
p("\\nsupseteqq", "\\html@mathml{\\@nsupseteqq}{⊉}");
p("\\varsubsetneq", "\\html@mathml{\\@varsubsetneq}{⊊}");
p("\\varsubsetneqq", "\\html@mathml{\\@varsubsetneqq}{⫋}");
p("\\varsupsetneq", "\\html@mathml{\\@varsupsetneq}{⊋}");
p("\\varsupsetneqq", "\\html@mathml{\\@varsupsetneqq}{⫌}");
p("\\imath", "\\html@mathml{\\@imath}{ı}");
p("\\jmath", "\\html@mathml{\\@jmath}{ȷ}");
p("\\llbracket", "\\html@mathml{\\mathopen{[\\mkern-3.2mu[}}{\\mathopen{\\char`⟦}}");
p("\\rrbracket", "\\html@mathml{\\mathclose{]\\mkern-3.2mu]}}{\\mathclose{\\char`⟧}}");
p("⟦", "\\llbracket");
p("⟧", "\\rrbracket");
p("\\lBrace", "\\html@mathml{\\mathopen{\\{\\mkern-3.2mu[}}{\\mathopen{\\char`⦃}}");
p("\\rBrace", "\\html@mathml{\\mathclose{]\\mkern-3.2mu\\}}}{\\mathclose{\\char`⦄}}");
p("⦃", "\\lBrace");
p("⦄", "\\rBrace");
p("\\minuso", "\\mathbin{\\html@mathml{{\\mathrlap{\\mathchoice{\\kern{0.145em}}{\\kern{0.145em}}{\\kern{0.1015em}}{\\kern{0.0725em}}\\circ}{-}}}{\\char`⦵}}");
p("⦵", "\\minuso");
p("\\darr", "\\downarrow");
p("\\dArr", "\\Downarrow");
p("\\Darr", "\\Downarrow");
p("\\lang", "\\langle");
p("\\rang", "\\rangle");
p("\\uarr", "\\uparrow");
p("\\uArr", "\\Uparrow");
p("\\Uarr", "\\Uparrow");
p("\\N", "\\mathbb{N}");
p("\\R", "\\mathbb{R}");
p("\\Z", "\\mathbb{Z}");
p("\\alef", "\\aleph");
p("\\alefsym", "\\aleph");
p("\\Alpha", "\\mathrm{A}");
p("\\Beta", "\\mathrm{B}");
p("\\bull", "\\bullet");
p("\\Chi", "\\mathrm{X}");
p("\\clubs", "\\clubsuit");
p("\\cnums", "\\mathbb{C}");
p("\\Complex", "\\mathbb{C}");
p("\\Dagger", "\\ddagger");
p("\\diamonds", "\\diamondsuit");
p("\\empty", "\\emptyset");
p("\\Epsilon", "\\mathrm{E}");
p("\\Eta", "\\mathrm{H}");
p("\\exist", "\\exists");
p("\\harr", "\\leftrightarrow");
p("\\hArr", "\\Leftrightarrow");
p("\\Harr", "\\Leftrightarrow");
p("\\hearts", "\\heartsuit");
p("\\image", "\\Im");
p("\\infin", "\\infty");
p("\\Iota", "\\mathrm{I}");
p("\\isin", "\\in");
p("\\Kappa", "\\mathrm{K}");
p("\\larr", "\\leftarrow");
p("\\lArr", "\\Leftarrow");
p("\\Larr", "\\Leftarrow");
p("\\lrarr", "\\leftrightarrow");
p("\\lrArr", "\\Leftrightarrow");
p("\\Lrarr", "\\Leftrightarrow");
p("\\Mu", "\\mathrm{M}");
p("\\natnums", "\\mathbb{N}");
p("\\Nu", "\\mathrm{N}");
p("\\Omicron", "\\mathrm{O}");
p("\\plusmn", "\\pm");
p("\\rarr", "\\rightarrow");
p("\\rArr", "\\Rightarrow");
p("\\Rarr", "\\Rightarrow");
p("\\real", "\\Re");
p("\\reals", "\\mathbb{R}");
p("\\Reals", "\\mathbb{R}");
p("\\Rho", "\\mathrm{P}");
p("\\sdot", "\\cdot");
p("\\sect", "\\S");
p("\\spades", "\\spadesuit");
p("\\sub", "\\subset");
p("\\sube", "\\subseteq");
p("\\supe", "\\supseteq");
p("\\Tau", "\\mathrm{T}");
p("\\thetasym", "\\vartheta");
p("\\weierp", "\\wp");
p("\\Zeta", "\\mathrm{Z}");
p("\\argmin", "\\DOTSB\\operatorname*{arg\\,min}");
p("\\argmax", "\\DOTSB\\operatorname*{arg\\,max}");
p("\\plim", "\\DOTSB\\mathop{\\operatorname{plim}}\\limits");
p("\\bra", "\\mathinner{\\langle{#1}|}");
p("\\ket", "\\mathinner{|{#1}\\rangle}");
p("\\braket", "\\mathinner{\\langle{#1}\\rangle}");
p("\\Bra", "\\left\\langle#1\\right|");
p("\\Ket", "\\left|#1\\right\\rangle");
var wu = (n) => (e) => {
  var t = e.consumeArg().tokens, r = e.consumeArg().tokens, a = e.consumeArg().tokens, i = e.consumeArg().tokens, l = e.macros.get("|"), s = e.macros.get("\\|");
  e.macros.beginGroup();
  var o = (d) => (g) => {
    n && (g.macros.set("|", l), a.length && g.macros.set("\\|", s));
    var v = d;
    if (!d && a.length) {
      var y = g.future();
      y.text === "|" && (g.popToken(), v = !0);
    }
    return {
      tokens: v ? a : r,
      numArgs: 0
    };
  };
  e.macros.set("|", o(!1)), a.length && e.macros.set("\\|", o(!0));
  var c = e.consumeArg().tokens, f = e.expandTokens([
    ...i,
    ...c,
    ...t
    // reversed
  ]);
  return e.macros.endGroup(), {
    tokens: f.reverse(),
    numArgs: 0
  };
};
p("\\bra@ket", wu(!1));
p("\\bra@set", wu(!0));
p("\\Braket", "\\bra@ket{\\left\\langle}{\\,\\middle\\vert\\,}{\\,\\middle\\vert\\,}{\\right\\rangle}");
p("\\Set", "\\bra@set{\\left\\{\\:}{\\;\\middle\\vert\\;}{\\;\\middle\\Vert\\;}{\\:\\right\\}}");
p("\\set", "\\bra@set{\\{\\,}{\\mid}{}{\\,\\}}");
p("\\angln", "{\\angl n}");
p("\\blue", "\\textcolor{##6495ed}{#1}");
p("\\orange", "\\textcolor{##ffa500}{#1}");
p("\\pink", "\\textcolor{##ff00af}{#1}");
p("\\red", "\\textcolor{##df0030}{#1}");
p("\\green", "\\textcolor{##28ae7b}{#1}");
p("\\gray", "\\textcolor{gray}{#1}");
p("\\purple", "\\textcolor{##9d38bd}{#1}");
p("\\blueA", "\\textcolor{##ccfaff}{#1}");
p("\\blueB", "\\textcolor{##80f6ff}{#1}");
p("\\blueC", "\\textcolor{##63d9ea}{#1}");
p("\\blueD", "\\textcolor{##11accd}{#1}");
p("\\blueE", "\\textcolor{##0c7f99}{#1}");
p("\\tealA", "\\textcolor{##94fff5}{#1}");
p("\\tealB", "\\textcolor{##26edd5}{#1}");
p("\\tealC", "\\textcolor{##01d1c1}{#1}");
p("\\tealD", "\\textcolor{##01a995}{#1}");
p("\\tealE", "\\textcolor{##208170}{#1}");
p("\\greenA", "\\textcolor{##b6ffb0}{#1}");
p("\\greenB", "\\textcolor{##8af281}{#1}");
p("\\greenC", "\\textcolor{##74cf70}{#1}");
p("\\greenD", "\\textcolor{##1fab54}{#1}");
p("\\greenE", "\\textcolor{##0d923f}{#1}");
p("\\goldA", "\\textcolor{##ffd0a9}{#1}");
p("\\goldB", "\\textcolor{##ffbb71}{#1}");
p("\\goldC", "\\textcolor{##ff9c39}{#1}");
p("\\goldD", "\\textcolor{##e07d10}{#1}");
p("\\goldE", "\\textcolor{##a75a05}{#1}");
p("\\redA", "\\textcolor{##fca9a9}{#1}");
p("\\redB", "\\textcolor{##ff8482}{#1}");
p("\\redC", "\\textcolor{##f9685d}{#1}");
p("\\redD", "\\textcolor{##e84d39}{#1}");
p("\\redE", "\\textcolor{##bc2612}{#1}");
p("\\maroonA", "\\textcolor{##ffbde0}{#1}");
p("\\maroonB", "\\textcolor{##ff92c6}{#1}");
p("\\maroonC", "\\textcolor{##ed5fa6}{#1}");
p("\\maroonD", "\\textcolor{##ca337c}{#1}");
p("\\maroonE", "\\textcolor{##9e034e}{#1}");
p("\\purpleA", "\\textcolor{##ddd7ff}{#1}");
p("\\purpleB", "\\textcolor{##c6b9fc}{#1}");
p("\\purpleC", "\\textcolor{##aa87ff}{#1}");
p("\\purpleD", "\\textcolor{##7854ab}{#1}");
p("\\purpleE", "\\textcolor{##543b78}{#1}");
p("\\mintA", "\\textcolor{##f5f9e8}{#1}");
p("\\mintB", "\\textcolor{##edf2df}{#1}");
p("\\mintC", "\\textcolor{##e0e5cc}{#1}");
p("\\grayA", "\\textcolor{##f6f7f7}{#1}");
p("\\grayB", "\\textcolor{##f0f1f2}{#1}");
p("\\grayC", "\\textcolor{##e3e5e6}{#1}");
p("\\grayD", "\\textcolor{##d6d8da}{#1}");
p("\\grayE", "\\textcolor{##babec2}{#1}");
p("\\grayF", "\\textcolor{##888d93}{#1}");
p("\\grayG", "\\textcolor{##626569}{#1}");
p("\\grayH", "\\textcolor{##3b3e40}{#1}");
p("\\grayI", "\\textcolor{##21242c}{#1}");
p("\\kaBlue", "\\textcolor{##314453}{#1}");
p("\\kaGreen", "\\textcolor{##71B307}{#1}");
var ku = {
  "^": !0,
  // Parser.js
  _: !0,
  // Parser.js
  "\\limits": !0,
  // Parser.js
  "\\nolimits": !0
  // Parser.js
};
class j4 {
  constructor(e, t, r) {
    this.settings = void 0, this.expansionCount = void 0, this.lexer = void 0, this.macros = void 0, this.stack = void 0, this.mode = void 0, this.settings = t, this.expansionCount = 0, this.feed(e), this.macros = new X4(Y4, t.macros), this.mode = r, this.stack = [];
  }
  /**
   * Feed a new input string to the same MacroExpander
   * (with existing macros etc.).
   */
  feed(e) {
    this.lexer = new Ol(e, this.settings);
  }
  /**
   * Switches between "text" and "math" modes.
   */
  switchMode(e) {
    this.mode = e;
  }
  /**
   * Start a new group nesting within all namespaces.
   */
  beginGroup() {
    this.macros.beginGroup();
  }
  /**
   * End current group nesting within all namespaces.
   */
  endGroup() {
    this.macros.endGroup();
  }
  /**
   * Ends all currently nested groups (if any), restoring values before the
   * groups began.  Useful in case of an error in the middle of parsing.
   */
  endGroups() {
    this.macros.endGroups();
  }
  /**
   * Returns the topmost token on the stack, without expanding it.
   * Similar in behavior to TeX's `\futurelet`.
   */
  future() {
    return this.stack.length === 0 && this.pushToken(this.lexer.lex()), this.stack[this.stack.length - 1];
  }
  /**
   * Remove and return the next unexpanded token.
   */
  popToken() {
    return this.future(), this.stack.pop();
  }
  /**
   * Add a given token to the token stack.  In particular, this get be used
   * to put back a token returned from one of the other methods.
   */
  pushToken(e) {
    this.stack.push(e);
  }
  /**
   * Append an array of tokens to the token stack.
   */
  pushTokens(e) {
    this.stack.push(...e);
  }
  /**
   * Find an macro argument without expanding tokens and append the array of
   * tokens to the token stack. Uses Token as a container for the result.
   */
  scanArgument(e) {
    var t, r, a;
    if (e) {
      if (this.consumeSpaces(), this.future().text !== "[")
        return null;
      t = this.popToken(), {
        tokens: a,
        end: r
      } = this.consumeArg(["]"]);
    } else
      ({
        tokens: a,
        start: t,
        end: r
      } = this.consumeArg());
    return this.pushToken(new mt("EOF", r.loc)), this.pushTokens(a), t.range(r, "");
  }
  /**
   * Consume all following space tokens, without expansion.
   */
  consumeSpaces() {
    for (; ; ) {
      var e = this.future();
      if (e.text === " ")
        this.stack.pop();
      else
        break;
    }
  }
  /**
   * Consume an argument from the token stream, and return the resulting array
   * of tokens and start/end token.
   */
  consumeArg(e) {
    var t = [], r = e && e.length > 0;
    r || this.consumeSpaces();
    var a = this.future(), i, l = 0, s = 0;
    do {
      if (i = this.popToken(), t.push(i), i.text === "{")
        ++l;
      else if (i.text === "}") {
        if (--l, l === -1)
          throw new L("Extra }", i);
      } else if (i.text === "EOF")
        throw new L("Unexpected end of input in a macro argument, expected '" + (e && r ? e[s] : "}") + "'", i);
      if (e && r)
        if ((l === 0 || l === 1 && e[s] === "{") && i.text === e[s]) {
          if (++s, s === e.length) {
            t.splice(-s, s);
            break;
          }
        } else
          s = 0;
    } while (l !== 0 || r);
    return a.text === "{" && t[t.length - 1].text === "}" && (t.pop(), t.shift()), t.reverse(), {
      tokens: t,
      start: a,
      end: i
    };
  }
  /**
   * Consume the specified number of (delimited) arguments from the token
   * stream and return the resulting array of arguments.
   */
  consumeArgs(e, t) {
    if (t) {
      if (t.length !== e + 1)
        throw new L("The length of delimiters doesn't match the number of args!");
      for (var r = t[0], a = 0; a < r.length; a++) {
        var i = this.popToken();
        if (r[a] !== i.text)
          throw new L("Use of the macro doesn't match its definition", i);
      }
    }
    for (var l = [], s = 0; s < e; s++)
      l.push(this.consumeArg(t && t[s + 1]).tokens);
    return l;
  }
  /**
   * Increment `expansionCount` by the specified amount.
   * Throw an error if it exceeds `maxExpand`.
   */
  countExpansion(e) {
    if (this.expansionCount += e, this.expansionCount > this.settings.maxExpand)
      throw new L("Too many expansions: infinite loop or need to increase maxExpand setting");
  }
  /**
   * Expand the next token only once if possible.
   *
   * If the token is expanded, the resulting tokens will be pushed onto
   * the stack in reverse order, and the number of such tokens will be
   * returned.  This number might be zero or positive.
   *
   * If not, the return value is `false`, and the next token remains at the
   * top of the stack.
   *
   * In either case, the next token will be on the top of the stack,
   * or the stack will be empty (in case of empty expansion
   * and no other tokens).
   *
   * Used to implement `expandAfterFuture` and `expandNextToken`.
   *
   * If expandableOnly, only expandable tokens are expanded and
   * an undefined control sequence results in an error.
   */
  expandOnce(e) {
    var t = this.popToken(), r = t.text, a = t.noexpand ? null : this._getExpansion(r);
    if (a == null || e && a.unexpandable) {
      if (e && a == null && r[0] === "\\" && !this.isDefined(r))
        throw new L("Undefined control sequence: " + r);
      return this.pushToken(t), !1;
    }
    this.countExpansion(1);
    var i = a.tokens, l = this.consumeArgs(a.numArgs, a.delimiters);
    if (a.numArgs) {
      i = i.slice();
      for (var s = i.length - 1; s >= 0; --s) {
        var o = i[s];
        if (o.text === "#") {
          if (s === 0)
            throw new L("Incomplete placeholder at end of macro body", o);
          if (o = i[--s], o.text === "#")
            i.splice(s + 1, 1);
          else if (/^[1-9]$/.test(o.text))
            i.splice(s, 2, ...l[+o.text - 1]);
          else
            throw new L("Not a valid argument number", o);
        }
      }
    }
    return this.pushTokens(i), i.length;
  }
  /**
   * Expand the next token only once (if possible), and return the resulting
   * top token on the stack (without removing anything from the stack).
   * Similar in behavior to TeX's `\expandafter\futurelet`.
   * Equivalent to expandOnce() followed by future().
   */
  expandAfterFuture() {
    return this.expandOnce(), this.future();
  }
  /**
   * Recursively expand first token, then return first non-expandable token.
   */
  expandNextToken() {
    for (; ; )
      if (this.expandOnce() === !1) {
        var e = this.stack.pop();
        return e.treatAsRelax && (e.text = "\\relax"), e;
      }
    throw new Error();
  }
  /**
   * Fully expand the given macro name and return the resulting list of
   * tokens, or return `undefined` if no such macro is defined.
   */
  expandMacro(e) {
    return this.macros.has(e) ? this.expandTokens([new mt(e)]) : void 0;
  }
  /**
   * Fully expand the given token stream and return the resulting list of
   * tokens.  Note that the input tokens are in reverse order, but the
   * output tokens are in forward order.
   */
  expandTokens(e) {
    var t = [], r = this.stack.length;
    for (this.pushTokens(e); this.stack.length > r; )
      if (this.expandOnce(!0) === !1) {
        var a = this.stack.pop();
        a.treatAsRelax && (a.noexpand = !1, a.treatAsRelax = !1), t.push(a);
      }
    return this.countExpansion(t.length), t;
  }
  /**
   * Fully expand the given macro name and return the result as a string,
   * or return `undefined` if no such macro is defined.
   */
  expandMacroAsText(e) {
    var t = this.expandMacro(e);
    return t && t.map((r) => r.text).join("");
  }
  /**
   * Returns the expanded macro as a reversed array of tokens and a macro
   * argument count.  Or returns `null` if no such macro.
   */
  _getExpansion(e) {
    var t = this.macros.get(e);
    if (t == null)
      return t;
    if (e.length === 1) {
      var r = this.lexer.catcodes[e];
      if (r != null && r !== 13)
        return;
    }
    var a = typeof t == "function" ? t(this) : t;
    if (typeof a == "string") {
      var i = 0;
      if (a.indexOf("#") !== -1)
        for (var l = a.replace(/##/g, ""); l.indexOf("#" + (i + 1)) !== -1; )
          ++i;
      for (var s = new Ol(a, this.settings), o = [], c = s.lex(); c.text !== "EOF"; )
        o.push(c), c = s.lex();
      o.reverse();
      var f = {
        tokens: o,
        numArgs: i
      };
      return f;
    }
    return a;
  }
  /**
   * Determine whether a command is currently "defined" (has some
   * functionality), meaning that it's a macro (in the current group),
   * a function, a symbol, or one of the special commands listed in
   * `implicitCommands`.
   */
  isDefined(e) {
    return this.macros.has(e) || w0.hasOwnProperty(e) || de.math.hasOwnProperty(e) || de.text.hasOwnProperty(e) || ku.hasOwnProperty(e);
  }
  /**
   * Determine whether a command is expandable.
   */
  isExpandable(e) {
    var t = this.macros.get(e);
    return t != null ? typeof t == "string" || typeof t == "function" || !t.unexpandable : w0.hasOwnProperty(e) && !w0[e].primitive;
  }
}
var Hl = /^[₊₋₌₍₎₀₁₂₃₄₅₆₇₈₉ₐₑₕᵢⱼₖₗₘₙₒₚᵣₛₜᵤᵥₓᵦᵧᵨᵩᵪ]/, Kr = Object.freeze({
  "₊": "+",
  "₋": "-",
  "₌": "=",
  "₍": "(",
  "₎": ")",
  "₀": "0",
  "₁": "1",
  "₂": "2",
  "₃": "3",
  "₄": "4",
  "₅": "5",
  "₆": "6",
  "₇": "7",
  "₈": "8",
  "₉": "9",
  "ₐ": "a",
  "ₑ": "e",
  "ₕ": "h",
  "ᵢ": "i",
  "ⱼ": "j",
  "ₖ": "k",
  "ₗ": "l",
  "ₘ": "m",
  "ₙ": "n",
  "ₒ": "o",
  "ₚ": "p",
  "ᵣ": "r",
  "ₛ": "s",
  "ₜ": "t",
  "ᵤ": "u",
  "ᵥ": "v",
  "ₓ": "x",
  "ᵦ": "β",
  "ᵧ": "γ",
  "ᵨ": "ρ",
  "ᵩ": "ϕ",
  "ᵪ": "χ",
  "⁺": "+",
  "⁻": "-",
  "⁼": "=",
  "⁽": "(",
  "⁾": ")",
  "⁰": "0",
  "¹": "1",
  "²": "2",
  "³": "3",
  "⁴": "4",
  "⁵": "5",
  "⁶": "6",
  "⁷": "7",
  "⁸": "8",
  "⁹": "9",
  "ᴬ": "A",
  "ᴮ": "B",
  "ᴰ": "D",
  "ᴱ": "E",
  "ᴳ": "G",
  "ᴴ": "H",
  "ᴵ": "I",
  "ᴶ": "J",
  "ᴷ": "K",
  "ᴸ": "L",
  "ᴹ": "M",
  "ᴺ": "N",
  "ᴼ": "O",
  "ᴾ": "P",
  "ᴿ": "R",
  "ᵀ": "T",
  "ᵁ": "U",
  "ⱽ": "V",
  "ᵂ": "W",
  "ᵃ": "a",
  "ᵇ": "b",
  "ᶜ": "c",
  "ᵈ": "d",
  "ᵉ": "e",
  "ᶠ": "f",
  "ᵍ": "g",
  ʰ: "h",
  "ⁱ": "i",
  ʲ: "j",
  "ᵏ": "k",
  ˡ: "l",
  "ᵐ": "m",
  ⁿ: "n",
  "ᵒ": "o",
  "ᵖ": "p",
  ʳ: "r",
  ˢ: "s",
  "ᵗ": "t",
  "ᵘ": "u",
  "ᵛ": "v",
  ʷ: "w",
  ˣ: "x",
  ʸ: "y",
  "ᶻ": "z",
  "ᵝ": "β",
  "ᵞ": "γ",
  "ᵟ": "δ",
  "ᵠ": "ϕ",
  "ᵡ": "χ",
  "ᶿ": "θ"
}), pa = {
  "́": {
    text: "\\'",
    math: "\\acute"
  },
  "̀": {
    text: "\\`",
    math: "\\grave"
  },
  "̈": {
    text: '\\"',
    math: "\\ddot"
  },
  "̃": {
    text: "\\~",
    math: "\\tilde"
  },
  "̄": {
    text: "\\=",
    math: "\\bar"
  },
  "̆": {
    text: "\\u",
    math: "\\breve"
  },
  "̌": {
    text: "\\v",
    math: "\\check"
  },
  "̂": {
    text: "\\^",
    math: "\\hat"
  },
  "̇": {
    text: "\\.",
    math: "\\dot"
  },
  "̊": {
    text: "\\r",
    math: "\\mathring"
  },
  "̋": {
    text: "\\H"
  },
  "̧": {
    text: "\\c"
  }
}, Ul = {
  á: "á",
  à: "à",
  ä: "ä",
  ǟ: "ǟ",
  ã: "ã",
  ā: "ā",
  ă: "ă",
  ắ: "ắ",
  ằ: "ằ",
  ẵ: "ẵ",
  ǎ: "ǎ",
  â: "â",
  ấ: "ấ",
  ầ: "ầ",
  ẫ: "ẫ",
  ȧ: "ȧ",
  ǡ: "ǡ",
  å: "å",
  ǻ: "ǻ",
  ḃ: "ḃ",
  ć: "ć",
  ḉ: "ḉ",
  č: "č",
  ĉ: "ĉ",
  ċ: "ċ",
  ç: "ç",
  ď: "ď",
  ḋ: "ḋ",
  ḑ: "ḑ",
  é: "é",
  è: "è",
  ë: "ë",
  ẽ: "ẽ",
  ē: "ē",
  ḗ: "ḗ",
  ḕ: "ḕ",
  ĕ: "ĕ",
  ḝ: "ḝ",
  ě: "ě",
  ê: "ê",
  ế: "ế",
  ề: "ề",
  ễ: "ễ",
  ė: "ė",
  ȩ: "ȩ",
  ḟ: "ḟ",
  ǵ: "ǵ",
  ḡ: "ḡ",
  ğ: "ğ",
  ǧ: "ǧ",
  ĝ: "ĝ",
  ġ: "ġ",
  ģ: "ģ",
  ḧ: "ḧ",
  ȟ: "ȟ",
  ĥ: "ĥ",
  ḣ: "ḣ",
  ḩ: "ḩ",
  í: "í",
  ì: "ì",
  ï: "ï",
  ḯ: "ḯ",
  ĩ: "ĩ",
  ī: "ī",
  ĭ: "ĭ",
  ǐ: "ǐ",
  î: "î",
  ǰ: "ǰ",
  ĵ: "ĵ",
  ḱ: "ḱ",
  ǩ: "ǩ",
  ķ: "ķ",
  ĺ: "ĺ",
  ľ: "ľ",
  ļ: "ļ",
  ḿ: "ḿ",
  ṁ: "ṁ",
  ń: "ń",
  ǹ: "ǹ",
  ñ: "ñ",
  ň: "ň",
  ṅ: "ṅ",
  ņ: "ņ",
  ó: "ó",
  ò: "ò",
  ö: "ö",
  ȫ: "ȫ",
  õ: "õ",
  ṍ: "ṍ",
  ṏ: "ṏ",
  ȭ: "ȭ",
  ō: "ō",
  ṓ: "ṓ",
  ṑ: "ṑ",
  ŏ: "ŏ",
  ǒ: "ǒ",
  ô: "ô",
  ố: "ố",
  ồ: "ồ",
  ỗ: "ỗ",
  ȯ: "ȯ",
  ȱ: "ȱ",
  ő: "ő",
  ṕ: "ṕ",
  ṗ: "ṗ",
  ŕ: "ŕ",
  ř: "ř",
  ṙ: "ṙ",
  ŗ: "ŗ",
  ś: "ś",
  ṥ: "ṥ",
  š: "š",
  ṧ: "ṧ",
  ŝ: "ŝ",
  ṡ: "ṡ",
  ş: "ş",
  ẗ: "ẗ",
  ť: "ť",
  ṫ: "ṫ",
  ţ: "ţ",
  ú: "ú",
  ù: "ù",
  ü: "ü",
  ǘ: "ǘ",
  ǜ: "ǜ",
  ǖ: "ǖ",
  ǚ: "ǚ",
  ũ: "ũ",
  ṹ: "ṹ",
  ū: "ū",
  ṻ: "ṻ",
  ŭ: "ŭ",
  ǔ: "ǔ",
  û: "û",
  ů: "ů",
  ű: "ű",
  ṽ: "ṽ",
  ẃ: "ẃ",
  ẁ: "ẁ",
  ẅ: "ẅ",
  ŵ: "ŵ",
  ẇ: "ẇ",
  ẘ: "ẘ",
  ẍ: "ẍ",
  ẋ: "ẋ",
  ý: "ý",
  ỳ: "ỳ",
  ÿ: "ÿ",
  ỹ: "ỹ",
  ȳ: "ȳ",
  ŷ: "ŷ",
  ẏ: "ẏ",
  ẙ: "ẙ",
  ź: "ź",
  ž: "ž",
  ẑ: "ẑ",
  ż: "ż",
  Á: "Á",
  À: "À",
  Ä: "Ä",
  Ǟ: "Ǟ",
  Ã: "Ã",
  Ā: "Ā",
  Ă: "Ă",
  Ắ: "Ắ",
  Ằ: "Ằ",
  Ẵ: "Ẵ",
  Ǎ: "Ǎ",
  Â: "Â",
  Ấ: "Ấ",
  Ầ: "Ầ",
  Ẫ: "Ẫ",
  Ȧ: "Ȧ",
  Ǡ: "Ǡ",
  Å: "Å",
  Ǻ: "Ǻ",
  Ḃ: "Ḃ",
  Ć: "Ć",
  Ḉ: "Ḉ",
  Č: "Č",
  Ĉ: "Ĉ",
  Ċ: "Ċ",
  Ç: "Ç",
  Ď: "Ď",
  Ḋ: "Ḋ",
  Ḑ: "Ḑ",
  É: "É",
  È: "È",
  Ë: "Ë",
  Ẽ: "Ẽ",
  Ē: "Ē",
  Ḗ: "Ḗ",
  Ḕ: "Ḕ",
  Ĕ: "Ĕ",
  Ḝ: "Ḝ",
  Ě: "Ě",
  Ê: "Ê",
  Ế: "Ế",
  Ề: "Ề",
  Ễ: "Ễ",
  Ė: "Ė",
  Ȩ: "Ȩ",
  Ḟ: "Ḟ",
  Ǵ: "Ǵ",
  Ḡ: "Ḡ",
  Ğ: "Ğ",
  Ǧ: "Ǧ",
  Ĝ: "Ĝ",
  Ġ: "Ġ",
  Ģ: "Ģ",
  Ḧ: "Ḧ",
  Ȟ: "Ȟ",
  Ĥ: "Ĥ",
  Ḣ: "Ḣ",
  Ḩ: "Ḩ",
  Í: "Í",
  Ì: "Ì",
  Ï: "Ï",
  Ḯ: "Ḯ",
  Ĩ: "Ĩ",
  Ī: "Ī",
  Ĭ: "Ĭ",
  Ǐ: "Ǐ",
  Î: "Î",
  İ: "İ",
  Ĵ: "Ĵ",
  Ḱ: "Ḱ",
  Ǩ: "Ǩ",
  Ķ: "Ķ",
  Ĺ: "Ĺ",
  Ľ: "Ľ",
  Ļ: "Ļ",
  Ḿ: "Ḿ",
  Ṁ: "Ṁ",
  Ń: "Ń",
  Ǹ: "Ǹ",
  Ñ: "Ñ",
  Ň: "Ň",
  Ṅ: "Ṅ",
  Ņ: "Ņ",
  Ó: "Ó",
  Ò: "Ò",
  Ö: "Ö",
  Ȫ: "Ȫ",
  Õ: "Õ",
  Ṍ: "Ṍ",
  Ṏ: "Ṏ",
  Ȭ: "Ȭ",
  Ō: "Ō",
  Ṓ: "Ṓ",
  Ṑ: "Ṑ",
  Ŏ: "Ŏ",
  Ǒ: "Ǒ",
  Ô: "Ô",
  Ố: "Ố",
  Ồ: "Ồ",
  Ỗ: "Ỗ",
  Ȯ: "Ȯ",
  Ȱ: "Ȱ",
  Ő: "Ő",
  Ṕ: "Ṕ",
  Ṗ: "Ṗ",
  Ŕ: "Ŕ",
  Ř: "Ř",
  Ṙ: "Ṙ",
  Ŗ: "Ŗ",
  Ś: "Ś",
  Ṥ: "Ṥ",
  Š: "Š",
  Ṧ: "Ṧ",
  Ŝ: "Ŝ",
  Ṡ: "Ṡ",
  Ş: "Ş",
  Ť: "Ť",
  Ṫ: "Ṫ",
  Ţ: "Ţ",
  Ú: "Ú",
  Ù: "Ù",
  Ü: "Ü",
  Ǘ: "Ǘ",
  Ǜ: "Ǜ",
  Ǖ: "Ǖ",
  Ǚ: "Ǚ",
  Ũ: "Ũ",
  Ṹ: "Ṹ",
  Ū: "Ū",
  Ṻ: "Ṻ",
  Ŭ: "Ŭ",
  Ǔ: "Ǔ",
  Û: "Û",
  Ů: "Ů",
  Ű: "Ű",
  Ṽ: "Ṽ",
  Ẃ: "Ẃ",
  Ẁ: "Ẁ",
  Ẅ: "Ẅ",
  Ŵ: "Ŵ",
  Ẇ: "Ẇ",
  Ẍ: "Ẍ",
  Ẋ: "Ẋ",
  Ý: "Ý",
  Ỳ: "Ỳ",
  Ÿ: "Ÿ",
  Ỹ: "Ỹ",
  Ȳ: "Ȳ",
  Ŷ: "Ŷ",
  Ẏ: "Ẏ",
  Ź: "Ź",
  Ž: "Ž",
  Ẑ: "Ẑ",
  Ż: "Ż",
  ά: "ά",
  ὰ: "ὰ",
  ᾱ: "ᾱ",
  ᾰ: "ᾰ",
  έ: "έ",
  ὲ: "ὲ",
  ή: "ή",
  ὴ: "ὴ",
  ί: "ί",
  ὶ: "ὶ",
  ϊ: "ϊ",
  ΐ: "ΐ",
  ῒ: "ῒ",
  ῑ: "ῑ",
  ῐ: "ῐ",
  ό: "ό",
  ὸ: "ὸ",
  ύ: "ύ",
  ὺ: "ὺ",
  ϋ: "ϋ",
  ΰ: "ΰ",
  ῢ: "ῢ",
  ῡ: "ῡ",
  ῠ: "ῠ",
  ώ: "ώ",
  ὼ: "ὼ",
  Ύ: "Ύ",
  Ὺ: "Ὺ",
  Ϋ: "Ϋ",
  Ῡ: "Ῡ",
  Ῠ: "Ῠ",
  Ώ: "Ώ",
  Ὼ: "Ὼ"
};
class Hn {
  constructor(e, t) {
    this.mode = void 0, this.gullet = void 0, this.settings = void 0, this.leftrightDepth = void 0, this.nextToken = void 0, this.mode = "math", this.gullet = new j4(e, t, this.mode), this.settings = t, this.leftrightDepth = 0;
  }
  /**
   * Checks a result to make sure it has the right type, and throws an
   * appropriate error otherwise.
   */
  expect(e, t) {
    if (t === void 0 && (t = !0), this.fetch().text !== e)
      throw new L("Expected '" + e + "', got '" + this.fetch().text + "'", this.fetch());
    t && this.consume();
  }
  /**
   * Discards the current lookahead token, considering it consumed.
   */
  consume() {
    this.nextToken = null;
  }
  /**
   * Return the current lookahead token, or if there isn't one (at the
   * beginning, or if the previous lookahead token was consume()d),
   * fetch the next token as the new lookahead token and return it.
   */
  fetch() {
    return this.nextToken == null && (this.nextToken = this.gullet.expandNextToken()), this.nextToken;
  }
  /**
   * Switches between "text" and "math" modes.
   */
  switchMode(e) {
    this.mode = e, this.gullet.switchMode(e);
  }
  /**
   * Main parsing function, which parses an entire input.
   */
  parse() {
    this.settings.globalGroup || this.gullet.beginGroup(), this.settings.colorIsTextColor && this.gullet.macros.set("\\color", "\\textcolor");
    try {
      var e = this.parseExpression(!1);
      return this.expect("EOF"), this.settings.globalGroup || this.gullet.endGroup(), e;
    } finally {
      this.gullet.endGroups();
    }
  }
  /**
   * Fully parse a separate sequence of tokens as a separate job.
   * Tokens should be specified in reverse order, as in a MacroDefinition.
   */
  subparse(e) {
    var t = this.nextToken;
    this.consume(), this.gullet.pushToken(new mt("}")), this.gullet.pushTokens(e);
    var r = this.parseExpression(!1);
    return this.expect("}"), this.nextToken = t, r;
  }
  /**
   * Parses an "expression", which is a list of atoms.
   *
   * `breakOnInfix`: Should the parsing stop when we hit infix nodes? This
   *                 happens when functions have higher precedence han infix
   *                 nodes in implicit parses.
   *
   * `breakOnTokenText`: The text of the token that the expression should end
   *                     with, or `null` if something else should end the
   *                     expression.
   */
  parseExpression(e, t) {
    for (var r = []; ; ) {
      this.mode === "math" && this.consumeSpaces();
      var a = this.fetch();
      if (Hn.endOfExpression.indexOf(a.text) !== -1 || t && a.text === t || e && w0[a.text] && w0[a.text].infix)
        break;
      var i = this.parseAtom(t);
      if (i) {
        if (i.type === "internal")
          continue;
      } else break;
      r.push(i);
    }
    return this.mode === "text" && this.formLigatures(r), this.handleInfixNodes(r);
  }
  /**
   * Rewrites infix operators such as \over with corresponding commands such
   * as \frac.
   *
   * There can only be one infix operator per group.  If there's more than one
   * then the expression is ambiguous.  This can be resolved by adding {}.
   */
  handleInfixNodes(e) {
    for (var t = -1, r, a = 0; a < e.length; a++)
      if (e[a].type === "infix") {
        if (t !== -1)
          throw new L("only one infix operator per group", e[a].token);
        t = a, r = e[a].replaceWith;
      }
    if (t !== -1 && r) {
      var i, l, s = e.slice(0, t), o = e.slice(t + 1);
      s.length === 1 && s[0].type === "ordgroup" ? i = s[0] : i = {
        type: "ordgroup",
        mode: this.mode,
        body: s
      }, o.length === 1 && o[0].type === "ordgroup" ? l = o[0] : l = {
        type: "ordgroup",
        mode: this.mode,
        body: o
      };
      var c;
      return r === "\\\\abovefrac" ? c = this.callFunction(r, [i, e[t], l], []) : c = this.callFunction(r, [i, l], []), [c];
    } else
      return e;
  }
  /**
   * Handle a subscript or superscript with nice errors.
   */
  handleSupSubscript(e) {
    var t = this.fetch(), r = t.text;
    this.consume(), this.consumeSpaces();
    var a = this.parseGroup(e);
    if (!a)
      throw new L("Expected group after '" + r + "'", t);
    return a;
  }
  /**
   * Converts the textual input of an unsupported command into a text node
   * contained within a color node whose color is determined by errorColor
   */
  formatUnsupportedCmd(e) {
    for (var t = [], r = 0; r < e.length; r++)
      t.push({
        type: "textord",
        mode: "text",
        text: e[r]
      });
    var a = {
      type: "text",
      mode: this.mode,
      body: t
    }, i = {
      type: "color",
      mode: this.mode,
      color: this.settings.errorColor,
      body: [a]
    };
    return i;
  }
  /**
   * Parses a group with optional super/subscripts.
   */
  parseAtom(e) {
    var t = this.parseGroup("atom", e);
    if (this.mode === "text")
      return t;
    for (var r, a; ; ) {
      this.consumeSpaces();
      var i = this.fetch();
      if (i.text === "\\limits" || i.text === "\\nolimits") {
        if (t && t.type === "op") {
          var l = i.text === "\\limits";
          t.limits = l, t.alwaysHandleSupSub = !0;
        } else if (t && t.type === "operatorname")
          t.alwaysHandleSupSub && (t.limits = i.text === "\\limits");
        else
          throw new L("Limit controls must follow a math operator", i);
        this.consume();
      } else if (i.text === "^") {
        if (r)
          throw new L("Double superscript", i);
        r = this.handleSupSubscript("superscript");
      } else if (i.text === "_") {
        if (a)
          throw new L("Double subscript", i);
        a = this.handleSupSubscript("subscript");
      } else if (i.text === "'") {
        if (r)
          throw new L("Double superscript", i);
        var s = {
          type: "textord",
          mode: this.mode,
          text: "\\prime"
        }, o = [s];
        for (this.consume(); this.fetch().text === "'"; )
          o.push(s), this.consume();
        this.fetch().text === "^" && o.push(this.handleSupSubscript("superscript")), r = {
          type: "ordgroup",
          mode: this.mode,
          body: o
        };
      } else if (Kr[i.text]) {
        var c = Hl.test(i.text), f = [];
        for (f.push(new mt(Kr[i.text])), this.consume(); ; ) {
          var d = this.fetch().text;
          if (!Kr[d] || Hl.test(d) !== c)
            break;
          f.unshift(new mt(Kr[d])), this.consume();
        }
        var g = this.subparse(f);
        c ? a = {
          type: "ordgroup",
          mode: "math",
          body: g
        } : r = {
          type: "ordgroup",
          mode: "math",
          body: g
        };
      } else
        break;
    }
    return r || a ? {
      type: "supsub",
      mode: this.mode,
      base: t,
      sup: r,
      sub: a
    } : t;
  }
  /**
   * Parses an entire function, including its base and all of its arguments.
   */
  parseFunction(e, t) {
    var r = this.fetch(), a = r.text, i = w0[a];
    if (!i)
      return null;
    if (this.consume(), t && t !== "atom" && !i.allowedInArgument)
      throw new L("Got function '" + a + "' with no arguments" + (t ? " as " + t : ""), r);
    if (this.mode === "text" && !i.allowedInText)
      throw new L("Can't use function '" + a + "' in text mode", r);
    if (this.mode === "math" && i.allowedInMath === !1)
      throw new L("Can't use function '" + a + "' in math mode", r);
    var {
      args: l,
      optArgs: s
    } = this.parseArguments(a, i);
    return this.callFunction(a, l, s, r, e);
  }
  /**
   * Call a function handler with a suitable context and arguments.
   */
  callFunction(e, t, r, a, i) {
    var l = {
      funcName: e,
      parser: this,
      token: a,
      breakOnTokenText: i
    }, s = w0[e];
    if (s && s.handler)
      return s.handler(l, t, r);
    throw new L("No function handler for " + e);
  }
  /**
   * Parses the arguments of a function or environment
   */
  parseArguments(e, t) {
    var r = t.numArgs + t.numOptionalArgs;
    if (r === 0)
      return {
        args: [],
        optArgs: []
      };
    for (var a = [], i = [], l = 0; l < r; l++) {
      var s = t.argTypes && t.argTypes[l], o = l < t.numOptionalArgs;
      (t.primitive && s == null || // \sqrt expands into primitive if optional argument doesn't exist
      t.type === "sqrt" && l === 1 && i[0] == null) && (s = "primitive");
      var c = this.parseGroupOfType("argument to '" + e + "'", s, o);
      if (o)
        i.push(c);
      else if (c != null)
        a.push(c);
      else
        throw new L("Null argument, please report this as a bug");
    }
    return {
      args: a,
      optArgs: i
    };
  }
  /**
   * Parses a group when the mode is changing.
   */
  parseGroupOfType(e, t, r) {
    switch (t) {
      case "color":
        return this.parseColorGroup(r);
      case "size":
        return this.parseSizeGroup(r);
      case "url":
        return this.parseUrlGroup(r);
      case "math":
      case "text":
        return this.parseArgumentGroup(r, t);
      case "hbox": {
        var a = this.parseArgumentGroup(r, "text");
        return a != null ? {
          type: "styling",
          mode: a.mode,
          body: [a],
          style: "text"
          // simulate \textstyle
        } : null;
      }
      case "raw": {
        var i = this.parseStringGroup("raw", r);
        return i != null ? {
          type: "raw",
          mode: "text",
          string: i.text
        } : null;
      }
      case "primitive": {
        if (r)
          throw new L("A primitive argument cannot be optional");
        var l = this.parseGroup(e);
        if (l == null)
          throw new L("Expected group as " + e, this.fetch());
        return l;
      }
      case "original":
      case null:
      case void 0:
        return this.parseArgumentGroup(r);
      default:
        throw new L("Unknown group type as " + e, this.fetch());
    }
  }
  /**
   * Discard any space tokens, fetching the next non-space token.
   */
  consumeSpaces() {
    for (; this.fetch().text === " "; )
      this.consume();
  }
  /**
   * Parses a group, essentially returning the string formed by the
   * brace-enclosed tokens plus some position information.
   */
  parseStringGroup(e, t) {
    var r = this.gullet.scanArgument(t);
    if (r == null)
      return null;
    for (var a = "", i; (i = this.fetch()).text !== "EOF"; )
      a += i.text, this.consume();
    return this.consume(), r.text = a, r;
  }
  /**
   * Parses a regex-delimited group: the largest sequence of tokens
   * whose concatenated strings match `regex`. Returns the string
   * formed by the tokens plus some position information.
   */
  parseRegexGroup(e, t) {
    for (var r = this.fetch(), a = r, i = "", l; (l = this.fetch()).text !== "EOF" && e.test(i + l.text); )
      a = l, i += a.text, this.consume();
    if (i === "")
      throw new L("Invalid " + t + ": '" + r.text + "'", r);
    return r.range(a, i);
  }
  /**
   * Parses a color description.
   */
  parseColorGroup(e) {
    var t = this.parseStringGroup("color", e);
    if (t == null)
      return null;
    var r = /^(#[a-f0-9]{3}|#?[a-f0-9]{6}|[a-z]+)$/i.exec(t.text);
    if (!r)
      throw new L("Invalid color: '" + t.text + "'", t);
    var a = r[0];
    return /^[0-9a-f]{6}$/i.test(a) && (a = "#" + a), {
      type: "color-token",
      mode: this.mode,
      color: a
    };
  }
  /**
   * Parses a size specification, consisting of magnitude and unit.
   */
  parseSizeGroup(e) {
    var t, r = !1;
    if (this.gullet.consumeSpaces(), !e && this.gullet.future().text !== "{" ? t = this.parseRegexGroup(/^[-+]? *(?:$|\d+|\d+\.\d*|\.\d*) *[a-z]{0,2} *$/, "size") : t = this.parseStringGroup("size", e), !t)
      return null;
    !e && t.text.length === 0 && (t.text = "0pt", r = !0);
    var a = /([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(t.text);
    if (!a)
      throw new L("Invalid size: '" + t.text + "'", t);
    var i = {
      number: +(a[1] + a[2]),
      // sign + magnitude, cast to number
      unit: a[3]
    };
    if (!Mo(i))
      throw new L("Invalid unit: '" + i.unit + "'", t);
    return {
      type: "size",
      mode: this.mode,
      value: i,
      isBlank: r
    };
  }
  /**
   * Parses an URL, checking escaped letters and allowed protocols,
   * and setting the catcode of % as an active character (as in \hyperref).
   */
  parseUrlGroup(e) {
    this.gullet.lexer.setCatcode("%", 13), this.gullet.lexer.setCatcode("~", 12);
    var t = this.parseStringGroup("url", e);
    if (this.gullet.lexer.setCatcode("%", 14), this.gullet.lexer.setCatcode("~", 13), t == null)
      return null;
    var r = t.text.replace(/\\([#$%&~_^{}])/g, "$1");
    return {
      type: "url",
      mode: this.mode,
      url: r
    };
  }
  /**
   * Parses an argument with the mode specified.
   */
  parseArgumentGroup(e, t) {
    var r = this.gullet.scanArgument(e);
    if (r == null)
      return null;
    var a = this.mode;
    t && this.switchMode(t), this.gullet.beginGroup();
    var i = this.parseExpression(!1, "EOF");
    this.expect("EOF"), this.gullet.endGroup();
    var l = {
      type: "ordgroup",
      mode: this.mode,
      loc: r.loc,
      body: i
    };
    return t && this.switchMode(a), l;
  }
  /**
   * Parses an ordinary group, which is either a single nucleus (like "x")
   * or an expression in braces (like "{x+y}") or an implicit group, a group
   * that starts at the current position, and ends right before a higher explicit
   * group ends, or at EOF.
   */
  parseGroup(e, t) {
    var r = this.fetch(), a = r.text, i;
    if (a === "{" || a === "\\begingroup") {
      this.consume();
      var l = a === "{" ? "}" : "\\endgroup";
      this.gullet.beginGroup();
      var s = this.parseExpression(!1, l), o = this.fetch();
      this.expect(l), this.gullet.endGroup(), i = {
        type: "ordgroup",
        mode: this.mode,
        loc: nt.range(r, o),
        body: s,
        // A group formed by \begingroup...\endgroup is a semi-simple group
        // which doesn't affect spacing in math mode, i.e., is transparent.
        // https://tex.stackexchange.com/questions/1930/when-should-one-
        // use-begingroup-instead-of-bgroup
        semisimple: a === "\\begingroup" || void 0
      };
    } else if (i = this.parseFunction(t, e) || this.parseSymbol(), i == null && a[0] === "\\" && !ku.hasOwnProperty(a)) {
      if (this.settings.throwOnError)
        throw new L("Undefined control sequence: " + a, r);
      i = this.formatUnsupportedCmd(a), this.consume();
    }
    return i;
  }
  /**
   * Form ligature-like combinations of characters for text mode.
   * This includes inputs like "--", "---", "``" and "''".
   * The result will simply replace multiple textord nodes with a single
   * character in each value by a single textord node having multiple
   * characters in its value.  The representation is still ASCII source.
   * The group will be modified in place.
   */
  formLigatures(e) {
    for (var t = e.length - 1, r = 0; r < t; ++r) {
      var a = e[r], i = a.text;
      i === "-" && e[r + 1].text === "-" && (r + 1 < t && e[r + 2].text === "-" ? (e.splice(r, 3, {
        type: "textord",
        mode: "text",
        loc: nt.range(a, e[r + 2]),
        text: "---"
      }), t -= 2) : (e.splice(r, 2, {
        type: "textord",
        mode: "text",
        loc: nt.range(a, e[r + 1]),
        text: "--"
      }), t -= 1)), (i === "'" || i === "`") && e[r + 1].text === i && (e.splice(r, 2, {
        type: "textord",
        mode: "text",
        loc: nt.range(a, e[r + 1]),
        text: i + i
      }), t -= 1);
    }
  }
  /**
   * Parse a single symbol out of the string. Here, we handle single character
   * symbols and special functions like \verb.
   */
  parseSymbol() {
    var e = this.fetch(), t = e.text;
    if (/^\\verb[^a-zA-Z]/.test(t)) {
      this.consume();
      var r = t.slice(5), a = r.charAt(0) === "*";
      if (a && (r = r.slice(1)), r.length < 2 || r.charAt(0) !== r.slice(-1))
        throw new L(`\\verb assertion failed --
                    please report what input caused this bug`);
      return r = r.slice(1, -1), {
        type: "verb",
        mode: "text",
        body: r,
        star: a
      };
    }
    Ul.hasOwnProperty(t[0]) && !de[this.mode][t[0]] && (this.settings.strict && this.mode === "math" && this.settings.reportNonstrict("unicodeTextInMathMode", 'Accented Unicode text character "' + t[0] + '" used in math mode', e), t = Ul[t[0]] + t.slice(1));
    var i = V4.exec(t);
    i && (t = t.substring(0, i.index), t === "i" ? t = "ı" : t === "j" && (t = "ȷ"));
    var l;
    if (de[this.mode][t]) {
      this.settings.strict && this.mode === "math" && Ua.indexOf(t) >= 0 && this.settings.reportNonstrict("unicodeTextInMathMode", 'Latin-1/Unicode text character "' + t[0] + '" used in math mode', e);
      var s = de[this.mode][t].group, o = nt.range(e), c;
      if (Ic.hasOwnProperty(s)) {
        var f = s;
        c = {
          type: "atom",
          mode: this.mode,
          family: f,
          loc: o,
          text: t
        };
      } else
        c = {
          type: s,
          mode: this.mode,
          loc: o,
          text: t
        };
      l = c;
    } else if (t.charCodeAt(0) >= 128)
      this.settings.strict && (Co(t.charCodeAt(0)) ? this.mode === "math" && this.settings.reportNonstrict("unicodeTextInMathMode", 'Unicode text character "' + t[0] + '" used in math mode', e) : this.settings.reportNonstrict("unknownSymbol", 'Unrecognized Unicode character "' + t[0] + '"' + (" (" + t.charCodeAt(0) + ")"), e)), l = {
        type: "textord",
        mode: "text",
        loc: nt.range(e),
        text: t
      };
    else
      return null;
    if (this.consume(), i)
      for (var d = 0; d < i[0].length; d++) {
        var g = i[0][d];
        if (!pa[g])
          throw new L("Unknown accent ' " + g + "'", e);
        var v = pa[g][this.mode] || pa[g].text;
        if (!v)
          throw new L("Accent " + g + " unsupported in " + this.mode + " mode", e);
        l = {
          type: "accent",
          mode: this.mode,
          loc: nt.range(e),
          label: v,
          isStretchy: !1,
          isShifty: !0,
          // $FlowFixMe
          base: l
        };
      }
    return l;
  }
}
Hn.endOfExpression = ["}", "\\endgroup", "\\end", "\\right", "&"];
var Ei = function(e, t) {
  if (!(typeof e == "string" || e instanceof String))
    throw new TypeError("KaTeX can only parse string typed expression");
  var r = new Hn(e, t);
  delete r.gullet.macros.current["\\df@tag"];
  var a = r.parse();
  if (delete r.gullet.macros.current["\\current@color"], delete r.gullet.macros.current["\\color"], r.gullet.macros.get("\\df@tag")) {
    if (!t.displayMode)
      throw new L("\\tag works only in display equations");
    a = [{
      type: "tag",
      mode: "text",
      body: a,
      tag: r.subparse([new mt("\\df@tag")])
    }];
  }
  return a;
}, _u = function(e, t, r) {
  t.textContent = "";
  var a = Fi(e, r).toNode();
  t.appendChild(a);
};
typeof document < "u" && document.compatMode !== "CSS1Compat" && (typeof console < "u" && console.warn("Warning: KaTeX doesn't work in quirks mode. Make sure your website has a suitable doctype."), _u = function() {
  throw new L("KaTeX doesn't work in quirks mode.");
});
var Z4 = function(e, t) {
  var r = Fi(e, t).toMarkup();
  return r;
}, K4 = function(e, t) {
  var r = new ui(t);
  return Ei(e, r);
}, Du = function(e, t, r) {
  if (r.throwOnError || !(e instanceof L))
    throw e;
  var a = C.makeSpan(["katex-error"], [new dt(t)]);
  return a.setAttribute("title", e.toString()), a.setAttribute("style", "color:" + r.errorColor), a;
}, Fi = function(e, t) {
  var r = new ui(t);
  try {
    var a = Ei(e, r);
    return i4(a, e, r);
  } catch (i) {
    return Du(i, e, r);
  }
}, Q4 = function(e, t) {
  var r = new ui(t);
  try {
    var a = Ei(e, r);
    return l4(a, e, r);
  } catch (i) {
    return Du(i, e, r);
  }
}, J4 = "0.16.19", $4 = {
  Span: Mr,
  Anchor: fi,
  SymbolNode: dt,
  SvgNode: h0,
  PathNode: x0,
  LineNode: Ha
}, Gl = {
  /**
   * Current KaTeX version
   */
  version: J4,
  /**
   * Renders the given LaTeX into an HTML+MathML combination, and adds
   * it as a child to the specified DOM node.
   */
  render: _u,
  /**
   * Renders the given LaTeX into an HTML+MathML combination string,
   * for sending to the client.
   */
  renderToString: Z4,
  /**
   * KaTeX error, usually during parsing.
   */
  ParseError: L,
  /**
   * The schema of Settings
   */
  SETTINGS_SCHEMA: dn,
  /**
   * Parses the given LaTeX into KaTeX's internal parse tree structure,
   * without rendering to HTML or MathML.
   *
   * NOTE: This method is not currently recommended for public use.
   * The internal tree representation is unstable and is very likely
   * to change. Use at your own risk.
   */
  __parse: K4,
  /**
   * Renders the given LaTeX into an HTML+MathML internal DOM tree
   * representation, without flattening that representation to a string.
   *
   * NOTE: This method is not currently recommended for public use.
   * The internal tree representation is unstable and is very likely
   * to change. Use at your own risk.
   */
  __renderToDomTree: Fi,
  /**
   * Renders the given LaTeX into an HTML internal DOM tree representation,
   * without MathML and without flattening that representation to a string.
   *
   * NOTE: This method is not currently recommended for public use.
   * The internal tree representation is unstable and is very likely
   * to change. Use at your own risk.
   */
  __renderToHTMLTree: Q4,
  /**
   * extends internal font metrics object with a new object
   * each key in the new object represents a font name
  */
  __setFontMetrics: Tc,
  /**
   * adds a new symbol to builtin symbols table
   */
  __defineSymbol: u,
  /**
   * adds a new function to builtin function list,
   * which directly produce parse tree elements
   * and have their own html/mathml builders
   */
  __defineFunction: G,
  /**
   * adds a new macro to builtin macro list
   */
  __defineMacro: p,
  /**
   * Expose the dom tree node types, which can be useful for type checking nodes.
   *
   * NOTE: These methods are not currently recommended for public use.
   * The internal tree representation is unstable and is very likely
   * to change. Use at your own risk.
   */
  __domTree: $4
}, eh = function(e, t, r) {
  for (var a = r, i = 0, l = e.length; a < t.length; ) {
    var s = t[a];
    if (i <= 0 && t.slice(a, a + l) === e)
      return a;
    s === "\\" ? a++ : s === "{" ? i++ : s === "}" && i--, a++;
  }
  return -1;
}, th = function(e) {
  return e.replace(/[-/\\^$*+?.()|[\]{}]/g, "\\$&");
}, rh = /^\\begin{/, nh = function(e, t) {
  for (var r, a = [], i = new RegExp("(" + t.map((c) => th(c.left)).join("|") + ")"); r = e.search(i), r !== -1; ) {
    r > 0 && (a.push({
      type: "text",
      data: e.slice(0, r)
    }), e = e.slice(r));
    var l = t.findIndex((c) => e.startsWith(c.left));
    if (r = eh(t[l].right, e, t[l].left.length), r === -1)
      break;
    var s = e.slice(0, r + t[l].right.length), o = rh.test(s) ? s : e.slice(t[l].left.length, r);
    a.push({
      type: "math",
      data: o,
      rawData: s,
      display: t[l].display
    }), e = e.slice(r + t[l].right.length);
  }
  return e !== "" && a.push({
    type: "text",
    data: e
  }), a;
}, ah = function(e, t) {
  var r = nh(e, t.delimiters);
  if (r.length === 1 && r[0].type === "text")
    return null;
  for (var a = document.createDocumentFragment(), i = 0; i < r.length; i++)
    if (r[i].type === "text")
      a.appendChild(document.createTextNode(r[i].data));
    else {
      var l = document.createElement("span"), s = r[i].data;
      t.displayMode = r[i].display;
      try {
        t.preProcess && (s = t.preProcess(s)), Gl.render(s, l, t);
      } catch (o) {
        if (!(o instanceof Gl.ParseError))
          throw o;
        t.errorCallback("KaTeX auto-render: Failed to parse `" + r[i].data + "` with ", o), a.appendChild(document.createTextNode(r[i].rawData));
        continue;
      }
      a.appendChild(l);
    }
  return a;
}, ih = function n(e, t) {
  for (var r = 0; r < e.childNodes.length; r++) {
    var a = e.childNodes[r];
    if (a.nodeType === 3) {
      for (var i = a.textContent, l = a.nextSibling, s = 0; l && l.nodeType === Node.TEXT_NODE; )
        i += l.textContent, l = l.nextSibling, s++;
      var o = ah(i, t);
      if (o) {
        for (var c = 0; c < s; c++)
          a.nextSibling.remove();
        r += o.childNodes.length - 1, e.replaceChild(o, a);
      } else
        r += s;
    } else a.nodeType === 1 && function() {
      var f = " " + a.className + " ", d = t.ignoredTags.indexOf(a.nodeName.toLowerCase()) === -1 && t.ignoredClasses.every((g) => f.indexOf(" " + g + " ") === -1);
      d && n(a, t);
    }();
  }
}, lh = function(e, t) {
  if (!e)
    throw new Error("No element provided to render");
  var r = {};
  for (var a in t)
    t.hasOwnProperty(a) && (r[a] = t[a]);
  r.delimiters = r.delimiters || [
    {
      left: "$$",
      right: "$$",
      display: !0
    },
    {
      left: "\\(",
      right: "\\)",
      display: !1
    },
    // LaTeX uses $…$, but it ruins the display of normal `$` in text:
    // {left: "$", right: "$", display: false},
    // $ must come after $$
    // Render AMS environments even if outside $$…$$ delimiters.
    {
      left: "\\begin{equation}",
      right: "\\end{equation}",
      display: !0
    },
    {
      left: "\\begin{align}",
      right: "\\end{align}",
      display: !0
    },
    {
      left: "\\begin{alignat}",
      right: "\\end{alignat}",
      display: !0
    },
    {
      left: "\\begin{gather}",
      right: "\\end{gather}",
      display: !0
    },
    {
      left: "\\begin{CD}",
      right: "\\end{CD}",
      display: !0
    },
    {
      left: "\\[",
      right: "\\]",
      display: !0
    }
  ], r.ignoredTags = r.ignoredTags || ["script", "noscript", "style", "textarea", "pre", "code", "option"], r.ignoredClasses = r.ignoredClasses || [], r.errorCallback = r.errorCallback || console.error, r.macros = r.macros || {}, ih(e, r);
};
function Ti() {
  return {
    async: !1,
    breaks: !1,
    extensions: null,
    gfm: !0,
    hooks: null,
    pedantic: !1,
    renderer: null,
    silent: !1,
    tokenizer: null,
    walkTokens: null
  };
}
let P0 = Ti();
function xu(n) {
  P0 = n;
}
const Au = /[&<>"']/, sh = new RegExp(Au.source, "g"), Su = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, oh = new RegExp(Su.source, "g"), uh = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#39;"
}, Vl = (n) => uh[n];
function at(n, e) {
  if (e) {
    if (Au.test(n))
      return n.replace(sh, Vl);
  } else if (Su.test(n))
    return n.replace(oh, Vl);
  return n;
}
const ch = /&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/ig;
function hh(n) {
  return n.replace(ch, (e, t) => (t = t.toLowerCase(), t === "colon" ? ":" : t.charAt(0) === "#" ? t.charAt(1) === "x" ? String.fromCharCode(parseInt(t.substring(2), 16)) : String.fromCharCode(+t.substring(1)) : ""));
}
const fh = /(^|[^\[])\^/g;
function he(n, e) {
  let t = typeof n == "string" ? n : n.source;
  e = e || "";
  const r = {
    replace: (a, i) => {
      let l = typeof i == "string" ? i : i.source;
      return l = l.replace(fh, "$1"), t = t.replace(a, l), r;
    },
    getRegex: () => new RegExp(t, e)
  };
  return r;
}
function Wl(n) {
  try {
    n = encodeURI(n).replace(/%25/g, "%");
  } catch {
    return null;
  }
  return n;
}
const kr = { exec: () => null };
function Xl(n, e) {
  const t = n.replace(/\|/g, (i, l, s) => {
    let o = !1, c = l;
    for (; --c >= 0 && s[c] === "\\"; )
      o = !o;
    return o ? "|" : " |";
  }), r = t.split(/ \|/);
  let a = 0;
  if (r[0].trim() || r.shift(), r.length > 0 && !r[r.length - 1].trim() && r.pop(), e)
    if (r.length > e)
      r.splice(e);
    else
      for (; r.length < e; )
        r.push("");
  for (; a < r.length; a++)
    r[a] = r[a].trim().replace(/\\\|/g, "|");
  return r;
}
function Qr(n, e, t) {
  const r = n.length;
  if (r === 0)
    return "";
  let a = 0;
  for (; a < r && n.charAt(r - a - 1) === e; )
    a++;
  return n.slice(0, r - a);
}
function mh(n, e) {
  if (n.indexOf(e[1]) === -1)
    return -1;
  let t = 0;
  for (let r = 0; r < n.length; r++)
    if (n[r] === "\\")
      r++;
    else if (n[r] === e[0])
      t++;
    else if (n[r] === e[1] && (t--, t < 0))
      return r;
  return -1;
}
function Yl(n, e, t, r) {
  const a = e.href, i = e.title ? at(e.title) : null, l = n[1].replace(/\\([\[\]])/g, "$1");
  if (n[0].charAt(0) !== "!") {
    r.state.inLink = !0;
    const s = {
      type: "link",
      raw: t,
      href: a,
      title: i,
      text: l,
      tokens: r.inlineTokens(l)
    };
    return r.state.inLink = !1, s;
  }
  return {
    type: "image",
    raw: t,
    href: a,
    title: i,
    text: at(l)
  };
}
function dh(n, e) {
  const t = n.match(/^(\s+)(?:```)/);
  if (t === null)
    return e;
  const r = t[1];
  return e.split(`
`).map((a) => {
    const i = a.match(/^\s+/);
    if (i === null)
      return a;
    const [l] = i;
    return l.length >= r.length ? a.slice(r.length) : a;
  }).join(`
`);
}
class Fn {
  // set by the lexer
  constructor(e) {
    pe(this, "options");
    pe(this, "rules");
    // set by the lexer
    pe(this, "lexer");
    this.options = e || P0;
  }
  space(e) {
    const t = this.rules.block.newline.exec(e);
    if (t && t[0].length > 0)
      return {
        type: "space",
        raw: t[0]
      };
  }
  code(e) {
    const t = this.rules.block.code.exec(e);
    if (t) {
      const r = t[0].replace(/^ {1,4}/gm, "");
      return {
        type: "code",
        raw: t[0],
        codeBlockStyle: "indented",
        text: this.options.pedantic ? r : Qr(r, `
`)
      };
    }
  }
  fences(e) {
    const t = this.rules.block.fences.exec(e);
    if (t) {
      const r = t[0], a = dh(r, t[3] || "");
      return {
        type: "code",
        raw: r,
        lang: t[2] ? t[2].trim().replace(this.rules.inline.anyPunctuation, "$1") : t[2],
        text: a
      };
    }
  }
  heading(e) {
    const t = this.rules.block.heading.exec(e);
    if (t) {
      let r = t[2].trim();
      if (/#$/.test(r)) {
        const a = Qr(r, "#");
        (this.options.pedantic || !a || / $/.test(a)) && (r = a.trim());
      }
      return {
        type: "heading",
        raw: t[0],
        depth: t[1].length,
        text: r,
        tokens: this.lexer.inline(r)
      };
    }
  }
  hr(e) {
    const t = this.rules.block.hr.exec(e);
    if (t)
      return {
        type: "hr",
        raw: t[0]
      };
  }
  blockquote(e) {
    const t = this.rules.block.blockquote.exec(e);
    if (t) {
      let r = t[0].replace(/\n {0,3}((?:=+|-+) *)(?=\n|$)/g, `
    $1`);
      r = Qr(r.replace(/^ *>[ \t]?/gm, ""), `
`);
      const a = this.lexer.state.top;
      this.lexer.state.top = !0;
      const i = this.lexer.blockTokens(r);
      return this.lexer.state.top = a, {
        type: "blockquote",
        raw: t[0],
        tokens: i,
        text: r
      };
    }
  }
  list(e) {
    let t = this.rules.block.list.exec(e);
    if (t) {
      let r = t[1].trim();
      const a = r.length > 1, i = {
        type: "list",
        raw: "",
        ordered: a,
        start: a ? +r.slice(0, -1) : "",
        loose: !1,
        items: []
      };
      r = a ? `\\d{1,9}\\${r.slice(-1)}` : `\\${r}`, this.options.pedantic && (r = a ? r : "[*+-]");
      const l = new RegExp(`^( {0,3}${r})((?:[	 ][^\\n]*)?(?:\\n|$))`);
      let s = "", o = "", c = !1;
      for (; e; ) {
        let f = !1;
        if (!(t = l.exec(e)) || this.rules.block.hr.test(e))
          break;
        s = t[0], e = e.substring(s.length);
        let d = t[2].split(`
`, 1)[0].replace(/^\t+/, (A) => " ".repeat(3 * A.length)), g = e.split(`
`, 1)[0], v = 0;
        this.options.pedantic ? (v = 2, o = d.trimStart()) : (v = t[2].search(/[^ ]/), v = v > 4 ? 1 : v, o = d.slice(v), v += t[1].length);
        let y = !1;
        if (!d && /^ *$/.test(g) && (s += g + `
`, e = e.substring(g.length + 1), f = !0), !f) {
          const A = new RegExp(`^ {0,${Math.min(3, v - 1)}}(?:[*+-]|\\d{1,9}[.)])((?:[ 	][^\\n]*)?(?:\\n|$))`), D = new RegExp(`^ {0,${Math.min(3, v - 1)}}((?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$)`), b = new RegExp(`^ {0,${Math.min(3, v - 1)}}(?:\`\`\`|~~~)`), F = new RegExp(`^ {0,${Math.min(3, v - 1)}}#`);
          for (; e; ) {
            const T = e.split(`
`, 1)[0];
            if (g = T, this.options.pedantic && (g = g.replace(/^ {1,4}(?=( {4})*[^ ])/g, "  ")), b.test(g) || F.test(g) || A.test(g) || D.test(e))
              break;
            if (g.search(/[^ ]/) >= v || !g.trim())
              o += `
` + g.slice(v);
            else {
              if (y || d.search(/[^ ]/) >= 4 || b.test(d) || F.test(d) || D.test(d))
                break;
              o += `
` + g;
            }
            !y && !g.trim() && (y = !0), s += T + `
`, e = e.substring(T.length + 1), d = g.slice(v);
          }
        }
        i.loose || (c ? i.loose = !0 : /\n *\n *$/.test(s) && (c = !0));
        let k = null, E;
        this.options.gfm && (k = /^\[[ xX]\] /.exec(o), k && (E = k[0] !== "[ ] ", o = o.replace(/^\[[ xX]\] +/, ""))), i.items.push({
          type: "list_item",
          raw: s,
          task: !!k,
          checked: E,
          loose: !1,
          text: o,
          tokens: []
        }), i.raw += s;
      }
      i.items[i.items.length - 1].raw = s.trimEnd(), i.items[i.items.length - 1].text = o.trimEnd(), i.raw = i.raw.trimEnd();
      for (let f = 0; f < i.items.length; f++)
        if (this.lexer.state.top = !1, i.items[f].tokens = this.lexer.blockTokens(i.items[f].text, []), !i.loose) {
          const d = i.items[f].tokens.filter((v) => v.type === "space"), g = d.length > 0 && d.some((v) => /\n.*\n/.test(v.raw));
          i.loose = g;
        }
      if (i.loose)
        for (let f = 0; f < i.items.length; f++)
          i.items[f].loose = !0;
      return i;
    }
  }
  html(e) {
    const t = this.rules.block.html.exec(e);
    if (t)
      return {
        type: "html",
        block: !0,
        raw: t[0],
        pre: t[1] === "pre" || t[1] === "script" || t[1] === "style",
        text: t[0]
      };
  }
  def(e) {
    const t = this.rules.block.def.exec(e);
    if (t) {
      const r = t[1].toLowerCase().replace(/\s+/g, " "), a = t[2] ? t[2].replace(/^<(.*)>$/, "$1").replace(this.rules.inline.anyPunctuation, "$1") : "", i = t[3] ? t[3].substring(1, t[3].length - 1).replace(this.rules.inline.anyPunctuation, "$1") : t[3];
      return {
        type: "def",
        tag: r,
        raw: t[0],
        href: a,
        title: i
      };
    }
  }
  table(e) {
    const t = this.rules.block.table.exec(e);
    if (!t || !/[:|]/.test(t[2]))
      return;
    const r = Xl(t[1]), a = t[2].replace(/^\||\| *$/g, "").split("|"), i = t[3] && t[3].trim() ? t[3].replace(/\n[ \t]*$/, "").split(`
`) : [], l = {
      type: "table",
      raw: t[0],
      header: [],
      align: [],
      rows: []
    };
    if (r.length === a.length) {
      for (const s of a)
        /^ *-+: *$/.test(s) ? l.align.push("right") : /^ *:-+: *$/.test(s) ? l.align.push("center") : /^ *:-+ *$/.test(s) ? l.align.push("left") : l.align.push(null);
      for (const s of r)
        l.header.push({
          text: s,
          tokens: this.lexer.inline(s)
        });
      for (const s of i)
        l.rows.push(Xl(s, l.header.length).map((o) => ({
          text: o,
          tokens: this.lexer.inline(o)
        })));
      return l;
    }
  }
  lheading(e) {
    const t = this.rules.block.lheading.exec(e);
    if (t)
      return {
        type: "heading",
        raw: t[0],
        depth: t[2].charAt(0) === "=" ? 1 : 2,
        text: t[1],
        tokens: this.lexer.inline(t[1])
      };
  }
  paragraph(e) {
    const t = this.rules.block.paragraph.exec(e);
    if (t) {
      const r = t[1].charAt(t[1].length - 1) === `
` ? t[1].slice(0, -1) : t[1];
      return {
        type: "paragraph",
        raw: t[0],
        text: r,
        tokens: this.lexer.inline(r)
      };
    }
  }
  text(e) {
    const t = this.rules.block.text.exec(e);
    if (t)
      return {
        type: "text",
        raw: t[0],
        text: t[0],
        tokens: this.lexer.inline(t[0])
      };
  }
  escape(e) {
    const t = this.rules.inline.escape.exec(e);
    if (t)
      return {
        type: "escape",
        raw: t[0],
        text: at(t[1])
      };
  }
  tag(e) {
    const t = this.rules.inline.tag.exec(e);
    if (t)
      return !this.lexer.state.inLink && /^<a /i.test(t[0]) ? this.lexer.state.inLink = !0 : this.lexer.state.inLink && /^<\/a>/i.test(t[0]) && (this.lexer.state.inLink = !1), !this.lexer.state.inRawBlock && /^<(pre|code|kbd|script)(\s|>)/i.test(t[0]) ? this.lexer.state.inRawBlock = !0 : this.lexer.state.inRawBlock && /^<\/(pre|code|kbd|script)(\s|>)/i.test(t[0]) && (this.lexer.state.inRawBlock = !1), {
        type: "html",
        raw: t[0],
        inLink: this.lexer.state.inLink,
        inRawBlock: this.lexer.state.inRawBlock,
        block: !1,
        text: t[0]
      };
  }
  link(e) {
    const t = this.rules.inline.link.exec(e);
    if (t) {
      const r = t[2].trim();
      if (!this.options.pedantic && /^</.test(r)) {
        if (!/>$/.test(r))
          return;
        const l = Qr(r.slice(0, -1), "\\");
        if ((r.length - l.length) % 2 === 0)
          return;
      } else {
        const l = mh(t[2], "()");
        if (l > -1) {
          const o = (t[0].indexOf("!") === 0 ? 5 : 4) + t[1].length + l;
          t[2] = t[2].substring(0, l), t[0] = t[0].substring(0, o).trim(), t[3] = "";
        }
      }
      let a = t[2], i = "";
      if (this.options.pedantic) {
        const l = /^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(a);
        l && (a = l[1], i = l[3]);
      } else
        i = t[3] ? t[3].slice(1, -1) : "";
      return a = a.trim(), /^</.test(a) && (this.options.pedantic && !/>$/.test(r) ? a = a.slice(1) : a = a.slice(1, -1)), Yl(t, {
        href: a && a.replace(this.rules.inline.anyPunctuation, "$1"),
        title: i && i.replace(this.rules.inline.anyPunctuation, "$1")
      }, t[0], this.lexer);
    }
  }
  reflink(e, t) {
    let r;
    if ((r = this.rules.inline.reflink.exec(e)) || (r = this.rules.inline.nolink.exec(e))) {
      const a = (r[2] || r[1]).replace(/\s+/g, " "), i = t[a.toLowerCase()];
      if (!i) {
        const l = r[0].charAt(0);
        return {
          type: "text",
          raw: l,
          text: l
        };
      }
      return Yl(r, i, r[0], this.lexer);
    }
  }
  emStrong(e, t, r = "") {
    let a = this.rules.inline.emStrongLDelim.exec(e);
    if (!a || a[3] && r.match(/[\p{L}\p{N}]/u))
      return;
    if (!(a[1] || a[2] || "") || !r || this.rules.inline.punctuation.exec(r)) {
      const l = [...a[0]].length - 1;
      let s, o, c = l, f = 0;
      const d = a[0][0] === "*" ? this.rules.inline.emStrongRDelimAst : this.rules.inline.emStrongRDelimUnd;
      for (d.lastIndex = 0, t = t.slice(-1 * e.length + l); (a = d.exec(t)) != null; ) {
        if (s = a[1] || a[2] || a[3] || a[4] || a[5] || a[6], !s)
          continue;
        if (o = [...s].length, a[3] || a[4]) {
          c += o;
          continue;
        } else if ((a[5] || a[6]) && l % 3 && !((l + o) % 3)) {
          f += o;
          continue;
        }
        if (c -= o, c > 0)
          continue;
        o = Math.min(o, o + c + f);
        const g = [...a[0]][0].length, v = e.slice(0, l + a.index + g + o);
        if (Math.min(l, o) % 2) {
          const k = v.slice(1, -1);
          return {
            type: "em",
            raw: v,
            text: k,
            tokens: this.lexer.inlineTokens(k)
          };
        }
        const y = v.slice(2, -2);
        return {
          type: "strong",
          raw: v,
          text: y,
          tokens: this.lexer.inlineTokens(y)
        };
      }
    }
  }
  codespan(e) {
    const t = this.rules.inline.code.exec(e);
    if (t) {
      let r = t[2].replace(/\n/g, " ");
      const a = /[^ ]/.test(r), i = /^ /.test(r) && / $/.test(r);
      return a && i && (r = r.substring(1, r.length - 1)), r = at(r, !0), {
        type: "codespan",
        raw: t[0],
        text: r
      };
    }
  }
  br(e) {
    const t = this.rules.inline.br.exec(e);
    if (t)
      return {
        type: "br",
        raw: t[0]
      };
  }
  del(e) {
    const t = this.rules.inline.del.exec(e);
    if (t)
      return {
        type: "del",
        raw: t[0],
        text: t[2],
        tokens: this.lexer.inlineTokens(t[2])
      };
  }
  autolink(e) {
    const t = this.rules.inline.autolink.exec(e);
    if (t) {
      let r, a;
      return t[2] === "@" ? (r = at(t[1]), a = "mailto:" + r) : (r = at(t[1]), a = r), {
        type: "link",
        raw: t[0],
        text: r,
        href: a,
        tokens: [
          {
            type: "text",
            raw: r,
            text: r
          }
        ]
      };
    }
  }
  url(e) {
    var r;
    let t;
    if (t = this.rules.inline.url.exec(e)) {
      let a, i;
      if (t[2] === "@")
        a = at(t[0]), i = "mailto:" + a;
      else {
        let l;
        do
          l = t[0], t[0] = ((r = this.rules.inline._backpedal.exec(t[0])) == null ? void 0 : r[0]) ?? "";
        while (l !== t[0]);
        a = at(t[0]), t[1] === "www." ? i = "http://" + t[0] : i = t[0];
      }
      return {
        type: "link",
        raw: t[0],
        text: a,
        href: i,
        tokens: [
          {
            type: "text",
            raw: a,
            text: a
          }
        ]
      };
    }
  }
  inlineText(e) {
    const t = this.rules.inline.text.exec(e);
    if (t) {
      let r;
      return this.lexer.state.inRawBlock ? r = t[0] : r = at(t[0]), {
        type: "text",
        raw: t[0],
        text: r
      };
    }
  }
}
const ph = /^(?: *(?:\n|$))+/, gh = /^( {4}[^\n]+(?:\n(?: *(?:\n|$))*)?)+/, vh = /^ {0,3}(`{3,}(?=[^`\n]*(?:\n|$))|~{3,})([^\n]*)(?:\n|$)(?:|([\s\S]*?)(?:\n|$))(?: {0,3}\1[~`]* *(?=\n|$)|$)/, Br = /^ {0,3}((?:-[\t ]*){3,}|(?:_[ \t]*){3,}|(?:\*[ \t]*){3,})(?:\n+|$)/, bh = /^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/, Eu = /(?:[*+-]|\d{1,9}[.)])/, Fu = he(/^(?!bull |blockCode|fences|blockquote|heading|html)((?:.|\n(?!\s*?\n|bull |blockCode|fences|blockquote|heading|html))+?)\n {0,3}(=+|-+) *(?:\n+|$)/).replace(/bull/g, Eu).replace(/blockCode/g, / {4}/).replace(/fences/g, / {0,3}(?:`{3,}|~{3,})/).replace(/blockquote/g, / {0,3}>/).replace(/heading/g, / {0,3}#{1,6}/).replace(/html/g, / {0,3}<[^\n>]+>\n/).getRegex(), Ci = /^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html|table| +\n)[^\n]+)*)/, yh = /^[^\n]+/, Mi = /(?!\s*\])(?:\\.|[^\[\]\\])+/, wh = he(/^ {0,3}\[(label)\]: *(?:\n *)?([^<\s][^\s]*|<.*?>)(?:(?: +(?:\n *)?| *\n *)(title))? *(?:\n+|$)/).replace("label", Mi).replace("title", /(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/).getRegex(), kh = he(/^( {0,3}bull)([ \t][^\n]+?)?(?:\n|$)/).replace(/bull/g, Eu).getRegex(), Un = "address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|search|section|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul", zi = /<!--(?:-?>|[\s\S]*?(?:-->|$))/, _h = he("^ {0,3}(?:<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?(?:\\?>\\n*|$)|<![A-Z][\\s\\S]*?(?:>\\n*|$)|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n *)+\\n|$)|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$))", "i").replace("comment", zi).replace("tag", Un).replace("attribute", / +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(), Tu = he(Ci).replace("hr", Br).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("|lheading", "").replace("|table", "").replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Un).getRegex(), Dh = he(/^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/).replace("paragraph", Tu).getRegex(), Bi = {
  blockquote: Dh,
  code: gh,
  def: wh,
  fences: vh,
  heading: bh,
  hr: Br,
  html: _h,
  lheading: Fu,
  list: kh,
  newline: ph,
  paragraph: Tu,
  table: kr,
  text: yh
}, jl = he("^ *([^\\n ].*)\\n {0,3}((?:\\| *)?:?-+:? *(?:\\| *:?-+:? *)*(?:\\| *)?)(?:\\n((?:(?! *\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)").replace("hr", Br).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("blockquote", " {0,3}>").replace("code", " {4}[^\\n]").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Un).getRegex(), xh = {
  ...Bi,
  table: jl,
  paragraph: he(Ci).replace("hr", Br).replace("heading", " {0,3}#{1,6}(?:\\s|$)").replace("|lheading", "").replace("table", jl).replace("blockquote", " {0,3}>").replace("fences", " {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list", " {0,3}(?:[*+-]|1[.)]) ").replace("html", "</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag", Un).getRegex()
}, Ah = {
  ...Bi,
  html: he(`^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:"[^"]*"|'[^']*'|\\s[^'"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))`).replace("comment", zi).replace(/tag/g, "(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(),
  def: /^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/,
  heading: /^(#{1,6})(.*)(?:\n+|$)/,
  fences: kr,
  // fences not supported
  lheading: /^(.+?)\n {0,3}(=+|-+) *(?:\n+|$)/,
  paragraph: he(Ci).replace("hr", Br).replace("heading", ` *#{1,6} *[^
]`).replace("lheading", Fu).replace("|table", "").replace("blockquote", " {0,3}>").replace("|fences", "").replace("|list", "").replace("|html", "").replace("|tag", "").getRegex()
}, Cu = /^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/, Sh = /^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/, Mu = /^( {2,}|\\)\n(?!\s*$)/, Eh = /^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/, Nr = "\\p{P}\\p{S}", Fh = he(/^((?![*_])[\spunctuation])/, "u").replace(/punctuation/g, Nr).getRegex(), Th = /\[[^[\]]*?\]\([^\(\)]*?\)|`[^`]*?`|<[^<>]*?>/g, Ch = he(/^(?:\*+(?:((?!\*)[punct])|[^\s*]))|^_+(?:((?!_)[punct])|([^\s_]))/, "u").replace(/punct/g, Nr).getRegex(), Mh = he("^[^_*]*?__[^_*]*?\\*[^_*]*?(?=__)|[^*]+(?=[^*])|(?!\\*)[punct](\\*+)(?=[\\s]|$)|[^punct\\s](\\*+)(?!\\*)(?=[punct\\s]|$)|(?!\\*)[punct\\s](\\*+)(?=[^punct\\s])|[\\s](\\*+)(?!\\*)(?=[punct])|(?!\\*)[punct](\\*+)(?!\\*)(?=[punct])|[^punct\\s](\\*+)(?=[^punct\\s])", "gu").replace(/punct/g, Nr).getRegex(), zh = he("^[^_*]*?\\*\\*[^_*]*?_[^_*]*?(?=\\*\\*)|[^_]+(?=[^_])|(?!_)[punct](_+)(?=[\\s]|$)|[^punct\\s](_+)(?!_)(?=[punct\\s]|$)|(?!_)[punct\\s](_+)(?=[^punct\\s])|[\\s](_+)(?!_)(?=[punct])|(?!_)[punct](_+)(?!_)(?=[punct])", "gu").replace(/punct/g, Nr).getRegex(), Bh = he(/\\([punct])/, "gu").replace(/punct/g, Nr).getRegex(), Nh = he(/^<(scheme:[^\s\x00-\x1f<>]*|email)>/).replace("scheme", /[a-zA-Z][a-zA-Z0-9+.-]{1,31}/).replace("email", /[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/).getRegex(), Rh = he(zi).replace("(?:-->|$)", "-->").getRegex(), Ih = he("^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>").replace("comment", Rh).replace("attribute", /\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/).getRegex(), Tn = /(?:\[(?:\\.|[^\[\]\\])*\]|\\.|`[^`]*`|[^\[\]\\`])*?/, Lh = he(/^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/).replace("label", Tn).replace("href", /<(?:\\.|[^\n<>\\])+>|[^\s\x00-\x1f]*/).replace("title", /"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/).getRegex(), zu = he(/^!?\[(label)\]\[(ref)\]/).replace("label", Tn).replace("ref", Mi).getRegex(), Bu = he(/^!?\[(ref)\](?:\[\])?/).replace("ref", Mi).getRegex(), Oh = he("reflink|nolink(?!\\()", "g").replace("reflink", zu).replace("nolink", Bu).getRegex(), Ni = {
  _backpedal: kr,
  // only used for GFM url
  anyPunctuation: Bh,
  autolink: Nh,
  blockSkip: Th,
  br: Mu,
  code: Sh,
  del: kr,
  emStrongLDelim: Ch,
  emStrongRDelimAst: Mh,
  emStrongRDelimUnd: zh,
  escape: Cu,
  link: Lh,
  nolink: Bu,
  punctuation: Fh,
  reflink: zu,
  reflinkSearch: Oh,
  tag: Ih,
  text: Eh,
  url: kr
}, qh = {
  ...Ni,
  link: he(/^!?\[(label)\]\((.*?)\)/).replace("label", Tn).getRegex(),
  reflink: he(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label", Tn).getRegex()
}, ja = {
  ...Ni,
  escape: he(Cu).replace("])", "~|])").getRegex(),
  url: he(/^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/, "i").replace("email", /[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/).getRegex(),
  _backpedal: /(?:[^?!.,:;*_'"~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_'"~)]+(?!$))+/,
  del: /^(~~?)(?=[^\s~])([\s\S]*?[^\s~])\1(?=[^~]|$)/,
  text: /^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/
}, Ph = {
  ...ja,
  br: he(Mu).replace("{2,}", "*").getRegex(),
  text: he(ja.text).replace("\\b_", "\\b_| {2,}\\n").replace(/\{2,\}/g, "*").getRegex()
}, Jr = {
  normal: Bi,
  gfm: xh,
  pedantic: Ah
}, hr = {
  normal: Ni,
  gfm: ja,
  breaks: Ph,
  pedantic: qh
};
class Ut {
  constructor(e) {
    pe(this, "tokens");
    pe(this, "options");
    pe(this, "state");
    pe(this, "tokenizer");
    pe(this, "inlineQueue");
    this.tokens = [], this.tokens.links = /* @__PURE__ */ Object.create(null), this.options = e || P0, this.options.tokenizer = this.options.tokenizer || new Fn(), this.tokenizer = this.options.tokenizer, this.tokenizer.options = this.options, this.tokenizer.lexer = this, this.inlineQueue = [], this.state = {
      inLink: !1,
      inRawBlock: !1,
      top: !0
    };
    const t = {
      block: Jr.normal,
      inline: hr.normal
    };
    this.options.pedantic ? (t.block = Jr.pedantic, t.inline = hr.pedantic) : this.options.gfm && (t.block = Jr.gfm, this.options.breaks ? t.inline = hr.breaks : t.inline = hr.gfm), this.tokenizer.rules = t;
  }
  /**
   * Expose Rules
   */
  static get rules() {
    return {
      block: Jr,
      inline: hr
    };
  }
  /**
   * Static Lex Method
   */
  static lex(e, t) {
    return new Ut(t).lex(e);
  }
  /**
   * Static Lex Inline Method
   */
  static lexInline(e, t) {
    return new Ut(t).inlineTokens(e);
  }
  /**
   * Preprocessing
   */
  lex(e) {
    e = e.replace(/\r\n|\r/g, `
`), this.blockTokens(e, this.tokens);
    for (let t = 0; t < this.inlineQueue.length; t++) {
      const r = this.inlineQueue[t];
      this.inlineTokens(r.src, r.tokens);
    }
    return this.inlineQueue = [], this.tokens;
  }
  blockTokens(e, t = []) {
    this.options.pedantic ? e = e.replace(/\t/g, "    ").replace(/^ +$/gm, "") : e = e.replace(/^( *)(\t+)/gm, (s, o, c) => o + "    ".repeat(c.length));
    let r, a, i, l;
    for (; e; )
      if (!(this.options.extensions && this.options.extensions.block && this.options.extensions.block.some((s) => (r = s.call({ lexer: this }, e, t)) ? (e = e.substring(r.raw.length), t.push(r), !0) : !1))) {
        if (r = this.tokenizer.space(e)) {
          e = e.substring(r.raw.length), r.raw.length === 1 && t.length > 0 ? t[t.length - 1].raw += `
` : t.push(r);
          continue;
        }
        if (r = this.tokenizer.code(e)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && (a.type === "paragraph" || a.type === "text") ? (a.raw += `
` + r.raw, a.text += `
` + r.text, this.inlineQueue[this.inlineQueue.length - 1].src = a.text) : t.push(r);
          continue;
        }
        if (r = this.tokenizer.fences(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.heading(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.hr(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.blockquote(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.list(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.html(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.def(e)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && (a.type === "paragraph" || a.type === "text") ? (a.raw += `
` + r.raw, a.text += `
` + r.raw, this.inlineQueue[this.inlineQueue.length - 1].src = a.text) : this.tokens.links[r.tag] || (this.tokens.links[r.tag] = {
            href: r.href,
            title: r.title
          });
          continue;
        }
        if (r = this.tokenizer.table(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.lheading(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (i = e, this.options.extensions && this.options.extensions.startBlock) {
          let s = 1 / 0;
          const o = e.slice(1);
          let c;
          this.options.extensions.startBlock.forEach((f) => {
            c = f.call({ lexer: this }, o), typeof c == "number" && c >= 0 && (s = Math.min(s, c));
          }), s < 1 / 0 && s >= 0 && (i = e.substring(0, s + 1));
        }
        if (this.state.top && (r = this.tokenizer.paragraph(i))) {
          a = t[t.length - 1], l && a.type === "paragraph" ? (a.raw += `
` + r.raw, a.text += `
` + r.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = a.text) : t.push(r), l = i.length !== e.length, e = e.substring(r.raw.length);
          continue;
        }
        if (r = this.tokenizer.text(e)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && a.type === "text" ? (a.raw += `
` + r.raw, a.text += `
` + r.text, this.inlineQueue.pop(), this.inlineQueue[this.inlineQueue.length - 1].src = a.text) : t.push(r);
          continue;
        }
        if (e) {
          const s = "Infinite loop on byte: " + e.charCodeAt(0);
          if (this.options.silent) {
            console.error(s);
            break;
          } else
            throw new Error(s);
        }
      }
    return this.state.top = !0, t;
  }
  inline(e, t = []) {
    return this.inlineQueue.push({ src: e, tokens: t }), t;
  }
  /**
   * Lexing/Compiling
   */
  inlineTokens(e, t = []) {
    let r, a, i, l = e, s, o, c;
    if (this.tokens.links) {
      const f = Object.keys(this.tokens.links);
      if (f.length > 0)
        for (; (s = this.tokenizer.rules.inline.reflinkSearch.exec(l)) != null; )
          f.includes(s[0].slice(s[0].lastIndexOf("[") + 1, -1)) && (l = l.slice(0, s.index) + "[" + "a".repeat(s[0].length - 2) + "]" + l.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex));
    }
    for (; (s = this.tokenizer.rules.inline.blockSkip.exec(l)) != null; )
      l = l.slice(0, s.index) + "[" + "a".repeat(s[0].length - 2) + "]" + l.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);
    for (; (s = this.tokenizer.rules.inline.anyPunctuation.exec(l)) != null; )
      l = l.slice(0, s.index) + "++" + l.slice(this.tokenizer.rules.inline.anyPunctuation.lastIndex);
    for (; e; )
      if (o || (c = ""), o = !1, !(this.options.extensions && this.options.extensions.inline && this.options.extensions.inline.some((f) => (r = f.call({ lexer: this }, e, t)) ? (e = e.substring(r.raw.length), t.push(r), !0) : !1))) {
        if (r = this.tokenizer.escape(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.tag(e)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && r.type === "text" && a.type === "text" ? (a.raw += r.raw, a.text += r.text) : t.push(r);
          continue;
        }
        if (r = this.tokenizer.link(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.reflink(e, this.tokens.links)) {
          e = e.substring(r.raw.length), a = t[t.length - 1], a && r.type === "text" && a.type === "text" ? (a.raw += r.raw, a.text += r.text) : t.push(r);
          continue;
        }
        if (r = this.tokenizer.emStrong(e, l, c)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.codespan(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.br(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.del(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (r = this.tokenizer.autolink(e)) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (!this.state.inLink && (r = this.tokenizer.url(e))) {
          e = e.substring(r.raw.length), t.push(r);
          continue;
        }
        if (i = e, this.options.extensions && this.options.extensions.startInline) {
          let f = 1 / 0;
          const d = e.slice(1);
          let g;
          this.options.extensions.startInline.forEach((v) => {
            g = v.call({ lexer: this }, d), typeof g == "number" && g >= 0 && (f = Math.min(f, g));
          }), f < 1 / 0 && f >= 0 && (i = e.substring(0, f + 1));
        }
        if (r = this.tokenizer.inlineText(i)) {
          e = e.substring(r.raw.length), r.raw.slice(-1) !== "_" && (c = r.raw.slice(-1)), o = !0, a = t[t.length - 1], a && a.type === "text" ? (a.raw += r.raw, a.text += r.text) : t.push(r);
          continue;
        }
        if (e) {
          const f = "Infinite loop on byte: " + e.charCodeAt(0);
          if (this.options.silent) {
            console.error(f);
            break;
          } else
            throw new Error(f);
        }
      }
    return t;
  }
}
class Cn {
  constructor(e) {
    pe(this, "options");
    this.options = e || P0;
  }
  code(e, t, r) {
    var i;
    const a = (i = (t || "").match(/^\S*/)) == null ? void 0 : i[0];
    return e = e.replace(/\n$/, "") + `
`, a ? '<pre><code class="language-' + at(a) + '">' + (r ? e : at(e, !0)) + `</code></pre>
` : "<pre><code>" + (r ? e : at(e, !0)) + `</code></pre>
`;
  }
  blockquote(e) {
    return `<blockquote>
${e}</blockquote>
`;
  }
  html(e, t) {
    return e;
  }
  heading(e, t, r) {
    return `<h${t}>${e}</h${t}>
`;
  }
  hr() {
    return `<hr>
`;
  }
  list(e, t, r) {
    const a = t ? "ol" : "ul", i = t && r !== 1 ? ' start="' + r + '"' : "";
    return "<" + a + i + `>
` + e + "</" + a + `>
`;
  }
  listitem(e, t, r) {
    return `<li>${e}</li>
`;
  }
  checkbox(e) {
    return "<input " + (e ? 'checked="" ' : "") + 'disabled="" type="checkbox">';
  }
  paragraph(e) {
    return `<p>${e}</p>
`;
  }
  table(e, t) {
    return t && (t = `<tbody>${t}</tbody>`), `<table>
<thead>
` + e + `</thead>
` + t + `</table>
`;
  }
  tablerow(e) {
    return `<tr>
${e}</tr>
`;
  }
  tablecell(e, t) {
    const r = t.header ? "th" : "td";
    return (t.align ? `<${r} align="${t.align}">` : `<${r}>`) + e + `</${r}>
`;
  }
  /**
   * span level renderer
   */
  strong(e) {
    return `<strong>${e}</strong>`;
  }
  em(e) {
    return `<em>${e}</em>`;
  }
  codespan(e) {
    return `<code>${e}</code>`;
  }
  br() {
    return "<br>";
  }
  del(e) {
    return `<del>${e}</del>`;
  }
  link(e, t, r) {
    const a = Wl(e);
    if (a === null)
      return r;
    e = a;
    let i = '<a href="' + e + '"';
    return t && (i += ' title="' + t + '"'), i += ">" + r + "</a>", i;
  }
  image(e, t, r) {
    const a = Wl(e);
    if (a === null)
      return r;
    e = a;
    let i = `<img src="${e}" alt="${r}"`;
    return t && (i += ` title="${t}"`), i += ">", i;
  }
  text(e) {
    return e;
  }
}
class Ri {
  // no need for block level renderers
  strong(e) {
    return e;
  }
  em(e) {
    return e;
  }
  codespan(e) {
    return e;
  }
  del(e) {
    return e;
  }
  html(e) {
    return e;
  }
  text(e) {
    return e;
  }
  link(e, t, r) {
    return "" + r;
  }
  image(e, t, r) {
    return "" + r;
  }
  br() {
    return "";
  }
}
class Gt {
  constructor(e) {
    pe(this, "options");
    pe(this, "renderer");
    pe(this, "textRenderer");
    this.options = e || P0, this.options.renderer = this.options.renderer || new Cn(), this.renderer = this.options.renderer, this.renderer.options = this.options, this.textRenderer = new Ri();
  }
  /**
   * Static Parse Method
   */
  static parse(e, t) {
    return new Gt(t).parse(e);
  }
  /**
   * Static Parse Inline Method
   */
  static parseInline(e, t) {
    return new Gt(t).parseInline(e);
  }
  /**
   * Parse Loop
   */
  parse(e, t = !0) {
    let r = "";
    for (let a = 0; a < e.length; a++) {
      const i = e[a];
      if (this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[i.type]) {
        const l = i, s = this.options.extensions.renderers[l.type].call({ parser: this }, l);
        if (s !== !1 || !["space", "hr", "heading", "code", "table", "blockquote", "list", "html", "paragraph", "text"].includes(l.type)) {
          r += s || "";
          continue;
        }
      }
      switch (i.type) {
        case "space":
          continue;
        case "hr": {
          r += this.renderer.hr();
          continue;
        }
        case "heading": {
          const l = i;
          r += this.renderer.heading(this.parseInline(l.tokens), l.depth, hh(this.parseInline(l.tokens, this.textRenderer)));
          continue;
        }
        case "code": {
          const l = i;
          r += this.renderer.code(l.text, l.lang, !!l.escaped);
          continue;
        }
        case "table": {
          const l = i;
          let s = "", o = "";
          for (let f = 0; f < l.header.length; f++)
            o += this.renderer.tablecell(this.parseInline(l.header[f].tokens), { header: !0, align: l.align[f] });
          s += this.renderer.tablerow(o);
          let c = "";
          for (let f = 0; f < l.rows.length; f++) {
            const d = l.rows[f];
            o = "";
            for (let g = 0; g < d.length; g++)
              o += this.renderer.tablecell(this.parseInline(d[g].tokens), { header: !1, align: l.align[g] });
            c += this.renderer.tablerow(o);
          }
          r += this.renderer.table(s, c);
          continue;
        }
        case "blockquote": {
          const l = i, s = this.parse(l.tokens);
          r += this.renderer.blockquote(s);
          continue;
        }
        case "list": {
          const l = i, s = l.ordered, o = l.start, c = l.loose;
          let f = "";
          for (let d = 0; d < l.items.length; d++) {
            const g = l.items[d], v = g.checked, y = g.task;
            let k = "";
            if (g.task) {
              const E = this.renderer.checkbox(!!v);
              c ? g.tokens.length > 0 && g.tokens[0].type === "paragraph" ? (g.tokens[0].text = E + " " + g.tokens[0].text, g.tokens[0].tokens && g.tokens[0].tokens.length > 0 && g.tokens[0].tokens[0].type === "text" && (g.tokens[0].tokens[0].text = E + " " + g.tokens[0].tokens[0].text)) : g.tokens.unshift({
                type: "text",
                text: E + " "
              }) : k += E + " ";
            }
            k += this.parse(g.tokens, c), f += this.renderer.listitem(k, y, !!v);
          }
          r += this.renderer.list(f, s, o);
          continue;
        }
        case "html": {
          const l = i;
          r += this.renderer.html(l.text, l.block);
          continue;
        }
        case "paragraph": {
          const l = i;
          r += this.renderer.paragraph(this.parseInline(l.tokens));
          continue;
        }
        case "text": {
          let l = i, s = l.tokens ? this.parseInline(l.tokens) : l.text;
          for (; a + 1 < e.length && e[a + 1].type === "text"; )
            l = e[++a], s += `
` + (l.tokens ? this.parseInline(l.tokens) : l.text);
          r += t ? this.renderer.paragraph(s) : s;
          continue;
        }
        default: {
          const l = 'Token with "' + i.type + '" type was not found.';
          if (this.options.silent)
            return console.error(l), "";
          throw new Error(l);
        }
      }
    }
    return r;
  }
  /**
   * Parse Inline Tokens
   */
  parseInline(e, t) {
    t = t || this.renderer;
    let r = "";
    for (let a = 0; a < e.length; a++) {
      const i = e[a];
      if (this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[i.type]) {
        const l = this.options.extensions.renderers[i.type].call({ parser: this }, i);
        if (l !== !1 || !["escape", "html", "link", "image", "strong", "em", "codespan", "br", "del", "text"].includes(i.type)) {
          r += l || "";
          continue;
        }
      }
      switch (i.type) {
        case "escape": {
          const l = i;
          r += t.text(l.text);
          break;
        }
        case "html": {
          const l = i;
          r += t.html(l.text);
          break;
        }
        case "link": {
          const l = i;
          r += t.link(l.href, l.title, this.parseInline(l.tokens, t));
          break;
        }
        case "image": {
          const l = i;
          r += t.image(l.href, l.title, l.text);
          break;
        }
        case "strong": {
          const l = i;
          r += t.strong(this.parseInline(l.tokens, t));
          break;
        }
        case "em": {
          const l = i;
          r += t.em(this.parseInline(l.tokens, t));
          break;
        }
        case "codespan": {
          const l = i;
          r += t.codespan(l.text);
          break;
        }
        case "br": {
          r += t.br();
          break;
        }
        case "del": {
          const l = i;
          r += t.del(this.parseInline(l.tokens, t));
          break;
        }
        case "text": {
          const l = i;
          r += t.text(l.text);
          break;
        }
        default: {
          const l = 'Token with "' + i.type + '" type was not found.';
          if (this.options.silent)
            return console.error(l), "";
          throw new Error(l);
        }
      }
    }
    return r;
  }
}
class _r {
  constructor(e) {
    pe(this, "options");
    this.options = e || P0;
  }
  /**
   * Process markdown before marked
   */
  preprocess(e) {
    return e;
  }
  /**
   * Process HTML after marked is finished
   */
  postprocess(e) {
    return e;
  }
  /**
   * Process all tokens before walk tokens
   */
  processAllTokens(e) {
    return e;
  }
}
pe(_r, "passThroughHooks", /* @__PURE__ */ new Set([
  "preprocess",
  "postprocess",
  "processAllTokens"
]));
var O0, Za, Ru;
class Nu {
  constructor(...e) {
    ea(this, O0);
    pe(this, "defaults", Ti());
    pe(this, "options", this.setOptions);
    pe(this, "parse", Hr(this, O0, Za).call(this, Ut.lex, Gt.parse));
    pe(this, "parseInline", Hr(this, O0, Za).call(this, Ut.lexInline, Gt.parseInline));
    pe(this, "Parser", Gt);
    pe(this, "Renderer", Cn);
    pe(this, "TextRenderer", Ri);
    pe(this, "Lexer", Ut);
    pe(this, "Tokenizer", Fn);
    pe(this, "Hooks", _r);
    this.use(...e);
  }
  /**
   * Run callback for every token
   */
  walkTokens(e, t) {
    var a, i;
    let r = [];
    for (const l of e)
      switch (r = r.concat(t.call(this, l)), l.type) {
        case "table": {
          const s = l;
          for (const o of s.header)
            r = r.concat(this.walkTokens(o.tokens, t));
          for (const o of s.rows)
            for (const c of o)
              r = r.concat(this.walkTokens(c.tokens, t));
          break;
        }
        case "list": {
          const s = l;
          r = r.concat(this.walkTokens(s.items, t));
          break;
        }
        default: {
          const s = l;
          (i = (a = this.defaults.extensions) == null ? void 0 : a.childTokens) != null && i[s.type] ? this.defaults.extensions.childTokens[s.type].forEach((o) => {
            const c = s[o].flat(1 / 0);
            r = r.concat(this.walkTokens(c, t));
          }) : s.tokens && (r = r.concat(this.walkTokens(s.tokens, t)));
        }
      }
    return r;
  }
  use(...e) {
    const t = this.defaults.extensions || { renderers: {}, childTokens: {} };
    return e.forEach((r) => {
      const a = { ...r };
      if (a.async = this.defaults.async || a.async || !1, r.extensions && (r.extensions.forEach((i) => {
        if (!i.name)
          throw new Error("extension name required");
        if ("renderer" in i) {
          const l = t.renderers[i.name];
          l ? t.renderers[i.name] = function(...s) {
            let o = i.renderer.apply(this, s);
            return o === !1 && (o = l.apply(this, s)), o;
          } : t.renderers[i.name] = i.renderer;
        }
        if ("tokenizer" in i) {
          if (!i.level || i.level !== "block" && i.level !== "inline")
            throw new Error("extension level must be 'block' or 'inline'");
          const l = t[i.level];
          l ? l.unshift(i.tokenizer) : t[i.level] = [i.tokenizer], i.start && (i.level === "block" ? t.startBlock ? t.startBlock.push(i.start) : t.startBlock = [i.start] : i.level === "inline" && (t.startInline ? t.startInline.push(i.start) : t.startInline = [i.start]));
        }
        "childTokens" in i && i.childTokens && (t.childTokens[i.name] = i.childTokens);
      }), a.extensions = t), r.renderer) {
        const i = this.defaults.renderer || new Cn(this.defaults);
        for (const l in r.renderer) {
          if (!(l in i))
            throw new Error(`renderer '${l}' does not exist`);
          if (l === "options")
            continue;
          const s = l, o = r.renderer[s], c = i[s];
          i[s] = (...f) => {
            let d = o.apply(i, f);
            return d === !1 && (d = c.apply(i, f)), d || "";
          };
        }
        a.renderer = i;
      }
      if (r.tokenizer) {
        const i = this.defaults.tokenizer || new Fn(this.defaults);
        for (const l in r.tokenizer) {
          if (!(l in i))
            throw new Error(`tokenizer '${l}' does not exist`);
          if (["options", "rules", "lexer"].includes(l))
            continue;
          const s = l, o = r.tokenizer[s], c = i[s];
          i[s] = (...f) => {
            let d = o.apply(i, f);
            return d === !1 && (d = c.apply(i, f)), d;
          };
        }
        a.tokenizer = i;
      }
      if (r.hooks) {
        const i = this.defaults.hooks || new _r();
        for (const l in r.hooks) {
          if (!(l in i))
            throw new Error(`hook '${l}' does not exist`);
          if (l === "options")
            continue;
          const s = l, o = r.hooks[s], c = i[s];
          _r.passThroughHooks.has(l) ? i[s] = (f) => {
            if (this.defaults.async)
              return Promise.resolve(o.call(i, f)).then((g) => c.call(i, g));
            const d = o.call(i, f);
            return c.call(i, d);
          } : i[s] = (...f) => {
            let d = o.apply(i, f);
            return d === !1 && (d = c.apply(i, f)), d;
          };
        }
        a.hooks = i;
      }
      if (r.walkTokens) {
        const i = this.defaults.walkTokens, l = r.walkTokens;
        a.walkTokens = function(s) {
          let o = [];
          return o.push(l.call(this, s)), i && (o = o.concat(i.call(this, s))), o;
        };
      }
      this.defaults = { ...this.defaults, ...a };
    }), this;
  }
  setOptions(e) {
    return this.defaults = { ...this.defaults, ...e }, this;
  }
  lexer(e, t) {
    return Ut.lex(e, t ?? this.defaults);
  }
  parser(e, t) {
    return Gt.parse(e, t ?? this.defaults);
  }
}
O0 = new WeakSet(), Za = function(e, t) {
  return (r, a) => {
    const i = { ...a }, l = { ...this.defaults, ...i };
    this.defaults.async === !0 && i.async === !1 && (l.silent || console.warn("marked(): The async option was set to true by an extension. The async: false option sent to parse will be ignored."), l.async = !0);
    const s = Hr(this, O0, Ru).call(this, !!l.silent, !!l.async);
    if (typeof r > "u" || r === null)
      return s(new Error("marked(): input parameter is undefined or null"));
    if (typeof r != "string")
      return s(new Error("marked(): input parameter is of type " + Object.prototype.toString.call(r) + ", string expected"));
    if (l.hooks && (l.hooks.options = l), l.async)
      return Promise.resolve(l.hooks ? l.hooks.preprocess(r) : r).then((o) => e(o, l)).then((o) => l.hooks ? l.hooks.processAllTokens(o) : o).then((o) => l.walkTokens ? Promise.all(this.walkTokens(o, l.walkTokens)).then(() => o) : o).then((o) => t(o, l)).then((o) => l.hooks ? l.hooks.postprocess(o) : o).catch(s);
    try {
      l.hooks && (r = l.hooks.preprocess(r));
      let o = e(r, l);
      l.hooks && (o = l.hooks.processAllTokens(o)), l.walkTokens && this.walkTokens(o, l.walkTokens);
      let c = t(o, l);
      return l.hooks && (c = l.hooks.postprocess(c)), c;
    } catch (o) {
      return s(o);
    }
  };
}, Ru = function(e, t) {
  return (r) => {
    if (r.message += `
Please report this to https://github.com/markedjs/marked.`, e) {
      const a = "<p>An error occurred:</p><pre>" + at(r.message + "", !0) + "</pre>";
      return t ? Promise.resolve(a) : a;
    }
    if (t)
      return Promise.reject(r);
    throw r;
  };
};
const I0 = new Nu();
function ce(n, e) {
  return I0.parse(n, e);
}
ce.options = ce.setOptions = function(n) {
  return I0.setOptions(n), ce.defaults = I0.defaults, xu(ce.defaults), ce;
};
ce.getDefaults = Ti;
ce.defaults = P0;
ce.use = function(...n) {
  return I0.use(...n), ce.defaults = I0.defaults, xu(ce.defaults), ce;
};
ce.walkTokens = function(n, e) {
  return I0.walkTokens(n, e);
};
ce.parseInline = I0.parseInline;
ce.Parser = Gt;
ce.parser = Gt.parse;
ce.Renderer = Cn;
ce.TextRenderer = Ri;
ce.Lexer = Ut;
ce.lexer = Ut.lex;
ce.Tokenizer = Fn;
ce.Hooks = _r;
ce.parse = ce;
ce.options;
ce.setOptions;
ce.use;
ce.walkTokens;
ce.parseInline;
Gt.parse;
Ut.lex;
function Hh(n) {
  if (typeof n == "function" && (n = {
    highlight: n
  }), !n || typeof n.highlight != "function")
    throw new Error("Must provide highlight function");
  return typeof n.langPrefix != "string" && (n.langPrefix = "language-"), typeof n.emptyLangClass != "string" && (n.emptyLangClass = ""), {
    async: !!n.async,
    walkTokens(e) {
      if (e.type !== "code")
        return;
      const t = Zl(e.lang);
      if (n.async)
        return Promise.resolve(n.highlight(e.text, t, e.lang || "")).then(Kl(e));
      const r = n.highlight(e.text, t, e.lang || "");
      if (r instanceof Promise)
        throw new Error("markedHighlight is not set to async but the highlight function is async. Set the async option to true on markedHighlight to await the async highlight function.");
      Kl(e)(r);
    },
    useNewRenderer: !0,
    renderer: {
      code(e, t, r) {
        typeof e == "object" && (r = e.escaped, t = e.lang, e = e.text);
        const a = Zl(t), i = a ? n.langPrefix + Jl(a) : n.emptyLangClass, l = i ? ` class="${i}"` : "";
        return e = e.replace(/\n$/, ""), `<pre><code${l}>${r ? e : Jl(e, !0)}
</code></pre>`;
      }
    }
  };
}
function Zl(n) {
  return (n || "").match(/\S*/)[0];
}
function Kl(n) {
  return (e) => {
    typeof e == "string" && e !== n.text && (n.escaped = !0, n.text = e);
  };
}
const Iu = /[&<>"']/, Uh = new RegExp(Iu.source, "g"), Lu = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, Gh = new RegExp(Lu.source, "g"), Vh = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#39;"
}, Ql = (n) => Vh[n];
function Jl(n, e) {
  if (e) {
    if (Iu.test(n))
      return n.replace(Uh, Ql);
  } else if (Lu.test(n))
    return n.replace(Gh, Ql);
  return n;
}
const Wh = /[\0-\x1F!-,\.\/:-@\[-\^`\{-\xA9\xAB-\xB4\xB6-\xB9\xBB-\xBF\xD7\xF7\u02C2-\u02C5\u02D2-\u02DF\u02E5-\u02EB\u02ED\u02EF-\u02FF\u0375\u0378\u0379\u037E\u0380-\u0385\u0387\u038B\u038D\u03A2\u03F6\u0482\u0530\u0557\u0558\u055A-\u055F\u0589-\u0590\u05BE\u05C0\u05C3\u05C6\u05C8-\u05CF\u05EB-\u05EE\u05F3-\u060F\u061B-\u061F\u066A-\u066D\u06D4\u06DD\u06DE\u06E9\u06FD\u06FE\u0700-\u070F\u074B\u074C\u07B2-\u07BF\u07F6-\u07F9\u07FB\u07FC\u07FE\u07FF\u082E-\u083F\u085C-\u085F\u086B-\u089F\u08B5\u08C8-\u08D2\u08E2\u0964\u0965\u0970\u0984\u098D\u098E\u0991\u0992\u09A9\u09B1\u09B3-\u09B5\u09BA\u09BB\u09C5\u09C6\u09C9\u09CA\u09CF-\u09D6\u09D8-\u09DB\u09DE\u09E4\u09E5\u09F2-\u09FB\u09FD\u09FF\u0A00\u0A04\u0A0B-\u0A0E\u0A11\u0A12\u0A29\u0A31\u0A34\u0A37\u0A3A\u0A3B\u0A3D\u0A43-\u0A46\u0A49\u0A4A\u0A4E-\u0A50\u0A52-\u0A58\u0A5D\u0A5F-\u0A65\u0A76-\u0A80\u0A84\u0A8E\u0A92\u0AA9\u0AB1\u0AB4\u0ABA\u0ABB\u0AC6\u0ACA\u0ACE\u0ACF\u0AD1-\u0ADF\u0AE4\u0AE5\u0AF0-\u0AF8\u0B00\u0B04\u0B0D\u0B0E\u0B11\u0B12\u0B29\u0B31\u0B34\u0B3A\u0B3B\u0B45\u0B46\u0B49\u0B4A\u0B4E-\u0B54\u0B58-\u0B5B\u0B5E\u0B64\u0B65\u0B70\u0B72-\u0B81\u0B84\u0B8B-\u0B8D\u0B91\u0B96-\u0B98\u0B9B\u0B9D\u0BA0-\u0BA2\u0BA5-\u0BA7\u0BAB-\u0BAD\u0BBA-\u0BBD\u0BC3-\u0BC5\u0BC9\u0BCE\u0BCF\u0BD1-\u0BD6\u0BD8-\u0BE5\u0BF0-\u0BFF\u0C0D\u0C11\u0C29\u0C3A-\u0C3C\u0C45\u0C49\u0C4E-\u0C54\u0C57\u0C5B-\u0C5F\u0C64\u0C65\u0C70-\u0C7F\u0C84\u0C8D\u0C91\u0CA9\u0CB4\u0CBA\u0CBB\u0CC5\u0CC9\u0CCE-\u0CD4\u0CD7-\u0CDD\u0CDF\u0CE4\u0CE5\u0CF0\u0CF3-\u0CFF\u0D0D\u0D11\u0D45\u0D49\u0D4F-\u0D53\u0D58-\u0D5E\u0D64\u0D65\u0D70-\u0D79\u0D80\u0D84\u0D97-\u0D99\u0DB2\u0DBC\u0DBE\u0DBF\u0DC7-\u0DC9\u0DCB-\u0DCE\u0DD5\u0DD7\u0DE0-\u0DE5\u0DF0\u0DF1\u0DF4-\u0E00\u0E3B-\u0E3F\u0E4F\u0E5A-\u0E80\u0E83\u0E85\u0E8B\u0EA4\u0EA6\u0EBE\u0EBF\u0EC5\u0EC7\u0ECE\u0ECF\u0EDA\u0EDB\u0EE0-\u0EFF\u0F01-\u0F17\u0F1A-\u0F1F\u0F2A-\u0F34\u0F36\u0F38\u0F3A-\u0F3D\u0F48\u0F6D-\u0F70\u0F85\u0F98\u0FBD-\u0FC5\u0FC7-\u0FFF\u104A-\u104F\u109E\u109F\u10C6\u10C8-\u10CC\u10CE\u10CF\u10FB\u1249\u124E\u124F\u1257\u1259\u125E\u125F\u1289\u128E\u128F\u12B1\u12B6\u12B7\u12BF\u12C1\u12C6\u12C7\u12D7\u1311\u1316\u1317\u135B\u135C\u1360-\u137F\u1390-\u139F\u13F6\u13F7\u13FE-\u1400\u166D\u166E\u1680\u169B-\u169F\u16EB-\u16ED\u16F9-\u16FF\u170D\u1715-\u171F\u1735-\u173F\u1754-\u175F\u176D\u1771\u1774-\u177F\u17D4-\u17D6\u17D8-\u17DB\u17DE\u17DF\u17EA-\u180A\u180E\u180F\u181A-\u181F\u1879-\u187F\u18AB-\u18AF\u18F6-\u18FF\u191F\u192C-\u192F\u193C-\u1945\u196E\u196F\u1975-\u197F\u19AC-\u19AF\u19CA-\u19CF\u19DA-\u19FF\u1A1C-\u1A1F\u1A5F\u1A7D\u1A7E\u1A8A-\u1A8F\u1A9A-\u1AA6\u1AA8-\u1AAF\u1AC1-\u1AFF\u1B4C-\u1B4F\u1B5A-\u1B6A\u1B74-\u1B7F\u1BF4-\u1BFF\u1C38-\u1C3F\u1C4A-\u1C4C\u1C7E\u1C7F\u1C89-\u1C8F\u1CBB\u1CBC\u1CC0-\u1CCF\u1CD3\u1CFB-\u1CFF\u1DFA\u1F16\u1F17\u1F1E\u1F1F\u1F46\u1F47\u1F4E\u1F4F\u1F58\u1F5A\u1F5C\u1F5E\u1F7E\u1F7F\u1FB5\u1FBD\u1FBF-\u1FC1\u1FC5\u1FCD-\u1FCF\u1FD4\u1FD5\u1FDC-\u1FDF\u1FED-\u1FF1\u1FF5\u1FFD-\u203E\u2041-\u2053\u2055-\u2070\u2072-\u207E\u2080-\u208F\u209D-\u20CF\u20F1-\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211E-\u2123\u2125\u2127\u2129\u212E\u213A\u213B\u2140-\u2144\u214A-\u214D\u214F-\u215F\u2189-\u24B5\u24EA-\u2BFF\u2C2F\u2C5F\u2CE5-\u2CEA\u2CF4-\u2CFF\u2D26\u2D28-\u2D2C\u2D2E\u2D2F\u2D68-\u2D6E\u2D70-\u2D7E\u2D97-\u2D9F\u2DA7\u2DAF\u2DB7\u2DBF\u2DC7\u2DCF\u2DD7\u2DDF\u2E00-\u2E2E\u2E30-\u3004\u3008-\u3020\u3030\u3036\u3037\u303D-\u3040\u3097\u3098\u309B\u309C\u30A0\u30FB\u3100-\u3104\u3130\u318F-\u319F\u31C0-\u31EF\u3200-\u33FF\u4DC0-\u4DFF\u9FFD-\u9FFF\uA48D-\uA4CF\uA4FE\uA4FF\uA60D-\uA60F\uA62C-\uA63F\uA673\uA67E\uA6F2-\uA716\uA720\uA721\uA789\uA78A\uA7C0\uA7C1\uA7CB-\uA7F4\uA828-\uA82B\uA82D-\uA83F\uA874-\uA87F\uA8C6-\uA8CF\uA8DA-\uA8DF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA954-\uA95F\uA97D-\uA97F\uA9C1-\uA9CE\uA9DA-\uA9DF\uA9FF\uAA37-\uAA3F\uAA4E\uAA4F\uAA5A-\uAA5F\uAA77-\uAA79\uAAC3-\uAADA\uAADE\uAADF\uAAF0\uAAF1\uAAF7-\uAB00\uAB07\uAB08\uAB0F\uAB10\uAB17-\uAB1F\uAB27\uAB2F\uAB5B\uAB6A-\uAB6F\uABEB\uABEE\uABEF\uABFA-\uABFF\uD7A4-\uD7AF\uD7C7-\uD7CA\uD7FC-\uD7FF\uE000-\uF8FF\uFA6E\uFA6F\uFADA-\uFAFF\uFB07-\uFB12\uFB18-\uFB1C\uFB29\uFB37\uFB3D\uFB3F\uFB42\uFB45\uFBB2-\uFBD2\uFD3E-\uFD4F\uFD90\uFD91\uFDC8-\uFDEF\uFDFC-\uFDFF\uFE10-\uFE1F\uFE30-\uFE32\uFE35-\uFE4C\uFE50-\uFE6F\uFE75\uFEFD-\uFF0F\uFF1A-\uFF20\uFF3B-\uFF3E\uFF40\uFF5B-\uFF65\uFFBF-\uFFC1\uFFC8\uFFC9\uFFD0\uFFD1\uFFD8\uFFD9\uFFDD-\uFFFF]|\uD800[\uDC0C\uDC27\uDC3B\uDC3E\uDC4E\uDC4F\uDC5E-\uDC7F\uDCFB-\uDD3F\uDD75-\uDDFC\uDDFE-\uDE7F\uDE9D-\uDE9F\uDED1-\uDEDF\uDEE1-\uDEFF\uDF20-\uDF2C\uDF4B-\uDF4F\uDF7B-\uDF7F\uDF9E\uDF9F\uDFC4-\uDFC7\uDFD0\uDFD6-\uDFFF]|\uD801[\uDC9E\uDC9F\uDCAA-\uDCAF\uDCD4-\uDCD7\uDCFC-\uDCFF\uDD28-\uDD2F\uDD64-\uDDFF\uDF37-\uDF3F\uDF56-\uDF5F\uDF68-\uDFFF]|\uD802[\uDC06\uDC07\uDC09\uDC36\uDC39-\uDC3B\uDC3D\uDC3E\uDC56-\uDC5F\uDC77-\uDC7F\uDC9F-\uDCDF\uDCF3\uDCF6-\uDCFF\uDD16-\uDD1F\uDD3A-\uDD7F\uDDB8-\uDDBD\uDDC0-\uDDFF\uDE04\uDE07-\uDE0B\uDE14\uDE18\uDE36\uDE37\uDE3B-\uDE3E\uDE40-\uDE5F\uDE7D-\uDE7F\uDE9D-\uDEBF\uDEC8\uDEE7-\uDEFF\uDF36-\uDF3F\uDF56-\uDF5F\uDF73-\uDF7F\uDF92-\uDFFF]|\uD803[\uDC49-\uDC7F\uDCB3-\uDCBF\uDCF3-\uDCFF\uDD28-\uDD2F\uDD3A-\uDE7F\uDEAA\uDEAD-\uDEAF\uDEB2-\uDEFF\uDF1D-\uDF26\uDF28-\uDF2F\uDF51-\uDFAF\uDFC5-\uDFDF\uDFF7-\uDFFF]|\uD804[\uDC47-\uDC65\uDC70-\uDC7E\uDCBB-\uDCCF\uDCE9-\uDCEF\uDCFA-\uDCFF\uDD35\uDD40-\uDD43\uDD48-\uDD4F\uDD74\uDD75\uDD77-\uDD7F\uDDC5-\uDDC8\uDDCD\uDDDB\uDDDD-\uDDFF\uDE12\uDE38-\uDE3D\uDE3F-\uDE7F\uDE87\uDE89\uDE8E\uDE9E\uDEA9-\uDEAF\uDEEB-\uDEEF\uDEFA-\uDEFF\uDF04\uDF0D\uDF0E\uDF11\uDF12\uDF29\uDF31\uDF34\uDF3A\uDF45\uDF46\uDF49\uDF4A\uDF4E\uDF4F\uDF51-\uDF56\uDF58-\uDF5C\uDF64\uDF65\uDF6D-\uDF6F\uDF75-\uDFFF]|\uD805[\uDC4B-\uDC4F\uDC5A-\uDC5D\uDC62-\uDC7F\uDCC6\uDCC8-\uDCCF\uDCDA-\uDD7F\uDDB6\uDDB7\uDDC1-\uDDD7\uDDDE-\uDDFF\uDE41-\uDE43\uDE45-\uDE4F\uDE5A-\uDE7F\uDEB9-\uDEBF\uDECA-\uDEFF\uDF1B\uDF1C\uDF2C-\uDF2F\uDF3A-\uDFFF]|\uD806[\uDC3B-\uDC9F\uDCEA-\uDCFE\uDD07\uDD08\uDD0A\uDD0B\uDD14\uDD17\uDD36\uDD39\uDD3A\uDD44-\uDD4F\uDD5A-\uDD9F\uDDA8\uDDA9\uDDD8\uDDD9\uDDE2\uDDE5-\uDDFF\uDE3F-\uDE46\uDE48-\uDE4F\uDE9A-\uDE9C\uDE9E-\uDEBF\uDEF9-\uDFFF]|\uD807[\uDC09\uDC37\uDC41-\uDC4F\uDC5A-\uDC71\uDC90\uDC91\uDCA8\uDCB7-\uDCFF\uDD07\uDD0A\uDD37-\uDD39\uDD3B\uDD3E\uDD48-\uDD4F\uDD5A-\uDD5F\uDD66\uDD69\uDD8F\uDD92\uDD99-\uDD9F\uDDAA-\uDEDF\uDEF7-\uDFAF\uDFB1-\uDFFF]|\uD808[\uDF9A-\uDFFF]|\uD809[\uDC6F-\uDC7F\uDD44-\uDFFF]|[\uD80A\uD80B\uD80E-\uD810\uD812-\uD819\uD824-\uD82B\uD82D\uD82E\uD830-\uD833\uD837\uD839\uD83D\uD83F\uD87B-\uD87D\uD87F\uD885-\uDB3F\uDB41-\uDBFF][\uDC00-\uDFFF]|\uD80D[\uDC2F-\uDFFF]|\uD811[\uDE47-\uDFFF]|\uD81A[\uDE39-\uDE3F\uDE5F\uDE6A-\uDECF\uDEEE\uDEEF\uDEF5-\uDEFF\uDF37-\uDF3F\uDF44-\uDF4F\uDF5A-\uDF62\uDF78-\uDF7C\uDF90-\uDFFF]|\uD81B[\uDC00-\uDE3F\uDE80-\uDEFF\uDF4B-\uDF4E\uDF88-\uDF8E\uDFA0-\uDFDF\uDFE2\uDFE5-\uDFEF\uDFF2-\uDFFF]|\uD821[\uDFF8-\uDFFF]|\uD823[\uDCD6-\uDCFF\uDD09-\uDFFF]|\uD82C[\uDD1F-\uDD4F\uDD53-\uDD63\uDD68-\uDD6F\uDEFC-\uDFFF]|\uD82F[\uDC6B-\uDC6F\uDC7D-\uDC7F\uDC89-\uDC8F\uDC9A-\uDC9C\uDC9F-\uDFFF]|\uD834[\uDC00-\uDD64\uDD6A-\uDD6C\uDD73-\uDD7A\uDD83\uDD84\uDD8C-\uDDA9\uDDAE-\uDE41\uDE45-\uDFFF]|\uD835[\uDC55\uDC9D\uDCA0\uDCA1\uDCA3\uDCA4\uDCA7\uDCA8\uDCAD\uDCBA\uDCBC\uDCC4\uDD06\uDD0B\uDD0C\uDD15\uDD1D\uDD3A\uDD3F\uDD45\uDD47-\uDD49\uDD51\uDEA6\uDEA7\uDEC1\uDEDB\uDEFB\uDF15\uDF35\uDF4F\uDF6F\uDF89\uDFA9\uDFC3\uDFCC\uDFCD]|\uD836[\uDC00-\uDDFF\uDE37-\uDE3A\uDE6D-\uDE74\uDE76-\uDE83\uDE85-\uDE9A\uDEA0\uDEB0-\uDFFF]|\uD838[\uDC07\uDC19\uDC1A\uDC22\uDC25\uDC2B-\uDCFF\uDD2D-\uDD2F\uDD3E\uDD3F\uDD4A-\uDD4D\uDD4F-\uDEBF\uDEFA-\uDFFF]|\uD83A[\uDCC5-\uDCCF\uDCD7-\uDCFF\uDD4C-\uDD4F\uDD5A-\uDFFF]|\uD83B[\uDC00-\uDDFF\uDE04\uDE20\uDE23\uDE25\uDE26\uDE28\uDE33\uDE38\uDE3A\uDE3C-\uDE41\uDE43-\uDE46\uDE48\uDE4A\uDE4C\uDE50\uDE53\uDE55\uDE56\uDE58\uDE5A\uDE5C\uDE5E\uDE60\uDE63\uDE65\uDE66\uDE6B\uDE73\uDE78\uDE7D\uDE7F\uDE8A\uDE9C-\uDEA0\uDEA4\uDEAA\uDEBC-\uDFFF]|\uD83C[\uDC00-\uDD2F\uDD4A-\uDD4F\uDD6A-\uDD6F\uDD8A-\uDFFF]|\uD83E[\uDC00-\uDFEF\uDFFA-\uDFFF]|\uD869[\uDEDE-\uDEFF]|\uD86D[\uDF35-\uDF3F]|\uD86E[\uDC1E\uDC1F]|\uD873[\uDEA2-\uDEAF]|\uD87A[\uDFE1-\uDFFF]|\uD87E[\uDE1E-\uDFFF]|\uD884[\uDF4B-\uDFFF]|\uDB40[\uDC00-\uDCFF\uDDF0-\uDFFF]/g, Xh = Object.hasOwnProperty;
class Ii {
  /**
   * Create a new slug class.
   */
  constructor() {
    this.occurrences, this.reset();
  }
  /**
   * Generate a unique slug.
  *
  * Tracks previously generated slugs: repeated calls with the same value
  * will result in different slugs.
  * Use the `slug` function to get same slugs.
   *
   * @param  {string} value
   *   String of text to slugify
   * @param  {boolean} [maintainCase=false]
   *   Keep the current case, otherwise make all lowercase
   * @return {string}
   *   A unique slug string
   */
  slug(e, t) {
    const r = this;
    let a = Yh(e, t === !0);
    const i = a;
    for (; Xh.call(r.occurrences, a); )
      r.occurrences[i]++, a = i + "-" + r.occurrences[i];
    return r.occurrences[a] = 0, a;
  }
  /**
   * Reset - Forget all previous slugs
   *
   * @return void
   */
  reset() {
    this.occurrences = /* @__PURE__ */ Object.create(null);
  }
}
function Yh(n, e) {
  return typeof n != "string" ? "" : (e || (n = n.toLowerCase()), n.replace(Wh, "").replace(/ /g, "-"));
}
let Ou = new Ii(), qu = [];
function jh({ prefix: n = "", globalSlugs: e = !1 } = {}) {
  return {
    headerIds: !1,
    // prevent deprecation warning; remove this once headerIds option is removed
    hooks: {
      preprocess(t) {
        return e || Zh(), t;
      }
    },
    renderer: {
      heading(t, r, a) {
        a = a.toLowerCase().trim().replace(/<[!\/a-z].*?>/gi, "");
        const i = `${n}${Ou.slug(a)}`, l = { level: r, text: t, id: i };
        return qu.push(l), `<h${r} id="${i}">${t}</h${r}>
`;
      }
    }
  };
}
function Zh() {
  qu = [], Ou = new Ii();
}
var $l = typeof globalThis < "u" ? globalThis : typeof window < "u" ? window : typeof global < "u" ? global : typeof self < "u" ? self : {}, Pu = { exports: {} };
(function(n) {
  var e = typeof window < "u" ? window : typeof WorkerGlobalScope < "u" && self instanceof WorkerGlobalScope ? self : {};
  /**
   * Prism: Lightweight, robust, elegant syntax highlighting
   *
   * @license MIT <https://opensource.org/licenses/MIT>
   * @author Lea Verou <https://lea.verou.me>
   * @namespace
   * @public
   */
  var t = function(r) {
    var a = /(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i, i = 0, l = {}, s = {
      /**
       * By default, Prism will attempt to highlight all code elements (by calling {@link Prism.highlightAll}) on the
       * current page after the page finished loading. This might be a problem if e.g. you wanted to asynchronously load
       * additional languages or plugins yourself.
       *
       * By setting this value to `true`, Prism will not automatically highlight all code elements on the page.
       *
       * You obviously have to change this value before the automatic highlighting started. To do this, you can add an
       * empty Prism object into the global scope before loading the Prism script like this:
       *
       * ```js
       * window.Prism = window.Prism || {};
       * Prism.manual = true;
       * // add a new <script> to load Prism's script
       * ```
       *
       * @default false
       * @type {boolean}
       * @memberof Prism
       * @public
       */
      manual: r.Prism && r.Prism.manual,
      /**
       * By default, if Prism is in a web worker, it assumes that it is in a worker it created itself, so it uses
       * `addEventListener` to communicate with its parent instance. However, if you're using Prism manually in your
       * own worker, you don't want it to do this.
       *
       * By setting this value to `true`, Prism will not add its own listeners to the worker.
       *
       * You obviously have to change this value before Prism executes. To do this, you can add an
       * empty Prism object into the global scope before loading the Prism script like this:
       *
       * ```js
       * window.Prism = window.Prism || {};
       * Prism.disableWorkerMessageHandler = true;
       * // Load Prism's script
       * ```
       *
       * @default false
       * @type {boolean}
       * @memberof Prism
       * @public
       */
      disableWorkerMessageHandler: r.Prism && r.Prism.disableWorkerMessageHandler,
      /**
       * A namespace for utility methods.
       *
       * All function in this namespace that are not explicitly marked as _public_ are for __internal use only__ and may
       * change or disappear at any time.
       *
       * @namespace
       * @memberof Prism
       */
      util: {
        encode: function D(b) {
          return b instanceof o ? new o(b.type, D(b.content), b.alias) : Array.isArray(b) ? b.map(D) : b.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/\u00a0/g, " ");
        },
        /**
         * Returns the name of the type of the given value.
         *
         * @param {any} o
         * @returns {string}
         * @example
         * type(null)      === 'Null'
         * type(undefined) === 'Undefined'
         * type(123)       === 'Number'
         * type('foo')     === 'String'
         * type(true)      === 'Boolean'
         * type([1, 2])    === 'Array'
         * type({})        === 'Object'
         * type(String)    === 'Function'
         * type(/abc+/)    === 'RegExp'
         */
        type: function(D) {
          return Object.prototype.toString.call(D).slice(8, -1);
        },
        /**
         * Returns a unique number for the given object. Later calls will still return the same number.
         *
         * @param {Object} obj
         * @returns {number}
         */
        objId: function(D) {
          return D.__id || Object.defineProperty(D, "__id", { value: ++i }), D.__id;
        },
        /**
         * Creates a deep clone of the given object.
         *
         * The main intended use of this function is to clone language definitions.
         *
         * @param {T} o
         * @param {Record<number, any>} [visited]
         * @returns {T}
         * @template T
         */
        clone: function D(b, F) {
          F = F || {};
          var T, M;
          switch (s.util.type(b)) {
            case "Object":
              if (M = s.util.objId(b), F[M])
                return F[M];
              T = /** @type {Record<string, any>} */
              {}, F[M] = T;
              for (var z in b)
                b.hasOwnProperty(z) && (T[z] = D(b[z], F));
              return (
                /** @type {any} */
                T
              );
            case "Array":
              return M = s.util.objId(b), F[M] ? F[M] : (T = [], F[M] = T, /** @type {Array} */
              /** @type {any} */
              b.forEach(function(O, R) {
                T[R] = D(O, F);
              }), /** @type {any} */
              T);
            default:
              return b;
          }
        },
        /**
         * Returns the Prism language of the given element set by a `language-xxxx` or `lang-xxxx` class.
         *
         * If no language is set for the element or the element is `null` or `undefined`, `none` will be returned.
         *
         * @param {Element} element
         * @returns {string}
         */
        getLanguage: function(D) {
          for (; D; ) {
            var b = a.exec(D.className);
            if (b)
              return b[1].toLowerCase();
            D = D.parentElement;
          }
          return "none";
        },
        /**
         * Sets the Prism `language-xxxx` class of the given element.
         *
         * @param {Element} element
         * @param {string} language
         * @returns {void}
         */
        setLanguage: function(D, b) {
          D.className = D.className.replace(RegExp(a, "gi"), ""), D.classList.add("language-" + b);
        },
        /**
         * Returns the script element that is currently executing.
         *
         * This does __not__ work for line script element.
         *
         * @returns {HTMLScriptElement | null}
         */
        currentScript: function() {
          if (typeof document > "u")
            return null;
          if ("currentScript" in document)
            return (
              /** @type {any} */
              document.currentScript
            );
          try {
            throw new Error();
          } catch (T) {
            var D = (/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(T.stack) || [])[1];
            if (D) {
              var b = document.getElementsByTagName("script");
              for (var F in b)
                if (b[F].src == D)
                  return b[F];
            }
            return null;
          }
        },
        /**
         * Returns whether a given class is active for `element`.
         *
         * The class can be activated if `element` or one of its ancestors has the given class and it can be deactivated
         * if `element` or one of its ancestors has the negated version of the given class. The _negated version_ of the
         * given class is just the given class with a `no-` prefix.
         *
         * Whether the class is active is determined by the closest ancestor of `element` (where `element` itself is
         * closest ancestor) that has the given class or the negated version of it. If neither `element` nor any of its
         * ancestors have the given class or the negated version of it, then the default activation will be returned.
         *
         * In the paradoxical situation where the closest ancestor contains __both__ the given class and the negated
         * version of it, the class is considered active.
         *
         * @param {Element} element
         * @param {string} className
         * @param {boolean} [defaultActivation=false]
         * @returns {boolean}
         */
        isActive: function(D, b, F) {
          for (var T = "no-" + b; D; ) {
            var M = D.classList;
            if (M.contains(b))
              return !0;
            if (M.contains(T))
              return !1;
            D = D.parentElement;
          }
          return !!F;
        }
      },
      /**
       * This namespace contains all currently loaded languages and the some helper functions to create and modify languages.
       *
       * @namespace
       * @memberof Prism
       * @public
       */
      languages: {
        /**
         * The grammar for plain, unformatted text.
         */
        plain: l,
        plaintext: l,
        text: l,
        txt: l,
        /**
         * Creates a deep copy of the language with the given id and appends the given tokens.
         *
         * If a token in `redef` also appears in the copied language, then the existing token in the copied language
         * will be overwritten at its original position.
         *
         * ## Best practices
         *
         * Since the position of overwriting tokens (token in `redef` that overwrite tokens in the copied language)
         * doesn't matter, they can technically be in any order. However, this can be confusing to others that trying to
         * understand the language definition because, normally, the order of tokens matters in Prism grammars.
         *
         * Therefore, it is encouraged to order overwriting tokens according to the positions of the overwritten tokens.
         * Furthermore, all non-overwriting tokens should be placed after the overwriting ones.
         *
         * @param {string} id The id of the language to extend. This has to be a key in `Prism.languages`.
         * @param {Grammar} redef The new tokens to append.
         * @returns {Grammar} The new language created.
         * @public
         * @example
         * Prism.languages['css-with-colors'] = Prism.languages.extend('css', {
         *     // Prism.languages.css already has a 'comment' token, so this token will overwrite CSS' 'comment' token
         *     // at its original position
         *     'comment': { ... },
         *     // CSS doesn't have a 'color' token, so this token will be appended
         *     'color': /\b(?:red|green|blue)\b/
         * });
         */
        extend: function(D, b) {
          var F = s.util.clone(s.languages[D]);
          for (var T in b)
            F[T] = b[T];
          return F;
        },
        /**
         * Inserts tokens _before_ another token in a language definition or any other grammar.
         *
         * ## Usage
         *
         * This helper method makes it easy to modify existing languages. For example, the CSS language definition
         * not only defines CSS highlighting for CSS documents, but also needs to define highlighting for CSS embedded
         * in HTML through `<style>` elements. To do this, it needs to modify `Prism.languages.markup` and add the
         * appropriate tokens. However, `Prism.languages.markup` is a regular JavaScript object literal, so if you do
         * this:
         *
         * ```js
         * Prism.languages.markup.style = {
         *     // token
         * };
         * ```
         *
         * then the `style` token will be added (and processed) at the end. `insertBefore` allows you to insert tokens
         * before existing tokens. For the CSS example above, you would use it like this:
         *
         * ```js
         * Prism.languages.insertBefore('markup', 'cdata', {
         *     'style': {
         *         // token
         *     }
         * });
         * ```
         *
         * ## Special cases
         *
         * If the grammars of `inside` and `insert` have tokens with the same name, the tokens in `inside`'s grammar
         * will be ignored.
         *
         * This behavior can be used to insert tokens after `before`:
         *
         * ```js
         * Prism.languages.insertBefore('markup', 'comment', {
         *     'comment': Prism.languages.markup.comment,
         *     // tokens after 'comment'
         * });
         * ```
         *
         * ## Limitations
         *
         * The main problem `insertBefore` has to solve is iteration order. Since ES2015, the iteration order for object
         * properties is guaranteed to be the insertion order (except for integer keys) but some browsers behave
         * differently when keys are deleted and re-inserted. So `insertBefore` can't be implemented by temporarily
         * deleting properties which is necessary to insert at arbitrary positions.
         *
         * To solve this problem, `insertBefore` doesn't actually insert the given tokens into the target object.
         * Instead, it will create a new object and replace all references to the target object with the new one. This
         * can be done without temporarily deleting properties, so the iteration order is well-defined.
         *
         * However, only references that can be reached from `Prism.languages` or `insert` will be replaced. I.e. if
         * you hold the target object in a variable, then the value of the variable will not change.
         *
         * ```js
         * var oldMarkup = Prism.languages.markup;
         * var newMarkup = Prism.languages.insertBefore('markup', 'comment', { ... });
         *
         * assert(oldMarkup !== Prism.languages.markup);
         * assert(newMarkup === Prism.languages.markup);
         * ```
         *
         * @param {string} inside The property of `root` (e.g. a language id in `Prism.languages`) that contains the
         * object to be modified.
         * @param {string} before The key to insert before.
         * @param {Grammar} insert An object containing the key-value pairs to be inserted.
         * @param {Object<string, any>} [root] The object containing `inside`, i.e. the object that contains the
         * object to be modified.
         *
         * Defaults to `Prism.languages`.
         * @returns {Grammar} The new grammar object.
         * @public
         */
        insertBefore: function(D, b, F, T) {
          T = T || /** @type {any} */
          s.languages;
          var M = T[D], z = {};
          for (var O in M)
            if (M.hasOwnProperty(O)) {
              if (O == b)
                for (var R in F)
                  F.hasOwnProperty(R) && (z[R] = F[R]);
              F.hasOwnProperty(O) || (z[O] = M[O]);
            }
          var B = T[D];
          return T[D] = z, s.languages.DFS(s.languages, function(X, $) {
            $ === B && X != D && (this[X] = z);
          }), z;
        },
        // Traverse a language definition with Depth First Search
        DFS: function D(b, F, T, M) {
          M = M || {};
          var z = s.util.objId;
          for (var O in b)
            if (b.hasOwnProperty(O)) {
              F.call(b, O, b[O], T || O);
              var R = b[O], B = s.util.type(R);
              B === "Object" && !M[z(R)] ? (M[z(R)] = !0, D(R, F, null, M)) : B === "Array" && !M[z(R)] && (M[z(R)] = !0, D(R, F, O, M));
            }
        }
      },
      plugins: {},
      /**
       * This is the most high-level function in Prism’s API.
       * It fetches all the elements that have a `.language-xxxx` class and then calls {@link Prism.highlightElement} on
       * each one of them.
       *
       * This is equivalent to `Prism.highlightAllUnder(document, async, callback)`.
       *
       * @param {boolean} [async=false] Same as in {@link Prism.highlightAllUnder}.
       * @param {HighlightCallback} [callback] Same as in {@link Prism.highlightAllUnder}.
       * @memberof Prism
       * @public
       */
      highlightAll: function(D, b) {
        s.highlightAllUnder(document, D, b);
      },
      /**
       * Fetches all the descendants of `container` that have a `.language-xxxx` class and then calls
       * {@link Prism.highlightElement} on each one of them.
       *
       * The following hooks will be run:
       * 1. `before-highlightall`
       * 2. `before-all-elements-highlight`
       * 3. All hooks of {@link Prism.highlightElement} for each element.
       *
       * @param {ParentNode} container The root element, whose descendants that have a `.language-xxxx` class will be highlighted.
       * @param {boolean} [async=false] Whether each element is to be highlighted asynchronously using Web Workers.
       * @param {HighlightCallback} [callback] An optional callback to be invoked on each element after its highlighting is done.
       * @memberof Prism
       * @public
       */
      highlightAllUnder: function(D, b, F) {
        var T = {
          callback: F,
          container: D,
          selector: 'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code'
        };
        s.hooks.run("before-highlightall", T), T.elements = Array.prototype.slice.apply(T.container.querySelectorAll(T.selector)), s.hooks.run("before-all-elements-highlight", T);
        for (var M = 0, z; z = T.elements[M++]; )
          s.highlightElement(z, b === !0, T.callback);
      },
      /**
       * Highlights the code inside a single element.
       *
       * The following hooks will be run:
       * 1. `before-sanity-check`
       * 2. `before-highlight`
       * 3. All hooks of {@link Prism.highlight}. These hooks will be run by an asynchronous worker if `async` is `true`.
       * 4. `before-insert`
       * 5. `after-highlight`
       * 6. `complete`
       *
       * Some the above hooks will be skipped if the element doesn't contain any text or there is no grammar loaded for
       * the element's language.
       *
       * @param {Element} element The element containing the code.
       * It must have a class of `language-xxxx` to be processed, where `xxxx` is a valid language identifier.
       * @param {boolean} [async=false] Whether the element is to be highlighted asynchronously using Web Workers
       * to improve performance and avoid blocking the UI when highlighting very large chunks of code. This option is
       * [disabled by default](https://prismjs.com/faq.html#why-is-asynchronous-highlighting-disabled-by-default).
       *
       * Note: All language definitions required to highlight the code must be included in the main `prism.js` file for
       * asynchronous highlighting to work. You can build your own bundle on the
       * [Download page](https://prismjs.com/download.html).
       * @param {HighlightCallback} [callback] An optional callback to be invoked after the highlighting is done.
       * Mostly useful when `async` is `true`, since in that case, the highlighting is done asynchronously.
       * @memberof Prism
       * @public
       */
      highlightElement: function(D, b, F) {
        var T = s.util.getLanguage(D), M = s.languages[T];
        s.util.setLanguage(D, T);
        var z = D.parentElement;
        z && z.nodeName.toLowerCase() === "pre" && s.util.setLanguage(z, T);
        var O = D.textContent, R = {
          element: D,
          language: T,
          grammar: M,
          code: O
        };
        function B($) {
          R.highlightedCode = $, s.hooks.run("before-insert", R), R.element.innerHTML = R.highlightedCode, s.hooks.run("after-highlight", R), s.hooks.run("complete", R), F && F.call(R.element);
        }
        if (s.hooks.run("before-sanity-check", R), z = R.element.parentElement, z && z.nodeName.toLowerCase() === "pre" && !z.hasAttribute("tabindex") && z.setAttribute("tabindex", "0"), !R.code) {
          s.hooks.run("complete", R), F && F.call(R.element);
          return;
        }
        if (s.hooks.run("before-highlight", R), !R.grammar) {
          B(s.util.encode(R.code));
          return;
        }
        if (b && r.Worker) {
          var X = new Worker(s.filename);
          X.onmessage = function($) {
            B($.data);
          }, X.postMessage(JSON.stringify({
            language: R.language,
            code: R.code,
            immediateClose: !0
          }));
        } else
          B(s.highlight(R.code, R.grammar, R.language));
      },
      /**
       * Low-level function, only use if you know what you’re doing. It accepts a string of text as input
       * and the language definitions to use, and returns a string with the HTML produced.
       *
       * The following hooks will be run:
       * 1. `before-tokenize`
       * 2. `after-tokenize`
       * 3. `wrap`: On each {@link Token}.
       *
       * @param {string} text A string with the code to be highlighted.
       * @param {Grammar} grammar An object containing the tokens to use.
       *
       * Usually a language definition like `Prism.languages.markup`.
       * @param {string} language The name of the language definition passed to `grammar`.
       * @returns {string} The highlighted HTML.
       * @memberof Prism
       * @public
       * @example
       * Prism.highlight('var foo = true;', Prism.languages.javascript, 'javascript');
       */
      highlight: function(D, b, F) {
        var T = {
          code: D,
          grammar: b,
          language: F
        };
        if (s.hooks.run("before-tokenize", T), !T.grammar)
          throw new Error('The language "' + T.language + '" has no grammar.');
        return T.tokens = s.tokenize(T.code, T.grammar), s.hooks.run("after-tokenize", T), o.stringify(s.util.encode(T.tokens), T.language);
      },
      /**
       * This is the heart of Prism, and the most low-level function you can use. It accepts a string of text as input
       * and the language definitions to use, and returns an array with the tokenized code.
       *
       * When the language definition includes nested tokens, the function is called recursively on each of these tokens.
       *
       * This method could be useful in other contexts as well, as a very crude parser.
       *
       * @param {string} text A string with the code to be highlighted.
       * @param {Grammar} grammar An object containing the tokens to use.
       *
       * Usually a language definition like `Prism.languages.markup`.
       * @returns {TokenStream} An array of strings and tokens, a token stream.
       * @memberof Prism
       * @public
       * @example
       * let code = `var foo = 0;`;
       * let tokens = Prism.tokenize(code, Prism.languages.javascript);
       * tokens.forEach(token => {
       *     if (token instanceof Prism.Token && token.type === 'number') {
       *         console.log(`Found numeric literal: ${token.content}`);
       *     }
       * });
       */
      tokenize: function(D, b) {
        var F = b.rest;
        if (F) {
          for (var T in F)
            b[T] = F[T];
          delete b.rest;
        }
        var M = new d();
        return g(M, M.head, D), f(D, M, b, M.head, 0), y(M);
      },
      /**
       * @namespace
       * @memberof Prism
       * @public
       */
      hooks: {
        all: {},
        /**
         * Adds the given callback to the list of callbacks for the given hook.
         *
         * The callback will be invoked when the hook it is registered for is run.
         * Hooks are usually directly run by a highlight function but you can also run hooks yourself.
         *
         * One callback function can be registered to multiple hooks and the same hook multiple times.
         *
         * @param {string} name The name of the hook.
         * @param {HookCallback} callback The callback function which is given environment variables.
         * @public
         */
        add: function(D, b) {
          var F = s.hooks.all;
          F[D] = F[D] || [], F[D].push(b);
        },
        /**
         * Runs a hook invoking all registered callbacks with the given environment variables.
         *
         * Callbacks will be invoked synchronously and in the order in which they were registered.
         *
         * @param {string} name The name of the hook.
         * @param {Object<string, any>} env The environment variables of the hook passed to all callbacks registered.
         * @public
         */
        run: function(D, b) {
          var F = s.hooks.all[D];
          if (!(!F || !F.length))
            for (var T = 0, M; M = F[T++]; )
              M(b);
        }
      },
      Token: o
    };
    r.Prism = s;
    function o(D, b, F, T) {
      this.type = D, this.content = b, this.alias = F, this.length = (T || "").length | 0;
    }
    o.stringify = function D(b, F) {
      if (typeof b == "string")
        return b;
      if (Array.isArray(b)) {
        var T = "";
        return b.forEach(function(B) {
          T += D(B, F);
        }), T;
      }
      var M = {
        type: b.type,
        content: D(b.content, F),
        tag: "span",
        classes: ["token", b.type],
        attributes: {},
        language: F
      }, z = b.alias;
      z && (Array.isArray(z) ? Array.prototype.push.apply(M.classes, z) : M.classes.push(z)), s.hooks.run("wrap", M);
      var O = "";
      for (var R in M.attributes)
        O += " " + R + '="' + (M.attributes[R] || "").replace(/"/g, "&quot;") + '"';
      return "<" + M.tag + ' class="' + M.classes.join(" ") + '"' + O + ">" + M.content + "</" + M.tag + ">";
    };
    function c(D, b, F, T) {
      D.lastIndex = b;
      var M = D.exec(F);
      if (M && T && M[1]) {
        var z = M[1].length;
        M.index += z, M[0] = M[0].slice(z);
      }
      return M;
    }
    function f(D, b, F, T, M, z) {
      for (var O in F)
        if (!(!F.hasOwnProperty(O) || !F[O])) {
          var R = F[O];
          R = Array.isArray(R) ? R : [R];
          for (var B = 0; B < R.length; ++B) {
            if (z && z.cause == O + "," + B)
              return;
            var X = R[B], $ = X.inside, Te = !!X.lookbehind, se = !!X.greedy, U = X.alias;
            if (se && !X.pattern.global) {
              var le = X.pattern.toString().match(/[imsuy]*$/)[0];
              X.pattern = RegExp(X.pattern.source, le + "g");
            }
            for (var Se = X.pattern || X, ue = T.next, Ce = M; ue !== b.tail && !(z && Ce >= z.reach); Ce += ue.value.length, ue = ue.next) {
              var xe = ue.value;
              if (b.length > D.length)
                return;
              if (!(xe instanceof o)) {
                var re = 1, oe;
                if (se) {
                  if (oe = c(Se, Ce, D, Te), !oe || oe.index >= D.length)
                    break;
                  var et = oe.index, fe = oe.index + oe[0].length, Ne = Ce;
                  for (Ne += ue.value.length; et >= Ne; )
                    ue = ue.next, Ne += ue.value.length;
                  if (Ne -= ue.value.length, Ce = Ne, ue.value instanceof o)
                    continue;
                  for (var H = ue; H !== b.tail && (Ne < fe || typeof H.value == "string"); H = H.next)
                    re++, Ne += H.value.length;
                  re--, xe = D.slice(Ce, Ne), oe.index -= Ce;
                } else if (oe = c(Se, 0, xe, Te), !oe)
                  continue;
                var et = oe.index, qe = oe[0], tt = xe.slice(0, et), yt = xe.slice(et + qe.length), wt = Ce + xe.length;
                z && wt > z.reach && (z.reach = wt);
                var Qt = ue.prev;
                tt && (Qt = g(b, Qt, tt), Ce += tt.length), v(b, Qt, re);
                var Bt = new o(O, $ ? s.tokenize(qe, $) : qe, U, qe);
                if (ue = g(b, Qt, Bt), yt && g(b, ue, yt), re > 1) {
                  var Jt = {
                    cause: O + "," + B,
                    reach: wt
                  };
                  f(D, b, F, ue.prev, Ce, Jt), z && Jt.reach > z.reach && (z.reach = Jt.reach);
                }
              }
            }
          }
        }
    }
    function d() {
      var D = { value: null, prev: null, next: null }, b = { value: null, prev: D, next: null };
      D.next = b, this.head = D, this.tail = b, this.length = 0;
    }
    function g(D, b, F) {
      var T = b.next, M = { value: F, prev: b, next: T };
      return b.next = M, T.prev = M, D.length++, M;
    }
    function v(D, b, F) {
      for (var T = b.next, M = 0; M < F && T !== D.tail; M++)
        T = T.next;
      b.next = T, T.prev = b, D.length -= M;
    }
    function y(D) {
      for (var b = [], F = D.head.next; F !== D.tail; )
        b.push(F.value), F = F.next;
      return b;
    }
    if (!r.document)
      return r.addEventListener && (s.disableWorkerMessageHandler || r.addEventListener("message", function(D) {
        var b = JSON.parse(D.data), F = b.language, T = b.code, M = b.immediateClose;
        r.postMessage(s.highlight(T, s.languages[F], F)), M && r.close();
      }, !1)), s;
    var k = s.util.currentScript();
    k && (s.filename = k.src, k.hasAttribute("data-manual") && (s.manual = !0));
    function E() {
      s.manual || s.highlightAll();
    }
    if (!s.manual) {
      var A = document.readyState;
      A === "loading" || A === "interactive" && k && k.defer ? document.addEventListener("DOMContentLoaded", E) : window.requestAnimationFrame ? window.requestAnimationFrame(E) : window.setTimeout(E, 16);
    }
    return s;
  }(e);
  n.exports && (n.exports = t), typeof $l < "u" && ($l.Prism = t), t.languages.markup = {
    comment: {
      pattern: /<!--(?:(?!<!--)[\s\S])*?-->/,
      greedy: !0
    },
    prolog: {
      pattern: /<\?[\s\S]+?\?>/,
      greedy: !0
    },
    doctype: {
      // https://www.w3.org/TR/xml/#NT-doctypedecl
      pattern: /<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,
      greedy: !0,
      inside: {
        "internal-subset": {
          pattern: /(^[^\[]*\[)[\s\S]+(?=\]>$)/,
          lookbehind: !0,
          greedy: !0,
          inside: null
          // see below
        },
        string: {
          pattern: /"[^"]*"|'[^']*'/,
          greedy: !0
        },
        punctuation: /^<!|>$|[[\]]/,
        "doctype-tag": /^DOCTYPE/i,
        name: /[^\s<>'"]+/
      }
    },
    cdata: {
      pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
      greedy: !0
    },
    tag: {
      pattern: /<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,
      greedy: !0,
      inside: {
        tag: {
          pattern: /^<\/?[^\s>\/]+/,
          inside: {
            punctuation: /^<\/?/,
            namespace: /^[^\s>\/:]+:/
          }
        },
        "special-attr": [],
        "attr-value": {
          pattern: /=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,
          inside: {
            punctuation: [
              {
                pattern: /^=/,
                alias: "attr-equals"
              },
              {
                pattern: /^(\s*)["']|["']$/,
                lookbehind: !0
              }
            ]
          }
        },
        punctuation: /\/?>/,
        "attr-name": {
          pattern: /[^\s>\/]+/,
          inside: {
            namespace: /^[^\s>\/:]+:/
          }
        }
      }
    },
    entity: [
      {
        pattern: /&[\da-z]{1,8};/i,
        alias: "named-entity"
      },
      /&#x?[\da-f]{1,8};/i
    ]
  }, t.languages.markup.tag.inside["attr-value"].inside.entity = t.languages.markup.entity, t.languages.markup.doctype.inside["internal-subset"].inside = t.languages.markup, t.hooks.add("wrap", function(r) {
    r.type === "entity" && (r.attributes.title = r.content.replace(/&amp;/, "&"));
  }), Object.defineProperty(t.languages.markup.tag, "addInlined", {
    /**
     * Adds an inlined language to markup.
     *
     * An example of an inlined language is CSS with `<style>` tags.
     *
     * @param {string} tagName The name of the tag that contains the inlined language. This name will be treated as
     * case insensitive.
     * @param {string} lang The language key.
     * @example
     * addInlined('style', 'css');
     */
    value: function(a, i) {
      var l = {};
      l["language-" + i] = {
        pattern: /(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,
        lookbehind: !0,
        inside: t.languages[i]
      }, l.cdata = /^<!\[CDATA\[|\]\]>$/i;
      var s = {
        "included-cdata": {
          pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
          inside: l
        }
      };
      s["language-" + i] = {
        pattern: /[\s\S]+/,
        inside: t.languages[i]
      };
      var o = {};
      o[a] = {
        pattern: RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g, function() {
          return a;
        }), "i"),
        lookbehind: !0,
        greedy: !0,
        inside: s
      }, t.languages.insertBefore("markup", "cdata", o);
    }
  }), Object.defineProperty(t.languages.markup.tag, "addAttribute", {
    /**
     * Adds an pattern to highlight languages embedded in HTML attributes.
     *
     * An example of an inlined language is CSS with `style` attributes.
     *
     * @param {string} attrName The name of the tag that contains the inlined language. This name will be treated as
     * case insensitive.
     * @param {string} lang The language key.
     * @example
     * addAttribute('style', 'css');
     */
    value: function(r, a) {
      t.languages.markup.tag.inside["special-attr"].push({
        pattern: RegExp(
          /(^|["'\s])/.source + "(?:" + r + ")" + /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,
          "i"
        ),
        lookbehind: !0,
        inside: {
          "attr-name": /^[^\s=]+/,
          "attr-value": {
            pattern: /=[\s\S]+/,
            inside: {
              value: {
                pattern: /(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,
                lookbehind: !0,
                alias: [a, "language-" + a],
                inside: t.languages[a]
              },
              punctuation: [
                {
                  pattern: /^=/,
                  alias: "attr-equals"
                },
                /"|'/
              ]
            }
          }
        }
      });
    }
  }), t.languages.html = t.languages.markup, t.languages.mathml = t.languages.markup, t.languages.svg = t.languages.markup, t.languages.xml = t.languages.extend("markup", {}), t.languages.ssml = t.languages.xml, t.languages.atom = t.languages.xml, t.languages.rss = t.languages.xml, function(r) {
    var a = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
    r.languages.css = {
      comment: /\/\*[\s\S]*?\*\//,
      atrule: {
        pattern: RegExp("@[\\w-](?:" + /[^;{\s"']|\s+(?!\s)/.source + "|" + a.source + ")*?" + /(?:;|(?=\s*\{))/.source),
        inside: {
          rule: /^@[\w-]+/,
          "selector-function-argument": {
            pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,
            lookbehind: !0,
            alias: "selector"
          },
          keyword: {
            pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/,
            lookbehind: !0
          }
          // See rest below
        }
      },
      url: {
        // https://drafts.csswg.org/css-values-3/#urls
        pattern: RegExp("\\burl\\((?:" + a.source + "|" + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ")\\)", "i"),
        greedy: !0,
        inside: {
          function: /^url/i,
          punctuation: /^\(|\)$/,
          string: {
            pattern: RegExp("^" + a.source + "$"),
            alias: "url"
          }
        }
      },
      selector: {
        pattern: RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|` + a.source + ")*(?=\\s*\\{)"),
        lookbehind: !0
      },
      string: {
        pattern: a,
        greedy: !0
      },
      property: {
        pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,
        lookbehind: !0
      },
      important: /!important\b/i,
      function: {
        pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,
        lookbehind: !0
      },
      punctuation: /[(){};:,]/
    }, r.languages.css.atrule.inside.rest = r.languages.css;
    var i = r.languages.markup;
    i && (i.tag.addInlined("style", "css"), i.tag.addAttribute("style", "css"));
  }(t), t.languages.clike = {
    comment: [
      {
        pattern: /(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,
        lookbehind: !0,
        greedy: !0
      },
      {
        pattern: /(^|[^\\:])\/\/.*/,
        lookbehind: !0,
        greedy: !0
      }
    ],
    string: {
      pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,
      greedy: !0
    },
    "class-name": {
      pattern: /(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,
      lookbehind: !0,
      inside: {
        punctuation: /[.\\]/
      }
    },
    keyword: /\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,
    boolean: /\b(?:false|true)\b/,
    function: /\b\w+(?=\()/,
    number: /\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,
    operator: /[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,
    punctuation: /[{}[\];(),.:]/
  }, t.languages.javascript = t.languages.extend("clike", {
    "class-name": [
      t.languages.clike["class-name"],
      {
        pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,
        lookbehind: !0
      }
    ],
    keyword: [
      {
        pattern: /((?:^|\})\s*)catch\b/,
        lookbehind: !0
      },
      {
        pattern: /(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,
        lookbehind: !0
      }
    ],
    // Allow for all non-ASCII characters (See http://stackoverflow.com/a/2008444)
    function: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,
    number: {
      pattern: RegExp(
        /(^|[^\w$])/.source + "(?:" + // constant
        (/NaN|Infinity/.source + "|" + // binary integer
        /0[bB][01]+(?:_[01]+)*n?/.source + "|" + // octal integer
        /0[oO][0-7]+(?:_[0-7]+)*n?/.source + "|" + // hexadecimal integer
        /0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source + "|" + // decimal bigint
        /\d+(?:_\d+)*n/.source + "|" + // decimal number (integer or float) but no bigint
        /(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source) + ")" + /(?![\w$])/.source
      ),
      lookbehind: !0
    },
    operator: /--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/
  }), t.languages.javascript["class-name"][0].pattern = /(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/, t.languages.insertBefore("javascript", "keyword", {
    regex: {
      pattern: RegExp(
        // lookbehind
        // eslint-disable-next-line regexp/no-dupe-characters-character-class
        /((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source + // Regex pattern:
        // There are 2 regex patterns here. The RegExp set notation proposal added support for nested character
        // classes if the `v` flag is present. Unfortunately, nested CCs are both context-free and incompatible
        // with the only syntax, so we have to define 2 different regex patterns.
        /\//.source + "(?:" + /(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source + "|" + // `v` flag syntax. This supports 3 levels of nested character classes.
        /(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source + ")" + // lookahead
        /(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source
      ),
      lookbehind: !0,
      greedy: !0,
      inside: {
        "regex-source": {
          pattern: /^(\/)[\s\S]+(?=\/[a-z]*$)/,
          lookbehind: !0,
          alias: "language-regex",
          inside: t.languages.regex
        },
        "regex-delimiter": /^\/|\/$/,
        "regex-flags": /^[a-z]+$/
      }
    },
    // This must be declared before keyword because we use "function" inside the look-forward
    "function-variable": {
      pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,
      alias: "function"
    },
    parameter: [
      {
        pattern: /(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,
        lookbehind: !0,
        inside: t.languages.javascript
      },
      {
        pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,
        lookbehind: !0,
        inside: t.languages.javascript
      },
      {
        pattern: /(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,
        lookbehind: !0,
        inside: t.languages.javascript
      },
      {
        pattern: /((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,
        lookbehind: !0,
        inside: t.languages.javascript
      }
    ],
    constant: /\b[A-Z](?:[A-Z_]|\dx?)*\b/
  }), t.languages.insertBefore("javascript", "string", {
    hashbang: {
      pattern: /^#!.*/,
      greedy: !0,
      alias: "comment"
    },
    "template-string": {
      pattern: /`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,
      greedy: !0,
      inside: {
        "template-punctuation": {
          pattern: /^`|`$/,
          alias: "string"
        },
        interpolation: {
          pattern: /((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,
          lookbehind: !0,
          inside: {
            "interpolation-punctuation": {
              pattern: /^\$\{|\}$/,
              alias: "punctuation"
            },
            rest: t.languages.javascript
          }
        },
        string: /[\s\S]+/
      }
    },
    "string-property": {
      pattern: /((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,
      lookbehind: !0,
      greedy: !0,
      alias: "property"
    }
  }), t.languages.insertBefore("javascript", "operator", {
    "literal-property": {
      pattern: /((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,
      lookbehind: !0,
      alias: "property"
    }
  }), t.languages.markup && (t.languages.markup.tag.addInlined("script", "javascript"), t.languages.markup.tag.addAttribute(
    /on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,
    "javascript"
  )), t.languages.js = t.languages.javascript, function() {
    if (typeof t > "u" || typeof document > "u")
      return;
    Element.prototype.matches || (Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector);
    var r = "Loading…", a = function(k, E) {
      return "✖ Error " + k + " while fetching file: " + E;
    }, i = "✖ Error: File does not exist or is empty", l = {
      js: "javascript",
      py: "python",
      rb: "ruby",
      ps1: "powershell",
      psm1: "powershell",
      sh: "bash",
      bat: "batch",
      h: "c",
      tex: "latex"
    }, s = "data-src-status", o = "loading", c = "loaded", f = "failed", d = "pre[data-src]:not([" + s + '="' + c + '"]):not([' + s + '="' + o + '"])';
    function g(k, E, A) {
      var D = new XMLHttpRequest();
      D.open("GET", k, !0), D.onreadystatechange = function() {
        D.readyState == 4 && (D.status < 400 && D.responseText ? E(D.responseText) : D.status >= 400 ? A(a(D.status, D.statusText)) : A(i));
      }, D.send(null);
    }
    function v(k) {
      var E = /^\s*(\d+)\s*(?:(,)\s*(?:(\d+)\s*)?)?$/.exec(k || "");
      if (E) {
        var A = Number(E[1]), D = E[2], b = E[3];
        return D ? b ? [A, Number(b)] : [A, void 0] : [A, A];
      }
    }
    t.hooks.add("before-highlightall", function(k) {
      k.selector += ", " + d;
    }), t.hooks.add("before-sanity-check", function(k) {
      var E = (
        /** @type {HTMLPreElement} */
        k.element
      );
      if (E.matches(d)) {
        k.code = "", E.setAttribute(s, o);
        var A = E.appendChild(document.createElement("CODE"));
        A.textContent = r;
        var D = E.getAttribute("data-src"), b = k.language;
        if (b === "none") {
          var F = (/\.(\w+)$/.exec(D) || [, "none"])[1];
          b = l[F] || F;
        }
        t.util.setLanguage(A, b), t.util.setLanguage(E, b);
        var T = t.plugins.autoloader;
        T && T.loadLanguages(b), g(
          D,
          function(M) {
            E.setAttribute(s, c);
            var z = v(E.getAttribute("data-range"));
            if (z) {
              var O = M.split(/\r\n?|\n/g), R = z[0], B = z[1] == null ? O.length : z[1];
              R < 0 && (R += O.length), R = Math.max(0, Math.min(R - 1, O.length)), B < 0 && (B += O.length), B = Math.max(0, Math.min(B, O.length)), M = O.slice(R, B).join(`
`), E.hasAttribute("data-start") || E.setAttribute("data-start", String(R + 1));
            }
            A.textContent = M, t.highlightElement(A);
          },
          function(M) {
            E.setAttribute(s, f), A.textContent = M;
          }
        );
      }
    }), t.plugins.fileHighlight = {
      /**
       * Executes the File Highlight plugin for all matching `pre` elements under the given container.
       *
       * Note: Elements which are already loaded or currently loading will not be touched by this method.
       *
       * @param {ParentNode} [container=document]
       */
      highlight: function(E) {
        for (var A = (E || document).querySelectorAll(d), D = 0, b; b = A[D++]; )
          t.highlightElement(b);
      }
    };
    var y = !1;
    t.fileHighlight = function() {
      y || (console.warn("Prism.fileHighlight is deprecated. Use `Prism.plugins.fileHighlight.highlight` instead."), y = !0), t.plugins.fileHighlight.highlight.apply(this, arguments);
    };
  }();
})(Pu);
var ga = Pu.exports;
Prism.languages.python = {
  comment: {
    pattern: /(^|[^\\])#.*/,
    lookbehind: !0,
    greedy: !0
  },
  "string-interpolation": {
    pattern: /(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i,
    greedy: !0,
    inside: {
      interpolation: {
        // "{" <expression> <optional "!s", "!r", or "!a"> <optional ":" format specifier> "}"
        pattern: /((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/,
        lookbehind: !0,
        inside: {
          "format-spec": {
            pattern: /(:)[^:(){}]+(?=\}$)/,
            lookbehind: !0
          },
          "conversion-option": {
            pattern: /![sra](?=[:}]$)/,
            alias: "punctuation"
          },
          rest: null
        }
      },
      string: /[\s\S]+/
    }
  },
  "triple-quoted-string": {
    pattern: /(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i,
    greedy: !0,
    alias: "string"
  },
  string: {
    pattern: /(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i,
    greedy: !0
  },
  function: {
    pattern: /((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g,
    lookbehind: !0
  },
  "class-name": {
    pattern: /(\bclass\s+)\w+/i,
    lookbehind: !0
  },
  decorator: {
    pattern: /(^[\t ]*)@\w+(?:\.\w+)*/m,
    lookbehind: !0,
    alias: ["annotation", "punctuation"],
    inside: {
      punctuation: /\./
    }
  },
  keyword: /\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/,
  builtin: /\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/,
  boolean: /\b(?:False|None|True)\b/,
  number: /\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i,
  operator: /[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,
  punctuation: /[{}[\];(),.:]/
};
Prism.languages.python["string-interpolation"].inside.interpolation.inside.rest = Prism.languages.python;
Prism.languages.py = Prism.languages.python;
(function(n) {
  var e = /\\(?:[^a-z()[\]]|[a-z*]+)/i, t = {
    "equation-command": {
      pattern: e,
      alias: "regex"
    }
  };
  n.languages.latex = {
    comment: /%.*/,
    // the verbatim environment prints whitespace to the document
    cdata: {
      pattern: /(\\begin\{((?:lstlisting|verbatim)\*?)\})[\s\S]*?(?=\\end\{\2\})/,
      lookbehind: !0
    },
    /*
     * equations can be between $$ $$ or $ $ or \( \) or \[ \]
     * (all are multiline)
     */
    equation: [
      {
        pattern: /\$\$(?:\\[\s\S]|[^\\$])+\$\$|\$(?:\\[\s\S]|[^\\$])+\$|\\\([\s\S]*?\\\)|\\\[[\s\S]*?\\\]/,
        inside: t,
        alias: "string"
      },
      {
        pattern: /(\\begin\{((?:align|eqnarray|equation|gather|math|multline)\*?)\})[\s\S]*?(?=\\end\{\2\})/,
        lookbehind: !0,
        inside: t,
        alias: "string"
      }
    ],
    /*
     * arguments which are keywords or references are highlighted
     * as keywords
     */
    keyword: {
      pattern: /(\\(?:begin|cite|documentclass|end|label|ref|usepackage)(?:\[[^\]]+\])?\{)[^}]+(?=\})/,
      lookbehind: !0
    },
    url: {
      pattern: /(\\url\{)[^}]+(?=\})/,
      lookbehind: !0
    },
    /*
     * section or chapter headlines are highlighted as bold so that
     * they stand out more
     */
    headline: {
      pattern: /(\\(?:chapter|frametitle|paragraph|part|section|subparagraph|subsection|subsubparagraph|subsubsection|subsubsubparagraph)\*?(?:\[[^\]]+\])?\{)[^}]+(?=\})/,
      lookbehind: !0,
      alias: "class-name"
    },
    function: {
      pattern: e,
      alias: "selector"
    },
    punctuation: /[[\]{}&]/
  }, n.languages.tex = n.languages.latex, n.languages.context = n.languages.latex;
})(Prism);
(function(n) {
  var e = "\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b", t = {
    pattern: /(^(["']?)\w+\2)[ \t]+\S.*/,
    lookbehind: !0,
    alias: "punctuation",
    // this looks reasonably well in all themes
    inside: null
    // see below
  }, r = {
    bash: t,
    environment: {
      pattern: RegExp("\\$" + e),
      alias: "constant"
    },
    variable: [
      // [0]: Arithmetic Environment
      {
        pattern: /\$?\(\([\s\S]+?\)\)/,
        greedy: !0,
        inside: {
          // If there is a $ sign at the beginning highlight $(( and )) as variable
          variable: [
            {
              pattern: /(^\$\(\([\s\S]+)\)\)/,
              lookbehind: !0
            },
            /^\$\(\(/
          ],
          number: /\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,
          // Operators according to https://www.gnu.org/software/bash/manual/bashref.html#Shell-Arithmetic
          operator: /--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/,
          // If there is no $ sign at the beginning highlight (( and )) as punctuation
          punctuation: /\(\(?|\)\)?|,|;/
        }
      },
      // [1]: Command Substitution
      {
        pattern: /\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/,
        greedy: !0,
        inside: {
          variable: /^\$\(|^`|\)$|`$/
        }
      },
      // [2]: Brace expansion
      {
        pattern: /\$\{[^}]+\}/,
        greedy: !0,
        inside: {
          operator: /:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/,
          punctuation: /[\[\]]/,
          environment: {
            pattern: RegExp("(\\{)" + e),
            lookbehind: !0,
            alias: "constant"
          }
        }
      },
      /\$(?:\w+|[#?*!@$])/
    ],
    // Escape sequences from echo and printf's manuals, and escaped quotes.
    entity: /\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/
  };
  n.languages.bash = {
    shebang: {
      pattern: /^#!\s*\/.*/,
      alias: "important"
    },
    comment: {
      pattern: /(^|[^"{\\$])#.*/,
      lookbehind: !0
    },
    "function-name": [
      // a) function foo {
      // b) foo() {
      // c) function foo() {
      // but not “foo {”
      {
        // a) and c)
        pattern: /(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/,
        lookbehind: !0,
        alias: "function"
      },
      {
        // b)
        pattern: /\b[\w-]+(?=\s*\(\s*\)\s*\{)/,
        alias: "function"
      }
    ],
    // Highlight variable names as variables in for and select beginnings.
    "for-or-select": {
      pattern: /(\b(?:for|select)\s+)\w+(?=\s+in\s)/,
      alias: "variable",
      lookbehind: !0
    },
    // Highlight variable names as variables in the left-hand part
    // of assignments (“=” and “+=”).
    "assign-left": {
      pattern: /(^|[\s;|&]|[<>]\()\w+(?:\.\w+)*(?=\+?=)/,
      inside: {
        environment: {
          pattern: RegExp("(^|[\\s;|&]|[<>]\\()" + e),
          lookbehind: !0,
          alias: "constant"
        }
      },
      alias: "variable",
      lookbehind: !0
    },
    // Highlight parameter names as variables
    parameter: {
      pattern: /(^|\s)-{1,2}(?:\w+:[+-]?)?\w+(?:\.\w+)*(?=[=\s]|$)/,
      alias: "variable",
      lookbehind: !0
    },
    string: [
      // Support for Here-documents https://en.wikipedia.org/wiki/Here_document
      {
        pattern: /((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/,
        lookbehind: !0,
        greedy: !0,
        inside: r
      },
      // Here-document with quotes around the tag
      // → No expansion (so no “inside”).
      {
        pattern: /((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/,
        lookbehind: !0,
        greedy: !0,
        inside: {
          bash: t
        }
      },
      // “Normal” string
      {
        // https://www.gnu.org/software/bash/manual/html_node/Double-Quotes.html
        pattern: /(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/,
        lookbehind: !0,
        greedy: !0,
        inside: r
      },
      {
        // https://www.gnu.org/software/bash/manual/html_node/Single-Quotes.html
        pattern: /(^|[^$\\])'[^']*'/,
        lookbehind: !0,
        greedy: !0
      },
      {
        // https://www.gnu.org/software/bash/manual/html_node/ANSI_002dC-Quoting.html
        pattern: /\$'(?:[^'\\]|\\[\s\S])*'/,
        greedy: !0,
        inside: {
          entity: r.entity
        }
      }
    ],
    environment: {
      pattern: RegExp("\\$?" + e),
      alias: "constant"
    },
    variable: r.variable,
    function: {
      pattern: /(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cargo|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|java|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|sysctl|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    keyword: {
      pattern: /(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    // https://www.gnu.org/software/bash/manual/html_node/Shell-Builtin-Commands.html
    builtin: {
      pattern: /(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/,
      lookbehind: !0,
      // Alias added to make those easier to distinguish from strings.
      alias: "class-name"
    },
    boolean: {
      pattern: /(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/,
      lookbehind: !0
    },
    "file-descriptor": {
      pattern: /\B&\d\b/,
      alias: "important"
    },
    operator: {
      // Lots of redirections here, but not just that.
      pattern: /\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/,
      inside: {
        "file-descriptor": {
          pattern: /^\d/,
          alias: "important"
        }
      }
    },
    punctuation: /\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/,
    number: {
      pattern: /(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/,
      lookbehind: !0
    }
  }, t.inside = n.languages.bash;
  for (var a = [
    "comment",
    "function-name",
    "for-or-select",
    "assign-left",
    "parameter",
    "string",
    "environment",
    "function",
    "keyword",
    "builtin",
    "boolean",
    "file-descriptor",
    "operator",
    "punctuation",
    "number"
  ], i = r.variable[1].inside, l = 0; l < a.length; l++)
    i[a[l]] = n.languages.bash[a[l]];
  n.languages.sh = n.languages.bash, n.languages.shell = n.languages.bash;
})(Prism);
const Kh = '<svg class="md-link-icon" viewBox="0 0 16 16" version="1.1" width="16" height="16" aria-hidden="true" fill="currentColor"><path d="m7.775 3.275 1.25-1.25a3.5 3.5 0 1 1 4.95 4.95l-2.5 2.5a3.5 3.5 0 0 1-4.95 0 .751.751 0 0 1 .018-1.042.751.751 0 0 1 1.042-.018 1.998 1.998 0 0 0 2.83 0l2.5-2.5a2.002 2.002 0 0 0-2.83-2.83l-1.25 1.25a.751.751 0 0 1-1.042-.018.751.751 0 0 1-.018-1.042Zm-4.69 9.64a1.998 1.998 0 0 0 2.83 0l1.25-1.25a.751.751 0 0 1 1.042.018.751.751 0 0 1 .018 1.042l-1.25 1.25a3.5 3.5 0 1 1-4.95-4.95l2.5-2.5a3.5 3.5 0 0 1 4.95 0 .751.751 0 0 1-.018 1.042.751.751 0 0 1-1.042.018 1.998 1.998 0 0 0-2.83 0l-2.5 2.5a1.998 1.998 0 0 0 0 2.83Z"></path></svg>', Qh = `
<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 15 15" color="currentColor" aria-hidden="true" aria-label="Copy" stroke-width="1.3" width="15" height="15">
  <path fill="currentColor" d="M12.728 4.545v8.182H4.545V4.545zm0 -0.909H4.545a0.909 0.909 0 0 0 -0.909 0.909v8.182a0.909 0.909 0 0 0 0.909 0.909h8.182a0.909 0.909 0 0 0 0.909 -0.909V4.545a0.909 0.909 0 0 0 -0.909 -0.909"/>
  <path fill="currentColor" d="M1.818 8.182H0.909V1.818a0.909 0.909 0 0 1 0.909 -0.909h6.364v0.909H1.818Z"/>
</svg>

`, Jh = `<svg xmlns="http://www.w3.org/2000/svg" width="17" height="17" viewBox="0 0 17 17" aria-hidden="true" aria-label="Copied" fill="none" stroke="currentColor" stroke-width="1.3">
  <path d="m13.813 4.781 -7.438 7.438 -3.188 -3.188"/>
</svg>
`, es = `<button title="copy" class="copy_code_button">
  <span class="copy-text">${Qh}</span>
  <span class="check">${Jh}</span>
</button>`, Hu = /[&<>"']/, $h = new RegExp(Hu.source, "g"), Uu = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/, ef = new RegExp(Uu.source, "g"), tf = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#39;"
}, ts = (n) => tf[n] || "";
function va(n, e) {
  if (e) {
    if (Hu.test(n))
      return n.replace($h, ts);
  } else if (Uu.test(n))
    return n.replace(ef, ts);
  return n;
}
function rf(n) {
  const e = n.map((t) => ({
    start: new RegExp(t.left.replace(/[-\/\\^$*+?.()|[\]{}]/g, "\\$&")),
    end: new RegExp(t.right.replace(/[-\/\\^$*+?.()|[\]{}]/g, "\\$&"))
  }));
  return {
    name: "latex",
    level: "block",
    start(t) {
      for (const r of e) {
        const a = t.match(r.start);
        if (a)
          return a.index;
      }
      return -1;
    },
    tokenizer(t, r) {
      for (const a of e) {
        const i = new RegExp(
          `${a.start.source}([\\s\\S]+?)${a.end.source}`
        ).exec(t);
        if (i)
          return {
            type: "latex",
            raw: i[0],
            text: i[1].trim()
          };
      }
    },
    renderer(t) {
      return `<div class="latex-block">${t.text}</div>`;
    }
  };
}
const nf = {
  code(n, e, t) {
    var a;
    const r = ((a = (e ?? "").match(/\S*/)) == null ? void 0 : a[0]) ?? "";
    return n = n.replace(/\n$/, "") + `
`, r ? '<div class="code_wrap">' + es + '<pre><code class="language-' + va(r) + '">' + (t ? n : va(n, !0)) + `</code></pre></div>
` : '<div class="code_wrap">' + es + "<pre><code>" + (t ? n : va(n, !0)) + `</code></pre></div>
`;
  }
}, af = new Ii();
function lf({
  header_links: n,
  line_breaks: e,
  latex_delimiters: t
}) {
  const r = new Nu();
  r.use(
    {
      gfm: !0,
      pedantic: !1,
      breaks: e
    },
    Hh({
      highlight: (i, l) => ga.languages[l] ? ga.highlight(i, ga.languages[l], l) : i
    }),
    { renderer: nf }
  ), n && (r.use(jh()), r.use({
    extensions: [
      {
        name: "heading",
        level: "block",
        renderer(i) {
          const l = i.raw.toLowerCase().trim().replace(/<[!\/a-z].*?>/gi, ""), s = "h" + af.slug(l), o = i.depth, c = this.parser.parseInline(i.tokens);
          return `<h${o} id="${s}"><a class="md-header-anchor" href="#${s}">${Kh}</a>${c}</h${o}>
`;
        }
      }
    ]
  }));
  const a = rf(t);
  return r.use({
    extensions: [a]
  }), r;
}
const Ka = (n) => JSON.parse(JSON.stringify(n)), sf = (n) => n.nodeType === 1, of = (n) => Tf.has(n.tagName), uf = (n) => "action" in n, cf = (n) => n.tagName === "IFRAME", hf = (n) => "formAction" in n, ff = (n) => "protocol" in n, $r = /* @__PURE__ */ (() => {
  const n = /^(?:\w+script|data):/i;
  return (e) => n.test(e);
})(), mf = /* @__PURE__ */ (() => {
  const n = /(?:script|data):/i;
  return (e) => n.test(e);
})(), df = (n) => {
  const e = {};
  for (let t = 0, r = n.length; t < r; t++) {
    const a = n[t];
    for (const i in a)
      e[i] ? e[i] = e[i].concat(a[i]) : e[i] = a[i];
  }
  return e;
}, Gu = (n, e) => {
  let t = n.firstChild;
  for (; t; ) {
    const r = t.nextSibling;
    sf(t) && (e(t, n), t.parentNode && Gu(t, e)), t = r;
  }
}, pf = (n, e) => {
  const t = document.createNodeIterator(n, NodeFilter.SHOW_ELEMENT);
  let r;
  for (; r = t.nextNode(); ) {
    const a = r.parentNode;
    a && e(r, a);
  }
}, gf = (n, e) => !!globalThis.document && !!globalThis.document.createNodeIterator ? pf(n, e) : Gu(n, e), Vu = [
  "a",
  "abbr",
  "acronym",
  "address",
  "area",
  "article",
  "aside",
  "audio",
  "b",
  "bdi",
  "bdo",
  "bgsound",
  "big",
  "blockquote",
  "body",
  "br",
  "button",
  "canvas",
  "caption",
  "center",
  "cite",
  "code",
  "col",
  "colgroup",
  "datalist",
  "dd",
  "del",
  "details",
  "dfn",
  "dialog",
  "dir",
  "div",
  "dl",
  "dt",
  "em",
  "fieldset",
  "figcaption",
  "figure",
  "font",
  "footer",
  "form",
  "h1",
  "h2",
  "h3",
  "h4",
  "h5",
  "h6",
  "head",
  "header",
  "hgroup",
  "hr",
  "html",
  "i",
  "img",
  "input",
  "ins",
  "kbd",
  "keygen",
  "label",
  "layer",
  "legend",
  "li",
  "link",
  "listing",
  "main",
  "map",
  "mark",
  "marquee",
  "menu",
  "meta",
  "meter",
  "nav",
  "nobr",
  "ol",
  "optgroup",
  "option",
  "output",
  "p",
  "picture",
  "popup",
  "pre",
  "progress",
  "q",
  "rb",
  "rp",
  "rt",
  "rtc",
  "ruby",
  "s",
  "samp",
  "section",
  "select",
  "selectmenu",
  "small",
  "source",
  "span",
  "strike",
  "strong",
  "style",
  "sub",
  "summary",
  "sup",
  "table",
  "tbody",
  "td",
  "tfoot",
  "th",
  "thead",
  "time",
  "tr",
  "track",
  "tt",
  "u",
  "ul",
  "var",
  "video",
  "wbr"
], vf = [
  "basefont",
  "command",
  "data",
  "iframe",
  "image",
  "plaintext",
  "portal",
  "slot",
  // 'template', //TODO: Not exactly correct to never allow this, too strict
  "textarea",
  "title",
  "xmp"
], bf = /* @__PURE__ */ new Set([
  ...Vu,
  ...vf
]), Wu = [
  "svg",
  "a",
  "altglyph",
  "altglyphdef",
  "altglyphitem",
  "animatecolor",
  "animatemotion",
  "animatetransform",
  "circle",
  "clippath",
  "defs",
  "desc",
  "ellipse",
  "filter",
  "font",
  "g",
  "glyph",
  "glyphref",
  "hkern",
  "image",
  "line",
  "lineargradient",
  "marker",
  "mask",
  "metadata",
  "mpath",
  "path",
  "pattern",
  "polygon",
  "polyline",
  "radialgradient",
  "rect",
  "stop",
  "style",
  "switch",
  "symbol",
  "text",
  "textpath",
  "title",
  "tref",
  "tspan",
  "view",
  "vkern",
  /* FILTERS */
  "feBlend",
  "feColorMatrix",
  "feComponentTransfer",
  "feComposite",
  "feConvolveMatrix",
  "feDiffuseLighting",
  "feDisplacementMap",
  "feDistantLight",
  "feFlood",
  "feFuncA",
  "feFuncB",
  "feFuncG",
  "feFuncR",
  "feGaussianBlur",
  "feImage",
  "feMerge",
  "feMergeNode",
  "feMorphology",
  "feOffset",
  "fePointLight",
  "feSpecularLighting",
  "feSpotLight",
  "feTile",
  "feTurbulence"
], yf = [
  "animate",
  "color-profile",
  "cursor",
  "discard",
  "fedropshadow",
  "font-face",
  "font-face-format",
  "font-face-name",
  "font-face-src",
  "font-face-uri",
  "foreignobject",
  "hatch",
  "hatchpath",
  "mesh",
  "meshgradient",
  "meshpatch",
  "meshrow",
  "missing-glyph",
  "script",
  "set",
  "solidcolor",
  "unknown",
  "use"
], wf = /* @__PURE__ */ new Set([
  ...Wu,
  ...yf
]), Xu = [
  "math",
  "menclose",
  "merror",
  "mfenced",
  "mfrac",
  "mglyph",
  "mi",
  "mlabeledtr",
  "mmultiscripts",
  "mn",
  "mo",
  "mover",
  "mpadded",
  "mphantom",
  "mroot",
  "mrow",
  "ms",
  "mspace",
  "msqrt",
  "mstyle",
  "msub",
  "msup",
  "msubsup",
  "mtable",
  "mtd",
  "mtext",
  "mtr",
  "munder",
  "munderover"
], kf = [
  "maction",
  "maligngroup",
  "malignmark",
  "mlongdiv",
  "mscarries",
  "mscarry",
  "msgroup",
  "mstack",
  "msline",
  "msrow",
  "semantics",
  "annotation",
  "annotation-xml",
  "mprescripts",
  "none"
], _f = /* @__PURE__ */ new Set([
  ...Xu,
  ...kf
]), Df = [
  "abbr",
  "accept",
  "accept-charset",
  "accesskey",
  "action",
  "align",
  "alink",
  "allow",
  "allowfullscreen",
  "alt",
  "anchor",
  "archive",
  "as",
  "async",
  "autocapitalize",
  "autocomplete",
  "autocorrect",
  "autofocus",
  "autopictureinpicture",
  "autoplay",
  "axis",
  "background",
  "behavior",
  "bgcolor",
  "border",
  "bordercolor",
  "capture",
  "cellpadding",
  "cellspacing",
  "challenge",
  "char",
  "charoff",
  "charset",
  "checked",
  "cite",
  "class",
  "classid",
  "clear",
  "code",
  "codebase",
  "codetype",
  "color",
  "cols",
  "colspan",
  "compact",
  "content",
  "contenteditable",
  "controls",
  "controlslist",
  "conversiondestination",
  "coords",
  "crossorigin",
  "csp",
  "data",
  "datetime",
  "declare",
  "decoding",
  "default",
  "defer",
  "dir",
  "direction",
  "dirname",
  "disabled",
  "disablepictureinpicture",
  "disableremoteplayback",
  "disallowdocumentaccess",
  "download",
  "draggable",
  "elementtiming",
  "enctype",
  "end",
  "enterkeyhint",
  "event",
  "exportparts",
  "face",
  "for",
  "form",
  "formaction",
  "formenctype",
  "formmethod",
  "formnovalidate",
  "formtarget",
  "frame",
  "frameborder",
  "headers",
  "height",
  "hidden",
  "high",
  "href",
  "hreflang",
  "hreftranslate",
  "hspace",
  "http-equiv",
  "id",
  "imagesizes",
  "imagesrcset",
  "importance",
  "impressiondata",
  "impressionexpiry",
  "incremental",
  "inert",
  "inputmode",
  "integrity",
  "invisible",
  "ismap",
  "keytype",
  "kind",
  "label",
  "lang",
  "language",
  "latencyhint",
  "leftmargin",
  "link",
  "list",
  "loading",
  "longdesc",
  "loop",
  "low",
  "lowsrc",
  "manifest",
  "marginheight",
  "marginwidth",
  "max",
  "maxlength",
  "mayscript",
  "media",
  "method",
  "min",
  "minlength",
  "multiple",
  "muted",
  "name",
  "nohref",
  "nomodule",
  "nonce",
  "noresize",
  "noshade",
  "novalidate",
  "nowrap",
  "object",
  "open",
  "optimum",
  "part",
  "pattern",
  "ping",
  "placeholder",
  "playsinline",
  "policy",
  "poster",
  "preload",
  "pseudo",
  "readonly",
  "referrerpolicy",
  "rel",
  "reportingorigin",
  "required",
  "resources",
  "rev",
  "reversed",
  "role",
  "rows",
  "rowspan",
  "rules",
  "sandbox",
  "scheme",
  "scope",
  "scopes",
  "scrollamount",
  "scrolldelay",
  "scrolling",
  "select",
  "selected",
  "shadowroot",
  "shadowrootdelegatesfocus",
  "shape",
  "size",
  "sizes",
  "slot",
  "span",
  "spellcheck",
  "src",
  "srclang",
  "srcset",
  "standby",
  "start",
  "step",
  "style",
  "summary",
  "tabindex",
  "target",
  "text",
  "title",
  "topmargin",
  "translate",
  "truespeed",
  "trusttoken",
  "type",
  "usemap",
  "valign",
  "value",
  "valuetype",
  "version",
  "virtualkeyboardpolicy",
  "vlink",
  "vspace",
  "webkitdirectory",
  "width",
  "wrap"
], xf = [
  "accent-height",
  "accumulate",
  "additive",
  "alignment-baseline",
  "ascent",
  "attributename",
  "attributetype",
  "azimuth",
  "basefrequency",
  "baseline-shift",
  "begin",
  "bias",
  "by",
  "class",
  "clip",
  "clippathunits",
  "clip-path",
  "clip-rule",
  "color",
  "color-interpolation",
  "color-interpolation-filters",
  "color-profile",
  "color-rendering",
  "cx",
  "cy",
  "d",
  "dx",
  "dy",
  "diffuseconstant",
  "direction",
  "display",
  "divisor",
  "dominant-baseline",
  "dur",
  "edgemode",
  "elevation",
  "end",
  "fill",
  "fill-opacity",
  "fill-rule",
  "filter",
  "filterunits",
  "flood-color",
  "flood-opacity",
  "font-family",
  "font-size",
  "font-size-adjust",
  "font-stretch",
  "font-style",
  "font-variant",
  "font-weight",
  "fx",
  "fy",
  "g1",
  "g2",
  "glyph-name",
  "glyphref",
  "gradientunits",
  "gradienttransform",
  "height",
  "href",
  "id",
  "image-rendering",
  "in",
  "in2",
  "k",
  "k1",
  "k2",
  "k3",
  "k4",
  "kerning",
  "keypoints",
  "keysplines",
  "keytimes",
  "lang",
  "lengthadjust",
  "letter-spacing",
  "kernelmatrix",
  "kernelunitlength",
  "lighting-color",
  "local",
  "marker-end",
  "marker-mid",
  "marker-start",
  "markerheight",
  "markerunits",
  "markerwidth",
  "maskcontentunits",
  "maskunits",
  "max",
  "mask",
  "media",
  "method",
  "mode",
  "min",
  "name",
  "numoctaves",
  "offset",
  "operator",
  "opacity",
  "order",
  "orient",
  "orientation",
  "origin",
  "overflow",
  "paint-order",
  "path",
  "pathlength",
  "patterncontentunits",
  "patterntransform",
  "patternunits",
  "points",
  "preservealpha",
  "preserveaspectratio",
  "primitiveunits",
  "r",
  "rx",
  "ry",
  "radius",
  "refx",
  "refy",
  "repeatcount",
  "repeatdur",
  "restart",
  "result",
  "rotate",
  "scale",
  "seed",
  "shape-rendering",
  "specularconstant",
  "specularexponent",
  "spreadmethod",
  "startoffset",
  "stddeviation",
  "stitchtiles",
  "stop-color",
  "stop-opacity",
  "stroke-dasharray",
  "stroke-dashoffset",
  "stroke-linecap",
  "stroke-linejoin",
  "stroke-miterlimit",
  "stroke-opacity",
  "stroke",
  "stroke-width",
  "style",
  "surfacescale",
  "systemlanguage",
  "tabindex",
  "targetx",
  "targety",
  "transform",
  "transform-origin",
  "text-anchor",
  "text-decoration",
  "text-rendering",
  "textlength",
  "type",
  "u1",
  "u2",
  "unicode",
  "values",
  "viewbox",
  "visibility",
  "version",
  "vert-adv-y",
  "vert-origin-x",
  "vert-origin-y",
  "width",
  "word-spacing",
  "wrap",
  "writing-mode",
  "xchannelselector",
  "ychannelselector",
  "x",
  "x1",
  "x2",
  "xmlns",
  "y",
  "y1",
  "y2",
  "z",
  "zoomandpan"
], Af = [
  "accent",
  "accentunder",
  "align",
  "bevelled",
  "close",
  "columnsalign",
  "columnlines",
  "columnspan",
  "denomalign",
  "depth",
  "dir",
  "display",
  "displaystyle",
  "encoding",
  "fence",
  "frame",
  "height",
  "href",
  "id",
  "largeop",
  "length",
  "linethickness",
  "lspace",
  "lquote",
  "mathbackground",
  "mathcolor",
  "mathsize",
  "mathvariant",
  "maxsize",
  "minsize",
  "movablelimits",
  "notation",
  "numalign",
  "open",
  "rowalign",
  "rowlines",
  "rowspacing",
  "rowspan",
  "rspace",
  "rquote",
  "scriptlevel",
  "scriptminsize",
  "scriptsizemultiplier",
  "selection",
  "separator",
  "separators",
  "stretchy",
  "subscriptshift",
  "supscriptshift",
  "symmetric",
  "voffset",
  "width",
  "xmlns"
], zt = {
  HTML: "http://www.w3.org/1999/xhtml",
  SVG: "http://www.w3.org/2000/svg",
  MATH: "http://www.w3.org/1998/Math/MathML"
}, Sf = {
  [zt.HTML]: bf,
  [zt.SVG]: wf,
  [zt.MATH]: _f
}, Ef = {
  [zt.HTML]: "html",
  [zt.SVG]: "svg",
  [zt.MATH]: "math"
}, Ff = {
  [zt.HTML]: "",
  [zt.SVG]: "svg:",
  [zt.MATH]: "math:"
}, Tf = /* @__PURE__ */ new Set([
  "A",
  "AREA",
  "BUTTON",
  "FORM",
  "IFRAME",
  "INPUT"
]), Yu = {
  allowComments: !0,
  allowCustomElements: !1,
  allowUnknownMarkup: !1,
  allowElements: [
    ...Vu,
    ...Wu.map((n) => `svg:${n}`),
    ...Xu.map((n) => `math:${n}`)
  ],
  allowAttributes: df([
    Object.fromEntries(Df.map((n) => [n, ["*"]])),
    Object.fromEntries(xf.map((n) => [n, ["svg:*"]])),
    Object.fromEntries(Af.map((n) => [n, ["math:*"]]))
  ])
};
var ba = function(n, e, t, r, a) {
  if (r === "m") throw new TypeError("Private method is not writable");
  if (r === "a" && !a) throw new TypeError("Private accessor was defined without a setter");
  if (typeof e == "function" ? n !== e || !a : !e.has(n)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
  return r === "a" ? a.call(n, t) : a ? a.value = t : e.set(n, t), t;
}, T0 = function(n, e, t, r) {
  if (t === "a" && !r) throw new TypeError("Private accessor was defined without a getter");
  if (typeof e == "function" ? n !== e || !r : !e.has(n)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
  return t === "m" ? r : t === "a" ? r.call(n) : r ? r.value : e.get(n);
}, v0, gn, vn;
class ju {
  /* CONSTRUCTOR */
  constructor(e = {}) {
    v0.set(this, void 0), gn.set(this, void 0), vn.set(this, void 0), this.getConfiguration = () => Ka(T0(this, v0, "f")), this.sanitize = (f) => {
      const d = T0(this, gn, "f"), g = T0(this, vn, "f");
      return gf(f, (v, y) => {
        const k = v.namespaceURI || zt.HTML, E = y.namespaceURI || zt.HTML, A = Sf[k], D = Ef[k], b = Ff[k], F = v.tagName.toLowerCase(), T = `${b}${F}`, z = `${b}*`;
        if (!A.has(F) || !d.has(T) || k !== E && F !== D)
          y.removeChild(v);
        else {
          const O = v.getAttributeNames(), R = O.length;
          if (R) {
            for (let B = 0; B < R; B++) {
              const X = O[B], $ = g[X];
              (!$ || !$.has(z) && !$.has(T)) && v.removeAttribute(X);
            }
            if (of(v))
              if (ff(v)) {
                const B = v.getAttribute("href");
                B && mf(B) && $r(v.protocol) && v.removeAttribute("href");
              } else uf(v) ? $r(v.action) && v.removeAttribute("action") : hf(v) ? $r(v.formAction) && v.removeAttribute("formaction") : cf(v) && ($r(v.src) && v.removeAttribute("formaction"), v.setAttribute("sandbox", "allow-scripts"));
          }
        }
      }), f;
    }, this.sanitizeFor = (f, d) => {
      throw new Error('"sanitizeFor" is not implemented yet');
    };
    const { allowComments: t, allowCustomElements: r, allowUnknownMarkup: a, blockElements: i, dropElements: l, dropAttributes: s } = e;
    if (t === !1)
      throw new Error('A false "allowComments" is not supported yet');
    if (r)
      throw new Error('A true "allowCustomElements" is not supported yet');
    if (a)
      throw new Error('A true "allowUnknownMarkup" is not supported yet');
    if (i)
      throw new Error('"blockElements" is not supported yet, use "allowElements" instead');
    if (l)
      throw new Error('"dropElements" is not supported yet, use "allowElements" instead');
    if (s)
      throw new Error('"dropAttributes" is not supported yet, use "allowAttributes" instead');
    ba(this, v0, Ka(Yu), "f");
    const { allowElements: o, allowAttributes: c } = e;
    o && (T0(this, v0, "f").allowElements = e.allowElements), c && (T0(this, v0, "f").allowAttributes = e.allowAttributes), ba(this, gn, new Set(T0(this, v0, "f").allowElements), "f"), ba(this, vn, Object.fromEntries(Object.entries(T0(this, v0, "f").allowAttributes || {}).map(([f, d]) => [f, new Set(d)])), "f");
  }
}
v0 = /* @__PURE__ */ new WeakMap(), gn = /* @__PURE__ */ new WeakMap(), vn = /* @__PURE__ */ new WeakMap();
ju.getDefaultConfiguration = () => Ka(Yu);
const Cf = (n, e) => {
  try {
    return !!n && new URL(n).origin !== new URL(e).origin;
  } catch {
    return !1;
  }
};
function rs(n, e) {
  const t = new ju(), r = new DOMParser().parseFromString(n, "text/html");
  return Zu(r.body, "A", (a) => {
    a instanceof HTMLElement && "target" in a && Cf(a.getAttribute("href"), e) && (a.setAttribute("target", "_blank"), a.setAttribute("rel", "noopener noreferrer"));
  }), t.sanitize(r).body.innerHTML;
}
function Zu(n, e, t) {
  n && n.nodeName === e && t(n);
  const r = (n == null ? void 0 : n.childNodes) || [];
  for (let a = 0; a < r.length; a++)
    Zu(r[a], e, t);
}
const {
  HtmlTagHydration: Mf,
  SvelteComponent: zf,
  attr: Bf,
  binding_callbacks: Nf,
  children: Rf,
  claim_element: If,
  claim_html_tag: Lf,
  detach: ns,
  element: Of,
  init: qf,
  insert_hydration: Pf,
  noop: as,
  safe_not_equal: Hf,
  toggle_class: en
} = window.__gradio__svelte__internal, { afterUpdate: Uf } = window.__gradio__svelte__internal;
function Gf(n) {
  let e, t;
  return {
    c() {
      e = Of("span"), t = new Mf(!1), this.h();
    },
    l(r) {
      e = If(r, "SPAN", { class: !0 });
      var a = Rf(e);
      t = Lf(a, !1), a.forEach(ns), this.h();
    },
    h() {
      t.a = null, Bf(e, "class", "md svelte-1m32c2s"), en(
        e,
        "chatbot",
        /*chatbot*/
        n[0]
      ), en(
        e,
        "prose",
        /*render_markdown*/
        n[1]
      );
    },
    m(r, a) {
      Pf(r, e, a), t.m(
        /*html*/
        n[3],
        e
      ), n[10](e);
    },
    p(r, [a]) {
      a & /*html*/
      8 && t.p(
        /*html*/
        r[3]
      ), a & /*chatbot*/
      1 && en(
        e,
        "chatbot",
        /*chatbot*/
        r[0]
      ), a & /*render_markdown*/
      2 && en(
        e,
        "prose",
        /*render_markdown*/
        r[1]
      );
    },
    i: as,
    o: as,
    d(r) {
      r && ns(e), n[10](null);
    }
  };
}
function is(n) {
  return n.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
}
function Vf(n, e, t) {
  let { chatbot: r = !0 } = e, { message: a } = e, { sanitize_html: i = !0 } = e, { latex_delimiters: l = [] } = e, { render_markdown: s = !0 } = e, { line_breaks: o = !0 } = e, { header_links: c = !1 } = e, { root: f } = e, d, g;
  const v = lf({
    header_links: c,
    line_breaks: o,
    latex_delimiters: l
  });
  function y(A) {
    let D = A;
    if (s) {
      const b = [];
      l.forEach((F, T) => {
        const M = is(F.left), z = is(F.right), O = new RegExp(`${M}([\\s\\S]+?)${z}`, "g");
        D = D.replace(O, (R, B) => (b.push(R), `%%%LATEX_BLOCK_${b.length - 1}%%%`));
      }), D = v.parse(D), D = D.replace(/%%%LATEX_BLOCK_(\d+)%%%/g, (F, T) => b[parseInt(T, 10)]);
    }
    return i && rs && (D = rs(D, f)), D;
  }
  async function k(A) {
    l.length > 0 && A && l.some((b) => A.includes(b.left) && A.includes(b.right)) && lh(d, {
      delimiters: l,
      throwOnError: !1
    });
  }
  Uf(async () => {
    d && document.body.contains(d) ? await k(a) : console.error("Element is not in the DOM");
  });
  function E(A) {
    Nf[A ? "unshift" : "push"](() => {
      d = A, t(2, d);
    });
  }
  return n.$$set = (A) => {
    "chatbot" in A && t(0, r = A.chatbot), "message" in A && t(4, a = A.message), "sanitize_html" in A && t(5, i = A.sanitize_html), "latex_delimiters" in A && t(6, l = A.latex_delimiters), "render_markdown" in A && t(1, s = A.render_markdown), "line_breaks" in A && t(7, o = A.line_breaks), "header_links" in A && t(8, c = A.header_links), "root" in A && t(9, f = A.root);
  }, n.$$.update = () => {
    n.$$.dirty & /*message*/
    16 && (a && a.trim() ? t(3, g = y(a)) : t(3, g = ""));
  }, [
    r,
    s,
    d,
    g,
    a,
    i,
    l,
    o,
    c,
    f,
    E
  ];
}
class Ku extends zf {
  constructor(e) {
    super(), qf(this, e, Vf, Gf, Hf, {
      chatbot: 0,
      message: 4,
      sanitize_html: 5,
      latex_delimiters: 6,
      render_markdown: 1,
      line_breaks: 7,
      header_links: 8,
      root: 9
    });
  }
}
const {
  SvelteComponent: Wf,
  attr: Xf,
  children: Yf,
  claim_component: jf,
  claim_element: Zf,
  create_component: Kf,
  destroy_component: Qf,
  detach: ls,
  element: Jf,
  init: $f,
  insert_hydration: e2,
  mount_component: t2,
  safe_not_equal: r2,
  transition_in: n2,
  transition_out: a2
} = window.__gradio__svelte__internal;
function i2(n) {
  let e, t, r;
  return t = new Ku({
    props: {
      root: (
        /*root*/
        n[1]
      ),
      message: (
        /*info*/
        n[0]
      ),
      sanitize_html: !0
    }
  }), {
    c() {
      e = Jf("div"), Kf(t.$$.fragment), this.h();
    },
    l(a) {
      e = Zf(a, "DIV", { class: !0 });
      var i = Yf(e);
      jf(t.$$.fragment, i), i.forEach(ls), this.h();
    },
    h() {
      Xf(e, "class", "svelte-17qq50w");
    },
    m(a, i) {
      e2(a, e, i), t2(t, e, null), r = !0;
    },
    p(a, [i]) {
      const l = {};
      i & /*root*/
      2 && (l.root = /*root*/
      a[1]), i & /*info*/
      1 && (l.message = /*info*/
      a[0]), t.$set(l);
    },
    i(a) {
      r || (n2(t.$$.fragment, a), r = !0);
    },
    o(a) {
      a2(t.$$.fragment, a), r = !1;
    },
    d(a) {
      a && ls(e), Qf(t);
    }
  };
}
function l2(n, e, t) {
  let { info: r } = e, { root: a } = e;
  return n.$$set = (i) => {
    "info" in i && t(0, r = i.info), "root" in i && t(1, a = i.root);
  }, [r, a];
}
class s2 extends Wf {
  constructor(e) {
    super(), $f(this, e, l2, i2, r2, { info: 0, root: 1 });
  }
}
const {
  SvelteComponent: o2,
  attr: ss,
  check_outros: u2,
  children: c2,
  claim_component: h2,
  claim_element: f2,
  claim_space: m2,
  create_component: d2,
  create_slot: p2,
  destroy_component: g2,
  detach: tn,
  element: v2,
  empty: os,
  get_all_dirty_from_scope: b2,
  get_slot_changes: y2,
  group_outros: w2,
  init: k2,
  insert_hydration: ya,
  mount_component: _2,
  safe_not_equal: D2,
  space: x2,
  toggle_class: Z0,
  transition_in: yr,
  transition_out: bn,
  update_slot_base: A2
} = window.__gradio__svelte__internal;
function us(n) {
  let e, t;
  return e = new s2({
    props: {
      root: (
        /*root*/
        n[2]
      ),
      info: (
        /*info*/
        n[1]
      )
    }
  }), {
    c() {
      d2(e.$$.fragment);
    },
    l(r) {
      h2(e.$$.fragment, r);
    },
    m(r, a) {
      _2(e, r, a), t = !0;
    },
    p(r, a) {
      const i = {};
      a & /*root*/
      4 && (i.root = /*root*/
      r[2]), a & /*info*/
      2 && (i.info = /*info*/
      r[1]), e.$set(i);
    },
    i(r) {
      t || (yr(e.$$.fragment, r), t = !0);
    },
    o(r) {
      bn(e.$$.fragment, r), t = !1;
    },
    d(r) {
      g2(e, r);
    }
  };
}
function S2(n) {
  let e, t, r, a;
  const i = (
    /*#slots*/
    n[4].default
  ), l = p2(
    i,
    n,
    /*$$scope*/
    n[3],
    null
  );
  let s = (
    /*info*/
    n[1] && us(n)
  );
  return {
    c() {
      e = v2("span"), l && l.c(), t = x2(), s && s.c(), r = os(), this.h();
    },
    l(o) {
      e = f2(o, "SPAN", { "data-testid": !0, class: !0 });
      var c = c2(e);
      l && l.l(c), c.forEach(tn), t = m2(o), s && s.l(o), r = os(), this.h();
    },
    h() {
      ss(e, "data-testid", "block-info"), ss(e, "class", "svelte-22c38v"), Z0(e, "sr-only", !/*show_label*/
      n[0]), Z0(e, "hide", !/*show_label*/
      n[0]), Z0(
        e,
        "has-info",
        /*info*/
        n[1] != null
      );
    },
    m(o, c) {
      ya(o, e, c), l && l.m(e, null), ya(o, t, c), s && s.m(o, c), ya(o, r, c), a = !0;
    },
    p(o, [c]) {
      l && l.p && (!a || c & /*$$scope*/
      8) && A2(
        l,
        i,
        o,
        /*$$scope*/
        o[3],
        a ? y2(
          i,
          /*$$scope*/
          o[3],
          c,
          null
        ) : b2(
          /*$$scope*/
          o[3]
        ),
        null
      ), (!a || c & /*show_label*/
      1) && Z0(e, "sr-only", !/*show_label*/
      o[0]), (!a || c & /*show_label*/
      1) && Z0(e, "hide", !/*show_label*/
      o[0]), (!a || c & /*info*/
      2) && Z0(
        e,
        "has-info",
        /*info*/
        o[1] != null
      ), /*info*/
      o[1] ? s ? (s.p(o, c), c & /*info*/
      2 && yr(s, 1)) : (s = us(o), s.c(), yr(s, 1), s.m(r.parentNode, r)) : s && (w2(), bn(s, 1, 1, () => {
        s = null;
      }), u2());
    },
    i(o) {
      a || (yr(l, o), yr(s), a = !0);
    },
    o(o) {
      bn(l, o), bn(s), a = !1;
    },
    d(o) {
      o && (tn(e), tn(t), tn(r)), l && l.d(o), s && s.d(o);
    }
  };
}
function E2(n, e, t) {
  let { $$slots: r = {}, $$scope: a } = e, { show_label: i = !0 } = e, { info: l = void 0 } = e, { root: s } = e;
  return n.$$set = (o) => {
    "show_label" in o && t(0, i = o.show_label), "info" in o && t(1, l = o.info), "root" in o && t(2, s = o.root), "$$scope" in o && t(3, a = o.$$scope);
  }, [i, l, s, a, r];
}
class F2 extends o2 {
  constructor(e) {
    super(), k2(this, e, E2, S2, D2, { show_label: 0, info: 1, root: 2 });
  }
}
const {
  SvelteComponent: T2,
  append_hydration: yn,
  attr: a0,
  bubble: C2,
  check_outros: M2,
  children: Qa,
  claim_component: z2,
  claim_element: Ja,
  claim_space: cs,
  claim_text: B2,
  construct_svelte_component: hs,
  create_component: fs,
  create_slot: N2,
  destroy_component: ms,
  detach: Dr,
  element: $a,
  get_all_dirty_from_scope: R2,
  get_slot_changes: I2,
  group_outros: L2,
  init: O2,
  insert_hydration: Qu,
  listen: q2,
  mount_component: ds,
  safe_not_equal: P2,
  set_data: H2,
  set_style: rn,
  space: ps,
  text: U2,
  toggle_class: Ze,
  transition_in: wa,
  transition_out: ka,
  update_slot_base: G2
} = window.__gradio__svelte__internal;
function gs(n) {
  let e, t;
  return {
    c() {
      e = $a("span"), t = U2(
        /*label*/
        n[1]
      ), this.h();
    },
    l(r) {
      e = Ja(r, "SPAN", { class: !0 });
      var a = Qa(e);
      t = B2(
        a,
        /*label*/
        n[1]
      ), a.forEach(Dr), this.h();
    },
    h() {
      a0(e, "class", "svelte-vk34kx");
    },
    m(r, a) {
      Qu(r, e, a), yn(e, t);
    },
    p(r, a) {
      a & /*label*/
      2 && H2(
        t,
        /*label*/
        r[1]
      );
    },
    d(r) {
      r && Dr(e);
    }
  };
}
function V2(n) {
  let e, t, r, a, i, l, s, o, c = (
    /*show_label*/
    n[2] && gs(n)
  );
  var f = (
    /*Icon*/
    n[0]
  );
  function d(y, k) {
    return {};
  }
  f && (a = hs(f, d()));
  const g = (
    /*#slots*/
    n[14].default
  ), v = N2(
    g,
    n,
    /*$$scope*/
    n[13],
    null
  );
  return {
    c() {
      e = $a("button"), c && c.c(), t = ps(), r = $a("div"), a && fs(a.$$.fragment), i = ps(), v && v.c(), this.h();
    },
    l(y) {
      e = Ja(y, "BUTTON", {
        "aria-label": !0,
        "aria-haspopup": !0,
        title: !0,
        class: !0
      });
      var k = Qa(e);
      c && c.l(k), t = cs(k), r = Ja(k, "DIV", { class: !0 });
      var E = Qa(r);
      a && z2(a.$$.fragment, E), i = cs(E), v && v.l(E), E.forEach(Dr), k.forEach(Dr), this.h();
    },
    h() {
      a0(r, "class", "svelte-vk34kx"), Ze(
        r,
        "small",
        /*size*/
        n[4] === "small"
      ), Ze(
        r,
        "large",
        /*size*/
        n[4] === "large"
      ), Ze(
        r,
        "medium",
        /*size*/
        n[4] === "medium"
      ), e.disabled = /*disabled*/
      n[7], a0(
        e,
        "aria-label",
        /*label*/
        n[1]
      ), a0(
        e,
        "aria-haspopup",
        /*hasPopup*/
        n[8]
      ), a0(
        e,
        "title",
        /*label*/
        n[1]
      ), a0(e, "class", "svelte-vk34kx"), Ze(
        e,
        "pending",
        /*pending*/
        n[3]
      ), Ze(
        e,
        "padded",
        /*padded*/
        n[5]
      ), Ze(
        e,
        "highlight",
        /*highlight*/
        n[6]
      ), Ze(
        e,
        "transparent",
        /*transparent*/
        n[9]
      ), rn(e, "color", !/*disabled*/
      n[7] && /*_color*/
      n[11] ? (
        /*_color*/
        n[11]
      ) : "var(--block-label-text-color)"), rn(e, "--bg-color", /*disabled*/
      n[7] ? "auto" : (
        /*background*/
        n[10]
      ));
    },
    m(y, k) {
      Qu(y, e, k), c && c.m(e, null), yn(e, t), yn(e, r), a && ds(a, r, null), yn(r, i), v && v.m(r, null), l = !0, s || (o = q2(
        e,
        "click",
        /*click_handler*/
        n[15]
      ), s = !0);
    },
    p(y, [k]) {
      if (/*show_label*/
      y[2] ? c ? c.p(y, k) : (c = gs(y), c.c(), c.m(e, t)) : c && (c.d(1), c = null), k & /*Icon*/
      1 && f !== (f = /*Icon*/
      y[0])) {
        if (a) {
          L2();
          const E = a;
          ka(E.$$.fragment, 1, 0, () => {
            ms(E, 1);
          }), M2();
        }
        f ? (a = hs(f, d()), fs(a.$$.fragment), wa(a.$$.fragment, 1), ds(a, r, i)) : a = null;
      }
      v && v.p && (!l || k & /*$$scope*/
      8192) && G2(
        v,
        g,
        y,
        /*$$scope*/
        y[13],
        l ? I2(
          g,
          /*$$scope*/
          y[13],
          k,
          null
        ) : R2(
          /*$$scope*/
          y[13]
        ),
        null
      ), (!l || k & /*size*/
      16) && Ze(
        r,
        "small",
        /*size*/
        y[4] === "small"
      ), (!l || k & /*size*/
      16) && Ze(
        r,
        "large",
        /*size*/
        y[4] === "large"
      ), (!l || k & /*size*/
      16) && Ze(
        r,
        "medium",
        /*size*/
        y[4] === "medium"
      ), (!l || k & /*disabled*/
      128) && (e.disabled = /*disabled*/
      y[7]), (!l || k & /*label*/
      2) && a0(
        e,
        "aria-label",
        /*label*/
        y[1]
      ), (!l || k & /*hasPopup*/
      256) && a0(
        e,
        "aria-haspopup",
        /*hasPopup*/
        y[8]
      ), (!l || k & /*label*/
      2) && a0(
        e,
        "title",
        /*label*/
        y[1]
      ), (!l || k & /*pending*/
      8) && Ze(
        e,
        "pending",
        /*pending*/
        y[3]
      ), (!l || k & /*padded*/
      32) && Ze(
        e,
        "padded",
        /*padded*/
        y[5]
      ), (!l || k & /*highlight*/
      64) && Ze(
        e,
        "highlight",
        /*highlight*/
        y[6]
      ), (!l || k & /*transparent*/
      512) && Ze(
        e,
        "transparent",
        /*transparent*/
        y[9]
      ), k & /*disabled, _color*/
      2176 && rn(e, "color", !/*disabled*/
      y[7] && /*_color*/
      y[11] ? (
        /*_color*/
        y[11]
      ) : "var(--block-label-text-color)"), k & /*disabled, background*/
      1152 && rn(e, "--bg-color", /*disabled*/
      y[7] ? "auto" : (
        /*background*/
        y[10]
      ));
    },
    i(y) {
      l || (a && wa(a.$$.fragment, y), wa(v, y), l = !0);
    },
    o(y) {
      a && ka(a.$$.fragment, y), ka(v, y), l = !1;
    },
    d(y) {
      y && Dr(e), c && c.d(), a && ms(a), v && v.d(y), s = !1, o();
    }
  };
}
function W2(n, e, t) {
  let r, { $$slots: a = {}, $$scope: i } = e, { Icon: l } = e, { label: s = "" } = e, { show_label: o = !1 } = e, { pending: c = !1 } = e, { size: f = "small" } = e, { padded: d = !0 } = e, { highlight: g = !1 } = e, { disabled: v = !1 } = e, { hasPopup: y = !1 } = e, { color: k = "var(--block-label-text-color)" } = e, { transparent: E = !1 } = e, { background: A = "var(--block-background-fill)" } = e;
  function D(b) {
    C2.call(this, n, b);
  }
  return n.$$set = (b) => {
    "Icon" in b && t(0, l = b.Icon), "label" in b && t(1, s = b.label), "show_label" in b && t(2, o = b.show_label), "pending" in b && t(3, c = b.pending), "size" in b && t(4, f = b.size), "padded" in b && t(5, d = b.padded), "highlight" in b && t(6, g = b.highlight), "disabled" in b && t(7, v = b.disabled), "hasPopup" in b && t(8, y = b.hasPopup), "color" in b && t(12, k = b.color), "transparent" in b && t(9, E = b.transparent), "background" in b && t(10, A = b.background), "$$scope" in b && t(13, i = b.$$scope);
  }, n.$$.update = () => {
    n.$$.dirty & /*highlight, color*/
    4160 && t(11, r = g ? "var(--color-accent)" : k);
  }, [
    l,
    s,
    o,
    c,
    f,
    d,
    g,
    v,
    y,
    E,
    A,
    r,
    k,
    i,
    a,
    D
  ];
}
let X2 = class extends T2 {
  constructor(e) {
    super(), O2(this, e, W2, V2, P2, {
      Icon: 0,
      label: 1,
      show_label: 2,
      pending: 3,
      size: 4,
      padded: 5,
      highlight: 6,
      disabled: 7,
      hasPopup: 8,
      color: 12,
      transparent: 9,
      background: 10
    });
  }
};
const {
  SvelteComponent: Y2,
  append_hydration: j2,
  attr: _t,
  children: vs,
  claim_svg_element: bs,
  detach: _a,
  init: Z2,
  insert_hydration: K2,
  noop: Da,
  safe_not_equal: Q2,
  svg_element: ys
} = window.__gradio__svelte__internal;
function J2(n) {
  let e, t;
  return {
    c() {
      e = ys("svg"), t = ys("polyline"), this.h();
    },
    l(r) {
      e = bs(r, "svg", {
        xmlns: !0,
        viewBox: !0,
        width: !0,
        height: !0,
        fill: !0,
        stroke: !0,
        "aria-hidden": !0,
        "stroke-width": !0,
        "stroke-linecap": !0,
        "stroke-linejoin": !0
      });
      var a = vs(e);
      t = bs(a, "polyline", { points: !0 }), vs(t).forEach(_a), a.forEach(_a), this.h();
    },
    h() {
      _t(t, "points", "20 6 9 17 4 12"), _t(e, "xmlns", "http://www.w3.org/2000/svg"), _t(e, "viewBox", "2 0 20 20"), _t(e, "width", "100%"), _t(e, "height", "100%"), _t(e, "fill", "none"), _t(e, "stroke", "currentColor"), _t(e, "aria-hidden", "true"), _t(e, "stroke-width", "1.5"), _t(e, "stroke-linecap", "round"), _t(e, "stroke-linejoin", "round");
    },
    m(r, a) {
      K2(r, e, a), j2(e, t);
    },
    p: Da,
    i: Da,
    o: Da,
    d(r) {
      r && _a(e);
    }
  };
}
class ws extends Y2 {
  constructor(e) {
    super(), Z2(this, e, null, J2, Q2, {});
  }
}
const {
  SvelteComponent: $2,
  append_hydration: xa,
  attr: Dt,
  children: nn,
  claim_svg_element: an,
  detach: fr,
  init: em,
  insert_hydration: tm,
  noop: Aa,
  safe_not_equal: rm,
  set_style: Lt,
  svg_element: ln
} = window.__gradio__svelte__internal;
function nm(n) {
  let e, t, r, a;
  return {
    c() {
      e = ln("svg"), t = ln("g"), r = ln("path"), a = ln("path"), this.h();
    },
    l(i) {
      e = an(i, "svg", {
        width: !0,
        height: !0,
        viewBox: !0,
        version: !0,
        xmlns: !0,
        "xmlns:xlink": !0,
        "xml:space": !0,
        stroke: !0,
        style: !0
      });
      var l = nn(e);
      t = an(l, "g", { transform: !0 });
      var s = nn(t);
      r = an(s, "path", { d: !0, style: !0 }), nn(r).forEach(fr), s.forEach(fr), a = an(l, "path", { d: !0, style: !0 }), nn(a).forEach(fr), l.forEach(fr), this.h();
    },
    h() {
      Dt(r, "d", "M18,6L6.087,17.913"), Lt(r, "fill", "none"), Lt(r, "fill-rule", "nonzero"), Lt(r, "stroke-width", "2px"), Dt(t, "transform", "matrix(1.14096,-0.140958,-0.140958,1.14096,-0.0559523,0.0559523)"), Dt(a, "d", "M4.364,4.364L19.636,19.636"), Lt(a, "fill", "none"), Lt(a, "fill-rule", "nonzero"), Lt(a, "stroke-width", "2px"), Dt(e, "width", "100%"), Dt(e, "height", "100%"), Dt(e, "viewBox", "0 0 24 24"), Dt(e, "version", "1.1"), Dt(e, "xmlns", "http://www.w3.org/2000/svg"), Dt(e, "xmlns:xlink", "http://www.w3.org/1999/xlink"), Dt(e, "xml:space", "preserve"), Dt(e, "stroke", "currentColor"), Lt(e, "fill-rule", "evenodd"), Lt(e, "clip-rule", "evenodd"), Lt(e, "stroke-linecap", "round"), Lt(e, "stroke-linejoin", "round");
    },
    m(i, l) {
      tm(i, e, l), xa(e, t), xa(t, r), xa(e, a);
    },
    p: Aa,
    i: Aa,
    o: Aa,
    d(i) {
      i && fr(e);
    }
  };
}
class am extends $2 {
  constructor(e) {
    super(), em(this, e, null, nm, rm, {});
  }
}
const {
  SvelteComponent: im,
  append_hydration: ks,
  attr: Ot,
  children: Sa,
  claim_svg_element: Ea,
  detach: sn,
  init: lm,
  insert_hydration: sm,
  noop: Fa,
  safe_not_equal: om,
  svg_element: Ta
} = window.__gradio__svelte__internal;
function um(n) {
  let e, t, r;
  return {
    c() {
      e = Ta("svg"), t = Ta("path"), r = Ta("path"), this.h();
    },
    l(a) {
      e = Ea(a, "svg", {
        xmlns: !0,
        viewBox: !0,
        color: !0,
        "aria-hidden": !0,
        width: !0,
        height: !0
      });
      var i = Sa(e);
      t = Ea(i, "path", { fill: !0, d: !0 }), Sa(t).forEach(sn), r = Ea(i, "path", { fill: !0, d: !0 }), Sa(r).forEach(sn), i.forEach(sn), this.h();
    },
    h() {
      Ot(t, "fill", "currentColor"), Ot(t, "d", "M28 10v18H10V10h18m0-2H10a2 2 0 0 0-2 2v18a2 2 0 0 0 2 2h18a2 2 0 0 0 2-2V10a2 2 0 0 0-2-2Z"), Ot(r, "fill", "currentColor"), Ot(r, "d", "M4 18H2V4a2 2 0 0 1 2-2h14v2H4Z"), Ot(e, "xmlns", "http://www.w3.org/2000/svg"), Ot(e, "viewBox", "0 0 33 33"), Ot(e, "color", "currentColor"), Ot(e, "aria-hidden", "true"), Ot(e, "width", "100%"), Ot(e, "height", "100%");
    },
    m(a, i) {
      sm(a, e, i), ks(e, t), ks(e, r);
    },
    p: Fa,
    i: Fa,
    o: Fa,
    d(a) {
      a && sn(e);
    }
  };
}
class _s extends im {
  constructor(e) {
    super(), lm(this, e, null, um, om, {});
  }
}
const cm = [
  { color: "red", primary: 600, secondary: 100 },
  { color: "green", primary: 600, secondary: 100 },
  { color: "blue", primary: 600, secondary: 100 },
  { color: "yellow", primary: 500, secondary: 100 },
  { color: "purple", primary: 600, secondary: 100 },
  { color: "teal", primary: 600, secondary: 100 },
  { color: "orange", primary: 600, secondary: 100 },
  { color: "cyan", primary: 600, secondary: 100 },
  { color: "lime", primary: 500, secondary: 100 },
  { color: "pink", primary: 600, secondary: 100 }
], Ds = {
  inherit: "inherit",
  current: "currentColor",
  transparent: "transparent",
  black: "#000",
  white: "#fff",
  slate: {
    50: "#f8fafc",
    100: "#f1f5f9",
    200: "#e2e8f0",
    300: "#cbd5e1",
    400: "#94a3b8",
    500: "#64748b",
    600: "#475569",
    700: "#334155",
    800: "#1e293b",
    900: "#0f172a",
    950: "#020617"
  },
  gray: {
    50: "#f9fafb",
    100: "#f3f4f6",
    200: "#e5e7eb",
    300: "#d1d5db",
    400: "#9ca3af",
    500: "#6b7280",
    600: "#4b5563",
    700: "#374151",
    800: "#1f2937",
    900: "#111827",
    950: "#030712"
  },
  zinc: {
    50: "#fafafa",
    100: "#f4f4f5",
    200: "#e4e4e7",
    300: "#d4d4d8",
    400: "#a1a1aa",
    500: "#71717a",
    600: "#52525b",
    700: "#3f3f46",
    800: "#27272a",
    900: "#18181b",
    950: "#09090b"
  },
  neutral: {
    50: "#fafafa",
    100: "#f5f5f5",
    200: "#e5e5e5",
    300: "#d4d4d4",
    400: "#a3a3a3",
    500: "#737373",
    600: "#525252",
    700: "#404040",
    800: "#262626",
    900: "#171717",
    950: "#0a0a0a"
  },
  stone: {
    50: "#fafaf9",
    100: "#f5f5f4",
    200: "#e7e5e4",
    300: "#d6d3d1",
    400: "#a8a29e",
    500: "#78716c",
    600: "#57534e",
    700: "#44403c",
    800: "#292524",
    900: "#1c1917",
    950: "#0c0a09"
  },
  red: {
    50: "#fef2f2",
    100: "#fee2e2",
    200: "#fecaca",
    300: "#fca5a5",
    400: "#f87171",
    500: "#ef4444",
    600: "#dc2626",
    700: "#b91c1c",
    800: "#991b1b",
    900: "#7f1d1d",
    950: "#450a0a"
  },
  orange: {
    50: "#fff7ed",
    100: "#ffedd5",
    200: "#fed7aa",
    300: "#fdba74",
    400: "#fb923c",
    500: "#f97316",
    600: "#ea580c",
    700: "#c2410c",
    800: "#9a3412",
    900: "#7c2d12",
    950: "#431407"
  },
  amber: {
    50: "#fffbeb",
    100: "#fef3c7",
    200: "#fde68a",
    300: "#fcd34d",
    400: "#fbbf24",
    500: "#f59e0b",
    600: "#d97706",
    700: "#b45309",
    800: "#92400e",
    900: "#78350f",
    950: "#451a03"
  },
  yellow: {
    50: "#fefce8",
    100: "#fef9c3",
    200: "#fef08a",
    300: "#fde047",
    400: "#facc15",
    500: "#eab308",
    600: "#ca8a04",
    700: "#a16207",
    800: "#854d0e",
    900: "#713f12",
    950: "#422006"
  },
  lime: {
    50: "#f7fee7",
    100: "#ecfccb",
    200: "#d9f99d",
    300: "#bef264",
    400: "#a3e635",
    500: "#84cc16",
    600: "#65a30d",
    700: "#4d7c0f",
    800: "#3f6212",
    900: "#365314",
    950: "#1a2e05"
  },
  green: {
    50: "#f0fdf4",
    100: "#dcfce7",
    200: "#bbf7d0",
    300: "#86efac",
    400: "#4ade80",
    500: "#22c55e",
    600: "#16a34a",
    700: "#15803d",
    800: "#166534",
    900: "#14532d",
    950: "#052e16"
  },
  emerald: {
    50: "#ecfdf5",
    100: "#d1fae5",
    200: "#a7f3d0",
    300: "#6ee7b7",
    400: "#34d399",
    500: "#10b981",
    600: "#059669",
    700: "#047857",
    800: "#065f46",
    900: "#064e3b",
    950: "#022c22"
  },
  teal: {
    50: "#f0fdfa",
    100: "#ccfbf1",
    200: "#99f6e4",
    300: "#5eead4",
    400: "#2dd4bf",
    500: "#14b8a6",
    600: "#0d9488",
    700: "#0f766e",
    800: "#115e59",
    900: "#134e4a",
    950: "#042f2e"
  },
  cyan: {
    50: "#ecfeff",
    100: "#cffafe",
    200: "#a5f3fc",
    300: "#67e8f9",
    400: "#22d3ee",
    500: "#06b6d4",
    600: "#0891b2",
    700: "#0e7490",
    800: "#155e75",
    900: "#164e63",
    950: "#083344"
  },
  sky: {
    50: "#f0f9ff",
    100: "#e0f2fe",
    200: "#bae6fd",
    300: "#7dd3fc",
    400: "#38bdf8",
    500: "#0ea5e9",
    600: "#0284c7",
    700: "#0369a1",
    800: "#075985",
    900: "#0c4a6e",
    950: "#082f49"
  },
  blue: {
    50: "#eff6ff",
    100: "#dbeafe",
    200: "#bfdbfe",
    300: "#93c5fd",
    400: "#60a5fa",
    500: "#3b82f6",
    600: "#2563eb",
    700: "#1d4ed8",
    800: "#1e40af",
    900: "#1e3a8a",
    950: "#172554"
  },
  indigo: {
    50: "#eef2ff",
    100: "#e0e7ff",
    200: "#c7d2fe",
    300: "#a5b4fc",
    400: "#818cf8",
    500: "#6366f1",
    600: "#4f46e5",
    700: "#4338ca",
    800: "#3730a3",
    900: "#312e81",
    950: "#1e1b4b"
  },
  violet: {
    50: "#f5f3ff",
    100: "#ede9fe",
    200: "#ddd6fe",
    300: "#c4b5fd",
    400: "#a78bfa",
    500: "#8b5cf6",
    600: "#7c3aed",
    700: "#6d28d9",
    800: "#5b21b6",
    900: "#4c1d95",
    950: "#2e1065"
  },
  purple: {
    50: "#faf5ff",
    100: "#f3e8ff",
    200: "#e9d5ff",
    300: "#d8b4fe",
    400: "#c084fc",
    500: "#a855f7",
    600: "#9333ea",
    700: "#7e22ce",
    800: "#6b21a8",
    900: "#581c87",
    950: "#3b0764"
  },
  fuchsia: {
    50: "#fdf4ff",
    100: "#fae8ff",
    200: "#f5d0fe",
    300: "#f0abfc",
    400: "#e879f9",
    500: "#d946ef",
    600: "#c026d3",
    700: "#a21caf",
    800: "#86198f",
    900: "#701a75",
    950: "#4a044e"
  },
  pink: {
    50: "#fdf2f8",
    100: "#fce7f3",
    200: "#fbcfe8",
    300: "#f9a8d4",
    400: "#f472b6",
    500: "#ec4899",
    600: "#db2777",
    700: "#be185d",
    800: "#9d174d",
    900: "#831843",
    950: "#500724"
  },
  rose: {
    50: "#fff1f2",
    100: "#ffe4e6",
    200: "#fecdd3",
    300: "#fda4af",
    400: "#fb7185",
    500: "#f43f5e",
    600: "#e11d48",
    700: "#be123c",
    800: "#9f1239",
    900: "#881337",
    950: "#4c0519"
  }
};
cm.reduce(
  (n, { color: e, primary: t, secondary: r }) => ({
    ...n,
    [e]: {
      primary: Ds[e][t],
      secondary: Ds[e][r]
    }
  }),
  {}
);
function hm(n) {
  n.addEventListener("click", e);
  async function e(t) {
    const r = t.composedPath(), [a] = r.filter(
      (i) => (i == null ? void 0 : i.tagName) === "BUTTON" && i.classList.contains("copy_code_button")
    );
    if (a) {
      let i = function(c) {
        c.style.opacity = "1", setTimeout(() => {
          c.style.opacity = "0";
        }, 2e3);
      };
      t.stopImmediatePropagation();
      const l = a.parentElement.innerText.trim(), s = Array.from(
        a.children
      )[1];
      await fm(l) && i(s);
    }
  }
  return {
    destroy() {
      n.removeEventListener("click", e);
    }
  };
}
async function fm(n) {
  let e = !1;
  if ("clipboard" in navigator)
    await navigator.clipboard.writeText(n), e = !0;
  else {
    const t = document.createElement("textarea");
    t.value = n, t.style.position = "absolute", t.style.left = "-999999px", document.body.prepend(t), t.select();
    try {
      document.execCommand("copy"), e = !0;
    } catch (r) {
      console.error(r), e = !1;
    } finally {
      t.remove();
    }
  }
  return e;
}
const on = (n) => typeof n == "number" ? n + "px" : n;
new Intl.Collator(0, { numeric: 1 }).compare;
typeof process < "u" && process.versions && process.versions.node;
var o0;
class q5 extends TransformStream {
  /** Constructs a new instance. */
  constructor(t = { allowCR: !1 }) {
    super({
      transform: (r, a) => {
        for (r = Y0(this, o0) + r; ; ) {
          const i = r.indexOf(`
`), l = t.allowCR ? r.indexOf("\r") : -1;
          if (l !== -1 && l !== r.length - 1 && (i === -1 || i - 1 > l)) {
            a.enqueue(r.slice(0, l)), r = r.slice(l + 1);
            continue;
          }
          if (i === -1)
            break;
          const s = r[i - 1] === "\r" ? i - 1 : i;
          a.enqueue(r.slice(0, s)), r = r.slice(i + 1);
        }
        ll(this, o0, r);
      },
      flush: (r) => {
        if (Y0(this, o0) === "")
          return;
        const a = t.allowCR && Y0(this, o0).endsWith("\r") ? Y0(this, o0).slice(0, -1) : Y0(this, o0);
        r.enqueue(a);
      }
    });
    ea(this, o0, "");
  }
}
o0 = new WeakMap();
const {
  SvelteComponent: mm,
  append_hydration: Ju,
  attr: ye,
  bubble: dm,
  check_outros: pm,
  children: $u,
  claim_element: Gn,
  claim_space: e1,
  create_slot: t1,
  detach: L0,
  element: Vn,
  empty: xs,
  get_all_dirty_from_scope: r1,
  get_slot_changes: n1,
  group_outros: gm,
  init: vm,
  insert_hydration: Rr,
  listen: bm,
  safe_not_equal: ym,
  set_style: Je,
  space: a1,
  src_url_equal: Mn,
  toggle_class: k0,
  transition_in: zn,
  transition_out: Bn,
  update_slot_base: i1
} = window.__gradio__svelte__internal;
function wm(n) {
  let e, t, r, a, i, l, s = (
    /*icon*/
    n[7] && As(n)
  );
  const o = (
    /*#slots*/
    n[12].default
  ), c = t1(
    o,
    n,
    /*$$scope*/
    n[11],
    null
  );
  return {
    c() {
      e = Vn("button"), s && s.c(), t = a1(), c && c.c(), this.h();
    },
    l(f) {
      e = Gn(f, "BUTTON", { class: !0, id: !0 });
      var d = $u(e);
      s && s.l(d), t = e1(d), c && c.l(d), d.forEach(L0), this.h();
    },
    h() {
      ye(e, "class", r = /*size*/
      n[4] + " " + /*variant*/
      n[3] + " " + /*elem_classes*/
      n[1].join(" ") + " svelte-1u1asd3"), ye(
        e,
        "id",
        /*elem_id*/
        n[0]
      ), e.disabled = /*disabled*/
      n[8], k0(e, "hidden", !/*visible*/
      n[2]), Je(
        e,
        "flex-grow",
        /*scale*/
        n[9]
      ), Je(
        e,
        "width",
        /*scale*/
        n[9] === 0 ? "fit-content" : null
      ), Je(e, "min-width", typeof /*min_width*/
      n[10] == "number" ? `calc(min(${/*min_width*/
      n[10]}px, 100%))` : null);
    },
    m(f, d) {
      Rr(f, e, d), s && s.m(e, null), Ju(e, t), c && c.m(e, null), a = !0, i || (l = bm(
        e,
        "click",
        /*click_handler*/
        n[13]
      ), i = !0);
    },
    p(f, d) {
      /*icon*/
      f[7] ? s ? s.p(f, d) : (s = As(f), s.c(), s.m(e, t)) : s && (s.d(1), s = null), c && c.p && (!a || d & /*$$scope*/
      2048) && i1(
        c,
        o,
        f,
        /*$$scope*/
        f[11],
        a ? n1(
          o,
          /*$$scope*/
          f[11],
          d,
          null
        ) : r1(
          /*$$scope*/
          f[11]
        ),
        null
      ), (!a || d & /*size, variant, elem_classes*/
      26 && r !== (r = /*size*/
      f[4] + " " + /*variant*/
      f[3] + " " + /*elem_classes*/
      f[1].join(" ") + " svelte-1u1asd3")) && ye(e, "class", r), (!a || d & /*elem_id*/
      1) && ye(
        e,
        "id",
        /*elem_id*/
        f[0]
      ), (!a || d & /*disabled*/
      256) && (e.disabled = /*disabled*/
      f[8]), (!a || d & /*size, variant, elem_classes, visible*/
      30) && k0(e, "hidden", !/*visible*/
      f[2]), d & /*scale*/
      512 && Je(
        e,
        "flex-grow",
        /*scale*/
        f[9]
      ), d & /*scale*/
      512 && Je(
        e,
        "width",
        /*scale*/
        f[9] === 0 ? "fit-content" : null
      ), d & /*min_width*/
      1024 && Je(e, "min-width", typeof /*min_width*/
      f[10] == "number" ? `calc(min(${/*min_width*/
      f[10]}px, 100%))` : null);
    },
    i(f) {
      a || (zn(c, f), a = !0);
    },
    o(f) {
      Bn(c, f), a = !1;
    },
    d(f) {
      f && L0(e), s && s.d(), c && c.d(f), i = !1, l();
    }
  };
}
function km(n) {
  let e, t, r, a, i = (
    /*icon*/
    n[7] && Ss(n)
  );
  const l = (
    /*#slots*/
    n[12].default
  ), s = t1(
    l,
    n,
    /*$$scope*/
    n[11],
    null
  );
  return {
    c() {
      e = Vn("a"), i && i.c(), t = a1(), s && s.c(), this.h();
    },
    l(o) {
      e = Gn(o, "A", {
        href: !0,
        rel: !0,
        "aria-disabled": !0,
        class: !0,
        id: !0
      });
      var c = $u(e);
      i && i.l(c), t = e1(c), s && s.l(c), c.forEach(L0), this.h();
    },
    h() {
      ye(
        e,
        "href",
        /*link*/
        n[6]
      ), ye(e, "rel", "noopener noreferrer"), ye(
        e,
        "aria-disabled",
        /*disabled*/
        n[8]
      ), ye(e, "class", r = /*size*/
      n[4] + " " + /*variant*/
      n[3] + " " + /*elem_classes*/
      n[1].join(" ") + " svelte-1u1asd3"), ye(
        e,
        "id",
        /*elem_id*/
        n[0]
      ), k0(e, "hidden", !/*visible*/
      n[2]), k0(
        e,
        "disabled",
        /*disabled*/
        n[8]
      ), Je(
        e,
        "flex-grow",
        /*scale*/
        n[9]
      ), Je(
        e,
        "pointer-events",
        /*disabled*/
        n[8] ? "none" : null
      ), Je(
        e,
        "width",
        /*scale*/
        n[9] === 0 ? "fit-content" : null
      ), Je(e, "min-width", typeof /*min_width*/
      n[10] == "number" ? `calc(min(${/*min_width*/
      n[10]}px, 100%))` : null);
    },
    m(o, c) {
      Rr(o, e, c), i && i.m(e, null), Ju(e, t), s && s.m(e, null), a = !0;
    },
    p(o, c) {
      /*icon*/
      o[7] ? i ? i.p(o, c) : (i = Ss(o), i.c(), i.m(e, t)) : i && (i.d(1), i = null), s && s.p && (!a || c & /*$$scope*/
      2048) && i1(
        s,
        l,
        o,
        /*$$scope*/
        o[11],
        a ? n1(
          l,
          /*$$scope*/
          o[11],
          c,
          null
        ) : r1(
          /*$$scope*/
          o[11]
        ),
        null
      ), (!a || c & /*link*/
      64) && ye(
        e,
        "href",
        /*link*/
        o[6]
      ), (!a || c & /*disabled*/
      256) && ye(
        e,
        "aria-disabled",
        /*disabled*/
        o[8]
      ), (!a || c & /*size, variant, elem_classes*/
      26 && r !== (r = /*size*/
      o[4] + " " + /*variant*/
      o[3] + " " + /*elem_classes*/
      o[1].join(" ") + " svelte-1u1asd3")) && ye(e, "class", r), (!a || c & /*elem_id*/
      1) && ye(
        e,
        "id",
        /*elem_id*/
        o[0]
      ), (!a || c & /*size, variant, elem_classes, visible*/
      30) && k0(e, "hidden", !/*visible*/
      o[2]), (!a || c & /*size, variant, elem_classes, disabled*/
      282) && k0(
        e,
        "disabled",
        /*disabled*/
        o[8]
      ), c & /*scale*/
      512 && Je(
        e,
        "flex-grow",
        /*scale*/
        o[9]
      ), c & /*disabled*/
      256 && Je(
        e,
        "pointer-events",
        /*disabled*/
        o[8] ? "none" : null
      ), c & /*scale*/
      512 && Je(
        e,
        "width",
        /*scale*/
        o[9] === 0 ? "fit-content" : null
      ), c & /*min_width*/
      1024 && Je(e, "min-width", typeof /*min_width*/
      o[10] == "number" ? `calc(min(${/*min_width*/
      o[10]}px, 100%))` : null);
    },
    i(o) {
      a || (zn(s, o), a = !0);
    },
    o(o) {
      Bn(s, o), a = !1;
    },
    d(o) {
      o && L0(e), i && i.d(), s && s.d(o);
    }
  };
}
function As(n) {
  let e, t, r;
  return {
    c() {
      e = Vn("img"), this.h();
    },
    l(a) {
      e = Gn(a, "IMG", { class: !0, src: !0, alt: !0 }), this.h();
    },
    h() {
      ye(e, "class", "button-icon svelte-1u1asd3"), Mn(e.src, t = /*icon*/
      n[7].url) || ye(e, "src", t), ye(e, "alt", r = `${/*value*/
      n[5]} icon`), k0(
        e,
        "right-padded",
        /*value*/
        n[5]
      );
    },
    m(a, i) {
      Rr(a, e, i);
    },
    p(a, i) {
      i & /*icon*/
      128 && !Mn(e.src, t = /*icon*/
      a[7].url) && ye(e, "src", t), i & /*value*/
      32 && r !== (r = `${/*value*/
      a[5]} icon`) && ye(e, "alt", r), i & /*value*/
      32 && k0(
        e,
        "right-padded",
        /*value*/
        a[5]
      );
    },
    d(a) {
      a && L0(e);
    }
  };
}
function Ss(n) {
  let e, t, r;
  return {
    c() {
      e = Vn("img"), this.h();
    },
    l(a) {
      e = Gn(a, "IMG", { class: !0, src: !0, alt: !0 }), this.h();
    },
    h() {
      ye(e, "class", "button-icon svelte-1u1asd3"), Mn(e.src, t = /*icon*/
      n[7].url) || ye(e, "src", t), ye(e, "alt", r = `${/*value*/
      n[5]} icon`);
    },
    m(a, i) {
      Rr(a, e, i);
    },
    p(a, i) {
      i & /*icon*/
      128 && !Mn(e.src, t = /*icon*/
      a[7].url) && ye(e, "src", t), i & /*value*/
      32 && r !== (r = `${/*value*/
      a[5]} icon`) && ye(e, "alt", r);
    },
    d(a) {
      a && L0(e);
    }
  };
}
function _m(n) {
  let e, t, r, a;
  const i = [km, wm], l = [];
  function s(o, c) {
    return (
      /*link*/
      o[6] && /*link*/
      o[6].length > 0 ? 0 : 1
    );
  }
  return e = s(n), t = l[e] = i[e](n), {
    c() {
      t.c(), r = xs();
    },
    l(o) {
      t.l(o), r = xs();
    },
    m(o, c) {
      l[e].m(o, c), Rr(o, r, c), a = !0;
    },
    p(o, [c]) {
      let f = e;
      e = s(o), e === f ? l[e].p(o, c) : (gm(), Bn(l[f], 1, 1, () => {
        l[f] = null;
      }), pm(), t = l[e], t ? t.p(o, c) : (t = l[e] = i[e](o), t.c()), zn(t, 1), t.m(r.parentNode, r));
    },
    i(o) {
      a || (zn(t), a = !0);
    },
    o(o) {
      Bn(t), a = !1;
    },
    d(o) {
      o && L0(r), l[e].d(o);
    }
  };
}
function Dm(n, e, t) {
  let { $$slots: r = {}, $$scope: a } = e, { elem_id: i = "" } = e, { elem_classes: l = [] } = e, { visible: s = !0 } = e, { variant: o = "secondary" } = e, { size: c = "lg" } = e, { value: f = null } = e, { link: d = null } = e, { icon: g = null } = e, { disabled: v = !1 } = e, { scale: y = null } = e, { min_width: k = void 0 } = e;
  function E(A) {
    dm.call(this, n, A);
  }
  return n.$$set = (A) => {
    "elem_id" in A && t(0, i = A.elem_id), "elem_classes" in A && t(1, l = A.elem_classes), "visible" in A && t(2, s = A.visible), "variant" in A && t(3, o = A.variant), "size" in A && t(4, c = A.size), "value" in A && t(5, f = A.value), "link" in A && t(6, d = A.link), "icon" in A && t(7, g = A.icon), "disabled" in A && t(8, v = A.disabled), "scale" in A && t(9, y = A.scale), "min_width" in A && t(10, k = A.min_width), "$$scope" in A && t(11, a = A.$$scope);
  }, [
    i,
    l,
    s,
    o,
    c,
    f,
    d,
    g,
    v,
    y,
    k,
    a,
    r,
    E
  ];
}
class l1 extends mm {
  constructor(e) {
    super(), vm(this, e, Dm, _m, ym, {
      elem_id: 0,
      elem_classes: 1,
      visible: 2,
      variant: 3,
      size: 4,
      value: 5,
      link: 6,
      icon: 7,
      disabled: 8,
      scale: 9,
      min_width: 10
    });
  }
}
function Q0(n) {
  let e = ["", "k", "M", "G", "T", "P", "E", "Z"], t = 0;
  for (; n > 1e3 && t < e.length - 1; )
    n /= 1e3, t++;
  let r = e[t];
  return (Number.isInteger(n) ? n : n.toFixed(1)) + r;
}
function wn() {
}
function xm(n, e) {
  return n != n ? e == e : n !== e || n && typeof n == "object" || typeof n == "function";
}
const s1 = typeof window < "u";
let Es = s1 ? () => window.performance.now() : () => Date.now(), o1 = s1 ? (n) => requestAnimationFrame(n) : wn;
const er = /* @__PURE__ */ new Set();
function u1(n) {
  er.forEach((e) => {
    e.c(n) || (er.delete(e), e.f());
  }), er.size !== 0 && o1(u1);
}
function Am(n) {
  let e;
  return er.size === 0 && o1(u1), {
    promise: new Promise((t) => {
      er.add(e = { c: n, f: t });
    }),
    abort() {
      er.delete(e);
    }
  };
}
const K0 = [];
function Sm(n, e = wn) {
  let t;
  const r = /* @__PURE__ */ new Set();
  function a(s) {
    if (xm(n, s) && (n = s, t)) {
      const o = !K0.length;
      for (const c of r)
        c[1](), K0.push(c, n);
      if (o) {
        for (let c = 0; c < K0.length; c += 2)
          K0[c][0](K0[c + 1]);
        K0.length = 0;
      }
    }
  }
  function i(s) {
    a(s(n));
  }
  function l(s, o = wn) {
    const c = [s, o];
    return r.add(c), r.size === 1 && (t = e(a, i) || wn), s(n), () => {
      r.delete(c), r.size === 0 && t && (t(), t = null);
    };
  }
  return { set: a, update: i, subscribe: l };
}
function Fs(n) {
  return Object.prototype.toString.call(n) === "[object Date]";
}
function ei(n, e, t, r) {
  if (typeof t == "number" || Fs(t)) {
    const a = r - t, i = (t - e) / (n.dt || 1 / 60), l = n.opts.stiffness * a, s = n.opts.damping * i, o = (l - s) * n.inv_mass, c = (i + o) * n.dt;
    return Math.abs(c) < n.opts.precision && Math.abs(a) < n.opts.precision ? r : (n.settled = !1, Fs(t) ? new Date(t.getTime() + c) : t + c);
  } else {
    if (Array.isArray(t))
      return t.map(
        (a, i) => ei(n, e[i], t[i], r[i])
      );
    if (typeof t == "object") {
      const a = {};
      for (const i in t)
        a[i] = ei(n, e[i], t[i], r[i]);
      return a;
    } else
      throw new Error(`Cannot spring ${typeof t} values`);
  }
}
function Ts(n, e = {}) {
  const t = Sm(n), { stiffness: r = 0.15, damping: a = 0.8, precision: i = 0.01 } = e;
  let l, s, o, c = n, f = n, d = 1, g = 0, v = !1;
  function y(E, A = {}) {
    f = E;
    const D = o = {};
    return n == null || A.hard || k.stiffness >= 1 && k.damping >= 1 ? (v = !0, l = Es(), c = E, t.set(n = f), Promise.resolve()) : (A.soft && (g = 1 / ((A.soft === !0 ? 0.5 : +A.soft) * 60), d = 0), s || (l = Es(), v = !1, s = Am((b) => {
      if (v)
        return v = !1, s = null, !1;
      d = Math.min(d + g, 1);
      const F = {
        inv_mass: d,
        opts: k,
        settled: !0,
        dt: (b - l) * 60 / 1e3
      }, T = ei(F, c, n, f);
      return l = b, c = n, t.set(n = T), F.settled && (s = null), !F.settled;
    })), new Promise((b) => {
      s.promise.then(() => {
        D === o && b();
      });
    }));
  }
  const k = {
    set: y,
    update: (E, A) => y(E(f, n), A),
    subscribe: t.subscribe,
    stiffness: r,
    damping: a,
    precision: i
  };
  return k;
}
const {
  SvelteComponent: Em,
  append_hydration: xt,
  attr: ae,
  children: ot,
  claim_element: Fm,
  claim_svg_element: At,
  component_subscribe: Cs,
  detach: rt,
  element: Tm,
  init: Cm,
  insert_hydration: Mm,
  noop: Ms,
  safe_not_equal: zm,
  set_style: un,
  svg_element: St,
  toggle_class: zs
} = window.__gradio__svelte__internal, { onMount: Bm } = window.__gradio__svelte__internal;
function Nm(n) {
  let e, t, r, a, i, l, s, o, c, f, d, g;
  return {
    c() {
      e = Tm("div"), t = St("svg"), r = St("g"), a = St("path"), i = St("path"), l = St("path"), s = St("path"), o = St("g"), c = St("path"), f = St("path"), d = St("path"), g = St("path"), this.h();
    },
    l(v) {
      e = Fm(v, "DIV", { class: !0 });
      var y = ot(e);
      t = At(y, "svg", {
        viewBox: !0,
        fill: !0,
        xmlns: !0,
        class: !0
      });
      var k = ot(t);
      r = At(k, "g", { style: !0 });
      var E = ot(r);
      a = At(E, "path", {
        d: !0,
        fill: !0,
        "fill-opacity": !0,
        class: !0
      }), ot(a).forEach(rt), i = At(E, "path", { d: !0, fill: !0, class: !0 }), ot(i).forEach(rt), l = At(E, "path", {
        d: !0,
        fill: !0,
        "fill-opacity": !0,
        class: !0
      }), ot(l).forEach(rt), s = At(E, "path", { d: !0, fill: !0, class: !0 }), ot(s).forEach(rt), E.forEach(rt), o = At(k, "g", { style: !0 });
      var A = ot(o);
      c = At(A, "path", {
        d: !0,
        fill: !0,
        "fill-opacity": !0,
        class: !0
      }), ot(c).forEach(rt), f = At(A, "path", { d: !0, fill: !0, class: !0 }), ot(f).forEach(rt), d = At(A, "path", {
        d: !0,
        fill: !0,
        "fill-opacity": !0,
        class: !0
      }), ot(d).forEach(rt), g = At(A, "path", { d: !0, fill: !0, class: !0 }), ot(g).forEach(rt), A.forEach(rt), k.forEach(rt), y.forEach(rt), this.h();
    },
    h() {
      ae(a, "d", "M255.926 0.754768L509.702 139.936V221.027L255.926 81.8465V0.754768Z"), ae(a, "fill", "#FF7C00"), ae(a, "fill-opacity", "0.4"), ae(a, "class", "svelte-43sxxs"), ae(i, "d", "M509.69 139.936L254.981 279.641V361.255L509.69 221.55V139.936Z"), ae(i, "fill", "#FF7C00"), ae(i, "class", "svelte-43sxxs"), ae(l, "d", "M0.250138 139.937L254.981 279.641V361.255L0.250138 221.55V139.937Z"), ae(l, "fill", "#FF7C00"), ae(l, "fill-opacity", "0.4"), ae(l, "class", "svelte-43sxxs"), ae(s, "d", "M255.923 0.232622L0.236328 139.936V221.55L255.923 81.8469V0.232622Z"), ae(s, "fill", "#FF7C00"), ae(s, "class", "svelte-43sxxs"), un(r, "transform", "translate(" + /*$top*/
      n[1][0] + "px, " + /*$top*/
      n[1][1] + "px)"), ae(c, "d", "M255.926 141.5L509.702 280.681V361.773L255.926 222.592V141.5Z"), ae(c, "fill", "#FF7C00"), ae(c, "fill-opacity", "0.4"), ae(c, "class", "svelte-43sxxs"), ae(f, "d", "M509.69 280.679L254.981 420.384V501.998L509.69 362.293V280.679Z"), ae(f, "fill", "#FF7C00"), ae(f, "class", "svelte-43sxxs"), ae(d, "d", "M0.250138 280.681L254.981 420.386V502L0.250138 362.295V280.681Z"), ae(d, "fill", "#FF7C00"), ae(d, "fill-opacity", "0.4"), ae(d, "class", "svelte-43sxxs"), ae(g, "d", "M255.923 140.977L0.236328 280.68V362.294L255.923 222.591V140.977Z"), ae(g, "fill", "#FF7C00"), ae(g, "class", "svelte-43sxxs"), un(o, "transform", "translate(" + /*$bottom*/
      n[2][0] + "px, " + /*$bottom*/
      n[2][1] + "px)"), ae(t, "viewBox", "-1200 -1200 3000 3000"), ae(t, "fill", "none"), ae(t, "xmlns", "http://www.w3.org/2000/svg"), ae(t, "class", "svelte-43sxxs"), ae(e, "class", "svelte-43sxxs"), zs(
        e,
        "margin",
        /*margin*/
        n[0]
      );
    },
    m(v, y) {
      Mm(v, e, y), xt(e, t), xt(t, r), xt(r, a), xt(r, i), xt(r, l), xt(r, s), xt(t, o), xt(o, c), xt(o, f), xt(o, d), xt(o, g);
    },
    p(v, [y]) {
      y & /*$top*/
      2 && un(r, "transform", "translate(" + /*$top*/
      v[1][0] + "px, " + /*$top*/
      v[1][1] + "px)"), y & /*$bottom*/
      4 && un(o, "transform", "translate(" + /*$bottom*/
      v[2][0] + "px, " + /*$bottom*/
      v[2][1] + "px)"), y & /*margin*/
      1 && zs(
        e,
        "margin",
        /*margin*/
        v[0]
      );
    },
    i: Ms,
    o: Ms,
    d(v) {
      v && rt(e);
    }
  };
}
function Rm(n, e, t) {
  let r, a, { margin: i = !0 } = e;
  const l = Ts([0, 0]);
  Cs(n, l, (g) => t(1, r = g));
  const s = Ts([0, 0]);
  Cs(n, s, (g) => t(2, a = g));
  let o;
  async function c() {
    await Promise.all([l.set([125, 140]), s.set([-125, -140])]), await Promise.all([l.set([-125, 140]), s.set([125, -140])]), await Promise.all([l.set([-125, 0]), s.set([125, -0])]), await Promise.all([l.set([125, 0]), s.set([-125, 0])]);
  }
  async function f() {
    await c(), o || f();
  }
  async function d() {
    await Promise.all([l.set([125, 0]), s.set([-125, 0])]), f();
  }
  return Bm(() => (d(), () => o = !0)), n.$$set = (g) => {
    "margin" in g && t(0, i = g.margin);
  }, [i, r, a, l, s];
}
class Im extends Em {
  constructor(e) {
    super(), Cm(this, e, Rm, Nm, zm, { margin: 0 });
  }
}
const {
  SvelteComponent: Lm,
  append_hydration: z0,
  attr: Mt,
  binding_callbacks: Bs,
  check_outros: ti,
  children: Vt,
  claim_component: c1,
  claim_element: Wt,
  claim_space: ht,
  claim_text: ke,
  create_component: h1,
  create_slot: f1,
  destroy_component: m1,
  destroy_each: d1,
  detach: Y,
  element: Xt,
  empty: gt,
  ensure_array_like: Nn,
  get_all_dirty_from_scope: p1,
  get_slot_changes: g1,
  group_outros: ri,
  init: Om,
  insert_hydration: ee,
  mount_component: v1,
  noop: ni,
  safe_not_equal: qm,
  set_data: vt,
  set_style: _0,
  space: ft,
  text: _e,
  toggle_class: ut,
  transition_in: Tt,
  transition_out: Yt,
  update_slot_base: b1
} = window.__gradio__svelte__internal, { tick: Pm } = window.__gradio__svelte__internal, { onDestroy: Hm } = window.__gradio__svelte__internal, { createEventDispatcher: Um } = window.__gradio__svelte__internal, Gm = (n) => ({}), Ns = (n) => ({}), Vm = (n) => ({}), Rs = (n) => ({});
function Is(n, e, t) {
  const r = n.slice();
  return r[40] = e[t], r[42] = t, r;
}
function Ls(n, e, t) {
  const r = n.slice();
  return r[40] = e[t], r;
}
function Wm(n) {
  let e, t, r, a, i = (
    /*i18n*/
    n[1]("common.error") + ""
  ), l, s, o;
  t = new X2({
    props: {
      Icon: am,
      label: (
        /*i18n*/
        n[1]("common.clear")
      ),
      disabled: !1
    }
  }), t.$on(
    "click",
    /*click_handler*/
    n[32]
  );
  const c = (
    /*#slots*/
    n[30].error
  ), f = f1(
    c,
    n,
    /*$$scope*/
    n[29],
    Ns
  );
  return {
    c() {
      e = Xt("div"), h1(t.$$.fragment), r = ft(), a = Xt("span"), l = _e(i), s = ft(), f && f.c(), this.h();
    },
    l(d) {
      e = Wt(d, "DIV", { class: !0 });
      var g = Vt(e);
      c1(t.$$.fragment, g), g.forEach(Y), r = ht(d), a = Wt(d, "SPAN", { class: !0 });
      var v = Vt(a);
      l = ke(v, i), v.forEach(Y), s = ht(d), f && f.l(d), this.h();
    },
    h() {
      Mt(e, "class", "clear-status svelte-17v219f"), Mt(a, "class", "error svelte-17v219f");
    },
    m(d, g) {
      ee(d, e, g), v1(t, e, null), ee(d, r, g), ee(d, a, g), z0(a, l), ee(d, s, g), f && f.m(d, g), o = !0;
    },
    p(d, g) {
      const v = {};
      g[0] & /*i18n*/
      2 && (v.label = /*i18n*/
      d[1]("common.clear")), t.$set(v), (!o || g[0] & /*i18n*/
      2) && i !== (i = /*i18n*/
      d[1]("common.error") + "") && vt(l, i), f && f.p && (!o || g[0] & /*$$scope*/
      536870912) && b1(
        f,
        c,
        d,
        /*$$scope*/
        d[29],
        o ? g1(
          c,
          /*$$scope*/
          d[29],
          g,
          Gm
        ) : p1(
          /*$$scope*/
          d[29]
        ),
        Ns
      );
    },
    i(d) {
      o || (Tt(t.$$.fragment, d), Tt(f, d), o = !0);
    },
    o(d) {
      Yt(t.$$.fragment, d), Yt(f, d), o = !1;
    },
    d(d) {
      d && (Y(e), Y(r), Y(a), Y(s)), m1(t), f && f.d(d);
    }
  };
}
function Xm(n) {
  let e, t, r, a, i, l, s, o, c, f = (
    /*variant*/
    n[8] === "default" && /*show_eta_bar*/
    n[18] && /*show_progress*/
    n[6] === "full" && Os(n)
  );
  function d(b, F) {
    if (
      /*progress*/
      b[7]
    ) return Zm;
    if (
      /*queue_position*/
      b[2] !== null && /*queue_size*/
      b[3] !== void 0 && /*queue_position*/
      b[2] >= 0
    ) return jm;
    if (
      /*queue_position*/
      b[2] === 0
    ) return Ym;
  }
  let g = d(n), v = g && g(n), y = (
    /*timer*/
    n[5] && Hs(n)
  );
  const k = [$m, Jm], E = [];
  function A(b, F) {
    return (
      /*last_progress_level*/
      b[15] != null ? 0 : (
        /*show_progress*/
        b[6] === "full" ? 1 : -1
      )
    );
  }
  ~(i = A(n)) && (l = E[i] = k[i](n));
  let D = !/*timer*/
  n[5] && js(n);
  return {
    c() {
      f && f.c(), e = ft(), t = Xt("div"), v && v.c(), r = ft(), y && y.c(), a = ft(), l && l.c(), s = ft(), D && D.c(), o = gt(), this.h();
    },
    l(b) {
      f && f.l(b), e = ht(b), t = Wt(b, "DIV", { class: !0 });
      var F = Vt(t);
      v && v.l(F), r = ht(F), y && y.l(F), F.forEach(Y), a = ht(b), l && l.l(b), s = ht(b), D && D.l(b), o = gt(), this.h();
    },
    h() {
      Mt(t, "class", "progress-text svelte-17v219f"), ut(
        t,
        "meta-text-center",
        /*variant*/
        n[8] === "center"
      ), ut(
        t,
        "meta-text",
        /*variant*/
        n[8] === "default"
      );
    },
    m(b, F) {
      f && f.m(b, F), ee(b, e, F), ee(b, t, F), v && v.m(t, null), z0(t, r), y && y.m(t, null), ee(b, a, F), ~i && E[i].m(b, F), ee(b, s, F), D && D.m(b, F), ee(b, o, F), c = !0;
    },
    p(b, F) {
      /*variant*/
      b[8] === "default" && /*show_eta_bar*/
      b[18] && /*show_progress*/
      b[6] === "full" ? f ? f.p(b, F) : (f = Os(b), f.c(), f.m(e.parentNode, e)) : f && (f.d(1), f = null), g === (g = d(b)) && v ? v.p(b, F) : (v && v.d(1), v = g && g(b), v && (v.c(), v.m(t, r))), /*timer*/
      b[5] ? y ? y.p(b, F) : (y = Hs(b), y.c(), y.m(t, null)) : y && (y.d(1), y = null), (!c || F[0] & /*variant*/
      256) && ut(
        t,
        "meta-text-center",
        /*variant*/
        b[8] === "center"
      ), (!c || F[0] & /*variant*/
      256) && ut(
        t,
        "meta-text",
        /*variant*/
        b[8] === "default"
      );
      let T = i;
      i = A(b), i === T ? ~i && E[i].p(b, F) : (l && (ri(), Yt(E[T], 1, 1, () => {
        E[T] = null;
      }), ti()), ~i ? (l = E[i], l ? l.p(b, F) : (l = E[i] = k[i](b), l.c()), Tt(l, 1), l.m(s.parentNode, s)) : l = null), /*timer*/
      b[5] ? D && (ri(), Yt(D, 1, 1, () => {
        D = null;
      }), ti()) : D ? (D.p(b, F), F[0] & /*timer*/
      32 && Tt(D, 1)) : (D = js(b), D.c(), Tt(D, 1), D.m(o.parentNode, o));
    },
    i(b) {
      c || (Tt(l), Tt(D), c = !0);
    },
    o(b) {
      Yt(l), Yt(D), c = !1;
    },
    d(b) {
      b && (Y(e), Y(t), Y(a), Y(s), Y(o)), f && f.d(b), v && v.d(), y && y.d(), ~i && E[i].d(b), D && D.d(b);
    }
  };
}
function Os(n) {
  let e, t = `translateX(${/*eta_level*/
  (n[17] || 0) * 100 - 100}%)`;
  return {
    c() {
      e = Xt("div"), this.h();
    },
    l(r) {
      e = Wt(r, "DIV", { class: !0 }), Vt(e).forEach(Y), this.h();
    },
    h() {
      Mt(e, "class", "eta-bar svelte-17v219f"), _0(e, "transform", t);
    },
    m(r, a) {
      ee(r, e, a);
    },
    p(r, a) {
      a[0] & /*eta_level*/
      131072 && t !== (t = `translateX(${/*eta_level*/
      (r[17] || 0) * 100 - 100}%)`) && _0(e, "transform", t);
    },
    d(r) {
      r && Y(e);
    }
  };
}
function Ym(n) {
  let e;
  return {
    c() {
      e = _e("processing |");
    },
    l(t) {
      e = ke(t, "processing |");
    },
    m(t, r) {
      ee(t, e, r);
    },
    p: ni,
    d(t) {
      t && Y(e);
    }
  };
}
function jm(n) {
  let e, t = (
    /*queue_position*/
    n[2] + 1 + ""
  ), r, a, i, l;
  return {
    c() {
      e = _e("queue: "), r = _e(t), a = _e("/"), i = _e(
        /*queue_size*/
        n[3]
      ), l = _e(" |");
    },
    l(s) {
      e = ke(s, "queue: "), r = ke(s, t), a = ke(s, "/"), i = ke(
        s,
        /*queue_size*/
        n[3]
      ), l = ke(s, " |");
    },
    m(s, o) {
      ee(s, e, o), ee(s, r, o), ee(s, a, o), ee(s, i, o), ee(s, l, o);
    },
    p(s, o) {
      o[0] & /*queue_position*/
      4 && t !== (t = /*queue_position*/
      s[2] + 1 + "") && vt(r, t), o[0] & /*queue_size*/
      8 && vt(
        i,
        /*queue_size*/
        s[3]
      );
    },
    d(s) {
      s && (Y(e), Y(r), Y(a), Y(i), Y(l));
    }
  };
}
function Zm(n) {
  let e, t = Nn(
    /*progress*/
    n[7]
  ), r = [];
  for (let a = 0; a < t.length; a += 1)
    r[a] = Ps(Ls(n, t, a));
  return {
    c() {
      for (let a = 0; a < r.length; a += 1)
        r[a].c();
      e = gt();
    },
    l(a) {
      for (let i = 0; i < r.length; i += 1)
        r[i].l(a);
      e = gt();
    },
    m(a, i) {
      for (let l = 0; l < r.length; l += 1)
        r[l] && r[l].m(a, i);
      ee(a, e, i);
    },
    p(a, i) {
      if (i[0] & /*progress*/
      128) {
        t = Nn(
          /*progress*/
          a[7]
        );
        let l;
        for (l = 0; l < t.length; l += 1) {
          const s = Ls(a, t, l);
          r[l] ? r[l].p(s, i) : (r[l] = Ps(s), r[l].c(), r[l].m(e.parentNode, e));
        }
        for (; l < r.length; l += 1)
          r[l].d(1);
        r.length = t.length;
      }
    },
    d(a) {
      a && Y(e), d1(r, a);
    }
  };
}
function qs(n) {
  let e, t = (
    /*p*/
    n[40].unit + ""
  ), r, a, i = " ", l;
  function s(f, d) {
    return (
      /*p*/
      f[40].length != null ? Qm : Km
    );
  }
  let o = s(n), c = o(n);
  return {
    c() {
      c.c(), e = ft(), r = _e(t), a = _e(" | "), l = _e(i);
    },
    l(f) {
      c.l(f), e = ht(f), r = ke(f, t), a = ke(f, " | "), l = ke(f, i);
    },
    m(f, d) {
      c.m(f, d), ee(f, e, d), ee(f, r, d), ee(f, a, d), ee(f, l, d);
    },
    p(f, d) {
      o === (o = s(f)) && c ? c.p(f, d) : (c.d(1), c = o(f), c && (c.c(), c.m(e.parentNode, e))), d[0] & /*progress*/
      128 && t !== (t = /*p*/
      f[40].unit + "") && vt(r, t);
    },
    d(f) {
      f && (Y(e), Y(r), Y(a), Y(l)), c.d(f);
    }
  };
}
function Km(n) {
  let e = Q0(
    /*p*/
    n[40].index || 0
  ) + "", t;
  return {
    c() {
      t = _e(e);
    },
    l(r) {
      t = ke(r, e);
    },
    m(r, a) {
      ee(r, t, a);
    },
    p(r, a) {
      a[0] & /*progress*/
      128 && e !== (e = Q0(
        /*p*/
        r[40].index || 0
      ) + "") && vt(t, e);
    },
    d(r) {
      r && Y(t);
    }
  };
}
function Qm(n) {
  let e = Q0(
    /*p*/
    n[40].index || 0
  ) + "", t, r, a = Q0(
    /*p*/
    n[40].length
  ) + "", i;
  return {
    c() {
      t = _e(e), r = _e("/"), i = _e(a);
    },
    l(l) {
      t = ke(l, e), r = ke(l, "/"), i = ke(l, a);
    },
    m(l, s) {
      ee(l, t, s), ee(l, r, s), ee(l, i, s);
    },
    p(l, s) {
      s[0] & /*progress*/
      128 && e !== (e = Q0(
        /*p*/
        l[40].index || 0
      ) + "") && vt(t, e), s[0] & /*progress*/
      128 && a !== (a = Q0(
        /*p*/
        l[40].length
      ) + "") && vt(i, a);
    },
    d(l) {
      l && (Y(t), Y(r), Y(i));
    }
  };
}
function Ps(n) {
  let e, t = (
    /*p*/
    n[40].index != null && qs(n)
  );
  return {
    c() {
      t && t.c(), e = gt();
    },
    l(r) {
      t && t.l(r), e = gt();
    },
    m(r, a) {
      t && t.m(r, a), ee(r, e, a);
    },
    p(r, a) {
      /*p*/
      r[40].index != null ? t ? t.p(r, a) : (t = qs(r), t.c(), t.m(e.parentNode, e)) : t && (t.d(1), t = null);
    },
    d(r) {
      r && Y(e), t && t.d(r);
    }
  };
}
function Hs(n) {
  let e, t = (
    /*eta*/
    n[0] ? `/${/*formatted_eta*/
    n[19]}` : ""
  ), r, a;
  return {
    c() {
      e = _e(
        /*formatted_timer*/
        n[20]
      ), r = _e(t), a = _e("s");
    },
    l(i) {
      e = ke(
        i,
        /*formatted_timer*/
        n[20]
      ), r = ke(i, t), a = ke(i, "s");
    },
    m(i, l) {
      ee(i, e, l), ee(i, r, l), ee(i, a, l);
    },
    p(i, l) {
      l[0] & /*formatted_timer*/
      1048576 && vt(
        e,
        /*formatted_timer*/
        i[20]
      ), l[0] & /*eta, formatted_eta*/
      524289 && t !== (t = /*eta*/
      i[0] ? `/${/*formatted_eta*/
      i[19]}` : "") && vt(r, t);
    },
    d(i) {
      i && (Y(e), Y(r), Y(a));
    }
  };
}
function Jm(n) {
  let e, t;
  return e = new Im({
    props: { margin: (
      /*variant*/
      n[8] === "default"
    ) }
  }), {
    c() {
      h1(e.$$.fragment);
    },
    l(r) {
      c1(e.$$.fragment, r);
    },
    m(r, a) {
      v1(e, r, a), t = !0;
    },
    p(r, a) {
      const i = {};
      a[0] & /*variant*/
      256 && (i.margin = /*variant*/
      r[8] === "default"), e.$set(i);
    },
    i(r) {
      t || (Tt(e.$$.fragment, r), t = !0);
    },
    o(r) {
      Yt(e.$$.fragment, r), t = !1;
    },
    d(r) {
      m1(e, r);
    }
  };
}
function $m(n) {
  let e, t, r, a, i, l = `${/*last_progress_level*/
  n[15] * 100}%`, s = (
    /*progress*/
    n[7] != null && Us(n)
  );
  return {
    c() {
      e = Xt("div"), t = Xt("div"), s && s.c(), r = ft(), a = Xt("div"), i = Xt("div"), this.h();
    },
    l(o) {
      e = Wt(o, "DIV", { class: !0 });
      var c = Vt(e);
      t = Wt(c, "DIV", { class: !0 });
      var f = Vt(t);
      s && s.l(f), f.forEach(Y), r = ht(c), a = Wt(c, "DIV", { class: !0 });
      var d = Vt(a);
      i = Wt(d, "DIV", { class: !0 }), Vt(i).forEach(Y), d.forEach(Y), c.forEach(Y), this.h();
    },
    h() {
      Mt(t, "class", "progress-level-inner svelte-17v219f"), Mt(i, "class", "progress-bar svelte-17v219f"), _0(i, "width", l), Mt(a, "class", "progress-bar-wrap svelte-17v219f"), Mt(e, "class", "progress-level svelte-17v219f");
    },
    m(o, c) {
      ee(o, e, c), z0(e, t), s && s.m(t, null), z0(e, r), z0(e, a), z0(a, i), n[31](i);
    },
    p(o, c) {
      /*progress*/
      o[7] != null ? s ? s.p(o, c) : (s = Us(o), s.c(), s.m(t, null)) : s && (s.d(1), s = null), c[0] & /*last_progress_level*/
      32768 && l !== (l = `${/*last_progress_level*/
      o[15] * 100}%`) && _0(i, "width", l);
    },
    i: ni,
    o: ni,
    d(o) {
      o && Y(e), s && s.d(), n[31](null);
    }
  };
}
function Us(n) {
  let e, t = Nn(
    /*progress*/
    n[7]
  ), r = [];
  for (let a = 0; a < t.length; a += 1)
    r[a] = Ys(Is(n, t, a));
  return {
    c() {
      for (let a = 0; a < r.length; a += 1)
        r[a].c();
      e = gt();
    },
    l(a) {
      for (let i = 0; i < r.length; i += 1)
        r[i].l(a);
      e = gt();
    },
    m(a, i) {
      for (let l = 0; l < r.length; l += 1)
        r[l] && r[l].m(a, i);
      ee(a, e, i);
    },
    p(a, i) {
      if (i[0] & /*progress_level, progress*/
      16512) {
        t = Nn(
          /*progress*/
          a[7]
        );
        let l;
        for (l = 0; l < t.length; l += 1) {
          const s = Is(a, t, l);
          r[l] ? r[l].p(s, i) : (r[l] = Ys(s), r[l].c(), r[l].m(e.parentNode, e));
        }
        for (; l < r.length; l += 1)
          r[l].d(1);
        r.length = t.length;
      }
    },
    d(a) {
      a && Y(e), d1(r, a);
    }
  };
}
function Gs(n) {
  let e, t, r, a, i = (
    /*i*/
    n[42] !== 0 && ed()
  ), l = (
    /*p*/
    n[40].desc != null && Vs(n)
  ), s = (
    /*p*/
    n[40].desc != null && /*progress_level*/
    n[14] && /*progress_level*/
    n[14][
      /*i*/
      n[42]
    ] != null && Ws()
  ), o = (
    /*progress_level*/
    n[14] != null && Xs(n)
  );
  return {
    c() {
      i && i.c(), e = ft(), l && l.c(), t = ft(), s && s.c(), r = ft(), o && o.c(), a = gt();
    },
    l(c) {
      i && i.l(c), e = ht(c), l && l.l(c), t = ht(c), s && s.l(c), r = ht(c), o && o.l(c), a = gt();
    },
    m(c, f) {
      i && i.m(c, f), ee(c, e, f), l && l.m(c, f), ee(c, t, f), s && s.m(c, f), ee(c, r, f), o && o.m(c, f), ee(c, a, f);
    },
    p(c, f) {
      /*p*/
      c[40].desc != null ? l ? l.p(c, f) : (l = Vs(c), l.c(), l.m(t.parentNode, t)) : l && (l.d(1), l = null), /*p*/
      c[40].desc != null && /*progress_level*/
      c[14] && /*progress_level*/
      c[14][
        /*i*/
        c[42]
      ] != null ? s || (s = Ws(), s.c(), s.m(r.parentNode, r)) : s && (s.d(1), s = null), /*progress_level*/
      c[14] != null ? o ? o.p(c, f) : (o = Xs(c), o.c(), o.m(a.parentNode, a)) : o && (o.d(1), o = null);
    },
    d(c) {
      c && (Y(e), Y(t), Y(r), Y(a)), i && i.d(c), l && l.d(c), s && s.d(c), o && o.d(c);
    }
  };
}
function ed(n) {
  let e;
  return {
    c() {
      e = _e(" /");
    },
    l(t) {
      e = ke(t, " /");
    },
    m(t, r) {
      ee(t, e, r);
    },
    d(t) {
      t && Y(e);
    }
  };
}
function Vs(n) {
  let e = (
    /*p*/
    n[40].desc + ""
  ), t;
  return {
    c() {
      t = _e(e);
    },
    l(r) {
      t = ke(r, e);
    },
    m(r, a) {
      ee(r, t, a);
    },
    p(r, a) {
      a[0] & /*progress*/
      128 && e !== (e = /*p*/
      r[40].desc + "") && vt(t, e);
    },
    d(r) {
      r && Y(t);
    }
  };
}
function Ws(n) {
  let e;
  return {
    c() {
      e = _e("-");
    },
    l(t) {
      e = ke(t, "-");
    },
    m(t, r) {
      ee(t, e, r);
    },
    d(t) {
      t && Y(e);
    }
  };
}
function Xs(n) {
  let e = (100 * /*progress_level*/
  (n[14][
    /*i*/
    n[42]
  ] || 0)).toFixed(1) + "", t, r;
  return {
    c() {
      t = _e(e), r = _e("%");
    },
    l(a) {
      t = ke(a, e), r = ke(a, "%");
    },
    m(a, i) {
      ee(a, t, i), ee(a, r, i);
    },
    p(a, i) {
      i[0] & /*progress_level*/
      16384 && e !== (e = (100 * /*progress_level*/
      (a[14][
        /*i*/
        a[42]
      ] || 0)).toFixed(1) + "") && vt(t, e);
    },
    d(a) {
      a && (Y(t), Y(r));
    }
  };
}
function Ys(n) {
  let e, t = (
    /*p*/
    (n[40].desc != null || /*progress_level*/
    n[14] && /*progress_level*/
    n[14][
      /*i*/
      n[42]
    ] != null) && Gs(n)
  );
  return {
    c() {
      t && t.c(), e = gt();
    },
    l(r) {
      t && t.l(r), e = gt();
    },
    m(r, a) {
      t && t.m(r, a), ee(r, e, a);
    },
    p(r, a) {
      /*p*/
      r[40].desc != null || /*progress_level*/
      r[14] && /*progress_level*/
      r[14][
        /*i*/
        r[42]
      ] != null ? t ? t.p(r, a) : (t = Gs(r), t.c(), t.m(e.parentNode, e)) : t && (t.d(1), t = null);
    },
    d(r) {
      r && Y(e), t && t.d(r);
    }
  };
}
function js(n) {
  let e, t, r, a;
  const i = (
    /*#slots*/
    n[30]["additional-loading-text"]
  ), l = f1(
    i,
    n,
    /*$$scope*/
    n[29],
    Rs
  );
  return {
    c() {
      e = Xt("p"), t = _e(
        /*loading_text*/
        n[9]
      ), r = ft(), l && l.c(), this.h();
    },
    l(s) {
      e = Wt(s, "P", { class: !0 });
      var o = Vt(e);
      t = ke(
        o,
        /*loading_text*/
        n[9]
      ), o.forEach(Y), r = ht(s), l && l.l(s), this.h();
    },
    h() {
      Mt(e, "class", "loading svelte-17v219f");
    },
    m(s, o) {
      ee(s, e, o), z0(e, t), ee(s, r, o), l && l.m(s, o), a = !0;
    },
    p(s, o) {
      (!a || o[0] & /*loading_text*/
      512) && vt(
        t,
        /*loading_text*/
        s[9]
      ), l && l.p && (!a || o[0] & /*$$scope*/
      536870912) && b1(
        l,
        i,
        s,
        /*$$scope*/
        s[29],
        a ? g1(
          i,
          /*$$scope*/
          s[29],
          o,
          Vm
        ) : p1(
          /*$$scope*/
          s[29]
        ),
        Rs
      );
    },
    i(s) {
      a || (Tt(l, s), a = !0);
    },
    o(s) {
      Yt(l, s), a = !1;
    },
    d(s) {
      s && (Y(e), Y(r)), l && l.d(s);
    }
  };
}
function td(n) {
  let e, t, r, a, i;
  const l = [Xm, Wm], s = [];
  function o(c, f) {
    return (
      /*status*/
      c[4] === "pending" ? 0 : (
        /*status*/
        c[4] === "error" ? 1 : -1
      )
    );
  }
  return ~(t = o(n)) && (r = s[t] = l[t](n)), {
    c() {
      e = Xt("div"), r && r.c(), this.h();
    },
    l(c) {
      e = Wt(c, "DIV", { class: !0 });
      var f = Vt(e);
      r && r.l(f), f.forEach(Y), this.h();
    },
    h() {
      Mt(e, "class", a = "wrap " + /*variant*/
      n[8] + " " + /*show_progress*/
      n[6] + " svelte-17v219f"), ut(e, "hide", !/*status*/
      n[4] || /*status*/
      n[4] === "complete" || /*show_progress*/
      n[6] === "hidden" || /*status*/
      n[4] == "streaming"), ut(
        e,
        "translucent",
        /*variant*/
        n[8] === "center" && /*status*/
        (n[4] === "pending" || /*status*/
        n[4] === "error") || /*translucent*/
        n[11] || /*show_progress*/
        n[6] === "minimal"
      ), ut(
        e,
        "generating",
        /*status*/
        n[4] === "generating" && /*show_progress*/
        n[6] === "full"
      ), ut(
        e,
        "border",
        /*border*/
        n[12]
      ), _0(
        e,
        "position",
        /*absolute*/
        n[10] ? "absolute" : "static"
      ), _0(
        e,
        "padding",
        /*absolute*/
        n[10] ? "0" : "var(--size-8) 0"
      );
    },
    m(c, f) {
      ee(c, e, f), ~t && s[t].m(e, null), n[33](e), i = !0;
    },
    p(c, f) {
      let d = t;
      t = o(c), t === d ? ~t && s[t].p(c, f) : (r && (ri(), Yt(s[d], 1, 1, () => {
        s[d] = null;
      }), ti()), ~t ? (r = s[t], r ? r.p(c, f) : (r = s[t] = l[t](c), r.c()), Tt(r, 1), r.m(e, null)) : r = null), (!i || f[0] & /*variant, show_progress*/
      320 && a !== (a = "wrap " + /*variant*/
      c[8] + " " + /*show_progress*/
      c[6] + " svelte-17v219f")) && Mt(e, "class", a), (!i || f[0] & /*variant, show_progress, status, show_progress*/
      336) && ut(e, "hide", !/*status*/
      c[4] || /*status*/
      c[4] === "complete" || /*show_progress*/
      c[6] === "hidden" || /*status*/
      c[4] == "streaming"), (!i || f[0] & /*variant, show_progress, variant, status, translucent, show_progress*/
      2384) && ut(
        e,
        "translucent",
        /*variant*/
        c[8] === "center" && /*status*/
        (c[4] === "pending" || /*status*/
        c[4] === "error") || /*translucent*/
        c[11] || /*show_progress*/
        c[6] === "minimal"
      ), (!i || f[0] & /*variant, show_progress, status, show_progress*/
      336) && ut(
        e,
        "generating",
        /*status*/
        c[4] === "generating" && /*show_progress*/
        c[6] === "full"
      ), (!i || f[0] & /*variant, show_progress, border*/
      4416) && ut(
        e,
        "border",
        /*border*/
        c[12]
      ), f[0] & /*absolute*/
      1024 && _0(
        e,
        "position",
        /*absolute*/
        c[10] ? "absolute" : "static"
      ), f[0] & /*absolute*/
      1024 && _0(
        e,
        "padding",
        /*absolute*/
        c[10] ? "0" : "var(--size-8) 0"
      );
    },
    i(c) {
      i || (Tt(r), i = !0);
    },
    o(c) {
      Yt(r), i = !1;
    },
    d(c) {
      c && Y(e), ~t && s[t].d(), n[33](null);
    }
  };
}
let cn = [], Ca = !1;
const rd = typeof window < "u", y1 = rd ? window.requestAnimationFrame : (n) => {
};
async function nd(n, e = !0) {
  if (!(window.__gradio_mode__ === "website" || window.__gradio_mode__ !== "app" && e !== !0)) {
    if (cn.push(n), !Ca) Ca = !0;
    else return;
    await Pm(), y1(() => {
      let t = [0, 0];
      for (let r = 0; r < cn.length; r++) {
        const i = cn[r].getBoundingClientRect();
        (r === 0 || i.top + window.scrollY <= t[0]) && (t[0] = i.top + window.scrollY, t[1] = r);
      }
      window.scrollTo({ top: t[0] - 20, behavior: "smooth" }), Ca = !1, cn = [];
    });
  }
}
function ad(n, e, t) {
  let r, { $$slots: a = {}, $$scope: i } = e;
  const l = Um();
  let { i18n: s } = e, { eta: o = null } = e, { queue_position: c } = e, { queue_size: f } = e, { status: d } = e, { scroll_to_output: g = !1 } = e, { timer: v = !0 } = e, { show_progress: y = "full" } = e, { message: k = null } = e, { progress: E = null } = e, { variant: A = "default" } = e, { loading_text: D = "Loading..." } = e, { absolute: b = !0 } = e, { translucent: F = !1 } = e, { border: T = !1 } = e, { autoscroll: M } = e, z, O = !1, R = 0, B = 0, X = null, $ = null, Te = 0, se = null, U, le = null, Se = !0;
  const ue = () => {
    t(0, o = t(27, X = t(19, re = null))), t(25, R = performance.now()), t(26, B = 0), O = !0, Ce();
  };
  function Ce() {
    y1(() => {
      t(26, B = (performance.now() - R) / 1e3), O && Ce();
    });
  }
  function xe() {
    t(26, B = 0), t(0, o = t(27, X = t(19, re = null))), O && (O = !1);
  }
  Hm(() => {
    O && xe();
  });
  let re = null;
  function oe(H) {
    Bs[H ? "unshift" : "push"](() => {
      le = H, t(16, le), t(7, E), t(14, se), t(15, U);
    });
  }
  const fe = () => {
    l("clear_status");
  };
  function Ne(H) {
    Bs[H ? "unshift" : "push"](() => {
      z = H, t(13, z);
    });
  }
  return n.$$set = (H) => {
    "i18n" in H && t(1, s = H.i18n), "eta" in H && t(0, o = H.eta), "queue_position" in H && t(2, c = H.queue_position), "queue_size" in H && t(3, f = H.queue_size), "status" in H && t(4, d = H.status), "scroll_to_output" in H && t(22, g = H.scroll_to_output), "timer" in H && t(5, v = H.timer), "show_progress" in H && t(6, y = H.show_progress), "message" in H && t(23, k = H.message), "progress" in H && t(7, E = H.progress), "variant" in H && t(8, A = H.variant), "loading_text" in H && t(9, D = H.loading_text), "absolute" in H && t(10, b = H.absolute), "translucent" in H && t(11, F = H.translucent), "border" in H && t(12, T = H.border), "autoscroll" in H && t(24, M = H.autoscroll), "$$scope" in H && t(29, i = H.$$scope);
  }, n.$$.update = () => {
    n.$$.dirty[0] & /*eta, old_eta, timer_start, eta_from_start*/
    436207617 && (o === null && t(0, o = X), o != null && X !== o && (t(28, $ = (performance.now() - R) / 1e3 + o), t(19, re = $.toFixed(1)), t(27, X = o))), n.$$.dirty[0] & /*eta_from_start, timer_diff*/
    335544320 && t(17, Te = $ === null || $ <= 0 || !B ? null : Math.min(B / $, 1)), n.$$.dirty[0] & /*progress*/
    128 && E != null && t(18, Se = !1), n.$$.dirty[0] & /*progress, progress_level, progress_bar, last_progress_level*/
    114816 && (E != null ? t(14, se = E.map((H) => {
      if (H.index != null && H.length != null)
        return H.index / H.length;
      if (H.progress != null)
        return H.progress;
    })) : t(14, se = null), se ? (t(15, U = se[se.length - 1]), le && (U === 0 ? t(16, le.style.transition = "0", le) : t(16, le.style.transition = "150ms", le))) : t(15, U = void 0)), n.$$.dirty[0] & /*status*/
    16 && (d === "pending" ? ue() : xe()), n.$$.dirty[0] & /*el, scroll_to_output, status, autoscroll*/
    20979728 && z && g && (d === "pending" || d === "complete") && nd(z, M), n.$$.dirty[0] & /*status, message*/
    8388624, n.$$.dirty[0] & /*timer_diff*/
    67108864 && t(20, r = B.toFixed(1));
  }, [
    o,
    s,
    c,
    f,
    d,
    v,
    y,
    E,
    A,
    D,
    b,
    F,
    T,
    z,
    se,
    U,
    le,
    Te,
    Se,
    re,
    r,
    l,
    g,
    k,
    M,
    R,
    B,
    X,
    $,
    i,
    a,
    oe,
    fe,
    Ne
  ];
}
class id extends Lm {
  constructor(e) {
    super(), Om(
      this,
      e,
      ad,
      td,
      qm,
      {
        i18n: 1,
        eta: 0,
        queue_position: 2,
        queue_size: 3,
        status: 4,
        scroll_to_output: 22,
        timer: 5,
        show_progress: 6,
        message: 23,
        progress: 7,
        variant: 8,
        loading_text: 9,
        absolute: 10,
        translucent: 11,
        border: 12,
        autoscroll: 24
      },
      null,
      [-1, -1]
    );
  }
}
/*! @license DOMPurify 3.2.3 | (c) Cure53 and other contributors | Released under the Apache license 2.0 and Mozilla Public License 2.0 | github.com/cure53/DOMPurify/blob/3.2.3/LICENSE */
const {
  entries: w1,
  setPrototypeOf: Zs,
  isFrozen: ld,
  getPrototypeOf: sd,
  getOwnPropertyDescriptor: od
} = Object;
let {
  freeze: We,
  seal: bt,
  create: k1
} = Object, {
  apply: ai,
  construct: ii
} = typeof Reflect < "u" && Reflect;
We || (We = function(e) {
  return e;
});
bt || (bt = function(e) {
  return e;
});
ai || (ai = function(e, t, r) {
  return e.apply(t, r);
});
ii || (ii = function(e, t) {
  return new e(...t);
});
const hn = lt(Array.prototype.forEach), Ks = lt(Array.prototype.pop), mr = lt(Array.prototype.push), kn = lt(String.prototype.toLowerCase), Ma = lt(String.prototype.toString), Qs = lt(String.prototype.match), dr = lt(String.prototype.replace), ud = lt(String.prototype.indexOf), cd = lt(String.prototype.trim), Et = lt(Object.prototype.hasOwnProperty), Ue = lt(RegExp.prototype.test), pr = hd(TypeError);
function lt(n) {
  return function(e) {
    for (var t = arguments.length, r = new Array(t > 1 ? t - 1 : 0), a = 1; a < t; a++)
      r[a - 1] = arguments[a];
    return ai(n, e, r);
  };
}
function hd(n) {
  return function() {
    for (var e = arguments.length, t = new Array(e), r = 0; r < e; r++)
      t[r] = arguments[r];
    return ii(n, t);
  };
}
function ne(n, e) {
  let t = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : kn;
  Zs && Zs(n, null);
  let r = e.length;
  for (; r--; ) {
    let a = e[r];
    if (typeof a == "string") {
      const i = t(a);
      i !== a && (ld(e) || (e[r] = i), a = i);
    }
    n[a] = !0;
  }
  return n;
}
function fd(n) {
  for (let e = 0; e < n.length; e++)
    Et(n, e) || (n[e] = null);
  return n;
}
function M0(n) {
  const e = k1(null);
  for (const [t, r] of w1(n))
    Et(n, t) && (Array.isArray(r) ? e[t] = fd(r) : r && typeof r == "object" && r.constructor === Object ? e[t] = M0(r) : e[t] = r);
  return e;
}
function gr(n, e) {
  for (; n !== null; ) {
    const r = od(n, e);
    if (r) {
      if (r.get)
        return lt(r.get);
      if (typeof r.value == "function")
        return lt(r.value);
    }
    n = sd(n);
  }
  function t() {
    return null;
  }
  return t;
}
const Js = We(["a", "abbr", "acronym", "address", "area", "article", "aside", "audio", "b", "bdi", "bdo", "big", "blink", "blockquote", "body", "br", "button", "canvas", "caption", "center", "cite", "code", "col", "colgroup", "content", "data", "datalist", "dd", "decorator", "del", "details", "dfn", "dialog", "dir", "div", "dl", "dt", "element", "em", "fieldset", "figcaption", "figure", "font", "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header", "hgroup", "hr", "html", "i", "img", "input", "ins", "kbd", "label", "legend", "li", "main", "map", "mark", "marquee", "menu", "menuitem", "meter", "nav", "nobr", "ol", "optgroup", "option", "output", "p", "picture", "pre", "progress", "q", "rp", "rt", "ruby", "s", "samp", "section", "select", "shadow", "small", "source", "spacer", "span", "strike", "strong", "style", "sub", "summary", "sup", "table", "tbody", "td", "template", "textarea", "tfoot", "th", "thead", "time", "tr", "track", "tt", "u", "ul", "var", "video", "wbr"]), za = We(["svg", "a", "altglyph", "altglyphdef", "altglyphitem", "animatecolor", "animatemotion", "animatetransform", "circle", "clippath", "defs", "desc", "ellipse", "filter", "font", "g", "glyph", "glyphref", "hkern", "image", "line", "lineargradient", "marker", "mask", "metadata", "mpath", "path", "pattern", "polygon", "polyline", "radialgradient", "rect", "stop", "style", "switch", "symbol", "text", "textpath", "title", "tref", "tspan", "view", "vkern"]), Ba = We(["feBlend", "feColorMatrix", "feComponentTransfer", "feComposite", "feConvolveMatrix", "feDiffuseLighting", "feDisplacementMap", "feDistantLight", "feDropShadow", "feFlood", "feFuncA", "feFuncB", "feFuncG", "feFuncR", "feGaussianBlur", "feImage", "feMerge", "feMergeNode", "feMorphology", "feOffset", "fePointLight", "feSpecularLighting", "feSpotLight", "feTile", "feTurbulence"]), md = We(["animate", "color-profile", "cursor", "discard", "font-face", "font-face-format", "font-face-name", "font-face-src", "font-face-uri", "foreignobject", "hatch", "hatchpath", "mesh", "meshgradient", "meshpatch", "meshrow", "missing-glyph", "script", "set", "solidcolor", "unknown", "use"]), Na = We(["math", "menclose", "merror", "mfenced", "mfrac", "mglyph", "mi", "mlabeledtr", "mmultiscripts", "mn", "mo", "mover", "mpadded", "mphantom", "mroot", "mrow", "ms", "mspace", "msqrt", "mstyle", "msub", "msup", "msubsup", "mtable", "mtd", "mtext", "mtr", "munder", "munderover", "mprescripts"]), dd = We(["maction", "maligngroup", "malignmark", "mlongdiv", "mscarries", "mscarry", "msgroup", "mstack", "msline", "msrow", "semantics", "annotation", "annotation-xml", "mprescripts", "none"]), $s = We(["#text"]), eo = We(["accept", "action", "align", "alt", "autocapitalize", "autocomplete", "autopictureinpicture", "autoplay", "background", "bgcolor", "border", "capture", "cellpadding", "cellspacing", "checked", "cite", "class", "clear", "color", "cols", "colspan", "controls", "controlslist", "coords", "crossorigin", "datetime", "decoding", "default", "dir", "disabled", "disablepictureinpicture", "disableremoteplayback", "download", "draggable", "enctype", "enterkeyhint", "face", "for", "headers", "height", "hidden", "high", "href", "hreflang", "id", "inputmode", "integrity", "ismap", "kind", "label", "lang", "list", "loading", "loop", "low", "max", "maxlength", "media", "method", "min", "minlength", "multiple", "muted", "name", "nonce", "noshade", "novalidate", "nowrap", "open", "optimum", "pattern", "placeholder", "playsinline", "popover", "popovertarget", "popovertargetaction", "poster", "preload", "pubdate", "radiogroup", "readonly", "rel", "required", "rev", "reversed", "role", "rows", "rowspan", "spellcheck", "scope", "selected", "shape", "size", "sizes", "span", "srclang", "start", "src", "srcset", "step", "style", "summary", "tabindex", "title", "translate", "type", "usemap", "valign", "value", "width", "wrap", "xmlns", "slot"]), Ra = We(["accent-height", "accumulate", "additive", "alignment-baseline", "amplitude", "ascent", "attributename", "attributetype", "azimuth", "basefrequency", "baseline-shift", "begin", "bias", "by", "class", "clip", "clippathunits", "clip-path", "clip-rule", "color", "color-interpolation", "color-interpolation-filters", "color-profile", "color-rendering", "cx", "cy", "d", "dx", "dy", "diffuseconstant", "direction", "display", "divisor", "dur", "edgemode", "elevation", "end", "exponent", "fill", "fill-opacity", "fill-rule", "filter", "filterunits", "flood-color", "flood-opacity", "font-family", "font-size", "font-size-adjust", "font-stretch", "font-style", "font-variant", "font-weight", "fx", "fy", "g1", "g2", "glyph-name", "glyphref", "gradientunits", "gradienttransform", "height", "href", "id", "image-rendering", "in", "in2", "intercept", "k", "k1", "k2", "k3", "k4", "kerning", "keypoints", "keysplines", "keytimes", "lang", "lengthadjust", "letter-spacing", "kernelmatrix", "kernelunitlength", "lighting-color", "local", "marker-end", "marker-mid", "marker-start", "markerheight", "markerunits", "markerwidth", "maskcontentunits", "maskunits", "max", "mask", "media", "method", "mode", "min", "name", "numoctaves", "offset", "operator", "opacity", "order", "orient", "orientation", "origin", "overflow", "paint-order", "path", "pathlength", "patterncontentunits", "patterntransform", "patternunits", "points", "preservealpha", "preserveaspectratio", "primitiveunits", "r", "rx", "ry", "radius", "refx", "refy", "repeatcount", "repeatdur", "restart", "result", "rotate", "scale", "seed", "shape-rendering", "slope", "specularconstant", "specularexponent", "spreadmethod", "startoffset", "stddeviation", "stitchtiles", "stop-color", "stop-opacity", "stroke-dasharray", "stroke-dashoffset", "stroke-linecap", "stroke-linejoin", "stroke-miterlimit", "stroke-opacity", "stroke", "stroke-width", "style", "surfacescale", "systemlanguage", "tabindex", "tablevalues", "targetx", "targety", "transform", "transform-origin", "text-anchor", "text-decoration", "text-rendering", "textlength", "type", "u1", "u2", "unicode", "values", "viewbox", "visibility", "version", "vert-adv-y", "vert-origin-x", "vert-origin-y", "width", "word-spacing", "wrap", "writing-mode", "xchannelselector", "ychannelselector", "x", "x1", "x2", "xmlns", "y", "y1", "y2", "z", "zoomandpan"]), to = We(["accent", "accentunder", "align", "bevelled", "close", "columnsalign", "columnlines", "columnspan", "denomalign", "depth", "dir", "display", "displaystyle", "encoding", "fence", "frame", "height", "href", "id", "largeop", "length", "linethickness", "lspace", "lquote", "mathbackground", "mathcolor", "mathsize", "mathvariant", "maxsize", "minsize", "movablelimits", "notation", "numalign", "open", "rowalign", "rowlines", "rowspacing", "rowspan", "rspace", "rquote", "scriptlevel", "scriptminsize", "scriptsizemultiplier", "selection", "separator", "separators", "stretchy", "subscriptshift", "supscriptshift", "symmetric", "voffset", "width", "xmlns"]), fn = We(["xlink:href", "xml:id", "xlink:title", "xml:space", "xmlns:xlink"]), pd = bt(/\{\{[\w\W]*|[\w\W]*\}\}/gm), gd = bt(/<%[\w\W]*|[\w\W]*%>/gm), vd = bt(/\$\{[\w\W]*}/gm), bd = bt(/^data-[\-\w.\u00B7-\uFFFF]+$/), yd = bt(/^aria-[\-\w]+$/), _1 = bt(
  /^(?:(?:(?:f|ht)tps?|mailto|tel|callto|sms|cid|xmpp):|[^a-z]|[a-z+.\-]+(?:[^a-z+.\-:]|$))/i
  // eslint-disable-line no-useless-escape
), wd = bt(/^(?:\w+script|data):/i), kd = bt(
  /[\u0000-\u0020\u00A0\u1680\u180E\u2000-\u2029\u205F\u3000]/g
  // eslint-disable-line no-control-regex
), D1 = bt(/^html$/i), _d = bt(/^[a-z][.\w]*(-[.\w]+)+$/i);
var ro = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  ARIA_ATTR: yd,
  ATTR_WHITESPACE: kd,
  CUSTOM_ELEMENT: _d,
  DATA_ATTR: bd,
  DOCTYPE_NAME: D1,
  ERB_EXPR: gd,
  IS_ALLOWED_URI: _1,
  IS_SCRIPT_OR_DATA: wd,
  MUSTACHE_EXPR: pd,
  TMPLIT_EXPR: vd
});
const vr = {
  element: 1,
  attribute: 2,
  text: 3,
  cdataSection: 4,
  entityReference: 5,
  // Deprecated
  entityNode: 6,
  // Deprecated
  progressingInstruction: 7,
  comment: 8,
  document: 9,
  documentType: 10,
  documentFragment: 11,
  notation: 12
  // Deprecated
}, Dd = function() {
  return typeof window > "u" ? null : window;
}, xd = function(e, t) {
  if (typeof e != "object" || typeof e.createPolicy != "function")
    return null;
  let r = null;
  const a = "data-tt-policy-suffix";
  t && t.hasAttribute(a) && (r = t.getAttribute(a));
  const i = "dompurify" + (r ? "#" + r : "");
  try {
    return e.createPolicy(i, {
      createHTML(l) {
        return l;
      },
      createScriptURL(l) {
        return l;
      }
    });
  } catch {
    return console.warn("TrustedTypes policy " + i + " could not be created."), null;
  }
}, no = function() {
  return {
    afterSanitizeAttributes: [],
    afterSanitizeElements: [],
    afterSanitizeShadowDOM: [],
    beforeSanitizeAttributes: [],
    beforeSanitizeElements: [],
    beforeSanitizeShadowDOM: [],
    uponSanitizeAttribute: [],
    uponSanitizeElement: [],
    uponSanitizeShadowNode: []
  };
};
function x1() {
  let n = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : Dd();
  const e = (Z) => x1(Z);
  if (e.version = "3.2.3", e.removed = [], !n || !n.document || n.document.nodeType !== vr.document)
    return e.isSupported = !1, e;
  let {
    document: t
  } = n;
  const r = t, a = r.currentScript, {
    DocumentFragment: i,
    HTMLTemplateElement: l,
    Node: s,
    Element: o,
    NodeFilter: c,
    NamedNodeMap: f = n.NamedNodeMap || n.MozNamedAttrMap,
    HTMLFormElement: d,
    DOMParser: g,
    trustedTypes: v
  } = n, y = o.prototype, k = gr(y, "cloneNode"), E = gr(y, "remove"), A = gr(y, "nextSibling"), D = gr(y, "childNodes"), b = gr(y, "parentNode");
  if (typeof l == "function") {
    const Z = t.createElement("template");
    Z.content && Z.content.ownerDocument && (t = Z.content.ownerDocument);
  }
  let F, T = "";
  const {
    implementation: M,
    createNodeIterator: z,
    createDocumentFragment: O,
    getElementsByTagName: R
  } = t, {
    importNode: B
  } = r;
  let X = no();
  e.isSupported = typeof w1 == "function" && typeof b == "function" && M && M.createHTMLDocument !== void 0;
  const {
    MUSTACHE_EXPR: $,
    ERB_EXPR: Te,
    TMPLIT_EXPR: se,
    DATA_ATTR: U,
    ARIA_ATTR: le,
    IS_SCRIPT_OR_DATA: Se,
    ATTR_WHITESPACE: ue,
    CUSTOM_ELEMENT: Ce
  } = ro;
  let {
    IS_ALLOWED_URI: xe
  } = ro, re = null;
  const oe = ne({}, [...Js, ...za, ...Ba, ...Na, ...$s]);
  let fe = null;
  const Ne = ne({}, [...eo, ...Ra, ...to, ...fn]);
  let H = Object.seal(k1(null, {
    tagNameCheck: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: null
    },
    attributeNameCheck: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: null
    },
    allowCustomizedBuiltInElements: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: !1
    }
  })), et = null, qe = null, tt = !0, yt = !0, wt = !1, Qt = !0, Bt = !1, Jt = !0, kt = !1, H0 = !1, U0 = !1, Nt = !1, $t = !1, e0 = !1, Hi = !0, Ui = !1;
  const F1 = "user-content-";
  let Yn = !0, or = !1, G0 = {}, V0 = null;
  const Gi = ne({}, ["annotation-xml", "audio", "colgroup", "desc", "foreignobject", "head", "iframe", "math", "mi", "mn", "mo", "ms", "mtext", "noembed", "noframes", "noscript", "plaintext", "script", "style", "svg", "template", "thead", "title", "video", "xmp"]);
  let Vi = null;
  const Wi = ne({}, ["audio", "video", "img", "source", "image", "track"]);
  let jn = null;
  const Xi = ne({}, ["alt", "class", "for", "id", "label", "name", "pattern", "placeholder", "role", "summary", "title", "value", "style", "xmlns"]), Ir = "http://www.w3.org/1998/Math/MathML", Lr = "http://www.w3.org/2000/svg", t0 = "http://www.w3.org/1999/xhtml";
  let W0 = t0, Zn = !1, Kn = null;
  const T1 = ne({}, [Ir, Lr, t0], Ma);
  let Or = ne({}, ["mi", "mo", "mn", "ms", "mtext"]), qr = ne({}, ["annotation-xml"]);
  const C1 = ne({}, ["title", "style", "font", "a", "script"]);
  let ur = null;
  const M1 = ["application/xhtml+xml", "text/html"], z1 = "text/html";
  let ze = null, X0 = null;
  const B1 = t.createElement("form"), Yi = function(S) {
    return S instanceof RegExp || S instanceof Function;
  }, Qn = function() {
    let S = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    if (!(X0 && X0 === S)) {
      if ((!S || typeof S != "object") && (S = {}), S = M0(S), ur = // eslint-disable-next-line unicorn/prefer-includes
      M1.indexOf(S.PARSER_MEDIA_TYPE) === -1 ? z1 : S.PARSER_MEDIA_TYPE, ze = ur === "application/xhtml+xml" ? Ma : kn, re = Et(S, "ALLOWED_TAGS") ? ne({}, S.ALLOWED_TAGS, ze) : oe, fe = Et(S, "ALLOWED_ATTR") ? ne({}, S.ALLOWED_ATTR, ze) : Ne, Kn = Et(S, "ALLOWED_NAMESPACES") ? ne({}, S.ALLOWED_NAMESPACES, Ma) : T1, jn = Et(S, "ADD_URI_SAFE_ATTR") ? ne(M0(Xi), S.ADD_URI_SAFE_ATTR, ze) : Xi, Vi = Et(S, "ADD_DATA_URI_TAGS") ? ne(M0(Wi), S.ADD_DATA_URI_TAGS, ze) : Wi, V0 = Et(S, "FORBID_CONTENTS") ? ne({}, S.FORBID_CONTENTS, ze) : Gi, et = Et(S, "FORBID_TAGS") ? ne({}, S.FORBID_TAGS, ze) : {}, qe = Et(S, "FORBID_ATTR") ? ne({}, S.FORBID_ATTR, ze) : {}, G0 = Et(S, "USE_PROFILES") ? S.USE_PROFILES : !1, tt = S.ALLOW_ARIA_ATTR !== !1, yt = S.ALLOW_DATA_ATTR !== !1, wt = S.ALLOW_UNKNOWN_PROTOCOLS || !1, Qt = S.ALLOW_SELF_CLOSE_IN_ATTR !== !1, Bt = S.SAFE_FOR_TEMPLATES || !1, Jt = S.SAFE_FOR_XML !== !1, kt = S.WHOLE_DOCUMENT || !1, Nt = S.RETURN_DOM || !1, $t = S.RETURN_DOM_FRAGMENT || !1, e0 = S.RETURN_TRUSTED_TYPE || !1, U0 = S.FORCE_BODY || !1, Hi = S.SANITIZE_DOM !== !1, Ui = S.SANITIZE_NAMED_PROPS || !1, Yn = S.KEEP_CONTENT !== !1, or = S.IN_PLACE || !1, xe = S.ALLOWED_URI_REGEXP || _1, W0 = S.NAMESPACE || t0, Or = S.MATHML_TEXT_INTEGRATION_POINTS || Or, qr = S.HTML_INTEGRATION_POINTS || qr, H = S.CUSTOM_ELEMENT_HANDLING || {}, S.CUSTOM_ELEMENT_HANDLING && Yi(S.CUSTOM_ELEMENT_HANDLING.tagNameCheck) && (H.tagNameCheck = S.CUSTOM_ELEMENT_HANDLING.tagNameCheck), S.CUSTOM_ELEMENT_HANDLING && Yi(S.CUSTOM_ELEMENT_HANDLING.attributeNameCheck) && (H.attributeNameCheck = S.CUSTOM_ELEMENT_HANDLING.attributeNameCheck), S.CUSTOM_ELEMENT_HANDLING && typeof S.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements == "boolean" && (H.allowCustomizedBuiltInElements = S.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements), Bt && (yt = !1), $t && (Nt = !0), G0 && (re = ne({}, $s), fe = [], G0.html === !0 && (ne(re, Js), ne(fe, eo)), G0.svg === !0 && (ne(re, za), ne(fe, Ra), ne(fe, fn)), G0.svgFilters === !0 && (ne(re, Ba), ne(fe, Ra), ne(fe, fn)), G0.mathMl === !0 && (ne(re, Na), ne(fe, to), ne(fe, fn))), S.ADD_TAGS && (re === oe && (re = M0(re)), ne(re, S.ADD_TAGS, ze)), S.ADD_ATTR && (fe === Ne && (fe = M0(fe)), ne(fe, S.ADD_ATTR, ze)), S.ADD_URI_SAFE_ATTR && ne(jn, S.ADD_URI_SAFE_ATTR, ze), S.FORBID_CONTENTS && (V0 === Gi && (V0 = M0(V0)), ne(V0, S.FORBID_CONTENTS, ze)), Yn && (re["#text"] = !0), kt && ne(re, ["html", "head", "body"]), re.table && (ne(re, ["tbody"]), delete et.tbody), S.TRUSTED_TYPES_POLICY) {
        if (typeof S.TRUSTED_TYPES_POLICY.createHTML != "function")
          throw pr('TRUSTED_TYPES_POLICY configuration option must provide a "createHTML" hook.');
        if (typeof S.TRUSTED_TYPES_POLICY.createScriptURL != "function")
          throw pr('TRUSTED_TYPES_POLICY configuration option must provide a "createScriptURL" hook.');
        F = S.TRUSTED_TYPES_POLICY, T = F.createHTML("");
      } else
        F === void 0 && (F = xd(v, a)), F !== null && typeof T == "string" && (T = F.createHTML(""));
      We && We(S), X0 = S;
    }
  }, ji = ne({}, [...za, ...Ba, ...md]), Zi = ne({}, [...Na, ...dd]), N1 = function(S) {
    let q = b(S);
    (!q || !q.tagName) && (q = {
      namespaceURI: W0,
      tagName: "template"
    });
    const W = kn(S.tagName), ge = kn(q.tagName);
    return Kn[S.namespaceURI] ? S.namespaceURI === Lr ? q.namespaceURI === t0 ? W === "svg" : q.namespaceURI === Ir ? W === "svg" && (ge === "annotation-xml" || Or[ge]) : !!ji[W] : S.namespaceURI === Ir ? q.namespaceURI === t0 ? W === "math" : q.namespaceURI === Lr ? W === "math" && qr[ge] : !!Zi[W] : S.namespaceURI === t0 ? q.namespaceURI === Lr && !qr[ge] || q.namespaceURI === Ir && !Or[ge] ? !1 : !Zi[W] && (C1[W] || !ji[W]) : !!(ur === "application/xhtml+xml" && Kn[S.namespaceURI]) : !1;
  }, Rt = function(S) {
    mr(e.removed, {
      element: S
    });
    try {
      b(S).removeChild(S);
    } catch {
      E(S);
    }
  }, Pr = function(S, q) {
    try {
      mr(e.removed, {
        attribute: q.getAttributeNode(S),
        from: q
      });
    } catch {
      mr(e.removed, {
        attribute: null,
        from: q
      });
    }
    if (q.removeAttribute(S), S === "is")
      if (Nt || $t)
        try {
          Rt(q);
        } catch {
        }
      else
        try {
          q.setAttribute(S, "");
        } catch {
        }
  }, Ki = function(S) {
    let q = null, W = null;
    if (U0)
      S = "<remove></remove>" + S;
    else {
      const Re = Qs(S, /^[\r\n\t ]+/);
      W = Re && Re[0];
    }
    ur === "application/xhtml+xml" && W0 === t0 && (S = '<html xmlns="http://www.w3.org/1999/xhtml"><head></head><body>' + S + "</body></html>");
    const ge = F ? F.createHTML(S) : S;
    if (W0 === t0)
      try {
        q = new g().parseFromString(ge, ur);
      } catch {
      }
    if (!q || !q.documentElement) {
      q = M.createDocument(W0, "template", null);
      try {
        q.documentElement.innerHTML = Zn ? T : ge;
      } catch {
      }
    }
    const Le = q.body || q.documentElement;
    return S && W && Le.insertBefore(t.createTextNode(W), Le.childNodes[0] || null), W0 === t0 ? R.call(q, kt ? "html" : "body")[0] : kt ? q.documentElement : Le;
  }, Qi = function(S) {
    return z.call(
      S.ownerDocument || S,
      S,
      // eslint-disable-next-line no-bitwise
      c.SHOW_ELEMENT | c.SHOW_COMMENT | c.SHOW_TEXT | c.SHOW_PROCESSING_INSTRUCTION | c.SHOW_CDATA_SECTION,
      null
    );
  }, Jn = function(S) {
    return S instanceof d && (typeof S.nodeName != "string" || typeof S.textContent != "string" || typeof S.removeChild != "function" || !(S.attributes instanceof f) || typeof S.removeAttribute != "function" || typeof S.setAttribute != "function" || typeof S.namespaceURI != "string" || typeof S.insertBefore != "function" || typeof S.hasChildNodes != "function");
  }, Ji = function(S) {
    return typeof s == "function" && S instanceof s;
  };
  function r0(Z, S, q) {
    hn(Z, (W) => {
      W.call(e, S, q, X0);
    });
  }
  const $i = function(S) {
    let q = null;
    if (r0(X.beforeSanitizeElements, S, null), Jn(S))
      return Rt(S), !0;
    const W = ze(S.nodeName);
    if (r0(X.uponSanitizeElement, S, {
      tagName: W,
      allowedTags: re
    }), S.hasChildNodes() && !Ji(S.firstElementChild) && Ue(/<[/\w]/g, S.innerHTML) && Ue(/<[/\w]/g, S.textContent) || S.nodeType === vr.progressingInstruction || Jt && S.nodeType === vr.comment && Ue(/<[/\w]/g, S.data))
      return Rt(S), !0;
    if (!re[W] || et[W]) {
      if (!et[W] && tl(W) && (H.tagNameCheck instanceof RegExp && Ue(H.tagNameCheck, W) || H.tagNameCheck instanceof Function && H.tagNameCheck(W)))
        return !1;
      if (Yn && !V0[W]) {
        const ge = b(S) || S.parentNode, Le = D(S) || S.childNodes;
        if (Le && ge) {
          const Re = Le.length;
          for (let Ye = Re - 1; Ye >= 0; --Ye) {
            const It = k(Le[Ye], !0);
            It.__removalCount = (S.__removalCount || 0) + 1, ge.insertBefore(It, A(S));
          }
        }
      }
      return Rt(S), !0;
    }
    return S instanceof o && !N1(S) || (W === "noscript" || W === "noembed" || W === "noframes") && Ue(/<\/no(script|embed|frames)/i, S.innerHTML) ? (Rt(S), !0) : (Bt && S.nodeType === vr.text && (q = S.textContent, hn([$, Te, se], (ge) => {
      q = dr(q, ge, " ");
    }), S.textContent !== q && (mr(e.removed, {
      element: S.cloneNode()
    }), S.textContent = q)), r0(X.afterSanitizeElements, S, null), !1);
  }, el = function(S, q, W) {
    if (Hi && (q === "id" || q === "name") && (W in t || W in B1))
      return !1;
    if (!(yt && !qe[q] && Ue(U, q))) {
      if (!(tt && Ue(le, q))) {
        if (!fe[q] || qe[q]) {
          if (
            // First condition does a very basic check if a) it's basically a valid custom element tagname AND
            // b) if the tagName passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.tagNameCheck
            // and c) if the attribute name passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.attributeNameCheck
            !(tl(S) && (H.tagNameCheck instanceof RegExp && Ue(H.tagNameCheck, S) || H.tagNameCheck instanceof Function && H.tagNameCheck(S)) && (H.attributeNameCheck instanceof RegExp && Ue(H.attributeNameCheck, q) || H.attributeNameCheck instanceof Function && H.attributeNameCheck(q)) || // Alternative, second condition checks if it's an `is`-attribute, AND
            // the value passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.tagNameCheck
            q === "is" && H.allowCustomizedBuiltInElements && (H.tagNameCheck instanceof RegExp && Ue(H.tagNameCheck, W) || H.tagNameCheck instanceof Function && H.tagNameCheck(W)))
          ) return !1;
        } else if (!jn[q]) {
          if (!Ue(xe, dr(W, ue, ""))) {
            if (!((q === "src" || q === "xlink:href" || q === "href") && S !== "script" && ud(W, "data:") === 0 && Vi[S])) {
              if (!(wt && !Ue(Se, dr(W, ue, "")))) {
                if (W)
                  return !1;
              }
            }
          }
        }
      }
    }
    return !0;
  }, tl = function(S) {
    return S !== "annotation-xml" && Qs(S, Ce);
  }, rl = function(S) {
    r0(X.beforeSanitizeAttributes, S, null);
    const {
      attributes: q
    } = S;
    if (!q || Jn(S))
      return;
    const W = {
      attrName: "",
      attrValue: "",
      keepAttr: !0,
      allowedAttributes: fe,
      forceKeepAttr: void 0
    };
    let ge = q.length;
    for (; ge--; ) {
      const Le = q[ge], {
        name: Re,
        namespaceURI: Ye,
        value: It
      } = Le, cr = ze(Re);
      let Pe = Re === "value" ? It : cd(It);
      if (W.attrName = cr, W.attrValue = Pe, W.keepAttr = !0, W.forceKeepAttr = void 0, r0(X.uponSanitizeAttribute, S, W), Pe = W.attrValue, Ui && (cr === "id" || cr === "name") && (Pr(Re, S), Pe = F1 + Pe), Jt && Ue(/((--!?|])>)|<\/(style|title)/i, Pe)) {
        Pr(Re, S);
        continue;
      }
      if (W.forceKeepAttr || (Pr(Re, S), !W.keepAttr))
        continue;
      if (!Qt && Ue(/\/>/i, Pe)) {
        Pr(Re, S);
        continue;
      }
      Bt && hn([$, Te, se], (al) => {
        Pe = dr(Pe, al, " ");
      });
      const nl = ze(S.nodeName);
      if (el(nl, cr, Pe)) {
        if (F && typeof v == "object" && typeof v.getAttributeType == "function" && !Ye)
          switch (v.getAttributeType(nl, cr)) {
            case "TrustedHTML": {
              Pe = F.createHTML(Pe);
              break;
            }
            case "TrustedScriptURL": {
              Pe = F.createScriptURL(Pe);
              break;
            }
          }
        try {
          Ye ? S.setAttributeNS(Ye, Re, Pe) : S.setAttribute(Re, Pe), Jn(S) ? Rt(S) : Ks(e.removed);
        } catch {
        }
      }
    }
    r0(X.afterSanitizeAttributes, S, null);
  }, R1 = function Z(S) {
    let q = null;
    const W = Qi(S);
    for (r0(X.beforeSanitizeShadowDOM, S, null); q = W.nextNode(); )
      r0(X.uponSanitizeShadowNode, q, null), $i(q), rl(q), q.content instanceof i && Z(q.content);
    r0(X.afterSanitizeShadowDOM, S, null);
  };
  return e.sanitize = function(Z) {
    let S = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, q = null, W = null, ge = null, Le = null;
    if (Zn = !Z, Zn && (Z = "<!-->"), typeof Z != "string" && !Ji(Z))
      if (typeof Z.toString == "function") {
        if (Z = Z.toString(), typeof Z != "string")
          throw pr("dirty is not a string, aborting");
      } else
        throw pr("toString is not a function");
    if (!e.isSupported)
      return Z;
    if (H0 || Qn(S), e.removed = [], typeof Z == "string" && (or = !1), or) {
      if (Z.nodeName) {
        const It = ze(Z.nodeName);
        if (!re[It] || et[It])
          throw pr("root node is forbidden and cannot be sanitized in-place");
      }
    } else if (Z instanceof s)
      q = Ki("<!---->"), W = q.ownerDocument.importNode(Z, !0), W.nodeType === vr.element && W.nodeName === "BODY" || W.nodeName === "HTML" ? q = W : q.appendChild(W);
    else {
      if (!Nt && !Bt && !kt && // eslint-disable-next-line unicorn/prefer-includes
      Z.indexOf("<") === -1)
        return F && e0 ? F.createHTML(Z) : Z;
      if (q = Ki(Z), !q)
        return Nt ? null : e0 ? T : "";
    }
    q && U0 && Rt(q.firstChild);
    const Re = Qi(or ? Z : q);
    for (; ge = Re.nextNode(); )
      $i(ge), rl(ge), ge.content instanceof i && R1(ge.content);
    if (or)
      return Z;
    if (Nt) {
      if ($t)
        for (Le = O.call(q.ownerDocument); q.firstChild; )
          Le.appendChild(q.firstChild);
      else
        Le = q;
      return (fe.shadowroot || fe.shadowrootmode) && (Le = B.call(r, Le, !0)), Le;
    }
    let Ye = kt ? q.outerHTML : q.innerHTML;
    return kt && re["!doctype"] && q.ownerDocument && q.ownerDocument.doctype && q.ownerDocument.doctype.name && Ue(D1, q.ownerDocument.doctype.name) && (Ye = "<!DOCTYPE " + q.ownerDocument.doctype.name + `>
` + Ye), Bt && hn([$, Te, se], (It) => {
      Ye = dr(Ye, It, " ");
    }), F && e0 ? F.createHTML(Ye) : Ye;
  }, e.setConfig = function() {
    let Z = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    Qn(Z), H0 = !0;
  }, e.clearConfig = function() {
    X0 = null, H0 = !1;
  }, e.isValidAttribute = function(Z, S, q) {
    X0 || Qn({});
    const W = ze(Z), ge = ze(S);
    return el(W, ge, q);
  }, e.addHook = function(Z, S) {
    typeof S == "function" && mr(X[Z], S);
  }, e.removeHook = function(Z) {
    return Ks(X[Z]);
  }, e.removeHooks = function(Z) {
    X[Z] = [];
  }, e.removeAllHooks = function() {
    X = no();
  }, e;
}
x1();
const {
  SvelteComponent: Ad,
  append_hydration: _n,
  attr: i0,
  bubble: Sd,
  check_outros: Ed,
  children: li,
  claim_component: Fd,
  claim_element: si,
  claim_space: ao,
  claim_text: Td,
  construct_svelte_component: io,
  create_component: lo,
  create_slot: Cd,
  destroy_component: so,
  detach: xr,
  element: oi,
  get_all_dirty_from_scope: Md,
  get_slot_changes: zd,
  group_outros: Bd,
  init: Nd,
  insert_hydration: A1,
  listen: Rd,
  mount_component: oo,
  safe_not_equal: Id,
  set_data: Ld,
  set_style: mn,
  space: uo,
  text: Od,
  toggle_class: Ke,
  transition_in: Ia,
  transition_out: La,
  update_slot_base: qd
} = window.__gradio__svelte__internal;
function co(n) {
  let e, t;
  return {
    c() {
      e = oi("span"), t = Od(
        /*label*/
        n[1]
      ), this.h();
    },
    l(r) {
      e = si(r, "SPAN", { class: !0 });
      var a = li(e);
      t = Td(
        a,
        /*label*/
        n[1]
      ), a.forEach(xr), this.h();
    },
    h() {
      i0(e, "class", "svelte-vk34kx");
    },
    m(r, a) {
      A1(r, e, a), _n(e, t);
    },
    p(r, a) {
      a & /*label*/
      2 && Ld(
        t,
        /*label*/
        r[1]
      );
    },
    d(r) {
      r && xr(e);
    }
  };
}
function Pd(n) {
  let e, t, r, a, i, l, s, o, c = (
    /*show_label*/
    n[2] && co(n)
  );
  var f = (
    /*Icon*/
    n[0]
  );
  function d(y, k) {
    return {};
  }
  f && (a = io(f, d()));
  const g = (
    /*#slots*/
    n[14].default
  ), v = Cd(
    g,
    n,
    /*$$scope*/
    n[13],
    null
  );
  return {
    c() {
      e = oi("button"), c && c.c(), t = uo(), r = oi("div"), a && lo(a.$$.fragment), i = uo(), v && v.c(), this.h();
    },
    l(y) {
      e = si(y, "BUTTON", {
        "aria-label": !0,
        "aria-haspopup": !0,
        title: !0,
        class: !0
      });
      var k = li(e);
      c && c.l(k), t = ao(k), r = si(k, "DIV", { class: !0 });
      var E = li(r);
      a && Fd(a.$$.fragment, E), i = ao(E), v && v.l(E), E.forEach(xr), k.forEach(xr), this.h();
    },
    h() {
      i0(r, "class", "svelte-vk34kx"), Ke(
        r,
        "small",
        /*size*/
        n[4] === "small"
      ), Ke(
        r,
        "large",
        /*size*/
        n[4] === "large"
      ), Ke(
        r,
        "medium",
        /*size*/
        n[4] === "medium"
      ), e.disabled = /*disabled*/
      n[7], i0(
        e,
        "aria-label",
        /*label*/
        n[1]
      ), i0(
        e,
        "aria-haspopup",
        /*hasPopup*/
        n[8]
      ), i0(
        e,
        "title",
        /*label*/
        n[1]
      ), i0(e, "class", "svelte-vk34kx"), Ke(
        e,
        "pending",
        /*pending*/
        n[3]
      ), Ke(
        e,
        "padded",
        /*padded*/
        n[5]
      ), Ke(
        e,
        "highlight",
        /*highlight*/
        n[6]
      ), Ke(
        e,
        "transparent",
        /*transparent*/
        n[9]
      ), mn(e, "color", !/*disabled*/
      n[7] && /*_color*/
      n[11] ? (
        /*_color*/
        n[11]
      ) : "var(--block-label-text-color)"), mn(e, "--bg-color", /*disabled*/
      n[7] ? "auto" : (
        /*background*/
        n[10]
      ));
    },
    m(y, k) {
      A1(y, e, k), c && c.m(e, null), _n(e, t), _n(e, r), a && oo(a, r, null), _n(r, i), v && v.m(r, null), l = !0, s || (o = Rd(
        e,
        "click",
        /*click_handler*/
        n[15]
      ), s = !0);
    },
    p(y, [k]) {
      if (/*show_label*/
      y[2] ? c ? c.p(y, k) : (c = co(y), c.c(), c.m(e, t)) : c && (c.d(1), c = null), k & /*Icon*/
      1 && f !== (f = /*Icon*/
      y[0])) {
        if (a) {
          Bd();
          const E = a;
          La(E.$$.fragment, 1, 0, () => {
            so(E, 1);
          }), Ed();
        }
        f ? (a = io(f, d()), lo(a.$$.fragment), Ia(a.$$.fragment, 1), oo(a, r, i)) : a = null;
      }
      v && v.p && (!l || k & /*$$scope*/
      8192) && qd(
        v,
        g,
        y,
        /*$$scope*/
        y[13],
        l ? zd(
          g,
          /*$$scope*/
          y[13],
          k,
          null
        ) : Md(
          /*$$scope*/
          y[13]
        ),
        null
      ), (!l || k & /*size*/
      16) && Ke(
        r,
        "small",
        /*size*/
        y[4] === "small"
      ), (!l || k & /*size*/
      16) && Ke(
        r,
        "large",
        /*size*/
        y[4] === "large"
      ), (!l || k & /*size*/
      16) && Ke(
        r,
        "medium",
        /*size*/
        y[4] === "medium"
      ), (!l || k & /*disabled*/
      128) && (e.disabled = /*disabled*/
      y[7]), (!l || k & /*label*/
      2) && i0(
        e,
        "aria-label",
        /*label*/
        y[1]
      ), (!l || k & /*hasPopup*/
      256) && i0(
        e,
        "aria-haspopup",
        /*hasPopup*/
        y[8]
      ), (!l || k & /*label*/
      2) && i0(
        e,
        "title",
        /*label*/
        y[1]
      ), (!l || k & /*pending*/
      8) && Ke(
        e,
        "pending",
        /*pending*/
        y[3]
      ), (!l || k & /*padded*/
      32) && Ke(
        e,
        "padded",
        /*padded*/
        y[5]
      ), (!l || k & /*highlight*/
      64) && Ke(
        e,
        "highlight",
        /*highlight*/
        y[6]
      ), (!l || k & /*transparent*/
      512) && Ke(
        e,
        "transparent",
        /*transparent*/
        y[9]
      ), k & /*disabled, _color*/
      2176 && mn(e, "color", !/*disabled*/
      y[7] && /*_color*/
      y[11] ? (
        /*_color*/
        y[11]
      ) : "var(--block-label-text-color)"), k & /*disabled, background*/
      1152 && mn(e, "--bg-color", /*disabled*/
      y[7] ? "auto" : (
        /*background*/
        y[10]
      ));
    },
    i(y) {
      l || (a && Ia(a.$$.fragment, y), Ia(v, y), l = !0);
    },
    o(y) {
      a && La(a.$$.fragment, y), La(v, y), l = !1;
    },
    d(y) {
      y && xr(e), c && c.d(), a && so(a), v && v.d(y), s = !1, o();
    }
  };
}
function Hd(n, e, t) {
  let r, { $$slots: a = {}, $$scope: i } = e, { Icon: l } = e, { label: s = "" } = e, { show_label: o = !1 } = e, { pending: c = !1 } = e, { size: f = "small" } = e, { padded: d = !0 } = e, { highlight: g = !1 } = e, { disabled: v = !1 } = e, { hasPopup: y = !1 } = e, { color: k = "var(--block-label-text-color)" } = e, { transparent: E = !1 } = e, { background: A = "var(--block-background-fill)" } = e;
  function D(b) {
    Sd.call(this, n, b);
  }
  return n.$$set = (b) => {
    "Icon" in b && t(0, l = b.Icon), "label" in b && t(1, s = b.label), "show_label" in b && t(2, o = b.show_label), "pending" in b && t(3, c = b.pending), "size" in b && t(4, f = b.size), "padded" in b && t(5, d = b.padded), "highlight" in b && t(6, g = b.highlight), "disabled" in b && t(7, v = b.disabled), "hasPopup" in b && t(8, y = b.hasPopup), "color" in b && t(12, k = b.color), "transparent" in b && t(9, E = b.transparent), "background" in b && t(10, A = b.background), "$$scope" in b && t(13, i = b.$$scope);
  }, n.$$.update = () => {
    n.$$.dirty & /*highlight, color*/
    4160 && t(11, r = g ? "var(--color-accent)" : k);
  }, [
    l,
    s,
    o,
    c,
    f,
    d,
    g,
    v,
    y,
    E,
    A,
    r,
    k,
    i,
    a,
    D
  ];
}
class Ud extends Ad {
  constructor(e) {
    super(), Nd(this, e, Hd, Pd, Id, {
      Icon: 0,
      label: 1,
      show_label: 2,
      pending: 3,
      size: 4,
      padded: 5,
      highlight: 6,
      disabled: 7,
      hasPopup: 8,
      color: 12,
      transparent: 9,
      background: 10
    });
  }
}
const {
  SvelteComponent: Gd,
  attr: ho,
  children: Vd,
  claim_element: Wd,
  create_slot: Xd,
  detach: fo,
  element: Yd,
  get_all_dirty_from_scope: jd,
  get_slot_changes: Zd,
  init: Kd,
  insert_hydration: Qd,
  null_to_empty: mo,
  safe_not_equal: Jd,
  transition_in: $d,
  transition_out: e5,
  update_slot_base: t5
} = window.__gradio__svelte__internal;
function r5(n) {
  let e, t, r;
  const a = (
    /*#slots*/
    n[3].default
  ), i = Xd(
    a,
    n,
    /*$$scope*/
    n[2],
    null
  );
  return {
    c() {
      e = Yd("div"), i && i.c(), this.h();
    },
    l(l) {
      e = Wd(l, "DIV", { class: !0 });
      var s = Vd(e);
      i && i.l(s), s.forEach(fo), this.h();
    },
    h() {
      ho(e, "class", t = mo(`icon-button-wrapper ${/*top_panel*/
      n[0] ? "top-panel" : ""} ${/*display_top_corner*/
      n[1] ? "display-top-corner" : "hide-top-corner"}`) + " svelte-1unz4en");
    },
    m(l, s) {
      Qd(l, e, s), i && i.m(e, null), r = !0;
    },
    p(l, [s]) {
      i && i.p && (!r || s & /*$$scope*/
      4) && t5(
        i,
        a,
        l,
        /*$$scope*/
        l[2],
        r ? Zd(
          a,
          /*$$scope*/
          l[2],
          s,
          null
        ) : jd(
          /*$$scope*/
          l[2]
        ),
        null
      ), (!r || s & /*top_panel, display_top_corner*/
      3 && t !== (t = mo(`icon-button-wrapper ${/*top_panel*/
      l[0] ? "top-panel" : ""} ${/*display_top_corner*/
      l[1] ? "display-top-corner" : "hide-top-corner"}`) + " svelte-1unz4en")) && ho(e, "class", t);
    },
    i(l) {
      r || ($d(i, l), r = !0);
    },
    o(l) {
      e5(i, l), r = !1;
    },
    d(l) {
      l && fo(e), i && i.d(l);
    }
  };
}
function n5(n, e, t) {
  let { $$slots: r = {}, $$scope: a } = e, { top_panel: i = !0 } = e, { display_top_corner: l = !1 } = e;
  return n.$$set = (s) => {
    "top_panel" in s && t(0, i = s.top_panel), "display_top_corner" in s && t(1, l = s.display_top_corner), "$$scope" in s && t(2, a = s.$$scope);
  }, [i, l, a, r];
}
class a5 extends Gd {
  constructor(e) {
    super(), Kd(this, e, n5, r5, Jd, { top_panel: 0, display_top_corner: 1 });
  }
}
const {
  SvelteComponent: i5,
  action_destroyer: l5,
  append_hydration: s5,
  attr: C0,
  check_outros: o5,
  children: u5,
  claim_component: Li,
  claim_element: c5,
  claim_space: h5,
  create_component: Oi,
  destroy_component: qi,
  detach: po,
  element: f5,
  group_outros: m5,
  init: d5,
  insert_hydration: p5,
  mount_component: Pi,
  safe_not_equal: g5,
  set_style: go,
  space: v5,
  toggle_class: vo,
  transition_in: J0,
  transition_out: Ar
} = window.__gradio__svelte__internal, { createEventDispatcher: b5 } = window.__gradio__svelte__internal;
function bo(n) {
  let e, t;
  return e = new a5({
    props: {
      $$slots: { default: [y5] },
      $$scope: { ctx: n }
    }
  }), {
    c() {
      Oi(e.$$.fragment);
    },
    l(r) {
      Li(e.$$.fragment, r);
    },
    m(r, a) {
      Pi(e, r, a), t = !0;
    },
    p(r, a) {
      const i = {};
      a & /*$$scope, copied*/
      270336 && (i.$$scope = { dirty: a, ctx: r }), e.$set(i);
    },
    i(r) {
      t || (J0(e.$$.fragment, r), t = !0);
    },
    o(r) {
      Ar(e.$$.fragment, r), t = !1;
    },
    d(r) {
      qi(e, r);
    }
  };
}
function y5(n) {
  let e, t;
  return e = new Ud({
    props: {
      Icon: (
        /*copied*/
        n[13] ? ws : _s
      ),
      label: (
        /*copied*/
        n[13] ? "Copied conversation" : "Copy conversation"
      )
    }
  }), e.$on(
    "click",
    /*handle_copy*/
    n[14]
  ), {
    c() {
      Oi(e.$$.fragment);
    },
    l(r) {
      Li(e.$$.fragment, r);
    },
    m(r, a) {
      Pi(e, r, a), t = !0;
    },
    p(r, a) {
      const i = {};
      a & /*copied*/
      8192 && (i.Icon = /*copied*/
      r[13] ? ws : _s), a & /*copied*/
      8192 && (i.label = /*copied*/
      r[13] ? "Copied conversation" : "Copy conversation"), e.$set(i);
    },
    i(r) {
      t || (J0(e.$$.fragment, r), t = !0);
    },
    o(r) {
      Ar(e.$$.fragment, r), t = !1;
    },
    d(r) {
      qi(e, r);
    }
  };
}
function w5(n) {
  let e, t, r, a, i, l, s, o, c, f = (
    /*show_copy_button*/
    n[10] && bo(n)
  );
  return r = new Ku({
    props: {
      message: (
        /*value*/
        n[2]
      ),
      latex_delimiters: (
        /*latex_delimiters*/
        n[7]
      ),
      sanitize_html: (
        /*sanitize_html*/
        n[5]
      ),
      line_breaks: (
        /*line_breaks*/
        n[6]
      ),
      chatbot: !1,
      header_links: (
        /*header_links*/
        n[8]
      ),
      root: (
        /*root*/
        n[11]
      )
    }
  }), {
    c() {
      e = f5("div"), f && f.c(), t = v5(), Oi(r.$$.fragment), this.h();
    },
    l(d) {
      e = c5(d, "DIV", {
        class: !0,
        "data-testid": !0,
        dir: !0,
        style: !0
      });
      var g = u5(e);
      f && f.l(g), t = h5(g), Li(r.$$.fragment, g), g.forEach(po), this.h();
    },
    h() {
      var d;
      C0(e, "class", a = "prose " + /*elem_classes*/
      n[0].join(" ") + " svelte-10njsez"), C0(e, "data-testid", "markdown"), C0(e, "dir", i = /*rtl*/
      n[4] ? "rtl" : "ltr"), C0(e, "style", l = /*height*/
      n[9] ? `max-height: ${on(
        /*height*/
        n[9]
      )}; overflow-y: auto;` : ""), vo(e, "hide", !/*visible*/
      n[1]), go(
        e,
        "min-height",
        /*min_height*/
        n[3] && /*loading_status*/
        ((d = n[12]) == null ? void 0 : d.status) !== "pending" ? on(
          /*min_height*/
          n[3]
        ) : void 0
      );
    },
    m(d, g) {
      p5(d, e, g), f && f.m(e, null), s5(e, t), Pi(r, e, null), s = !0, o || (c = l5(hm.call(null, e)), o = !0);
    },
    p(d, [g]) {
      var k;
      /*show_copy_button*/
      d[10] ? f ? (f.p(d, g), g & /*show_copy_button*/
      1024 && J0(f, 1)) : (f = bo(d), f.c(), J0(f, 1), f.m(e, t)) : f && (m5(), Ar(f, 1, 1, () => {
        f = null;
      }), o5());
      const v = {};
      g & /*value*/
      4 && (v.message = /*value*/
      d[2]), g & /*latex_delimiters*/
      128 && (v.latex_delimiters = /*latex_delimiters*/
      d[7]), g & /*sanitize_html*/
      32 && (v.sanitize_html = /*sanitize_html*/
      d[5]), g & /*line_breaks*/
      64 && (v.line_breaks = /*line_breaks*/
      d[6]), g & /*header_links*/
      256 && (v.header_links = /*header_links*/
      d[8]), g & /*root*/
      2048 && (v.root = /*root*/
      d[11]), r.$set(v), (!s || g & /*elem_classes*/
      1 && a !== (a = "prose " + /*elem_classes*/
      d[0].join(" ") + " svelte-10njsez")) && C0(e, "class", a), (!s || g & /*rtl*/
      16 && i !== (i = /*rtl*/
      d[4] ? "rtl" : "ltr")) && C0(e, "dir", i), (!s || g & /*height*/
      512 && l !== (l = /*height*/
      d[9] ? `max-height: ${on(
        /*height*/
        d[9]
      )}; overflow-y: auto;` : "")) && C0(e, "style", l), (!s || g & /*elem_classes, visible*/
      3) && vo(e, "hide", !/*visible*/
      d[1]);
      const y = g & /*height*/
      512;
      (g & /*min_height, loading_status, height*/
      4616 || y) && go(
        e,
        "min-height",
        /*min_height*/
        d[3] && /*loading_status*/
        ((k = d[12]) == null ? void 0 : k.status) !== "pending" ? on(
          /*min_height*/
          d[3]
        ) : void 0
      );
    },
    i(d) {
      s || (J0(f), J0(r.$$.fragment, d), s = !0);
    },
    o(d) {
      Ar(f), Ar(r.$$.fragment, d), s = !1;
    },
    d(d) {
      d && po(e), f && f.d(), qi(r), o = !1, c();
    }
  };
}
function k5(n, e, t) {
  let { elem_classes: r = [] } = e, { visible: a = !0 } = e, { value: i } = e, { min_height: l = void 0 } = e, { rtl: s = !1 } = e, { sanitize_html: o = !0 } = e, { line_breaks: c = !1 } = e, { latex_delimiters: f } = e, { header_links: d = !1 } = e, { height: g = void 0 } = e, { show_copy_button: v = !1 } = e, { root: y } = e, { loading_status: k = void 0 } = e, E = !1, A;
  const D = b5();
  async function b() {
    "clipboard" in navigator && (await navigator.clipboard.writeText(i), D("copy", { value: i }), F());
  }
  function F() {
    t(13, E = !0), A && clearTimeout(A), A = setTimeout(
      () => {
        t(13, E = !1);
      },
      1e3
    );
  }
  return n.$$set = (T) => {
    "elem_classes" in T && t(0, r = T.elem_classes), "visible" in T && t(1, a = T.visible), "value" in T && t(2, i = T.value), "min_height" in T && t(3, l = T.min_height), "rtl" in T && t(4, s = T.rtl), "sanitize_html" in T && t(5, o = T.sanitize_html), "line_breaks" in T && t(6, c = T.line_breaks), "latex_delimiters" in T && t(7, f = T.latex_delimiters), "header_links" in T && t(8, d = T.header_links), "height" in T && t(9, g = T.height), "show_copy_button" in T && t(10, v = T.show_copy_button), "root" in T && t(11, y = T.root), "loading_status" in T && t(12, k = T.loading_status);
  }, n.$$.update = () => {
    n.$$.dirty & /*value*/
    4 && D("change");
  }, [
    r,
    a,
    i,
    l,
    s,
    o,
    c,
    f,
    d,
    g,
    v,
    y,
    k,
    E,
    b
  ];
}
class _5 extends i5 {
  constructor(e) {
    super(), d5(this, e, k5, w5, g5, {
      elem_classes: 0,
      visible: 1,
      value: 2,
      min_height: 3,
      rtl: 4,
      sanitize_html: 5,
      line_breaks: 6,
      latex_delimiters: 7,
      header_links: 8,
      height: 9,
      show_copy_button: 10,
      root: 11,
      loading_status: 12
    });
  }
}
const {
  SvelteComponent: D5,
  append_hydration: l0,
  assign: x5,
  attr: Ge,
  check_outros: Fr,
  children: B0,
  claim_component: rr,
  claim_element: b0,
  claim_space: N0,
  claim_text: Wn,
  create_component: nr,
  destroy_component: ar,
  destroy_each: A5,
  detach: Be,
  element: y0,
  empty: yo,
  ensure_array_like: wo,
  get_spread_object: S5,
  get_spread_update: E5,
  group_outros: Tr,
  init: F5,
  insert_hydration: Ct,
  listen: Oa,
  mount_component: ir,
  noop: T5,
  not_equal: S1,
  run_all: C5,
  set_data: E1,
  space: R0,
  text: Xn,
  transition_in: Ee,
  transition_out: Oe
} = window.__gradio__svelte__internal;
function ko(n, e, t) {
  const r = n.slice();
  return r[28] = e[t], r[30] = t, r;
}
function M5(n) {
  let e;
  return {
    c() {
      e = Xn(
        /*label*/
        n[10]
      );
    },
    l(t) {
      e = Wn(
        t,
        /*label*/
        n[10]
      );
    },
    m(t, r) {
      Ct(t, e, r);
    },
    p(t, r) {
      r[0] & /*label*/
      1024 && E1(
        e,
        /*label*/
        t[10]
      );
    },
    d(t) {
      t && Be(e);
    }
  };
}
function _o(n) {
  let e, t = (
    /*buttons*/
    n[6].includes("select_all")
  ), r, a = (
    /*buttons*/
    n[6].includes("deselect_all")
  ), i, l = t && Do(n), s = a && xo(n);
  return {
    c() {
      e = y0("div"), l && l.c(), r = R0(), s && s.c(), this.h();
    },
    l(o) {
      e = b0(o, "DIV", { class: !0 });
      var c = B0(e);
      l && l.l(c), r = N0(c), s && s.l(c), c.forEach(Be), this.h();
    },
    h() {
      Ge(e, "class", "button-container svelte-1ygc3tn");
    },
    m(o, c) {
      Ct(o, e, c), l && l.m(e, null), l0(e, r), s && s.m(e, null), i = !0;
    },
    p(o, c) {
      c[0] & /*buttons*/
      64 && (t = /*buttons*/
      o[6].includes("select_all")), t ? l ? (l.p(o, c), c[0] & /*buttons*/
      64 && Ee(l, 1)) : (l = Do(o), l.c(), Ee(l, 1), l.m(e, r)) : l && (Tr(), Oe(l, 1, 1, () => {
        l = null;
      }), Fr()), c[0] & /*buttons*/
      64 && (a = /*buttons*/
      o[6].includes("deselect_all")), a ? s ? (s.p(o, c), c[0] & /*buttons*/
      64 && Ee(s, 1)) : (s = xo(o), s.c(), Ee(s, 1), s.m(e, null)) : s && (Tr(), Oe(s, 1, 1, () => {
        s = null;
      }), Fr());
    },
    i(o) {
      i || (Ee(l), Ee(s), i = !0);
    },
    o(o) {
      Oe(l), Oe(s), i = !1;
    },
    d(o) {
      o && Be(e), l && l.d(), s && s.d();
    }
  };
}
function Do(n) {
  let e, t;
  return e = new l1({
    props: {
      size: "sm",
      variant: "secondary",
      $$slots: { default: [z5] },
      $$scope: { ctx: n }
    }
  }), e.$on(
    "click",
    /*click_handler*/
    n[23]
  ), {
    c() {
      nr(e.$$.fragment);
    },
    l(r) {
      rr(e.$$.fragment, r);
    },
    m(r, a) {
      ir(e, r, a), t = !0;
    },
    p(r, a) {
      const i = {};
      a[1] & /*$$scope*/
      1 && (i.$$scope = { dirty: a, ctx: r }), e.$set(i);
    },
    i(r) {
      t || (Ee(e.$$.fragment, r), t = !0);
    },
    o(r) {
      Oe(e.$$.fragment, r), t = !1;
    },
    d(r) {
      ar(e, r);
    }
  };
}
function z5(n) {
  let e;
  return {
    c() {
      e = Xn("Select All");
    },
    l(t) {
      e = Wn(t, "Select All");
    },
    m(t, r) {
      Ct(t, e, r);
    },
    d(t) {
      t && Be(e);
    }
  };
}
function xo(n) {
  let e, t;
  return e = new l1({
    props: {
      size: "sm",
      variant: "secondary",
      $$slots: { default: [B5] },
      $$scope: { ctx: n }
    }
  }), e.$on(
    "click",
    /*click_handler_1*/
    n[24]
  ), {
    c() {
      nr(e.$$.fragment);
    },
    l(r) {
      rr(e.$$.fragment, r);
    },
    m(r, a) {
      ir(e, r, a), t = !0;
    },
    p(r, a) {
      const i = {};
      a[1] & /*$$scope*/
      1 && (i.$$scope = { dirty: a, ctx: r }), e.$set(i);
    },
    i(r) {
      t || (Ee(e.$$.fragment, r), t = !0);
    },
    o(r) {
      Oe(e.$$.fragment, r), t = !1;
    },
    d(r) {
      ar(e, r);
    }
  };
}
function B5(n) {
  let e;
  return {
    c() {
      e = Xn("Deselect All");
    },
    l(t) {
      e = Wn(t, "Deselect All");
    },
    m(t, r) {
      Ct(t, e, r);
    },
    d(t) {
      t && Be(e);
    }
  };
}
function Ao(n) {
  let e, t, r, a, i, l, s, o, c = (
    /*choice*/
    n[28].title + ""
  ), f, d, g, v, y, k, E, A, D;
  function b() {
    return (
      /*change_handler*/
      n[25](
        /*choice*/
        n[28]
      )
    );
  }
  function F(...M) {
    return (
      /*input_handler*/
      n[26](
        /*i*/
        n[30],
        /*choice*/
        n[28],
        ...M
      )
    );
  }
  function T(...M) {
    return (
      /*keydown_handler*/
      n[27](
        /*choice*/
        n[28],
        /*i*/
        n[30],
        ...M
      )
    );
  }
  return v = new _5({
    props: {
      value: (
        /*choice*/
        n[28].content
      ),
      elem_classes: (
        /*elem_classes*/
        n[4]
      ),
      visible: (
        /*visible*/
        n[5]
      ),
      rtl: (
        /*rtl*/
        n[15]
      ),
      latex_delimiters: (
        /*latex_delimiters*/
        n[16]
      ),
      root: (
        /*gradio*/
        n[2].root
      ),
      loading_status: (
        /*loading_status*/
        n[14]
      )
    }
  }), {
    c() {
      e = y0("label"), t = y0("div"), r = y0("input"), s = R0(), o = y0("span"), f = Xn(c), d = R0(), g = y0("div"), nr(v.$$.fragment), y = R0(), this.h();
    },
    l(M) {
      e = b0(M, "LABEL", { class: !0 });
      var z = B0(e);
      t = b0(z, "DIV", { class: !0 });
      var O = B0(t);
      r = b0(O, "INPUT", {
        type: !0,
        name: !0,
        title: !0,
        class: !0
      }), s = N0(O), o = b0(O, "SPAN", { class: !0 });
      var R = B0(o);
      f = Wn(R, c), R.forEach(Be), O.forEach(Be), d = N0(z), g = b0(z, "DIV", { class: !0 });
      var B = B0(g);
      rr(v.$$.fragment, B), B.forEach(Be), y = N0(z), z.forEach(Be), this.h();
    },
    h() {
      var M, z;
      r.disabled = /*disabled*/
      n[17], r.checked = a = /*value*/
      n[0].includes(
        /*choice*/
        n[28].id
      ), Ge(r, "type", "checkbox"), Ge(r, "name", i = /*choice*/
      (M = n[28].id) == null ? void 0 : M.toString()), Ge(r, "title", l = /*choice*/
      (z = n[28].title) == null ? void 0 : z.toString()), Ge(r, "class", "svelte-1ygc3tn"), Ge(o, "class", "choice-title svelte-1ygc3tn"), Ge(t, "class", "choice-header svelte-1ygc3tn"), Ge(g, "class", "choice-content svelte-1ygc3tn"), Ge(e, "class", k = "choice-container " + /*disabled*/
      (n[17] ? "disabled" : "") + " " + /*value*/
      (n[0].includes(
        /*choice*/
        n[28].id
      ) ? "selected" : "") + " svelte-1ygc3tn");
    },
    m(M, z) {
      Ct(M, e, z), l0(e, t), l0(t, r), l0(t, s), l0(t, o), l0(o, f), l0(e, d), l0(e, g), ir(v, g, null), l0(e, y), E = !0, A || (D = [
        Oa(r, "change", b),
        Oa(r, "input", F),
        Oa(r, "keydown", T)
      ], A = !0);
    },
    p(M, z) {
      var R, B;
      n = M, (!E || z[0] & /*disabled*/
      131072) && (r.disabled = /*disabled*/
      n[17]), (!E || z[0] & /*value, choices*/
      3 && a !== (a = /*value*/
      n[0].includes(
        /*choice*/
        n[28].id
      ))) && (r.checked = a), (!E || z[0] & /*choices*/
      2 && i !== (i = /*choice*/
      (R = n[28].id) == null ? void 0 : R.toString())) && Ge(r, "name", i), (!E || z[0] & /*choices*/
      2 && l !== (l = /*choice*/
      (B = n[28].title) == null ? void 0 : B.toString())) && Ge(r, "title", l), (!E || z[0] & /*choices*/
      2) && c !== (c = /*choice*/
      n[28].title + "") && E1(f, c);
      const O = {};
      z[0] & /*choices*/
      2 && (O.value = /*choice*/
      n[28].content), z[0] & /*elem_classes*/
      16 && (O.elem_classes = /*elem_classes*/
      n[4]), z[0] & /*visible*/
      32 && (O.visible = /*visible*/
      n[5]), z[0] & /*rtl*/
      32768 && (O.rtl = /*rtl*/
      n[15]), z[0] & /*latex_delimiters*/
      65536 && (O.latex_delimiters = /*latex_delimiters*/
      n[16]), z[0] & /*gradio*/
      4 && (O.root = /*gradio*/
      n[2].root), z[0] & /*loading_status*/
      16384 && (O.loading_status = /*loading_status*/
      n[14]), v.$set(O), (!E || z[0] & /*disabled, value, choices*/
      131075 && k !== (k = "choice-container " + /*disabled*/
      (n[17] ? "disabled" : "") + " " + /*value*/
      (n[0].includes(
        /*choice*/
        n[28].id
      ) ? "selected" : "") + " svelte-1ygc3tn")) && Ge(e, "class", k);
    },
    i(M) {
      E || (Ee(v.$$.fragment, M), E = !0);
    },
    o(M) {
      Oe(v.$$.fragment, M), E = !1;
    },
    d(M) {
      M && Be(e), ar(v), A = !1, C5(D);
    }
  };
}
function So(n) {
  let e, t, r = wo(
    /*choices*/
    n[1]
  ), a = [];
  for (let l = 0; l < r.length; l += 1)
    a[l] = Ao(ko(n, r, l));
  const i = (l) => Oe(a[l], 1, 1, () => {
    a[l] = null;
  });
  return {
    c() {
      for (let l = 0; l < a.length; l += 1)
        a[l].c();
      e = yo();
    },
    l(l) {
      for (let s = 0; s < a.length; s += 1)
        a[s].l(l);
      e = yo();
    },
    m(l, s) {
      for (let o = 0; o < a.length; o += 1)
        a[o] && a[o].m(l, s);
      Ct(l, e, s), t = !0;
    },
    p(l, s) {
      if (s[0] & /*disabled, value, choices, elem_classes, visible, rtl, latex_delimiters, gradio, loading_status, toggle_choice*/
      507959) {
        r = wo(
          /*choices*/
          l[1]
        );
        let o;
        for (o = 0; o < r.length; o += 1) {
          const c = ko(l, r, o);
          a[o] ? (a[o].p(c, s), Ee(a[o], 1)) : (a[o] = Ao(c), a[o].c(), Ee(a[o], 1), a[o].m(e.parentNode, e));
        }
        for (Tr(), o = r.length; o < a.length; o += 1)
          i(o);
        Fr();
      }
    },
    i(l) {
      if (!t) {
        for (let s = 0; s < r.length; s += 1)
          Ee(a[s]);
        t = !0;
      }
    },
    o(l) {
      a = a.filter(Boolean);
      for (let s = 0; s < a.length; s += 1)
        Oe(a[s]);
      t = !1;
    },
    d(l) {
      l && Be(e), A5(a, l);
    }
  };
}
function N5(n) {
  let e, t, r, a, i, l, s, o = (
    /*choices*/
    n[1]
  ), c;
  const f = [
    { autoscroll: (
      /*gradio*/
      n[2].autoscroll
    ) },
    { i18n: (
      /*gradio*/
      n[2].i18n
    ) },
    /*loading_status*/
    n[14]
  ];
  let d = {};
  for (let y = 0; y < f.length; y += 1)
    d = x5(d, f[y]);
  e = new id({ props: d }), e.$on(
    "clear_status",
    /*clear_status_handler*/
    n[22]
  ), r = new F2({
    props: {
      root: (
        /*root*/
        n[13]
      ),
      show_label: (
        /*show_label*/
        n[12]
      ),
      info: (
        /*info*/
        n[11]
      ),
      $$slots: { default: [M5] },
      $$scope: { ctx: n }
    }
  });
  let g = (
    /*buttons*/
    n[6] && /*buttons*/
    n[6].length > 0 && _o(n)
  ), v = So(n);
  return {
    c() {
      nr(e.$$.fragment), t = R0(), nr(r.$$.fragment), a = R0(), i = y0("div"), g && g.c(), l = R0(), s = y0("div"), v.c(), this.h();
    },
    l(y) {
      rr(e.$$.fragment, y), t = N0(y), rr(r.$$.fragment, y), a = N0(y), i = b0(y, "DIV", { class: !0 });
      var k = B0(i);
      g && g.l(k), k.forEach(Be), l = N0(y), s = b0(y, "DIV", { class: !0, "data-testid": !0 });
      var E = B0(s);
      v.l(E), E.forEach(Be), this.h();
    },
    h() {
      Ge(i, "class", "header-container svelte-1ygc3tn"), Ge(s, "class", "wrap svelte-1ygc3tn"), Ge(s, "data-testid", "checkbox-group");
    },
    m(y, k) {
      ir(e, y, k), Ct(y, t, k), ir(r, y, k), Ct(y, a, k), Ct(y, i, k), g && g.m(i, null), Ct(y, l, k), Ct(y, s, k), v.m(s, null), c = !0;
    },
    p(y, k) {
      const E = k[0] & /*gradio, loading_status*/
      16388 ? E5(f, [
        k[0] & /*gradio*/
        4 && { autoscroll: (
          /*gradio*/
          y[2].autoscroll
        ) },
        k[0] & /*gradio*/
        4 && { i18n: (
          /*gradio*/
          y[2].i18n
        ) },
        k[0] & /*loading_status*/
        16384 && S5(
          /*loading_status*/
          y[14]
        )
      ]) : {};
      e.$set(E);
      const A = {};
      k[0] & /*root*/
      8192 && (A.root = /*root*/
      y[13]), k[0] & /*show_label*/
      4096 && (A.show_label = /*show_label*/
      y[12]), k[0] & /*info*/
      2048 && (A.info = /*info*/
      y[11]), k[0] & /*label*/
      1024 | k[1] & /*$$scope*/
      1 && (A.$$scope = { dirty: k, ctx: y }), r.$set(A), /*buttons*/
      y[6] && /*buttons*/
      y[6].length > 0 ? g ? (g.p(y, k), k[0] & /*buttons*/
      64 && Ee(g, 1)) : (g = _o(y), g.c(), Ee(g, 1), g.m(i, null)) : g && (Tr(), Oe(g, 1, 1, () => {
        g = null;
      }), Fr()), k[0] & /*choices*/
      2 && S1(o, o = /*choices*/
      y[1]) ? (Tr(), Oe(v, 1, 1, T5), Fr(), v = So(y), v.c(), Ee(v, 1), v.m(s, null)) : v.p(y, k);
    },
    i(y) {
      c || (Ee(e.$$.fragment, y), Ee(r.$$.fragment, y), Ee(g), Ee(v), c = !0);
    },
    o(y) {
      Oe(e.$$.fragment, y), Oe(r.$$.fragment, y), Oe(g), Oe(v), c = !1;
    },
    d(y) {
      y && (Be(t), Be(a), Be(i), Be(l), Be(s)), ar(e, y), ar(r, y), g && g.d(), v.d(y);
    }
  };
}
function R5(n) {
  let e, t;
  return e = new ec({
    props: {
      visible: (
        /*visible*/
        n[5]
      ),
      elem_id: (
        /*elem_id*/
        n[3]
      ),
      elem_classes: (
        /*elem_classes*/
        n[4]
      ),
      type: "fieldset",
      container: (
        /*container*/
        n[7]
      ),
      scale: (
        /*scale*/
        n[8]
      ),
      min_width: (
        /*min_width*/
        n[9]
      ),
      $$slots: { default: [N5] },
      $$scope: { ctx: n }
    }
  }), {
    c() {
      nr(e.$$.fragment);
    },
    l(r) {
      rr(e.$$.fragment, r);
    },
    m(r, a) {
      ir(e, r, a), t = !0;
    },
    p(r, a) {
      const i = {};
      a[0] & /*visible*/
      32 && (i.visible = /*visible*/
      r[5]), a[0] & /*elem_id*/
      8 && (i.elem_id = /*elem_id*/
      r[3]), a[0] & /*elem_classes*/
      16 && (i.elem_classes = /*elem_classes*/
      r[4]), a[0] & /*container*/
      128 && (i.container = /*container*/
      r[7]), a[0] & /*scale*/
      256 && (i.scale = /*scale*/
      r[8]), a[0] & /*min_width*/
      512 && (i.min_width = /*min_width*/
      r[9]), a[0] & /*choices, disabled, value, elem_classes, visible, rtl, latex_delimiters, gradio, loading_status, buttons, root, show_label, info, label*/
      261239 | a[1] & /*$$scope*/
      1 && (i.$$scope = { dirty: a, ctx: r }), e.$set(i);
    },
    i(r) {
      t || (Ee(e.$$.fragment, r), t = !0);
    },
    o(r) {
      Oe(e.$$.fragment, r), t = !1;
    },
    d(r) {
      ar(e, r);
    }
  };
}
function I5(n, e, t) {
  let r, { gradio: a } = e, { elem_id: i = "" } = e, { elem_classes: l = [] } = e, { visible: s = !0 } = e, { value: o = [] } = e, { choices: c = [] } = e, { buttons: f = [] } = e, { container: d = !0 } = e, { scale: g = null } = e, { min_width: v = void 0 } = e, { label: y = a.i18n("checkbox.checkbox_group") } = e, { info: k = void 0 } = e, { show_label: E = !0 } = e, { root: A } = e, { loading_status: D } = e, { interactive: b = !0 } = e, { old_value: F = o.slice() } = e, { rtl: T = !1 } = e, { latex_delimiters: M } = e;
  function z(U) {
    o.includes(U) ? t(0, o = o.filter((le) => le !== U)) : t(0, o = [...o, U]), t(1, c = c.map((le) => ({ ...le, selected: o.includes(le.id) }))), a.dispatch("input");
  }
  function O(U) {
    const le = U ? c.map((Se) => Se.id) : [];
    t(0, o = le), a.dispatch("change");
  }
  const R = () => a.dispatch("clear_status", D), B = () => O(!0), X = () => O(!1), $ = (U) => z(U.id), Te = (U, le, Se) => a.dispatch("select", {
    index: U,
    value: le.id,
    selected: Se.currentTarget.checked
  }), se = (U, le, Se) => {
    Se.key === "Enter" && (z(U.id), a.dispatch("select", {
      index: le,
      value: U.id,
      selected: !o.includes(U.id)
    }));
  };
  return n.$$set = (U) => {
    "gradio" in U && t(2, a = U.gradio), "elem_id" in U && t(3, i = U.elem_id), "elem_classes" in U && t(4, l = U.elem_classes), "visible" in U && t(5, s = U.visible), "value" in U && t(0, o = U.value), "choices" in U && t(1, c = U.choices), "buttons" in U && t(6, f = U.buttons), "container" in U && t(7, d = U.container), "scale" in U && t(8, g = U.scale), "min_width" in U && t(9, v = U.min_width), "label" in U && t(10, y = U.label), "info" in U && t(11, k = U.info), "show_label" in U && t(12, E = U.show_label), "root" in U && t(13, A = U.root), "loading_status" in U && t(14, D = U.loading_status), "interactive" in U && t(21, b = U.interactive), "old_value" in U && t(20, F = U.old_value), "rtl" in U && t(15, T = U.rtl), "latex_delimiters" in U && t(16, M = U.latex_delimiters);
  }, n.$$.update = () => {
    n.$$.dirty[0] & /*interactive*/
    2097152 && t(17, r = !b), n.$$.dirty[0] & /*old_value, value, gradio*/
    1048581 && JSON.stringify(F) !== JSON.stringify(o) && (t(20, F = o), a.dispatch("change"));
  }, [
    o,
    c,
    a,
    i,
    l,
    s,
    f,
    d,
    g,
    v,
    y,
    k,
    E,
    A,
    D,
    T,
    M,
    r,
    z,
    O,
    F,
    b,
    R,
    B,
    X,
    $,
    Te,
    se
  ];
}
class P5 extends D5 {
  constructor(e) {
    super(), F5(
      this,
      e,
      I5,
      R5,
      S1,
      {
        gradio: 2,
        elem_id: 3,
        elem_classes: 4,
        visible: 5,
        value: 0,
        choices: 1,
        buttons: 6,
        container: 7,
        scale: 8,
        min_width: 9,
        label: 10,
        info: 11,
        show_label: 12,
        root: 13,
        loading_status: 14,
        interactive: 21,
        old_value: 20,
        rtl: 15,
        latex_delimiters: 16
      },
      null,
      [-1, -1]
    );
  }
}
export {
  P5 as default
};
